from __future__ import annotations
from typing import Optional, TYPE_CHECKING

from spark_auto_mapper_fhir.fhir_types.boolean import FhirBoolean
from spark_auto_mapper_fhir.fhir_types.list import FhirList
from spark_auto_mapper_fhir.fhir_types.string import FhirString
from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase

from spark_auto_mapper_fhir.base_types.fhir_backbone_element_base import (
    FhirBackboneElementBase,
)

if TYPE_CHECKING:
    pass
    # id_ (string)
    # extension (Extension)
    # modifierExtension (Extension)
    # sequence (positiveInt)
    from spark_auto_mapper_fhir.fhir_types.positive_int import FhirPositiveInt

    # focal (boolean)
    # identifier (Identifier)
    from spark_auto_mapper_fhir.complex_types.identifier import Identifier

    # coverage (Reference)
    from spark_auto_mapper_fhir.complex_types.reference import Reference

    # Imports for References for coverage
    from spark_auto_mapper_fhir.resources.coverage import Coverage

    # businessArrangement (string)
    # preAuthRef (string)
    # claimResponse (Reference)
    # Imports for References for claimResponse
    from spark_auto_mapper_fhir.resources.claim_response import ClaimResponse


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class ClaimInsurance(FhirBackboneElementBase):
    """
    Claim.Insurance
        A provider issued list of professional services and products which have been provided, or are to be provided, to a patient which is sent to an insurer for reimbursement.
    """

    # noinspection PyPep8Naming
    def __init__(
        self,
        *,
        id_: Optional[FhirString] = None,
        extension: Optional[FhirList[ExtensionBase]] = None,
        modifierExtension: Optional[FhirList[ExtensionBase]] = None,
        sequence: FhirPositiveInt,
        focal: FhirBoolean,
        identifier: Optional[Identifier] = None,
        coverage: Reference[Coverage],
        businessArrangement: Optional[FhirString] = None,
        preAuthRef: Optional[FhirList[FhirString]] = None,
        claimResponse: Optional[Reference[ClaimResponse]] = None,
    ) -> None:
        """
            A provider issued list of professional services and products which have been
        provided, or are to be provided, to a patient which is sent to an insurer for
        reimbursement.

            :param id_: None
            :param extension: May be used to represent additional information that is not part of the basic
        definition of the element. To make the use of extensions safe and manageable,
        there is a strict set of governance  applied to the definition and use of
        extensions. Though any implementer can define an extension, there is a set of
        requirements that SHALL be met as part of the definition of the extension.
            :param modifierExtension: May be used to represent additional information that is not part of the basic
        definition of the element and that modifies the understanding of the element
        in which it is contained and/or the understanding of the containing element's
        descendants. Usually modifier elements provide negation or qualification. To
        make the use of extensions safe and manageable, there is a strict set of
        governance applied to the definition and use of extensions. Though any
        implementer can define an extension, there is a set of requirements that SHALL
        be met as part of the definition of the extension. Applications processing a
        resource are required to check for modifier extensions.

        Modifier extensions SHALL NOT change the meaning of any elements on Resource
        or DomainResource (including cannot change the meaning of modifierExtension
        itself).
            :param sequence: A number to uniquely identify insurance entries and provide a sequence of
        coverages to convey coordination of benefit order.
            :param focal: A flag to indicate that this Coverage is to be used for adjudication of this
        claim when set to true.
            :param identifier: The business identifier to be used when the claim is sent for adjudication
        against this insurance policy.
            :param coverage: Reference to the insurance card level information contained in the Coverage
        resource. The coverage issuing insurer will use these details to locate the
        patient's actual coverage within the insurer's information system.
            :param businessArrangement: A business agreement number established between the provider and the insurer
        for special business processing purposes.
            :param preAuthRef: Reference numbers previously provided by the insurer to the provider to be
        quoted on subsequent claims containing services or products related to the
        prior authorization.
            :param claimResponse: The result of the adjudication of the line items for the Coverage specified in
        this insurance.
        """
        super().__init__(
            id_=id_,
            extension=extension,
            modifierExtension=modifierExtension,
            sequence=sequence,
            focal=focal,
            identifier=identifier,
            coverage=coverage,
            businessArrangement=businessArrangement,
            preAuthRef=preAuthRef,
            claimResponse=claimResponse,
        )
