from __future__ import annotations
from typing import Optional, TYPE_CHECKING

from spark_auto_mapper_fhir.fhir_types.date_time import FhirDateTime
from spark_auto_mapper_fhir.fhir_types.list import FhirList
from spark_auto_mapper_fhir.fhir_types.string import FhirString
from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase

from spark_auto_mapper_fhir.base_types.fhir_backbone_element_base import (
    FhirBackboneElementBase,
)

if TYPE_CHECKING:
    pass
    # id_ (string)
    # extension (Extension)
    # modifierExtension (Extension)
    # sequence (positiveInt)
    from spark_auto_mapper_fhir.fhir_types.positive_int import FhirPositiveInt

    # type_ (CodeableConcept)
    from spark_auto_mapper_fhir.complex_types.codeable_concept import CodeableConcept

    # End Import for References for type_
    # Import for CodeableConcept for type_
    from spark_auto_mapper_fhir.value_sets.example_procedure_type_codes import (
        ExampleProcedureTypeCodesCode,
    )

    # End Import for CodeableConcept for type_
    # date (dateTime)
    # procedureCodeableConcept (CodeableConcept)
    # End Import for References for procedureCodeableConcept
    # Import for CodeableConcept for procedureCodeableConcept
    from spark_auto_mapper_fhir.value_sets.icd_10_procedure_codes import (
        ICD_10ProcedureCodesCode,
    )

    # End Import for CodeableConcept for procedureCodeableConcept
    # procedureReference (Reference)
    from spark_auto_mapper_fhir.complex_types.reference import Reference

    # Imports for References for procedureReference
    from spark_auto_mapper_fhir.resources.procedure import Procedure

    # udi (Reference)
    # Imports for References for udi
    from spark_auto_mapper_fhir.resources.device import Device


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class ClaimProcedure(FhirBackboneElementBase):
    """
    Claim.Procedure
        A provider issued list of professional services and products which have been provided, or are to be provided, to a patient which is sent to an insurer for reimbursement.
    """

    # noinspection PyPep8Naming
    def __init__(
        self,
        *,
        id_: Optional[FhirString] = None,
        extension: Optional[FhirList[ExtensionBase]] = None,
        modifierExtension: Optional[FhirList[ExtensionBase]] = None,
        sequence: FhirPositiveInt,
        type_: Optional[
            FhirList[CodeableConcept[ExampleProcedureTypeCodesCode]]
        ] = None,
        date: Optional[FhirDateTime] = None,
        procedureCodeableConcept: Optional[
            CodeableConcept[ICD_10ProcedureCodesCode]
        ] = None,
        procedureReference: Optional[Reference[Procedure]] = None,
        udi: Optional[FhirList[Reference[Device]]] = None,
    ) -> None:
        """
            A provider issued list of professional services and products which have been
        provided, or are to be provided, to a patient which is sent to an insurer for
        reimbursement.

            :param id_: None
            :param extension: May be used to represent additional information that is not part of the basic
        definition of the element. To make the use of extensions safe and manageable,
        there is a strict set of governance  applied to the definition and use of
        extensions. Though any implementer can define an extension, there is a set of
        requirements that SHALL be met as part of the definition of the extension.
            :param modifierExtension: May be used to represent additional information that is not part of the basic
        definition of the element and that modifies the understanding of the element
        in which it is contained and/or the understanding of the containing element's
        descendants. Usually modifier elements provide negation or qualification. To
        make the use of extensions safe and manageable, there is a strict set of
        governance applied to the definition and use of extensions. Though any
        implementer can define an extension, there is a set of requirements that SHALL
        be met as part of the definition of the extension. Applications processing a
        resource are required to check for modifier extensions.

        Modifier extensions SHALL NOT change the meaning of any elements on Resource
        or DomainResource (including cannot change the meaning of modifierExtension
        itself).
            :param sequence: A number to uniquely identify procedure entries.
            :param type_: When the condition was observed or the relative ranking.
            :param date: Date and optionally time the procedure was performed.
            :param procedureCodeableConcept: None
            :param procedureReference: None
            :param udi: Unique Device Identifiers associated with this line item.
        """
        super().__init__(
            id_=id_,
            extension=extension,
            modifierExtension=modifierExtension,
            sequence=sequence,
            type_=type_,
            date=date,
            procedureCodeableConcept=procedureCodeableConcept,
            procedureReference=procedureReference,
            udi=udi,
        )
