from __future__ import annotations
from typing import Optional, TYPE_CHECKING

from spark_auto_mapper_fhir.fhir_types.list import FhirList
from spark_auto_mapper_fhir.fhir_types.string import FhirString
from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase

from spark_auto_mapper_fhir.base_types.fhir_backbone_element_base import (
    FhirBackboneElementBase,
)

if TYPE_CHECKING:
    pass
    # id_ (string)
    # extension (Extension)
    # modifierExtension (Extension)
    # claim (Reference)
    from spark_auto_mapper_fhir.complex_types.reference import Reference

    # Imports for References for claim
    from spark_auto_mapper_fhir.resources.claim import Claim

    # relationship (CodeableConcept)
    from spark_auto_mapper_fhir.complex_types.codeable_concept import CodeableConcept

    # End Import for References for relationship
    # Import for CodeableConcept for relationship
    from spark_auto_mapper_fhir.value_sets.example_related_claim_relationship_codes import (
        ExampleRelatedClaimRelationshipCodesCode,
    )

    # End Import for CodeableConcept for relationship
    # reference (Identifier)
    from spark_auto_mapper_fhir.complex_types.identifier import Identifier


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class ClaimRelated(FhirBackboneElementBase):
    """
    Claim.Related
        A provider issued list of professional services and products which have been provided, or are to be provided, to a patient which is sent to an insurer for reimbursement.
    """

    # noinspection PyPep8Naming
    def __init__(
        self,
        *,
        id_: Optional[FhirString] = None,
        extension: Optional[FhirList[ExtensionBase]] = None,
        modifierExtension: Optional[FhirList[ExtensionBase]] = None,
        claim: Optional[Reference[Claim]] = None,
        relationship: Optional[
            CodeableConcept[ExampleRelatedClaimRelationshipCodesCode]
        ] = None,
        reference: Optional[Identifier] = None,
    ) -> None:
        """
            A provider issued list of professional services and products which have been
        provided, or are to be provided, to a patient which is sent to an insurer for
        reimbursement.

            :param id_: None
            :param extension: May be used to represent additional information that is not part of the basic
        definition of the element. To make the use of extensions safe and manageable,
        there is a strict set of governance  applied to the definition and use of
        extensions. Though any implementer can define an extension, there is a set of
        requirements that SHALL be met as part of the definition of the extension.
            :param modifierExtension: May be used to represent additional information that is not part of the basic
        definition of the element and that modifies the understanding of the element
        in which it is contained and/or the understanding of the containing element's
        descendants. Usually modifier elements provide negation or qualification. To
        make the use of extensions safe and manageable, there is a strict set of
        governance applied to the definition and use of extensions. Though any
        implementer can define an extension, there is a set of requirements that SHALL
        be met as part of the definition of the extension. Applications processing a
        resource are required to check for modifier extensions.

        Modifier extensions SHALL NOT change the meaning of any elements on Resource
        or DomainResource (including cannot change the meaning of modifierExtension
        itself).
            :param claim: Reference to a related claim.
            :param relationship: A code to convey how the claims are related.
            :param reference: An alternate organizational reference to the case or file to which this
        particular claim pertains.
        """
        super().__init__(
            id_=id_,
            extension=extension,
            modifierExtension=modifierExtension,
            claim=claim,
            relationship=relationship,
            reference=reference,
        )
