from __future__ import annotations
from typing import Optional, TYPE_CHECKING

from spark_auto_mapper_fhir.fhir_types.list import FhirList
from spark_auto_mapper_fhir.fhir_types.string import FhirString
from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase

from spark_auto_mapper_fhir.base_types.fhir_backbone_element_base import (
    FhirBackboneElementBase,
)

if TYPE_CHECKING:
    pass
    # id_ (string)
    # extension (Extension)
    # modifierExtension (Extension)
    # number (unsignedInt)
    from spark_auto_mapper_fhir.fhir_types.unsigned_int import FhirUnsignedInt

    # classification (Coding)
    from spark_auto_mapper_fhir.complex_types.coding import Coding

    # End Import for References for classification
    # Import for CodeableConcept for classification
    from spark_auto_mapper_fhir.value_sets.contract_resource_scope_codes import (
        ContractResourceScopeCodesCode,
    )

    # End Import for CodeableConcept for classification
    # category (Coding)
    # End Import for References for category
    # Import for CodeableConcept for category
    # End Import for CodeableConcept for category
    # control (Coding)
    # End Import for References for control
    # Import for CodeableConcept for control
    from spark_auto_mapper_fhir.value_sets.contract_resource_security_control_codes import (
        ContractResourceSecurityControlCodesCode,
    )

    # End Import for CodeableConcept for control


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class ContractSecurityLabel(FhirBackboneElementBase):
    """
    Contract.SecurityLabel
        Legally enforceable, formally recorded unilateral or bilateral directive i.e., a policy or agreement.
    """

    # noinspection PyPep8Naming
    def __init__(
        self,
        *,
        id_: Optional[FhirString] = None,
        extension: Optional[FhirList[ExtensionBase]] = None,
        modifierExtension: Optional[FhirList[ExtensionBase]] = None,
        number: Optional[FhirList[FhirUnsignedInt]] = None,
        classification: Coding[ContractResourceScopeCodesCode],
        category: Optional[FhirList[Coding[ContractResourceScopeCodesCode]]] = None,
        control: Optional[
            FhirList[Coding[ContractResourceSecurityControlCodesCode]]
        ] = None,
    ) -> None:
        """
            Legally enforceable, formally recorded unilateral or bilateral directive i.e.,
        a policy or agreement.

            :param id_: None
            :param extension: May be used to represent additional information that is not part of the basic
        definition of the element. To make the use of extensions safe and manageable,
        there is a strict set of governance  applied to the definition and use of
        extensions. Though any implementer can define an extension, there is a set of
        requirements that SHALL be met as part of the definition of the extension.
            :param modifierExtension: May be used to represent additional information that is not part of the basic
        definition of the element and that modifies the understanding of the element
        in which it is contained and/or the understanding of the containing element's
        descendants. Usually modifier elements provide negation or qualification. To
        make the use of extensions safe and manageable, there is a strict set of
        governance applied to the definition and use of extensions. Though any
        implementer can define an extension, there is a set of requirements that SHALL
        be met as part of the definition of the extension. Applications processing a
        resource are required to check for modifier extensions.

        Modifier extensions SHALL NOT change the meaning of any elements on Resource
        or DomainResource (including cannot change the meaning of modifierExtension
        itself).
            :param number: Number used to link this term or term element to the applicable Security
        Label.
            :param classification: Security label privacy tag that species the level of confidentiality
        protection required for this term and/or term elements.
            :param category: Security label privacy tag that species the applicable privacy and security
        policies governing this term and/or term elements.
            :param control: Security label privacy tag that species the manner in which term and/or term
        elements are to be protected.
        """
        super().__init__(
            id_=id_,
            extension=extension,
            modifierExtension=modifierExtension,
            number=number,
            classification=classification,
            category=category,
            control=control,
        )
