from __future__ import annotations
from typing import Optional, TYPE_CHECKING

from spark_auto_mapper_fhir.fhir_types.boolean import FhirBoolean
from spark_auto_mapper_fhir.fhir_types.list import FhirList
from spark_auto_mapper_fhir.fhir_types.string import FhirString
from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase

from spark_auto_mapper_fhir.base_types.fhir_backbone_element_base import (
    FhirBackboneElementBase,
)

if TYPE_CHECKING:
    pass
    # id_ (string)
    # extension (Extension)
    # modifierExtension (Extension)
    # number (string)
    # type_ (string)
    # name (string)
    # initiator (string)
    # receiver (string)
    # description (markdown)
    from spark_auto_mapper_fhir.fhir_types.markdown import FhirMarkdown

    # initiatorActive (boolean)
    # receiverActive (boolean)
    # request (ExampleScenario.ContainedInstance)
    from spark_auto_mapper_fhir.backbone_elements.example_scenario_contained_instance import (
        ExampleScenarioContainedInstance,
    )

    # response (ExampleScenario.ContainedInstance)


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class ExampleScenarioOperation(FhirBackboneElementBase):
    """
    ExampleScenario.Operation
        Example of workflow instance.
    """

    # noinspection PyPep8Naming
    def __init__(
        self,
        *,
        id_: Optional[FhirString] = None,
        extension: Optional[FhirList[ExtensionBase]] = None,
        modifierExtension: Optional[FhirList[ExtensionBase]] = None,
        number: FhirString,
        type_: Optional[FhirString] = None,
        name: Optional[FhirString] = None,
        initiator: Optional[FhirString] = None,
        receiver: Optional[FhirString] = None,
        description: Optional[FhirMarkdown] = None,
        initiatorActive: Optional[FhirBoolean] = None,
        receiverActive: Optional[FhirBoolean] = None,
        request: Optional[ExampleScenarioContainedInstance] = None,
        response: Optional[ExampleScenarioContainedInstance] = None,
    ) -> None:
        """
            Example of workflow instance.

            :param id_: None
            :param extension: May be used to represent additional information that is not part of the basic
        definition of the element. To make the use of extensions safe and manageable,
        there is a strict set of governance  applied to the definition and use of
        extensions. Though any implementer can define an extension, there is a set of
        requirements that SHALL be met as part of the definition of the extension.
            :param modifierExtension: May be used to represent additional information that is not part of the basic
        definition of the element and that modifies the understanding of the element
        in which it is contained and/or the understanding of the containing element's
        descendants. Usually modifier elements provide negation or qualification. To
        make the use of extensions safe and manageable, there is a strict set of
        governance applied to the definition and use of extensions. Though any
        implementer can define an extension, there is a set of requirements that SHALL
        be met as part of the definition of the extension. Applications processing a
        resource are required to check for modifier extensions.

        Modifier extensions SHALL NOT change the meaning of any elements on Resource
        or DomainResource (including cannot change the meaning of modifierExtension
        itself).
            :param number: The sequential number of the interaction, e.g. 1.2.5.
            :param type_: The type of operation - CRUD.
            :param name: The human-friendly name of the interaction.
            :param initiator: Who starts the transaction.
            :param receiver: Who receives the transaction.
            :param description: A comment to be inserted in the diagram.
            :param initiatorActive: Whether the initiator is deactivated right after the transaction.
            :param receiverActive: Whether the receiver is deactivated right after the transaction.
            :param request: Each resource instance used by the initiator.
            :param response: Each resource instance used by the responder.
        """
        super().__init__(
            id_=id_,
            extension=extension,
            modifierExtension=modifierExtension,
            number=number,
            type_=type_,
            name=name,
            initiator=initiator,
            receiver=receiver,
            description=description,
            initiatorActive=initiatorActive,
            receiverActive=receiverActive,
            request=request,
            response=response,
        )
