from __future__ import annotations
from typing import Optional, TYPE_CHECKING

from spark_auto_mapper_fhir.fhir_types.list import FhirList
from spark_auto_mapper_fhir.fhir_types.string import FhirString
from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase

from spark_auto_mapper_fhir.base_types.fhir_backbone_element_base import (
    FhirBackboneElementBase,
)

if TYPE_CHECKING:
    pass
    # id_ (string)
    # extension (Extension)
    # modifierExtension (Extension)
    # title (string)
    # description (markdown)
    from spark_auto_mapper_fhir.fhir_types.markdown import FhirMarkdown

    # preConditions (markdown)
    # postConditions (markdown)
    # step (ExampleScenario.Step)
    from spark_auto_mapper_fhir.backbone_elements.example_scenario_step import (
        ExampleScenarioStep,
    )


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class ExampleScenarioProcess(FhirBackboneElementBase):
    """
    ExampleScenario.Process
        Example of workflow instance.
    """

    # noinspection PyPep8Naming
    def __init__(
        self,
        *,
        id_: Optional[FhirString] = None,
        extension: Optional[FhirList[ExtensionBase]] = None,
        modifierExtension: Optional[FhirList[ExtensionBase]] = None,
        title: FhirString,
        description: Optional[FhirMarkdown] = None,
        preConditions: Optional[FhirMarkdown] = None,
        postConditions: Optional[FhirMarkdown] = None,
        step: Optional[FhirList[ExampleScenarioStep]] = None,
    ) -> None:
        """
            Example of workflow instance.

            :param id_: None
            :param extension: May be used to represent additional information that is not part of the basic
        definition of the element. To make the use of extensions safe and manageable,
        there is a strict set of governance  applied to the definition and use of
        extensions. Though any implementer can define an extension, there is a set of
        requirements that SHALL be met as part of the definition of the extension.
            :param modifierExtension: May be used to represent additional information that is not part of the basic
        definition of the element and that modifies the understanding of the element
        in which it is contained and/or the understanding of the containing element's
        descendants. Usually modifier elements provide negation or qualification. To
        make the use of extensions safe and manageable, there is a strict set of
        governance applied to the definition and use of extensions. Though any
        implementer can define an extension, there is a set of requirements that SHALL
        be met as part of the definition of the extension. Applications processing a
        resource are required to check for modifier extensions.

        Modifier extensions SHALL NOT change the meaning of any elements on Resource
        or DomainResource (including cannot change the meaning of modifierExtension
        itself).
            :param title: The diagram title of the group of operations.
            :param description: A longer description of the group of operations.
            :param preConditions: Description of initial status before the process starts.
            :param postConditions: Description of final status after the process ends.
            :param step: Each step of the process.
        """
        super().__init__(
            id_=id_,
            extension=extension,
            modifierExtension=modifierExtension,
            title=title,
            description=description,
            preConditions=preConditions,
            postConditions=postConditions,
            step=step,
        )
