from __future__ import annotations
from typing import Optional, TYPE_CHECKING

from spark_auto_mapper_fhir.fhir_types.list import FhirList
from spark_auto_mapper_fhir.fhir_types.integer import FhirInteger
from spark_auto_mapper_fhir.fhir_types.string import FhirString
from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase

from spark_auto_mapper_fhir.base_types.fhir_backbone_element_base import (
    FhirBackboneElementBase,
)

if TYPE_CHECKING:
    pass
    # id_ (string)
    # extension (Extension)
    # modifierExtension (Extension)
    # path (string)
    # sliceName (string)
    # min (integer)
    # max (string)
    # description (string)
    # target (GraphDefinition.Target)
    from spark_auto_mapper_fhir.backbone_elements.graph_definition_target import (
        GraphDefinitionTarget,
    )


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class GraphDefinitionLink(FhirBackboneElementBase):
    """
    GraphDefinition.Link
        A formal computable definition of a graph of resources - that is, a coherent set of resources that form a graph by following references. The Graph Definition resource defines a set and makes rules about the set.
    """

    # noinspection PyPep8Naming
    def __init__(
        self,
        *,
        id_: Optional[FhirString] = None,
        extension: Optional[FhirList[ExtensionBase]] = None,
        modifierExtension: Optional[FhirList[ExtensionBase]] = None,
        path: Optional[FhirString] = None,
        sliceName: Optional[FhirString] = None,
        min: Optional[FhirInteger] = None,
        max: Optional[FhirString] = None,
        description: Optional[FhirString] = None,
        target: Optional[FhirList[GraphDefinitionTarget]] = None,
    ) -> None:
        """
            A formal computable definition of a graph of resources - that is, a coherent
        set of resources that form a graph by following references. The Graph
        Definition resource defines a set and makes rules about the set.

            :param id_: None
            :param extension: May be used to represent additional information that is not part of the basic
        definition of the element. To make the use of extensions safe and manageable,
        there is a strict set of governance  applied to the definition and use of
        extensions. Though any implementer can define an extension, there is a set of
        requirements that SHALL be met as part of the definition of the extension.
            :param modifierExtension: May be used to represent additional information that is not part of the basic
        definition of the element and that modifies the understanding of the element
        in which it is contained and/or the understanding of the containing element's
        descendants. Usually modifier elements provide negation or qualification. To
        make the use of extensions safe and manageable, there is a strict set of
        governance applied to the definition and use of extensions. Though any
        implementer can define an extension, there is a set of requirements that SHALL
        be met as part of the definition of the extension. Applications processing a
        resource are required to check for modifier extensions.

        Modifier extensions SHALL NOT change the meaning of any elements on Resource
        or DomainResource (including cannot change the meaning of modifierExtension
        itself).
            :param path: A FHIR expression that identifies one of FHIR References to other resources.
            :param sliceName: Which slice (if profiled).
            :param min: Minimum occurrences for this link.
            :param max: Maximum occurrences for this link.
            :param description: Information about why this link is of interest in this graph definition.
            :param target: Potential target for the link.
        """
        super().__init__(
            id_=id_,
            extension=extension,
            modifierExtension=modifierExtension,
            path=path,
            sliceName=sliceName,
            min=min,
            max=max,
            description=description,
            target=target,
        )
