from __future__ import annotations
from typing import Optional, TYPE_CHECKING

from spark_auto_mapper_fhir.fhir_types.boolean import FhirBoolean
from spark_auto_mapper_fhir.fhir_types.list import FhirList
from spark_auto_mapper_fhir.fhir_types.string import FhirString
from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase

from spark_auto_mapper_fhir.base_types.fhir_backbone_element_base import (
    FhirBackboneElementBase,
)

if TYPE_CHECKING:
    pass
    # id_ (string)
    # extension (Extension)
    # modifierExtension (Extension)
    # daysOfWeek (DaysOfWeek)
    from spark_auto_mapper_fhir.value_sets.days_of_week import DaysOfWeekCode

    # allDay (boolean)
    # availableStartTime (time)
    from spark_auto_mapper_fhir.fhir_types.time import FhirTime

    # availableEndTime (time)


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class HealthcareServiceAvailableTime(FhirBackboneElementBase):
    """
    HealthcareService.AvailableTime
        The details of a healthcare service available at a location.
    """

    # noinspection PyPep8Naming
    def __init__(
        self,
        *,
        id_: Optional[FhirString] = None,
        extension: Optional[FhirList[ExtensionBase]] = None,
        modifierExtension: Optional[FhirList[ExtensionBase]] = None,
        daysOfWeek: Optional[FhirList[DaysOfWeekCode]] = None,
        allDay: Optional[FhirBoolean] = None,
        availableStartTime: Optional[FhirTime] = None,
        availableEndTime: Optional[FhirTime] = None,
    ) -> None:
        """
            The details of a healthcare service available at a location.

            :param id_: None
            :param extension: May be used to represent additional information that is not part of the basic
        definition of the element. To make the use of extensions safe and manageable,
        there is a strict set of governance  applied to the definition and use of
        extensions. Though any implementer can define an extension, there is a set of
        requirements that SHALL be met as part of the definition of the extension.
            :param modifierExtension: May be used to represent additional information that is not part of the basic
        definition of the element and that modifies the understanding of the element
        in which it is contained and/or the understanding of the containing element's
        descendants. Usually modifier elements provide negation or qualification. To
        make the use of extensions safe and manageable, there is a strict set of
        governance applied to the definition and use of extensions. Though any
        implementer can define an extension, there is a set of requirements that SHALL
        be met as part of the definition of the extension. Applications processing a
        resource are required to check for modifier extensions.

        Modifier extensions SHALL NOT change the meaning of any elements on Resource
        or DomainResource (including cannot change the meaning of modifierExtension
        itself).
            :param daysOfWeek: Indicates which days of the week are available between the start and end
        Times.
            :param allDay: Is this always available? (hence times are irrelevant) e.g. 24 hour service.
            :param availableStartTime: The opening time of day. Note: If the AllDay flag is set, then this time is
        ignored.
            :param availableEndTime: The closing time of day. Note: If the AllDay flag is set, then this time is
        ignored.
        """
        super().__init__(
            id_=id_,
            extension=extension,
            modifierExtension=modifierExtension,
            daysOfWeek=daysOfWeek,
            allDay=allDay,
            availableStartTime=availableStartTime,
            availableEndTime=availableEndTime,
        )
