from __future__ import annotations
from typing import Optional, TYPE_CHECKING

from spark_auto_mapper_fhir.fhir_types.list import FhirList
from spark_auto_mapper_fhir.fhir_types.string import FhirString
from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase

from spark_auto_mapper_fhir.base_types.fhir_backbone_element_base import (
    FhirBackboneElementBase,
)

if TYPE_CHECKING:
    pass
    # id_ (string)
    # extension (Extension)
    # modifierExtension (Extension)
    # nameUrl (url)
    from spark_auto_mapper_fhir.fhir_types.url import FhirUrl

    # nameReference (Reference)
    from spark_auto_mapper_fhir.complex_types.reference import Reference

    # Imports for References for nameReference
    from spark_auto_mapper_fhir.resources.binary import Binary

    # title (string)
    # generation (GuidePageGeneration)
    from spark_auto_mapper_fhir.value_sets.guide_page_generation import (
        GuidePageGenerationCode,
    )


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class ImplementationGuidePage(FhirBackboneElementBase):
    """
    ImplementationGuide.Page
        A set of rules of how a particular interoperability or standards problem is solved - typically through the use of FHIR resources. This resource is used to gather all the parts of an implementation guide into a logical whole and to publish a computable definition of all the parts.
    """

    # noinspection PyPep8Naming
    def __init__(
        self,
        *,
        id_: Optional[FhirString] = None,
        extension: Optional[FhirList[ExtensionBase]] = None,
        modifierExtension: Optional[FhirList[ExtensionBase]] = None,
        nameUrl: Optional[FhirUrl] = None,
        nameReference: Optional[Reference[Binary]] = None,
        title: FhirString,
        generation: GuidePageGenerationCode,
        page: Optional[FhirList[ImplementationGuidePage]] = None,
    ) -> None:
        """
            A set of rules of how a particular interoperability or standards problem is
        solved - typically through the use of FHIR resources. This resource is used to
        gather all the parts of an implementation guide into a logical whole and to
        publish a computable definition of all the parts.

            :param id_: None
            :param extension: May be used to represent additional information that is not part of the basic
        definition of the element. To make the use of extensions safe and manageable,
        there is a strict set of governance  applied to the definition and use of
        extensions. Though any implementer can define an extension, there is a set of
        requirements that SHALL be met as part of the definition of the extension.
            :param modifierExtension: May be used to represent additional information that is not part of the basic
        definition of the element and that modifies the understanding of the element
        in which it is contained and/or the understanding of the containing element's
        descendants. Usually modifier elements provide negation or qualification. To
        make the use of extensions safe and manageable, there is a strict set of
        governance applied to the definition and use of extensions. Though any
        implementer can define an extension, there is a set of requirements that SHALL
        be met as part of the definition of the extension. Applications processing a
        resource are required to check for modifier extensions.

        Modifier extensions SHALL NOT change the meaning of any elements on Resource
        or DomainResource (including cannot change the meaning of modifierExtension
        itself).
            :param nameUrl: None
            :param nameReference: None
            :param title: A short title used to represent this page in navigational structures such as
        table of contents, bread crumbs, etc.
            :param generation: A code that indicates how the page is generated.
            :param page: Nested Pages/Sections under this page.
        """
        super().__init__(
            id_=id_,
            extension=extension,
            modifierExtension=modifierExtension,
            nameUrl=nameUrl,
            nameReference=nameReference,
            title=title,
            generation=generation,
            page=page,
        )
