from __future__ import annotations
from typing import Optional, TYPE_CHECKING

from spark_auto_mapper_fhir.fhir_types.boolean import FhirBoolean
from spark_auto_mapper_fhir.fhir_types.list import FhirList
from spark_auto_mapper_fhir.fhir_types.string import FhirString
from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase
from spark_auto_mapper_fhir.fhir_types.id import FhirId
from spark_auto_mapper_fhir.resources.resource import Resource

from spark_auto_mapper_fhir.base_types.fhir_backbone_element_base import (
    FhirBackboneElementBase,
)

if TYPE_CHECKING:
    pass
    # id_ (string)
    # extension (Extension)
    # modifierExtension (Extension)
    # reference (Reference)
    from spark_auto_mapper_fhir.complex_types.reference import Reference

    # Imports for References for reference
    # fhirVersion (FHIRVersion)
    from spark_auto_mapper_fhir.value_sets.fhir_version import FHIRVersionCode

    # name (string)
    # description (string)
    # exampleBoolean (boolean)
    # exampleCanonical (canonical)
    from spark_auto_mapper_fhir.fhir_types.canonical import FhirCanonical

    # groupingId (id)


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class ImplementationGuideResource(FhirBackboneElementBase):
    """
    ImplementationGuide.Resource
        A set of rules of how a particular interoperability or standards problem is solved - typically through the use of FHIR resources. This resource is used to gather all the parts of an implementation guide into a logical whole and to publish a computable definition of all the parts.
    """

    # noinspection PyPep8Naming
    def __init__(
        self,
        *,
        id_: Optional[FhirString] = None,
        extension: Optional[FhirList[ExtensionBase]] = None,
        modifierExtension: Optional[FhirList[ExtensionBase]] = None,
        reference: Reference[Resource],
        fhirVersion: Optional[FhirList[FHIRVersionCode]] = None,
        name: Optional[FhirString] = None,
        description: Optional[FhirString] = None,
        exampleBoolean: Optional[FhirBoolean] = None,
        exampleCanonical: Optional[FhirCanonical] = None,
        groupingId: Optional[FhirId] = None,
    ) -> None:
        """
            A set of rules of how a particular interoperability or standards problem is
        solved - typically through the use of FHIR resources. This resource is used to
        gather all the parts of an implementation guide into a logical whole and to
        publish a computable definition of all the parts.

            :param id_: None
            :param extension: May be used to represent additional information that is not part of the basic
        definition of the element. To make the use of extensions safe and manageable,
        there is a strict set of governance  applied to the definition and use of
        extensions. Though any implementer can define an extension, there is a set of
        requirements that SHALL be met as part of the definition of the extension.
            :param modifierExtension: May be used to represent additional information that is not part of the basic
        definition of the element and that modifies the understanding of the element
        in which it is contained and/or the understanding of the containing element's
        descendants. Usually modifier elements provide negation or qualification. To
        make the use of extensions safe and manageable, there is a strict set of
        governance applied to the definition and use of extensions. Though any
        implementer can define an extension, there is a set of requirements that SHALL
        be met as part of the definition of the extension. Applications processing a
        resource are required to check for modifier extensions.

        Modifier extensions SHALL NOT change the meaning of any elements on Resource
        or DomainResource (including cannot change the meaning of modifierExtension
        itself).
            :param reference: Where this resource is found.
            :param fhirVersion: Indicates the FHIR Version(s) this artifact is intended to apply to. If no
        versions are specified, the resource is assumed to apply to all the versions
        stated in ImplementationGuide.fhirVersion.
            :param name: A human assigned name for the resource. All resources SHOULD have a name, but
        the name may be extracted from the resource (e.g. ValueSet.name).
            :param description: A description of the reason that a resource has been included in the
        implementation guide.
            :param exampleBoolean: None
            :param exampleCanonical: None
            :param groupingId: Reference to the id of the grouping this resource appears in.
        """
        super().__init__(
            id_=id_,
            extension=extension,
            modifierExtension=modifierExtension,
            reference=reference,
            fhirVersion=fhirVersion,
            name=name,
            description=description,
            exampleBoolean=exampleBoolean,
            exampleCanonical=exampleCanonical,
            groupingId=groupingId,
        )
