from __future__ import annotations
from typing import Optional, TYPE_CHECKING

from spark_auto_mapper_fhir.fhir_types.list import FhirList
from spark_auto_mapper_fhir.fhir_types.string import FhirString
from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase

from spark_auto_mapper_fhir.base_types.fhir_backbone_element_base import (
    FhirBackboneElementBase,
)

if TYPE_CHECKING:
    pass
    # id_ (string)
    # extension (Extension)
    # modifierExtension (Extension)
    # code (CodeableConcept)
    from spark_auto_mapper_fhir.complex_types.codeable_concept import CodeableConcept

    # End Import for References for code
    # Import for CodeableConcept for code
    from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode

    # End Import for CodeableConcept for code
    # population (MeasureReport.Population)
    from spark_auto_mapper_fhir.backbone_elements.measure_report_population import (
        MeasureReportPopulation,
    )

    # measureScore (Quantity)
    from spark_auto_mapper_fhir.complex_types.quantity import Quantity

    # stratifier (MeasureReport.Stratifier)
    from spark_auto_mapper_fhir.backbone_elements.measure_report_stratifier import (
        MeasureReportStratifier,
    )


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class MeasureReportGroup(FhirBackboneElementBase):
    """
    MeasureReport.Group
        The MeasureReport resource contains the results of the calculation of a measure; and optionally a reference to the resources involved in that calculation.
    """

    # noinspection PyPep8Naming
    def __init__(
        self,
        *,
        id_: Optional[FhirString] = None,
        extension: Optional[FhirList[ExtensionBase]] = None,
        modifierExtension: Optional[FhirList[ExtensionBase]] = None,
        code: Optional[CodeableConcept[GenericTypeCode]] = None,
        population: Optional[FhirList[MeasureReportPopulation]] = None,
        measureScore: Optional[Quantity] = None,
        stratifier: Optional[FhirList[MeasureReportStratifier]] = None,
    ) -> None:
        """
            The MeasureReport resource contains the results of the calculation of a
        measure; and optionally a reference to the resources involved in that
        calculation.

            :param id_: None
            :param extension: May be used to represent additional information that is not part of the basic
        definition of the element. To make the use of extensions safe and manageable,
        there is a strict set of governance  applied to the definition and use of
        extensions. Though any implementer can define an extension, there is a set of
        requirements that SHALL be met as part of the definition of the extension.
            :param modifierExtension: May be used to represent additional information that is not part of the basic
        definition of the element and that modifies the understanding of the element
        in which it is contained and/or the understanding of the containing element's
        descendants. Usually modifier elements provide negation or qualification. To
        make the use of extensions safe and manageable, there is a strict set of
        governance applied to the definition and use of extensions. Though any
        implementer can define an extension, there is a set of requirements that SHALL
        be met as part of the definition of the extension. Applications processing a
        resource are required to check for modifier extensions.

        Modifier extensions SHALL NOT change the meaning of any elements on Resource
        or DomainResource (including cannot change the meaning of modifierExtension
        itself).
            :param code: The meaning of the population group as defined in the measure definition.
            :param population: The populations that make up the population group, one for each type of
        population appropriate for the measure.
            :param measureScore: The measure score for this population group, calculated as appropriate for the
        measure type and scoring method, and based on the contents of the populations
        defined in the group.
            :param stratifier: When a measure includes multiple stratifiers, there will be a stratifier group
        for each stratifier defined by the measure.
        """
        super().__init__(
            id_=id_,
            extension=extension,
            modifierExtension=modifierExtension,
            code=code,
            population=population,
            measureScore=measureScore,
            stratifier=stratifier,
        )
