from __future__ import annotations
from typing import Optional, TYPE_CHECKING

from spark_auto_mapper_fhir.fhir_types.list import FhirList
from spark_auto_mapper_fhir.fhir_types.string import FhirString
from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase

from spark_auto_mapper_fhir.base_types.fhir_backbone_element_base import (
    FhirBackboneElementBase,
)

if TYPE_CHECKING:
    pass
    # id_ (string)
    # extension (Extension)
    # modifierExtension (Extension)
    # regulatoryAuthority (Reference)
    from spark_auto_mapper_fhir.complex_types.reference import Reference

    # Imports for References for regulatoryAuthority
    from spark_auto_mapper_fhir.resources.organization import Organization

    # substitution (MedicationKnowledge.Substitution)
    from spark_auto_mapper_fhir.backbone_elements.medication_knowledge_substitution import (
        MedicationKnowledgeSubstitution,
    )

    # schedule (MedicationKnowledge.Schedule)
    from spark_auto_mapper_fhir.backbone_elements.medication_knowledge_schedule import (
        MedicationKnowledgeSchedule,
    )

    # maxDispense (MedicationKnowledge.MaxDispense)
    from spark_auto_mapper_fhir.backbone_elements.medication_knowledge_max_dispense import (
        MedicationKnowledgeMaxDispense,
    )


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class MedicationKnowledgeRegulatory(FhirBackboneElementBase):
    """
    MedicationKnowledge.Regulatory
        Information about a medication that is used to support knowledge.
    """

    # noinspection PyPep8Naming
    def __init__(
        self,
        *,
        id_: Optional[FhirString] = None,
        extension: Optional[FhirList[ExtensionBase]] = None,
        modifierExtension: Optional[FhirList[ExtensionBase]] = None,
        regulatoryAuthority: Reference[Organization],
        substitution: Optional[FhirList[MedicationKnowledgeSubstitution]] = None,
        schedule: Optional[FhirList[MedicationKnowledgeSchedule]] = None,
        maxDispense: Optional[MedicationKnowledgeMaxDispense] = None,
    ) -> None:
        """
            Information about a medication that is used to support knowledge.

            :param id_: None
            :param extension: May be used to represent additional information that is not part of the basic
        definition of the element. To make the use of extensions safe and manageable,
        there is a strict set of governance  applied to the definition and use of
        extensions. Though any implementer can define an extension, there is a set of
        requirements that SHALL be met as part of the definition of the extension.
            :param modifierExtension: May be used to represent additional information that is not part of the basic
        definition of the element and that modifies the understanding of the element
        in which it is contained and/or the understanding of the containing element's
        descendants. Usually modifier elements provide negation or qualification. To
        make the use of extensions safe and manageable, there is a strict set of
        governance applied to the definition and use of extensions. Though any
        implementer can define an extension, there is a set of requirements that SHALL
        be met as part of the definition of the extension. Applications processing a
        resource are required to check for modifier extensions.

        Modifier extensions SHALL NOT change the meaning of any elements on Resource
        or DomainResource (including cannot change the meaning of modifierExtension
        itself).
            :param regulatoryAuthority: The authority that is specifying the regulations.
            :param substitution: Specifies if changes are allowed when dispensing a medication from a
        regulatory perspective.
            :param schedule: Specifies the schedule of a medication in jurisdiction.
            :param maxDispense: The maximum number of units of the medication that can be dispensed in a
        period.
        """
        super().__init__(
            id_=id_,
            extension=extension,
            modifierExtension=modifierExtension,
            regulatoryAuthority=regulatoryAuthority,
            substitution=substitution,
            schedule=schedule,
            maxDispense=maxDispense,
        )
