from __future__ import annotations
from typing import Optional, TYPE_CHECKING, Union

from spark_auto_mapper_fhir.fhir_types.list import FhirList
from spark_auto_mapper_fhir.fhir_types.string import FhirString
from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase

from spark_auto_mapper_fhir.base_types.fhir_backbone_element_base import (
    FhirBackboneElementBase,
)

if TYPE_CHECKING:
    pass
    # id_ (string)
    # extension (Extension)
    # modifierExtension (Extension)
    # therapyRelationshipType (CodeableConcept)
    from spark_auto_mapper_fhir.complex_types.codeable_concept import CodeableConcept

    # End Import for References for therapyRelationshipType
    # Import for CodeableConcept for therapyRelationshipType
    from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode

    # End Import for CodeableConcept for therapyRelationshipType
    # medicationCodeableConcept (CodeableConcept)
    # End Import for References for medicationCodeableConcept
    # Import for CodeableConcept for medicationCodeableConcept
    # End Import for CodeableConcept for medicationCodeableConcept
    # medicationReference (Reference)
    from spark_auto_mapper_fhir.complex_types.reference import Reference

    # Imports for References for medicationReference
    from spark_auto_mapper_fhir.resources.medicinal_product import MedicinalProduct
    from spark_auto_mapper_fhir.resources.medication import Medication
    from spark_auto_mapper_fhir.resources.substance import Substance
    from spark_auto_mapper_fhir.resources.substance_specification import (
        SubstanceSpecification,
    )


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class MedicinalProductContraindicationOtherTherapy(FhirBackboneElementBase):
    """
    MedicinalProductContraindication.OtherTherapy
        The clinical particulars - indications, contraindications etc. of a medicinal product, including for regulatory purposes.
    """

    # noinspection PyPep8Naming
    def __init__(
        self,
        *,
        id_: Optional[FhirString] = None,
        extension: Optional[FhirList[ExtensionBase]] = None,
        modifierExtension: Optional[FhirList[ExtensionBase]] = None,
        therapyRelationshipType: CodeableConcept[GenericTypeCode],
        medicationCodeableConcept: Optional[CodeableConcept[GenericTypeCode]] = None,
        medicationReference: Optional[
            Reference[
                Union[MedicinalProduct, Medication, Substance, SubstanceSpecification]
            ]
        ] = None,
    ) -> None:
        """
            The clinical particulars - indications, contraindications etc. of a medicinal
        product, including for regulatory purposes.

            :param id_: None
            :param extension: May be used to represent additional information that is not part of the basic
        definition of the element. To make the use of extensions safe and manageable,
        there is a strict set of governance  applied to the definition and use of
        extensions. Though any implementer can define an extension, there is a set of
        requirements that SHALL be met as part of the definition of the extension.
            :param modifierExtension: May be used to represent additional information that is not part of the basic
        definition of the element and that modifies the understanding of the element
        in which it is contained and/or the understanding of the containing element's
        descendants. Usually modifier elements provide negation or qualification. To
        make the use of extensions safe and manageable, there is a strict set of
        governance applied to the definition and use of extensions. Though any
        implementer can define an extension, there is a set of requirements that SHALL
        be met as part of the definition of the extension. Applications processing a
        resource are required to check for modifier extensions.

        Modifier extensions SHALL NOT change the meaning of any elements on Resource
        or DomainResource (including cannot change the meaning of modifierExtension
        itself).
            :param therapyRelationshipType: The type of relationship between the medicinal product indication or
        contraindication and another therapy.
            :param medicationCodeableConcept: None
            :param medicationReference: None
        """
        super().__init__(
            id_=id_,
            extension=extension,
            modifierExtension=modifierExtension,
            therapyRelationshipType=therapyRelationshipType,
            medicationCodeableConcept=medicationCodeableConcept,
            medicationReference=medicationReference,
        )
