from __future__ import annotations
from typing import Optional, TYPE_CHECKING

from spark_auto_mapper_fhir.fhir_types.list import FhirList
from spark_auto_mapper_fhir.fhir_types.string import FhirString
from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase

from spark_auto_mapper_fhir.base_types.fhir_backbone_element_base import (
    FhirBackboneElementBase,
)

if TYPE_CHECKING:
    pass
    # id_ (string)
    # extension (Extension)
    # modifierExtension (Extension)
    # code (CodeableConcept)
    from spark_auto_mapper_fhir.complex_types.codeable_concept import CodeableConcept

    # End Import for References for code
    # Import for CodeableConcept for code
    from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode

    # End Import for CodeableConcept for code
    # firstDose (Quantity)
    from spark_auto_mapper_fhir.complex_types.quantity import Quantity

    # maxSingleDose (Quantity)
    # maxDosePerDay (Quantity)
    # maxDosePerTreatmentPeriod (Ratio)
    from spark_auto_mapper_fhir.complex_types.ratio import Ratio

    # maxTreatmentPeriod (Duration)
    from spark_auto_mapper_fhir.complex_types.duration import Duration

    # targetSpecies (MedicinalProductPharmaceutical.TargetSpecies)
    from spark_auto_mapper_fhir.backbone_elements.medicinal_product_pharmaceutical_target_species import (
        MedicinalProductPharmaceuticalTargetSpecies,
    )


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class MedicinalProductPharmaceuticalRouteOfAdministration(FhirBackboneElementBase):
    """
    MedicinalProductPharmaceutical.RouteOfAdministration
        A pharmaceutical product described in terms of its composition and dose form.
    """

    # noinspection PyPep8Naming
    def __init__(
        self,
        *,
        id_: Optional[FhirString] = None,
        extension: Optional[FhirList[ExtensionBase]] = None,
        modifierExtension: Optional[FhirList[ExtensionBase]] = None,
        code: CodeableConcept[GenericTypeCode],
        firstDose: Optional[Quantity] = None,
        maxSingleDose: Optional[Quantity] = None,
        maxDosePerDay: Optional[Quantity] = None,
        maxDosePerTreatmentPeriod: Optional[Ratio] = None,
        maxTreatmentPeriod: Optional[Duration] = None,
        targetSpecies: Optional[
            FhirList[MedicinalProductPharmaceuticalTargetSpecies]
        ] = None,
    ) -> None:
        """
            A pharmaceutical product described in terms of its composition and dose form.

            :param id_: None
            :param extension: May be used to represent additional information that is not part of the basic
        definition of the element. To make the use of extensions safe and manageable,
        there is a strict set of governance  applied to the definition and use of
        extensions. Though any implementer can define an extension, there is a set of
        requirements that SHALL be met as part of the definition of the extension.
            :param modifierExtension: May be used to represent additional information that is not part of the basic
        definition of the element and that modifies the understanding of the element
        in which it is contained and/or the understanding of the containing element's
        descendants. Usually modifier elements provide negation or qualification. To
        make the use of extensions safe and manageable, there is a strict set of
        governance applied to the definition and use of extensions. Though any
        implementer can define an extension, there is a set of requirements that SHALL
        be met as part of the definition of the extension. Applications processing a
        resource are required to check for modifier extensions.

        Modifier extensions SHALL NOT change the meaning of any elements on Resource
        or DomainResource (including cannot change the meaning of modifierExtension
        itself).
            :param code: Coded expression for the route.
            :param firstDose: The first dose (dose quantity) administered in humans can be specified, for a
        product under investigation, using a numerical value and its unit of
        measurement.
            :param maxSingleDose: The maximum single dose that can be administered as per the protocol of a
        clinical trial can be specified using a numerical value and its unit of
        measurement.
            :param maxDosePerDay: The maximum dose per day (maximum dose quantity to be administered in any one
        24-h period) that can be administered as per the protocol referenced in the
        clinical trial authorisation.
            :param maxDosePerTreatmentPeriod: The maximum dose per treatment period that can be administered as per the
        protocol referenced in the clinical trial authorisation.
            :param maxTreatmentPeriod: The maximum treatment period during which an Investigational Medicinal Product
        can be administered as per the protocol referenced in the clinical trial
        authorisation.
            :param targetSpecies: A species for which this route applies.
        """
        super().__init__(
            id_=id_,
            extension=extension,
            modifierExtension=modifierExtension,
            code=code,
            firstDose=firstDose,
            maxSingleDose=maxSingleDose,
            maxDosePerDay=maxDosePerDay,
            maxDosePerTreatmentPeriod=maxDosePerTreatmentPeriod,
            maxTreatmentPeriod=maxTreatmentPeriod,
            targetSpecies=targetSpecies,
        )
