from __future__ import annotations
from typing import Optional, TYPE_CHECKING

from spark_auto_mapper_fhir.fhir_types.list import FhirList
from spark_auto_mapper_fhir.fhir_types.string import FhirString
from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase
from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.base_types.fhir_backbone_element_base import (
    FhirBackboneElementBase,
)

if TYPE_CHECKING:
    pass
    # id_ (string)
    # extension (Extension)
    # modifierExtension (Extension)
    # type_ (repositoryType)
    from spark_auto_mapper_fhir.value_sets.repository_type import RepositoryTypeCode

    # url (uri)
    # name (string)
    # datasetId (string)
    # variantsetId (string)
    # readsetId (string)


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class MolecularSequenceRepository(FhirBackboneElementBase):
    """
    MolecularSequence.Repository
        Raw data describing a biological sequence.
    """

    # noinspection PyPep8Naming
    def __init__(
        self,
        *,
        id_: Optional[FhirString] = None,
        extension: Optional[FhirList[ExtensionBase]] = None,
        modifierExtension: Optional[FhirList[ExtensionBase]] = None,
        type_: RepositoryTypeCode,
        url: Optional[FhirUri] = None,
        name: Optional[FhirString] = None,
        datasetId: Optional[FhirString] = None,
        variantsetId: Optional[FhirString] = None,
        readsetId: Optional[FhirString] = None,
    ) -> None:
        """
            Raw data describing a biological sequence.

            :param id_: None
            :param extension: May be used to represent additional information that is not part of the basic
        definition of the element. To make the use of extensions safe and manageable,
        there is a strict set of governance  applied to the definition and use of
        extensions. Though any implementer can define an extension, there is a set of
        requirements that SHALL be met as part of the definition of the extension.
            :param modifierExtension: May be used to represent additional information that is not part of the basic
        definition of the element and that modifies the understanding of the element
        in which it is contained and/or the understanding of the containing element's
        descendants. Usually modifier elements provide negation or qualification. To
        make the use of extensions safe and manageable, there is a strict set of
        governance applied to the definition and use of extensions. Though any
        implementer can define an extension, there is a set of requirements that SHALL
        be met as part of the definition of the extension. Applications processing a
        resource are required to check for modifier extensions.

        Modifier extensions SHALL NOT change the meaning of any elements on Resource
        or DomainResource (including cannot change the meaning of modifierExtension
        itself).
            :param type_: Click and see / RESTful API / Need login to see / RESTful API with
        authentication / Other ways to see resource.
            :param url: URI of an external repository which contains further details about the
        genetics data.
            :param name: URI of an external repository which contains further details about the
        genetics data.
            :param datasetId: Id of the variant in this external repository. The server will understand how
        to use this id to call for more info about datasets in external repository.
            :param variantsetId: Id of the variantset in this external repository. The server will understand
        how to use this id to call for more info about variantsets in external
        repository.
            :param readsetId: Id of the read in this external repository.
        """
        super().__init__(
            id_=id_,
            extension=extension,
            modifierExtension=modifierExtension,
            type_=type_,
            url=url,
            name=name,
            datasetId=datasetId,
            variantsetId=variantsetId,
            readsetId=readsetId,
        )
