from __future__ import annotations
from typing import Optional, TYPE_CHECKING

from spark_auto_mapper_fhir.fhir_types.boolean import FhirBoolean
from spark_auto_mapper_fhir.fhir_types.list import FhirList
from spark_auto_mapper_fhir.fhir_types.integer import FhirInteger
from spark_auto_mapper_fhir.fhir_types.string import FhirString
from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase

from spark_auto_mapper_fhir.base_types.fhir_backbone_element_base import (
    FhirBackboneElementBase,
)

if TYPE_CHECKING:
    pass
    # id_ (string)
    # extension (Extension)
    # modifierExtension (Extension)
    # variantType (CodeableConcept)
    from spark_auto_mapper_fhir.complex_types.codeable_concept import CodeableConcept

    # End Import for References for variantType
    # Import for CodeableConcept for variantType
    from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode

    # End Import for CodeableConcept for variantType
    # exact (boolean)
    # length (integer)
    # outer (MolecularSequence.Outer)
    from spark_auto_mapper_fhir.backbone_elements.molecular_sequence_outer import (
        MolecularSequenceOuter,
    )

    # inner (MolecularSequence.Inner)
    from spark_auto_mapper_fhir.backbone_elements.molecular_sequence_inner import (
        MolecularSequenceInner,
    )


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class MolecularSequenceStructureVariant(FhirBackboneElementBase):
    """
    MolecularSequence.StructureVariant
        Raw data describing a biological sequence.
    """

    # noinspection PyPep8Naming
    def __init__(
        self,
        *,
        id_: Optional[FhirString] = None,
        extension: Optional[FhirList[ExtensionBase]] = None,
        modifierExtension: Optional[FhirList[ExtensionBase]] = None,
        variantType: Optional[CodeableConcept[GenericTypeCode]] = None,
        exact: Optional[FhirBoolean] = None,
        length: Optional[FhirInteger] = None,
        outer: Optional[MolecularSequenceOuter] = None,
        inner: Optional[MolecularSequenceInner] = None,
    ) -> None:
        """
            Raw data describing a biological sequence.

            :param id_: None
            :param extension: May be used to represent additional information that is not part of the basic
        definition of the element. To make the use of extensions safe and manageable,
        there is a strict set of governance  applied to the definition and use of
        extensions. Though any implementer can define an extension, there is a set of
        requirements that SHALL be met as part of the definition of the extension.
            :param modifierExtension: May be used to represent additional information that is not part of the basic
        definition of the element and that modifies the understanding of the element
        in which it is contained and/or the understanding of the containing element's
        descendants. Usually modifier elements provide negation or qualification. To
        make the use of extensions safe and manageable, there is a strict set of
        governance applied to the definition and use of extensions. Though any
        implementer can define an extension, there is a set of requirements that SHALL
        be met as part of the definition of the extension. Applications processing a
        resource are required to check for modifier extensions.

        Modifier extensions SHALL NOT change the meaning of any elements on Resource
        or DomainResource (including cannot change the meaning of modifierExtension
        itself).
            :param variantType: Information about chromosome structure variation DNA change type.
            :param exact: Used to indicate if the outer and inner start-end values have the same
        meaning.
            :param length: Length of the variant chromosome.
            :param outer: Structural variant outer.
            :param inner: Structural variant inner.
        """
        super().__init__(
            id_=id_,
            extension=extension,
            modifierExtension=modifierExtension,
            variantType=variantType,
            exact=exact,
            length=length,
            outer=outer,
            inner=inner,
        )
