from __future__ import annotations
from typing import Optional, TYPE_CHECKING

from spark_auto_mapper_fhir.fhir_types.list import FhirList
from spark_auto_mapper_fhir.fhir_types.string import FhirString
from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase

from spark_auto_mapper_fhir.base_types.fhir_backbone_element_base import (
    FhirBackboneElementBase,
)

if TYPE_CHECKING:
    pass
    # id_ (string)
    # extension (Extension)
    # modifierExtension (Extension)
    # height (Quantity)
    from spark_auto_mapper_fhir.complex_types.quantity import Quantity

    # width (Quantity)
    # depth (Quantity)
    # weight (Quantity)
    # nominalVolume (Quantity)
    # externalDiameter (Quantity)
    # shape (string)
    # color (string)
    # imprint (string)
    # image (Attachment)
    from spark_auto_mapper_fhir.complex_types.attachment import Attachment

    # scoring (CodeableConcept)
    from spark_auto_mapper_fhir.complex_types.codeable_concept import CodeableConcept

    # End Import for References for scoring
    # Import for CodeableConcept for scoring
    from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode

    # End Import for CodeableConcept for scoring


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class ProdCharacteristic(FhirBackboneElementBase):
    """
    ProdCharacteristic
        The marketing status describes the date when a medicinal product is actually put on the market or the date as of which it is no longer available.
        If the element is present, it must have a value for at least one of the defined elements, an @id referenced from the Narrative, or extensions
    """

    # noinspection PyPep8Naming
    def __init__(
        self,
        *,
        id_: Optional[FhirString] = None,
        extension: Optional[FhirList[ExtensionBase]] = None,
        modifierExtension: Optional[FhirList[ExtensionBase]] = None,
        height: Optional[Quantity] = None,
        width: Optional[Quantity] = None,
        depth: Optional[Quantity] = None,
        weight: Optional[Quantity] = None,
        nominalVolume: Optional[Quantity] = None,
        externalDiameter: Optional[Quantity] = None,
        shape: Optional[FhirString] = None,
        color: Optional[FhirList[FhirString]] = None,
        imprint: Optional[FhirList[FhirString]] = None,
        image: Optional[FhirList[Attachment]] = None,
        scoring: Optional[CodeableConcept[GenericTypeCode]] = None,
    ) -> None:
        """
            The marketing status describes the date when a medicinal product is actually
        put on the market or the date as of which it is no longer available.
            If the element is present, it must have a value for at least one of the
        defined elements, an @id referenced from the Narrative, or extensions

            :param id_: None
            :param extension: May be used to represent additional information that is not part of the basic
        definition of the element. To make the use of extensions safe and manageable,
        there is a strict set of governance  applied to the definition and use of
        extensions. Though any implementer can define an extension, there is a set of
        requirements that SHALL be met as part of the definition of the extension.
            :param modifierExtension: May be used to represent additional information that is not part of the basic
        definition of the element and that modifies the understanding of the element
        in which it is contained and/or the understanding of the containing element's
        descendants. Usually modifier elements provide negation or qualification. To
        make the use of extensions safe and manageable, there is a strict set of
        governance applied to the definition and use of extensions. Though any
        implementer can define an extension, there is a set of requirements that SHALL
        be met as part of the definition of the extension. Applications processing a
        resource are required to check for modifier extensions.

        Modifier extensions SHALL NOT change the meaning of any elements on Resource
        or DomainResource (including cannot change the meaning of modifierExtension
        itself).
            :param height: Where applicable, the height can be specified using a numerical value and its
        unit of measurement The unit of measurement shall be specified in accordance
        with ISO 11240 and the resulting terminology The symbol and the symbol
        identifier shall be used.
            :param width: Where applicable, the width can be specified using a numerical value and its
        unit of measurement The unit of measurement shall be specified in accordance
        with ISO 11240 and the resulting terminology The symbol and the symbol
        identifier shall be used.
            :param depth: Where applicable, the depth can be specified using a numerical value and its
        unit of measurement The unit of measurement shall be specified in accordance
        with ISO 11240 and the resulting terminology The symbol and the symbol
        identifier shall be used.
            :param weight: Where applicable, the weight can be specified using a numerical value and its
        unit of measurement The unit of measurement shall be specified in accordance
        with ISO 11240 and the resulting terminology The symbol and the symbol
        identifier shall be used.
            :param nominalVolume: Where applicable, the nominal volume can be specified using a numerical value
        and its unit of measurement The unit of measurement shall be specified in
        accordance with ISO 11240 and the resulting terminology The symbol and the
        symbol identifier shall be used.
            :param externalDiameter: Where applicable, the external diameter can be specified using a numerical
        value and its unit of measurement The unit of measurement shall be specified
        in accordance with ISO 11240 and the resulting terminology The symbol and the
        symbol identifier shall be used.
            :param shape: Where applicable, the shape can be specified An appropriate controlled
        vocabulary shall be used The term and the term identifier shall be used.
            :param color: Where applicable, the color can be specified An appropriate controlled
        vocabulary shall be used The term and the term identifier shall be used.
            :param imprint: Where applicable, the imprint can be specified as text.
            :param image: Where applicable, the image can be provided The format of the image attachment
        shall be specified by regional implementations.
            :param scoring: Where applicable, the scoring can be specified An appropriate controlled
        vocabulary shall be used The term and the term identifier shall be used.
        """
        super().__init__(
            id_=id_,
            extension=extension,
            modifierExtension=modifierExtension,
            height=height,
            width=width,
            depth=depth,
            weight=weight,
            nominalVolume=nominalVolume,
            externalDiameter=externalDiameter,
            shape=shape,
            color=color,
            imprint=imprint,
            image=image,
            scoring=scoring,
        )
