from __future__ import annotations
from typing import Optional, TYPE_CHECKING

from spark_auto_mapper_fhir.fhir_types.list import FhirList
from spark_auto_mapper_fhir.fhir_types.string import FhirString
from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase

from spark_auto_mapper_fhir.base_types.fhir_backbone_element_base import (
    FhirBackboneElementBase,
)

if TYPE_CHECKING:
    pass
    # id_ (string)
    # extension (Extension)
    # modifierExtension (Extension)
    # temperatureQualifier (CodeableConcept)
    from spark_auto_mapper_fhir.complex_types.codeable_concept import CodeableConcept

    # End Import for References for temperatureQualifier
    # Import for CodeableConcept for temperatureQualifier
    from spark_auto_mapper_fhir.value_sets.handling_condition_set import (
        HandlingConditionSetCode,
    )

    # End Import for CodeableConcept for temperatureQualifier
    # temperatureRange (Range)
    from spark_auto_mapper_fhir.complex_types.range import Range

    # maxDuration (Duration)
    from spark_auto_mapper_fhir.complex_types.duration import Duration

    # instruction (string)


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class SpecimenDefinitionHandling(FhirBackboneElementBase):
    """
    SpecimenDefinition.Handling
        A kind of specimen with associated set of requirements.
    """

    # noinspection PyPep8Naming
    def __init__(
        self,
        *,
        id_: Optional[FhirString] = None,
        extension: Optional[FhirList[ExtensionBase]] = None,
        modifierExtension: Optional[FhirList[ExtensionBase]] = None,
        temperatureQualifier: Optional[
            CodeableConcept[HandlingConditionSetCode]
        ] = None,
        temperatureRange: Optional[Range] = None,
        maxDuration: Optional[Duration] = None,
        instruction: Optional[FhirString] = None,
    ) -> None:
        """
            A kind of specimen with associated set of requirements.

            :param id_: None
            :param extension: May be used to represent additional information that is not part of the basic
        definition of the element. To make the use of extensions safe and manageable,
        there is a strict set of governance  applied to the definition and use of
        extensions. Though any implementer can define an extension, there is a set of
        requirements that SHALL be met as part of the definition of the extension.
            :param modifierExtension: May be used to represent additional information that is not part of the basic
        definition of the element and that modifies the understanding of the element
        in which it is contained and/or the understanding of the containing element's
        descendants. Usually modifier elements provide negation or qualification. To
        make the use of extensions safe and manageable, there is a strict set of
        governance applied to the definition and use of extensions. Though any
        implementer can define an extension, there is a set of requirements that SHALL
        be met as part of the definition of the extension. Applications processing a
        resource are required to check for modifier extensions.

        Modifier extensions SHALL NOT change the meaning of any elements on Resource
        or DomainResource (including cannot change the meaning of modifierExtension
        itself).
            :param temperatureQualifier: It qualifies the interval of temperature, which characterizes an occurrence of
        handling. Conditions that are not related to temperature may be handled in the
        instruction element.
            :param temperatureRange: The temperature interval for this set of handling instructions.
            :param maxDuration: The maximum time interval of preservation of the specimen with these
        conditions.
            :param instruction: Additional textual instructions for the preservation or transport of the
        specimen. For instance, 'Protect from light exposure'.
        """
        super().__init__(
            id_=id_,
            extension=extension,
            modifierExtension=modifierExtension,
            temperatureQualifier=temperatureQualifier,
            temperatureRange=temperatureRange,
            maxDuration=maxDuration,
            instruction=instruction,
        )
