from __future__ import annotations
from typing import Optional, TYPE_CHECKING

from spark_auto_mapper_fhir.fhir_types.list import FhirList
from spark_auto_mapper_fhir.fhir_types.string import FhirString
from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase
from spark_auto_mapper_fhir.fhir_types.id import FhirId

from spark_auto_mapper_fhir.base_types.fhir_backbone_element_base import (
    FhirBackboneElementBase,
)

if TYPE_CHECKING:
    pass
    # id_ (string)
    # extension (Extension)
    # modifierExtension (Extension)
    # context (id)
    # contextType (StructureMapContextType)
    from spark_auto_mapper_fhir.value_sets.structure_map_context_type import (
        StructureMapContextTypeCode,
    )

    # element (string)
    # variable (id)
    # listMode (StructureMapTargetListMode)
    from spark_auto_mapper_fhir.value_sets.structure_map_target_list_mode import (
        StructureMapTargetListModeCode,
    )

    # listRuleId (id)
    # transform (StructureMapTransform)
    from spark_auto_mapper_fhir.value_sets.structure_map_transform import (
        StructureMapTransformCode,
    )

    # parameter (StructureMap.Parameter)
    from spark_auto_mapper_fhir.backbone_elements.structure_map_parameter import (
        StructureMapParameter,
    )


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class StructureMapTarget(FhirBackboneElementBase):
    """
    StructureMap.Target
        A Map of relationships between 2 structures that can be used to transform data.
    """

    # noinspection PyPep8Naming
    def __init__(
        self,
        *,
        id_: Optional[FhirString] = None,
        extension: Optional[FhirList[ExtensionBase]] = None,
        modifierExtension: Optional[FhirList[ExtensionBase]] = None,
        context: Optional[FhirId] = None,
        contextType: Optional[StructureMapContextTypeCode] = None,
        element: Optional[FhirString] = None,
        variable: Optional[FhirId] = None,
        listMode: Optional[FhirList[StructureMapTargetListModeCode]] = None,
        listRuleId: Optional[FhirId] = None,
        transform: Optional[StructureMapTransformCode] = None,
        parameter: Optional[FhirList[StructureMapParameter]] = None,
    ) -> None:
        """
            A Map of relationships between 2 structures that can be used to transform
        data.

            :param id_: None
            :param extension: May be used to represent additional information that is not part of the basic
        definition of the element. To make the use of extensions safe and manageable,
        there is a strict set of governance  applied to the definition and use of
        extensions. Though any implementer can define an extension, there is a set of
        requirements that SHALL be met as part of the definition of the extension.
            :param modifierExtension: May be used to represent additional information that is not part of the basic
        definition of the element and that modifies the understanding of the element
        in which it is contained and/or the understanding of the containing element's
        descendants. Usually modifier elements provide negation or qualification. To
        make the use of extensions safe and manageable, there is a strict set of
        governance applied to the definition and use of extensions. Though any
        implementer can define an extension, there is a set of requirements that SHALL
        be met as part of the definition of the extension. Applications processing a
        resource are required to check for modifier extensions.

        Modifier extensions SHALL NOT change the meaning of any elements on Resource
        or DomainResource (including cannot change the meaning of modifierExtension
        itself).
            :param context: Type or variable this rule applies to.
            :param contextType: How to interpret the context.
            :param element: Field to create in the context.
            :param variable: Named context for field, if desired, and a field is specified.
            :param listMode: If field is a list, how to manage the list.
            :param listRuleId: Internal rule reference for shared list items.
            :param transform: How the data is copied / created.
            :param parameter: Parameters to the transform.
        """
        super().__init__(
            id_=id_,
            extension=extension,
            modifierExtension=modifierExtension,
            context=context,
            contextType=contextType,
            element=element,
            variable=variable,
            listMode=listMode,
            listRuleId=listRuleId,
            transform=transform,
            parameter=parameter,
        )
