from __future__ import annotations
from typing import Optional, TYPE_CHECKING

from spark_auto_mapper_fhir.fhir_types.list import FhirList
from spark_auto_mapper_fhir.fhir_types.string import FhirString
from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase

from spark_auto_mapper_fhir.base_types.fhir_backbone_element_base import (
    FhirBackboneElementBase,
)

if TYPE_CHECKING:
    pass
    # id_ (string)
    # extension (Extension)
    # modifierExtension (Extension)
    # quantity (Ratio)
    from spark_auto_mapper_fhir.complex_types.ratio import Ratio

    # substanceCodeableConcept (CodeableConcept)
    from spark_auto_mapper_fhir.complex_types.codeable_concept import CodeableConcept

    # End Import for References for substanceCodeableConcept
    # Import for CodeableConcept for substanceCodeableConcept
    from spark_auto_mapper_fhir.value_sets.substance_code import SubstanceCodeCode

    # End Import for CodeableConcept for substanceCodeableConcept
    # substanceReference (Reference)
    from spark_auto_mapper_fhir.complex_types.reference import Reference

    # Imports for References for substanceReference
    from spark_auto_mapper_fhir.resources.substance import Substance


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class SubstanceIngredient(FhirBackboneElementBase):
    """
    Substance.Ingredient
        A homogeneous material with a definite composition.
    """

    # noinspection PyPep8Naming
    def __init__(
        self,
        *,
        id_: Optional[FhirString] = None,
        extension: Optional[FhirList[ExtensionBase]] = None,
        modifierExtension: Optional[FhirList[ExtensionBase]] = None,
        quantity: Optional[Ratio] = None,
        substanceCodeableConcept: Optional[CodeableConcept[SubstanceCodeCode]] = None,
        substanceReference: Optional[Reference[Substance]] = None,
    ) -> None:
        """
            A homogeneous material with a definite composition.

            :param id_: None
            :param extension: May be used to represent additional information that is not part of the basic
        definition of the element. To make the use of extensions safe and manageable,
        there is a strict set of governance  applied to the definition and use of
        extensions. Though any implementer can define an extension, there is a set of
        requirements that SHALL be met as part of the definition of the extension.
            :param modifierExtension: May be used to represent additional information that is not part of the basic
        definition of the element and that modifies the understanding of the element
        in which it is contained and/or the understanding of the containing element's
        descendants. Usually modifier elements provide negation or qualification. To
        make the use of extensions safe and manageable, there is a strict set of
        governance applied to the definition and use of extensions. Though any
        implementer can define an extension, there is a set of requirements that SHALL
        be met as part of the definition of the extension. Applications processing a
        resource are required to check for modifier extensions.

        Modifier extensions SHALL NOT change the meaning of any elements on Resource
        or DomainResource (including cannot change the meaning of modifierExtension
        itself).
            :param quantity: The amount of the ingredient in the substance - a concentration ratio.
            :param substanceCodeableConcept: None
            :param substanceReference: None
        """
        super().__init__(
            id_=id_,
            extension=extension,
            modifierExtension=modifierExtension,
            quantity=quantity,
            substanceCodeableConcept=substanceCodeableConcept,
            substanceReference=substanceReference,
        )
