from __future__ import annotations
from typing import Optional, TYPE_CHECKING

from spark_auto_mapper_fhir.fhir_types.list import FhirList
from spark_auto_mapper_fhir.fhir_types.string import FhirString
from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase

from spark_auto_mapper_fhir.base_types.fhir_backbone_element_base import (
    FhirBackboneElementBase,
)

if TYPE_CHECKING:
    pass
    # id_ (string)
    # extension (Extension)
    # modifierExtension (Extension)
    # family (CodeableConcept)
    from spark_auto_mapper_fhir.complex_types.codeable_concept import CodeableConcept

    # End Import for References for family
    # Import for CodeableConcept for family
    from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode

    # End Import for CodeableConcept for family
    # genus (CodeableConcept)
    # End Import for References for genus
    # Import for CodeableConcept for genus
    # End Import for CodeableConcept for genus
    # species (CodeableConcept)
    # End Import for References for species
    # Import for CodeableConcept for species
    # End Import for CodeableConcept for species
    # intraspecificType (CodeableConcept)
    # End Import for References for intraspecificType
    # Import for CodeableConcept for intraspecificType
    # End Import for CodeableConcept for intraspecificType
    # intraspecificDescription (string)
    # author (SubstanceSourceMaterial.Author)
    from spark_auto_mapper_fhir.backbone_elements.substance_source_material_author import (
        SubstanceSourceMaterialAuthor,
    )

    # hybrid (SubstanceSourceMaterial.Hybrid)
    from spark_auto_mapper_fhir.backbone_elements.substance_source_material_hybrid import (
        SubstanceSourceMaterialHybrid,
    )

    # organismGeneral (SubstanceSourceMaterial.OrganismGeneral)
    from spark_auto_mapper_fhir.backbone_elements.substance_source_material_organism_general import (
        SubstanceSourceMaterialOrganismGeneral,
    )


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class SubstanceSourceMaterialOrganism(FhirBackboneElementBase):
    """
    SubstanceSourceMaterial.Organism
        Source material shall capture information on the taxonomic and anatomical origins as well as the fraction of a material that can result in or can be modified to form a substance. This set of data elements shall be used to define polymer substances isolated from biological matrices. Taxonomic and anatomical origins shall be described using a controlled vocabulary as required. This information is captured for naturally derived polymers ( . starch) and structurally diverse substances. For Organisms belonging to the Kingdom Plantae the Substance level defines the fresh material of a single species or infraspecies, the Herbal Drug and the Herbal preparation. For Herbal preparations, the fraction information will be captured at the Substance information level and additional information for herbal extracts will be captured at the Specified Substance Group 1 information level. See for further explanation the Substance Class: Structurally Diverse and the herbal annex.
    """

    # noinspection PyPep8Naming
    def __init__(
        self,
        *,
        id_: Optional[FhirString] = None,
        extension: Optional[FhirList[ExtensionBase]] = None,
        modifierExtension: Optional[FhirList[ExtensionBase]] = None,
        family: Optional[CodeableConcept[GenericTypeCode]] = None,
        genus: Optional[CodeableConcept[GenericTypeCode]] = None,
        species: Optional[CodeableConcept[GenericTypeCode]] = None,
        intraspecificType: Optional[CodeableConcept[GenericTypeCode]] = None,
        intraspecificDescription: Optional[FhirString] = None,
        author: Optional[FhirList[SubstanceSourceMaterialAuthor]] = None,
        hybrid: Optional[SubstanceSourceMaterialHybrid] = None,
        organismGeneral: Optional[SubstanceSourceMaterialOrganismGeneral] = None,
    ) -> None:
        """
            Source material shall capture information on the taxonomic and anatomical
        origins as well as the fraction of a material that can result in or can be
        modified to form a substance. This set of data elements shall be used to
        define polymer substances isolated from biological matrices. Taxonomic and
        anatomical origins shall be described using a controlled vocabulary as
        required. This information is captured for naturally derived polymers ( .
        starch) and structurally diverse substances. For Organisms belonging to the
        Kingdom Plantae the Substance level defines the fresh material of a single
        species or infraspecies, the Herbal Drug and the Herbal preparation. For
        Herbal preparations, the fraction information will be captured at the
        Substance information level and additional information for herbal extracts
        will be captured at the Specified Substance Group 1 information level. See for
        further explanation the Substance Class: Structurally Diverse and the herbal
        annex.

            :param id_: None
            :param extension: May be used to represent additional information that is not part of the basic
        definition of the element. To make the use of extensions safe and manageable,
        there is a strict set of governance  applied to the definition and use of
        extensions. Though any implementer can define an extension, there is a set of
        requirements that SHALL be met as part of the definition of the extension.
            :param modifierExtension: May be used to represent additional information that is not part of the basic
        definition of the element and that modifies the understanding of the element
        in which it is contained and/or the understanding of the containing element's
        descendants. Usually modifier elements provide negation or qualification. To
        make the use of extensions safe and manageable, there is a strict set of
        governance applied to the definition and use of extensions. Though any
        implementer can define an extension, there is a set of requirements that SHALL
        be met as part of the definition of the extension. Applications processing a
        resource are required to check for modifier extensions.

        Modifier extensions SHALL NOT change the meaning of any elements on Resource
        or DomainResource (including cannot change the meaning of modifierExtension
        itself).
            :param family: The family of an organism shall be specified.
            :param genus: The genus of an organism shall be specified; refers to the Latin epithet of
        the genus element of the plant/animal scientific name; it is present in names
        for genera, species and infraspecies.
            :param species: The species of an organism shall be specified; refers to the Latin epithet of
        the species of the plant/animal; it is present in names for species and
        infraspecies.
            :param intraspecificType: The Intraspecific type of an organism shall be specified.
            :param intraspecificDescription: The intraspecific description of an organism shall be specified based on a
        controlled vocabulary. For Influenza Vaccine, the intraspecific description
        shall contain the syntax of the antigen in line with the WHO convention.
            :param author: 4.9.13.6.1 Author type (Conditional).
            :param hybrid: 4.9.13.8.1 Hybrid species maternal organism ID (Optional).
            :param organismGeneral: 4.9.13.7.1 Kingdom (Conditional).
        """
        super().__init__(
            id_=id_,
            extension=extension,
            modifierExtension=modifierExtension,
            family=family,
            genus=genus,
            species=species,
            intraspecificType=intraspecificType,
            intraspecificDescription=intraspecificDescription,
            author=author,
            hybrid=hybrid,
            organismGeneral=organismGeneral,
        )
