from __future__ import annotations
from typing import Optional, TYPE_CHECKING

from spark_auto_mapper_fhir.fhir_types.list import FhirList
from spark_auto_mapper_fhir.fhir_types.string import FhirString
from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase

from spark_auto_mapper_fhir.base_types.fhir_backbone_element_base import (
    FhirBackboneElementBase,
)

if TYPE_CHECKING:
    pass
    # id_ (string)
    # extension (Extension)
    # modifierExtension (Extension)
    # boundsDuration (Duration)
    from spark_auto_mapper_fhir.complex_types.duration import Duration

    # boundsRange (Range)
    from spark_auto_mapper_fhir.complex_types.range import Range

    # boundsPeriod (Period)
    from spark_auto_mapper_fhir.complex_types.period import Period

    # count (positiveInt)
    from spark_auto_mapper_fhir.fhir_types.positive_int import FhirPositiveInt

    # countMax (positiveInt)
    # duration (decimal)
    from spark_auto_mapper_fhir.fhir_types.decimal import FhirDecimal

    # durationMax (decimal)
    # durationUnit (UnitsOfTime)
    from spark_auto_mapper_fhir.value_sets.units_of_time import UnitsOfTimeCode

    # frequency (positiveInt)
    # frequencyMax (positiveInt)
    # period (decimal)
    # periodMax (decimal)
    # periodUnit (UnitsOfTime)
    # dayOfWeek (DaysOfWeek)
    from spark_auto_mapper_fhir.value_sets.days_of_week import DaysOfWeekCode

    # timeOfDay (time)
    from spark_auto_mapper_fhir.fhir_types.time import FhirTime

    # when (EventTiming)
    from spark_auto_mapper_fhir.value_sets.event_timing import EventTimingCode

    # offset (unsignedInt)
    from spark_auto_mapper_fhir.fhir_types.unsigned_int import FhirUnsignedInt


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class TimingRepeat(FhirBackboneElementBase):
    """
    Timing.Repeat
        Specifies an event that may occur multiple times. Timing schedules are used to record when things are planned, expected or requested to occur. The most common usage is in dosage instructions for medications. They are also used when planning care of various kinds, and may be used for reporting the schedule to which past regular activities were carried out.
        If the element is present, it must have a value for at least one of the defined elements, an @id referenced from the Narrative, or extensions
    """

    # noinspection PyPep8Naming
    def __init__(
        self,
        *,
        id_: Optional[FhirString] = None,
        extension: Optional[FhirList[ExtensionBase]] = None,
        modifierExtension: Optional[FhirList[ExtensionBase]] = None,
        boundsDuration: Optional[Duration] = None,
        boundsRange: Optional[Range] = None,
        boundsPeriod: Optional[Period] = None,
        count: Optional[FhirPositiveInt] = None,
        countMax: Optional[FhirPositiveInt] = None,
        duration: Optional[FhirDecimal] = None,
        durationMax: Optional[FhirDecimal] = None,
        durationUnit: Optional[UnitsOfTimeCode] = None,
        frequency: Optional[FhirPositiveInt] = None,
        frequencyMax: Optional[FhirPositiveInt] = None,
        period: Optional[FhirDecimal] = None,
        periodMax: Optional[FhirDecimal] = None,
        periodUnit: Optional[UnitsOfTimeCode] = None,
        dayOfWeek: Optional[FhirList[DaysOfWeekCode]] = None,
        timeOfDay: Optional[FhirList[FhirTime]] = None,
        when: Optional[FhirList[EventTimingCode]] = None,
        offset: Optional[FhirUnsignedInt] = None,
    ) -> None:
        """
            Specifies an event that may occur multiple times. Timing schedules are used to
        record when things are planned, expected or requested to occur. The most
        common usage is in dosage instructions for medications. They are also used
        when planning care of various kinds, and may be used for reporting the
        schedule to which past regular activities were carried out.
            If the element is present, it must have a value for at least one of the
        defined elements, an @id referenced from the Narrative, or extensions

            :param id_: None
            :param extension: May be used to represent additional information that is not part of the basic
        definition of the element. To make the use of extensions safe and manageable,
        there is a strict set of governance  applied to the definition and use of
        extensions. Though any implementer can define an extension, there is a set of
        requirements that SHALL be met as part of the definition of the extension.
            :param modifierExtension: May be used to represent additional information that is not part of the basic
        definition of the element and that modifies the understanding of the element
        in which it is contained and/or the understanding of the containing element's
        descendants. Usually modifier elements provide negation or qualification. To
        make the use of extensions safe and manageable, there is a strict set of
        governance applied to the definition and use of extensions. Though any
        implementer can define an extension, there is a set of requirements that SHALL
        be met as part of the definition of the extension. Applications processing a
        resource are required to check for modifier extensions.

        Modifier extensions SHALL NOT change the meaning of any elements on Resource
        or DomainResource (including cannot change the meaning of modifierExtension
        itself).
            :param boundsDuration: None
            :param boundsRange: None
            :param boundsPeriod: None
            :param count: A total count of the desired number of repetitions across the duration of the
        entire timing specification. If countMax is present, this element indicates
        the lower bound of the allowed range of count values.
            :param countMax: If present, indicates that the count is a range - so to perform the action
        between [count] and [countMax] times.
            :param duration: How long this thing happens for when it happens. If durationMax is present,
        this element indicates the lower bound of the allowed range of the duration.
            :param durationMax: If present, indicates that the duration is a range - so to perform the action
        between [duration] and [durationMax] time length.
            :param durationUnit: The units of time for the duration, in UCUM units.
            :param frequency: The number of times to repeat the action within the specified period. If
        frequencyMax is present, this element indicates the lower bound of the allowed
        range of the frequency.
            :param frequencyMax: If present, indicates that the frequency is a range - so to repeat between
        [frequency] and [frequencyMax] times within the period or period range.
            :param period: Indicates the duration of time over which repetitions are to occur; e.g. to
        express "3 times per day", 3 would be the frequency and "1 day" would be the
        period. If periodMax is present, this element indicates the lower bound of the
        allowed range of the period length.
            :param periodMax: If present, indicates that the period is a range from [period] to [periodMax],
        allowing expressing concepts such as "do this once every 3-5 days.
            :param periodUnit: The units of time for the period in UCUM units.
            :param dayOfWeek: If one or more days of week is provided, then the action happens only on the
        specified day(s).
            :param timeOfDay: Specified time of day for action to take place.
            :param when: An approximate time period during the day, potentially linked to an event of
        daily living that indicates when the action should occur.
            :param offset: The number of minutes from the event. If the event code does not indicate
        whether the minutes is before or after the event, then the offset is assumed
        to be after the event.
        """
        super().__init__(
            id_=id_,
            extension=extension,
            modifierExtension=modifierExtension,
            boundsDuration=boundsDuration,
            boundsRange=boundsRange,
            boundsPeriod=boundsPeriod,
            count=count,
            countMax=countMax,
            duration=duration,
            durationMax=durationMax,
            durationUnit=durationUnit,
            frequency=frequency,
            frequencyMax=frequencyMax,
            period=period,
            periodMax=periodMax,
            periodUnit=periodUnit,
            dayOfWeek=dayOfWeek,
            timeOfDay=timeOfDay,
            when=when,
            offset=offset,
        )
