from __future__ import annotations
from typing import Optional, TYPE_CHECKING

from spark_auto_mapper_fhir.fhir_types.list import FhirList
from spark_auto_mapper_fhir.fhir_types.string import FhirString
from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase
from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.base_types.fhir_backbone_element_base import (
    FhirBackboneElementBase,
)

if TYPE_CHECKING:
    pass
    # id_ (string)
    # extension (Extension)
    # modifierExtension (Extension)
    # system (uri)
    # version (string)
    # concept (ValueSet.Concept)
    from spark_auto_mapper_fhir.backbone_elements.value_set_concept import (
        ValueSetConcept,
    )

    # filter (ValueSet.Filter)
    from spark_auto_mapper_fhir.backbone_elements.value_set_filter import ValueSetFilter

    # valueSet (canonical)
    from spark_auto_mapper_fhir.fhir_types.canonical import FhirCanonical


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class ValueSetInclude(FhirBackboneElementBase):
    """
    ValueSet.Include
        A ValueSet resource instance specifies a set of codes drawn from one or more code systems, intended for use in a particular context. Value sets link between [[[CodeSystem]]] definitions and their use in [coded elements](terminologies.html).
    """

    # noinspection PyPep8Naming
    def __init__(
        self,
        *,
        id_: Optional[FhirString] = None,
        extension: Optional[FhirList[ExtensionBase]] = None,
        modifierExtension: Optional[FhirList[ExtensionBase]] = None,
        system: Optional[FhirUri] = None,
        version: Optional[FhirString] = None,
        concept: Optional[FhirList[ValueSetConcept]] = None,
        filter: Optional[FhirList[ValueSetFilter]] = None,
        valueSet: Optional[FhirList[FhirCanonical]] = None,
    ) -> None:
        """
            A ValueSet resource instance specifies a set of codes drawn from one or more
        code systems, intended for use in a particular context. Value sets link
        between [[[CodeSystem]]] definitions and their use in [coded
        elements](terminologies.html).

            :param id_: None
            :param extension: May be used to represent additional information that is not part of the basic
        definition of the element. To make the use of extensions safe and manageable,
        there is a strict set of governance  applied to the definition and use of
        extensions. Though any implementer can define an extension, there is a set of
        requirements that SHALL be met as part of the definition of the extension.
            :param modifierExtension: May be used to represent additional information that is not part of the basic
        definition of the element and that modifies the understanding of the element
        in which it is contained and/or the understanding of the containing element's
        descendants. Usually modifier elements provide negation or qualification. To
        make the use of extensions safe and manageable, there is a strict set of
        governance applied to the definition and use of extensions. Though any
        implementer can define an extension, there is a set of requirements that SHALL
        be met as part of the definition of the extension. Applications processing a
        resource are required to check for modifier extensions.

        Modifier extensions SHALL NOT change the meaning of any elements on Resource
        or DomainResource (including cannot change the meaning of modifierExtension
        itself).
            :param system: An absolute URI which is the code system from which the selected codes come
        from.
            :param version: The version of the code system that the codes are selected from, or the
        special version '*' for all versions.
            :param concept: Specifies a concept to be included or excluded.
            :param filter: Select concepts by specify a matching criterion based on the properties
        (including relationships) defined by the system, or on filters defined by the
        system. If multiple filters are specified, they SHALL all be true.
            :param valueSet: Selects the concepts found in this value set (based on its value set
        definition). This is an absolute URI that is a reference to ValueSet.url.  If
        multiple value sets are specified this includes the union of the contents of
        all of the referenced value sets.
        """
        super().__init__(
            id_=id_,
            extension=extension,
            modifierExtension=modifierExtension,
            system=system,
            version=version,
            concept=concept,
            filter=filter,
            valueSet=valueSet,
        )
