from __future__ import annotations
from typing import Optional, TYPE_CHECKING, Union

from pyspark.sql.types import StructType, DataType
from spark_auto_mapper_fhir.fhir_types.list import FhirList
from spark_auto_mapper_fhir.fhir_types.string import FhirString

from spark_auto_mapper_fhir.extensions.custom.nested_extension_item import (
    NestedExtensionItem,
)

from spark_auto_mapper_fhir.base_types.fhir_complex_type_base import FhirComplexTypeBase
from spark_fhir_schemas.r4.complex_types.contactpoint import ContactPointSchema


if TYPE_CHECKING:
    pass
    # id_ (string)
    # extension (Extension)
    # system (ContactPointSystem)
    from spark_auto_mapper_fhir.value_sets.contact_point_system import (
        ContactPointSystemCode,
    )

    # value (string)
    # use (ContactPointUse)
    from spark_auto_mapper_fhir.value_sets.contact_point_use import ContactPointUseCode

    # rank (positiveInt)
    from spark_auto_mapper_fhir.fhir_types.positive_int import FhirPositiveInt

    # period (Period)
    from spark_auto_mapper_fhir.complex_types.period import Period


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class ContactPoint(FhirComplexTypeBase):
    """
    ContactPoint
    fhir-base.xsd
        Details for all kinds of technology mediated contact points for a person or organization, including telephone, email, etc.
        If the element is present, it must have a value for at least one of the defined elements, an @id referenced from the Narrative, or extensions
    """

    # noinspection PyPep8Naming
    def __init__(
        self,
        *,
        id_: Optional[FhirString] = None,
        extension: Optional[FhirList[NestedExtensionItem]] = None,
        system: Optional[ContactPointSystemCode] = None,
        value: Optional[FhirString] = None,
        use: Optional[ContactPointUseCode] = None,
        rank: Optional[FhirPositiveInt] = None,
        period: Optional[Period] = None,
    ) -> None:
        """
            Details for all kinds of technology mediated contact points for a person or
        organization, including telephone, email, etc.
            If the element is present, it must have a value for at least one of the
        defined elements, an @id referenced from the Narrative, or extensions

            :param id_: None
            :param extension: May be used to represent additional information that is not part of the basic
        definition of the element. To make the use of extensions safe and manageable,
        there is a strict set of governance  applied to the definition and use of
        extensions. Though any implementer can define an extension, there is a set of
        requirements that SHALL be met as part of the definition of the extension.
            :param system: Telecommunications form for contact point - what communications system is
        required to make use of the contact.
            :param value: The actual contact point details, in a form that is meaningful to the
        designated communication system (i.e. phone number or email address).
            :param use: Identifies the purpose for the contact point.
            :param rank: Specifies a preferred order in which to use a set of contacts. ContactPoints
        with lower rank values are more preferred than those with higher rank values.
            :param period: Time period when the contact point was/is in use.
        """
        super().__init__(
            id_=id_,
            extension=extension,
            system=system,
            value=value,
            use=use,
            rank=rank,
            period=period,
        )

    def get_schema(
        self, include_extension: bool
    ) -> Optional[Union[StructType, DataType]]:
        return ContactPointSchema.get_schema(include_extension=include_extension)
