from __future__ import annotations
from typing import Optional, TYPE_CHECKING, Union

from pyspark.sql.types import StructType, DataType
from spark_auto_mapper_fhir.fhir_types.list import FhirList
from spark_auto_mapper_fhir.fhir_types.string import FhirString

from spark_auto_mapper_fhir.extensions.custom.nested_extension_item import (
    NestedExtensionItem,
)

from spark_auto_mapper_fhir.base_types.fhir_complex_type_base import FhirComplexTypeBase
from spark_fhir_schemas.r4.complex_types.range import RangeSchema


if TYPE_CHECKING:
    pass
    # id_ (string)
    # extension (Extension)
    # low (Quantity)
    from spark_auto_mapper_fhir.complex_types.quantity import Quantity

    # high (Quantity)


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class Range(FhirComplexTypeBase):
    """
    Range
    fhir-base.xsd
        A set of ordered Quantities defined by a low and high limit.
        If the element is present, it must have a value for at least one of the defined elements, an @id referenced from the Narrative, or extensions
    """

    # noinspection PyPep8Naming
    def __init__(
        self,
        *,
        id_: Optional[FhirString] = None,
        extension: Optional[FhirList[NestedExtensionItem]] = None,
        low: Optional[Quantity] = None,
        high: Optional[Quantity] = None,
    ) -> None:
        """
            A set of ordered Quantities defined by a low and high limit.
            If the element is present, it must have a value for at least one of the
        defined elements, an @id referenced from the Narrative, or extensions

            :param id_: None
            :param extension: May be used to represent additional information that is not part of the basic
        definition of the element. To make the use of extensions safe and manageable,
        there is a strict set of governance  applied to the definition and use of
        extensions. Though any implementer can define an extension, there is a set of
        requirements that SHALL be met as part of the definition of the extension.
            :param low: The low limit. The boundary is inclusive.
            :param high: The high limit. The boundary is inclusive.
        """
        super().__init__(
            id_=id_,
            extension=extension,
            low=low,
            high=high,
        )

    def get_schema(
        self, include_extension: bool
    ) -> Optional[Union[StructType, DataType]]:
        return RangeSchema.get_schema(include_extension=include_extension)
