from __future__ import annotations
from typing import Optional, TYPE_CHECKING, Union

# noinspection PyPackageRequirements
from pyspark.sql.types import StructType, DataType
from spark_auto_mapper_fhir.fhir_types.list import FhirList
from spark_auto_mapper_fhir.fhir_types.string import FhirString
from spark_auto_mapper_fhir.complex_types.meta import Meta
from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase
from spark_auto_mapper_fhir.fhir_types.id import FhirId
from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.base_types.fhir_resource_base import FhirResourceBase
from spark_fhir_schemas.r4.resources.account import AccountSchema

if TYPE_CHECKING:
    pass
    # id_ (id)
    # meta (Meta)
    # implicitRules (uri)
    # language (CommonLanguages)
    from spark_auto_mapper_fhir.value_sets.common_languages import CommonLanguagesCode

    # text (Narrative)
    from spark_auto_mapper_fhir.complex_types.narrative import Narrative

    # contained (ResourceContainer)
    from spark_auto_mapper_fhir.complex_types.resource_container import (
        ResourceContainer,
    )

    # extension (Extension)
    # modifierExtension (Extension)
    # identifier (Identifier)
    from spark_auto_mapper_fhir.complex_types.identifier import Identifier

    # status (AccountStatus)
    from spark_auto_mapper_fhir.value_sets.account_status import AccountStatusCode

    # type_ (CodeableConcept)
    from spark_auto_mapper_fhir.complex_types.codeable_concept import CodeableConcept

    # Import for CodeableConcept for type_
    from spark_auto_mapper_fhir.value_sets.account_types import AccountTypesCode

    # End Import for CodeableConcept for type_
    # name (string)
    # subject (Reference)
    from spark_auto_mapper_fhir.complex_types.reference import Reference

    # Imports for References for subject
    from spark_auto_mapper_fhir.resources.patient import Patient
    from spark_auto_mapper_fhir.resources.device import Device
    from spark_auto_mapper_fhir.resources.practitioner import Practitioner
    from spark_auto_mapper_fhir.resources.practitioner_role import PractitionerRole
    from spark_auto_mapper_fhir.resources.location import Location
    from spark_auto_mapper_fhir.resources.healthcare_service import HealthcareService
    from spark_auto_mapper_fhir.resources.organization import Organization

    # servicePeriod (Period)
    from spark_auto_mapper_fhir.complex_types.period import Period

    # coverage (Account.Coverage)
    from spark_auto_mapper_fhir.backbone_elements.account_coverage import (
        AccountCoverage,
    )

    # owner (Reference)
    # Imports for References for owner
    # description (string)
    # guarantor (Account.Guarantor)
    from spark_auto_mapper_fhir.backbone_elements.account_guarantor import (
        AccountGuarantor,
    )

    # partOf (Reference)
    # Imports for References for partOf


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class Account(FhirResourceBase):
    """
    Account
    account.xsd
        A financial tool for tracking value accrued for a particular purpose.  In the
    healthcare field, used to track charges for a patient, cost centers, etc.
        If the element is present, it must have either a @value, an @id, or extensions
    """

    # noinspection PyPep8Naming
    def __init__(
        self,
        *,
        id_: Optional[FhirId] = None,
        meta: Optional[Meta] = None,
        implicitRules: Optional[FhirUri] = None,
        language: Optional[CommonLanguagesCode] = None,
        text: Optional[Narrative] = None,
        contained: Optional[FhirList[ResourceContainer]] = None,
        extension: Optional[FhirList[ExtensionBase]] = None,
        modifierExtension: Optional[FhirList[ExtensionBase]] = None,
        identifier: Optional[FhirList[Identifier]] = None,
        status: AccountStatusCode,
        type_: Optional[CodeableConcept[AccountTypesCode]] = None,
        name: Optional[FhirString] = None,
        subject: Optional[
            FhirList[
                Reference[
                    Union[
                        Patient,
                        Device,
                        Practitioner,
                        PractitionerRole,
                        Location,
                        HealthcareService,
                        Organization,
                    ]
                ]
            ]
        ] = None,
        servicePeriod: Optional[Period] = None,
        coverage: Optional[FhirList[AccountCoverage]] = None,
        owner: Optional[Reference[Organization]] = None,
        description: Optional[FhirString] = None,
        guarantor: Optional[FhirList[AccountGuarantor]] = None,
        partOf: Optional[Reference[Account]] = None,
    ) -> None:
        """
            A financial tool for tracking value accrued for a particular purpose.  In the
        healthcare field, used to track charges for a patient, cost centers, etc.
            If the element is present, it must have either a @value, an @id, or extensions

            :param id_: The logical id of the resource, as used in the URL for the resource. Once
        assigned, this value never changes.
            :param meta: The metadata about the resource. This is content that is maintained by the
        infrastructure. Changes to the content might not always be associated with
        version changes to the resource.
            :param implicitRules: A reference to a set of rules that were followed when the resource was
        constructed, and which must be understood when processing the content. Often,
        this is a reference to an implementation guide that defines the special rules
        along with other profiles etc.
            :param language: The base language in which the resource is written.
            :param text: A human-readable narrative that contains a summary of the resource and can be
        used to represent the content of the resource to a human. The narrative need
        not encode all the structured data, but is required to contain sufficient
        detail to make it "clinically safe" for a human to just read the narrative.
        Resource definitions may define what content should be represented in the
        narrative to ensure clinical safety.
            :param contained: These resources do not have an independent existence apart from the resource
        that contains them - they cannot be identified independently, and nor can they
        have their own independent transaction scope.
            :param extension: May be used to represent additional information that is not part of the basic
        definition of the resource. To make the use of extensions safe and manageable,
        there is a strict set of governance  applied to the definition and use of
        extensions. Though any implementer can define an extension, there is a set of
        requirements that SHALL be met as part of the definition of the extension.
            :param modifierExtension: May be used to represent additional information that is not part of the basic
        definition of the resource and that modifies the understanding of the element
        that contains it and/or the understanding of the containing element's
        descendants. Usually modifier elements provide negation or qualification. To
        make the use of extensions safe and manageable, there is a strict set of
        governance applied to the definition and use of extensions. Though any
        implementer is allowed to define an extension, there is a set of requirements
        that SHALL be met as part of the definition of the extension. Applications
        processing a resource are required to check for modifier extensions.

        Modifier extensions SHALL NOT change the meaning of any elements on Resource
        or DomainResource (including cannot change the meaning of modifierExtension
        itself).
            :param identifier: Unique identifier used to reference the account.  Might or might not be
        intended for human use (e.g. credit card number).
            :param status: Indicates whether the account is presently used/usable or not.
            :param type_: Categorizes the account for reporting and searching purposes.
            :param name: Name used for the account when displaying it to humans in reports, etc.
            :param subject: Identifies the entity which incurs the expenses. While the immediate
        recipients of services or goods might be entities related to the subject, the
        expenses were ultimately incurred by the subject of the Account.
            :param servicePeriod: The date range of services associated with this account.
            :param coverage: The party(s) that are responsible for covering the payment of this account,
        and what order should they be applied to the account.
            :param owner: Indicates the service area, hospital, department, etc. with responsibility for
        managing the Account.
            :param description: Provides additional information about what the account tracks and how it is
        used.
            :param guarantor: The parties responsible for balancing the account if other payment options
        fall short.
            :param partOf: Reference to a parent Account.
        """
        super().__init__(
            resourceType="Account",
            id_=id_,
            meta=meta,
            implicitRules=implicitRules,
            language=language,
            text=text,
            contained=contained,
            extension=extension,
            modifierExtension=modifierExtension,
            identifier=identifier,
            status=status,
            type_=type_,
            name=name,
            subject=subject,
            servicePeriod=servicePeriod,
            coverage=coverage,
            owner=owner,
            description=description,
            guarantor=guarantor,
            partOf=partOf,
        )

    def get_schema(
        self, include_extension: bool
    ) -> Optional[Union[StructType, DataType]]:
        return AccountSchema.get_schema(include_extension=include_extension)
