from __future__ import annotations
from typing import Optional, TYPE_CHECKING, Union

# noinspection PyPackageRequirements
from pyspark.sql.types import StructType, DataType
from spark_auto_mapper_fhir.fhir_types.date_time import FhirDateTime
from spark_auto_mapper_fhir.fhir_types.list import FhirList
from spark_auto_mapper_fhir.fhir_types.string import FhirString
from spark_auto_mapper_fhir.complex_types.meta import Meta
from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase
from spark_auto_mapper_fhir.fhir_types.id import FhirId
from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.base_types.fhir_resource_base import FhirResourceBase
from spark_fhir_schemas.r4.resources.allergyintolerance import AllergyIntoleranceSchema

if TYPE_CHECKING:
    pass
    # id_ (id)
    # meta (Meta)
    # implicitRules (uri)
    # language (CommonLanguages)
    from spark_auto_mapper_fhir.value_sets.common_languages import CommonLanguagesCode

    # text (Narrative)
    from spark_auto_mapper_fhir.complex_types.narrative import Narrative

    # contained (ResourceContainer)
    from spark_auto_mapper_fhir.complex_types.resource_container import (
        ResourceContainer,
    )

    # extension (Extension)
    # modifierExtension (Extension)
    # identifier (Identifier)
    from spark_auto_mapper_fhir.complex_types.identifier import Identifier

    # clinicalStatus (CodeableConcept)
    from spark_auto_mapper_fhir.complex_types.codeable_concept import CodeableConcept

    # Import for CodeableConcept for clinicalStatus
    from spark_auto_mapper_fhir.value_sets.allergy_intolerance_clinical_status_codes import (
        AllergyIntoleranceClinicalStatusCodesCode,
    )

    # End Import for CodeableConcept for clinicalStatus
    # verificationStatus (CodeableConcept)
    # Import for CodeableConcept for verificationStatus
    from spark_auto_mapper_fhir.value_sets.allergy_intolerance_verification_status_codes import (
        AllergyIntoleranceVerificationStatusCodesCode,
    )

    # End Import for CodeableConcept for verificationStatus
    # type_ (AllergyIntoleranceType)
    from spark_auto_mapper_fhir.value_sets.allergy_intolerance_type import (
        AllergyIntoleranceTypeCode,
    )

    # category (AllergyIntoleranceCategory)
    from spark_auto_mapper_fhir.value_sets.allergy_intolerance_category import (
        AllergyIntoleranceCategoryCode,
    )

    # criticality (AllergyIntoleranceCriticality)
    from spark_auto_mapper_fhir.value_sets.allergy_intolerance_criticality import (
        AllergyIntoleranceCriticalityCode,
    )

    # code (CodeableConcept)
    # Import for CodeableConcept for code
    from spark_auto_mapper_fhir.value_sets.allergy_intolerance_substance_or__product__condition_and_negation_codes import (
        AllergyIntoleranceSubstance_or_Product_ConditionAndNegationCodesCode,
    )

    # End Import for CodeableConcept for code
    # patient (Reference)
    from spark_auto_mapper_fhir.complex_types.reference import Reference

    # Imports for References for patient
    from spark_auto_mapper_fhir.resources.patient import Patient

    # encounter (Reference)
    # Imports for References for encounter
    from spark_auto_mapper_fhir.resources.encounter import Encounter

    # onsetDateTime (dateTime)
    # onsetAge (Age)
    from spark_auto_mapper_fhir.complex_types.age import Age

    # onsetPeriod (Period)
    from spark_auto_mapper_fhir.complex_types.period import Period

    # onsetRange (Range)
    from spark_auto_mapper_fhir.complex_types.range import Range

    # onsetString (string)
    # recordedDate (dateTime)
    # recorder (Reference)
    # Imports for References for recorder
    from spark_auto_mapper_fhir.resources.practitioner import Practitioner
    from spark_auto_mapper_fhir.resources.practitioner_role import PractitionerRole
    from spark_auto_mapper_fhir.resources.related_person import RelatedPerson

    # asserter (Reference)
    # Imports for References for asserter
    # lastOccurrence (dateTime)
    # note (Annotation)
    from spark_auto_mapper_fhir.complex_types.annotation import Annotation

    # reaction (AllergyIntolerance.Reaction)
    from spark_auto_mapper_fhir.backbone_elements.allergy_intolerance_reaction import (
        AllergyIntoleranceReaction,
    )


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class AllergyIntolerance(FhirResourceBase):
    """
    AllergyIntolerance
    allergyintolerance.xsd
        Risk of harmful or undesirable, physiological response which is unique to an
    individual and associated with exposure to a substance.
        If the element is present, it must have either a @value, an @id, or extensions
    """

    # noinspection PyPep8Naming
    def __init__(
        self,
        *,
        id_: Optional[FhirId] = None,
        meta: Optional[Meta] = None,
        implicitRules: Optional[FhirUri] = None,
        language: Optional[CommonLanguagesCode] = None,
        text: Optional[Narrative] = None,
        contained: Optional[FhirList[ResourceContainer]] = None,
        extension: Optional[FhirList[ExtensionBase]] = None,
        modifierExtension: Optional[FhirList[ExtensionBase]] = None,
        identifier: Optional[FhirList[Identifier]] = None,
        clinicalStatus: Optional[
            CodeableConcept[AllergyIntoleranceClinicalStatusCodesCode]
        ] = None,
        verificationStatus: Optional[
            CodeableConcept[AllergyIntoleranceVerificationStatusCodesCode]
        ] = None,
        type_: Optional[AllergyIntoleranceTypeCode] = None,
        category: Optional[FhirList[AllergyIntoleranceCategoryCode]] = None,
        criticality: Optional[AllergyIntoleranceCriticalityCode] = None,
        code: Optional[
            CodeableConcept[
                AllergyIntoleranceSubstance_or_Product_ConditionAndNegationCodesCode
            ]
        ] = None,
        patient: Reference[Patient],
        encounter: Optional[Reference[Encounter]] = None,
        onsetDateTime: Optional[FhirDateTime] = None,
        onsetAge: Optional[Age] = None,
        onsetPeriod: Optional[Period] = None,
        onsetRange: Optional[Range] = None,
        onsetString: Optional[FhirString] = None,
        recordedDate: Optional[FhirDateTime] = None,
        recorder: Optional[
            Reference[Union[Practitioner, PractitionerRole, Patient, RelatedPerson]]
        ] = None,
        asserter: Optional[
            Reference[Union[Patient, RelatedPerson, Practitioner, PractitionerRole]]
        ] = None,
        lastOccurrence: Optional[FhirDateTime] = None,
        note: Optional[FhirList[Annotation]] = None,
        reaction: Optional[FhirList[AllergyIntoleranceReaction]] = None,
    ) -> None:
        """
            Risk of harmful or undesirable, physiological response which is unique to an
        individual and associated with exposure to a substance.
            If the element is present, it must have either a @value, an @id, or extensions

            :param id_: The logical id of the resource, as used in the URL for the resource. Once
        assigned, this value never changes.
            :param meta: The metadata about the resource. This is content that is maintained by the
        infrastructure. Changes to the content might not always be associated with
        version changes to the resource.
            :param implicitRules: A reference to a set of rules that were followed when the resource was
        constructed, and which must be understood when processing the content. Often,
        this is a reference to an implementation guide that defines the special rules
        along with other profiles etc.
            :param language: The base language in which the resource is written.
            :param text: A human-readable narrative that contains a summary of the resource and can be
        used to represent the content of the resource to a human. The narrative need
        not encode all the structured data, but is required to contain sufficient
        detail to make it "clinically safe" for a human to just read the narrative.
        Resource definitions may define what content should be represented in the
        narrative to ensure clinical safety.
            :param contained: These resources do not have an independent existence apart from the resource
        that contains them - they cannot be identified independently, and nor can they
        have their own independent transaction scope.
            :param extension: May be used to represent additional information that is not part of the basic
        definition of the resource. To make the use of extensions safe and manageable,
        there is a strict set of governance  applied to the definition and use of
        extensions. Though any implementer can define an extension, there is a set of
        requirements that SHALL be met as part of the definition of the extension.
            :param modifierExtension: May be used to represent additional information that is not part of the basic
        definition of the resource and that modifies the understanding of the element
        that contains it and/or the understanding of the containing element's
        descendants. Usually modifier elements provide negation or qualification. To
        make the use of extensions safe and manageable, there is a strict set of
        governance applied to the definition and use of extensions. Though any
        implementer is allowed to define an extension, there is a set of requirements
        that SHALL be met as part of the definition of the extension. Applications
        processing a resource are required to check for modifier extensions.

        Modifier extensions SHALL NOT change the meaning of any elements on Resource
        or DomainResource (including cannot change the meaning of modifierExtension
        itself).
            :param identifier: Business identifiers assigned to this AllergyIntolerance by the performer or
        other systems which remain constant as the resource is updated and propagates
        from server to server.
            :param clinicalStatus: The clinical status of the allergy or intolerance.
            :param verificationStatus: Assertion about certainty associated with the propensity, or potential risk,
        of a reaction to the identified substance (including pharmaceutical product).
            :param type_: Identification of the underlying physiological mechanism for the reaction
        risk.
            :param category: Category of the identified substance.
            :param criticality: Estimate of the potential clinical harm, or seriousness, of the reaction to
        the identified substance.
            :param code: Code for an allergy or intolerance statement (either a positive or a
        negated/excluded statement).  This may be a code for a substance or
        pharmaceutical product that is considered to be responsible for the adverse
        reaction risk (e.g., "Latex"), an allergy or intolerance condition (e.g.,
        "Latex allergy"), or a negated/excluded code for a specific substance or class
        (e.g., "No latex allergy") or a general or categorical negated statement
        (e.g.,  "No known allergy", "No known drug allergies").  Note: the substance
        for a specific reaction may be different from the substance identified as the
        cause of the risk, but it must be consistent with it. For instance, it may be
        a more specific substance (e.g. a brand medication) or a composite product
        that includes the identified substance. It must be clinically safe to only
        process the 'code' and ignore the 'reaction.substance'.  If a receiving system
        is unable to confirm that AllergyIntolerance.reaction.substance falls within
        the semantic scope of AllergyIntolerance.code, then the receiving system
        should ignore AllergyIntolerance.reaction.substance.
            :param patient: The patient who has the allergy or intolerance.
            :param encounter: The encounter when the allergy or intolerance was asserted.
            :param onsetDateTime: None
            :param onsetAge: None
            :param onsetPeriod: None
            :param onsetRange: None
            :param onsetString: None
            :param recordedDate: The recordedDate represents when this particular AllergyIntolerance record was
        created in the system, which is often a system-generated date.
            :param recorder: Individual who recorded the record and takes responsibility for its content.
            :param asserter: The source of the information about the allergy that is recorded.
            :param lastOccurrence: Represents the date and/or time of the last known occurrence of a reaction
        event.
            :param note: Additional narrative about the propensity for the Adverse Reaction, not
        captured in other fields.
            :param reaction: Details about each adverse reaction event linked to exposure to the identified
        substance.
        """
        super().__init__(
            resourceType="AllergyIntolerance",
            id_=id_,
            meta=meta,
            implicitRules=implicitRules,
            language=language,
            text=text,
            contained=contained,
            extension=extension,
            modifierExtension=modifierExtension,
            identifier=identifier,
            clinicalStatus=clinicalStatus,
            verificationStatus=verificationStatus,
            type_=type_,
            category=category,
            criticality=criticality,
            code=code,
            patient=patient,
            encounter=encounter,
            onsetDateTime=onsetDateTime,
            onsetAge=onsetAge,
            onsetPeriod=onsetPeriod,
            onsetRange=onsetRange,
            onsetString=onsetString,
            recordedDate=recordedDate,
            recorder=recorder,
            asserter=asserter,
            lastOccurrence=lastOccurrence,
            note=note,
            reaction=reaction,
        )

    def get_schema(
        self, include_extension: bool
    ) -> Optional[Union[StructType, DataType]]:
        return AllergyIntoleranceSchema.get_schema(include_extension=include_extension)
