from __future__ import annotations
from typing import Optional, TYPE_CHECKING, Union

# noinspection PyPackageRequirements
from pyspark.sql.types import StructType, DataType
from spark_auto_mapper_fhir.fhir_types.date import FhirDate
from spark_auto_mapper_fhir.fhir_types.date_time import FhirDateTime
from spark_auto_mapper_fhir.fhir_types.list import FhirList
from spark_auto_mapper_fhir.fhir_types.string import FhirString
from spark_auto_mapper_fhir.complex_types.meta import Meta
from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase
from spark_auto_mapper_fhir.fhir_types.id import FhirId
from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.base_types.fhir_resource_base import FhirResourceBase
from spark_fhir_schemas.r4.resources.coverageeligibilityresponse import (
    CoverageEligibilityResponseSchema,
)

if TYPE_CHECKING:
    pass
    # id_ (id)
    # meta (Meta)
    # implicitRules (uri)
    # language (CommonLanguages)
    from spark_auto_mapper_fhir.value_sets.common_languages import CommonLanguagesCode

    # text (Narrative)
    from spark_auto_mapper_fhir.complex_types.narrative import Narrative

    # contained (ResourceContainer)
    from spark_auto_mapper_fhir.complex_types.resource_container import (
        ResourceContainer,
    )

    # extension (Extension)
    # modifierExtension (Extension)
    # identifier (Identifier)
    from spark_auto_mapper_fhir.complex_types.identifier import Identifier

    # status (FinancialResourceStatusCodes)
    from spark_auto_mapper_fhir.value_sets.financial_resource_status_codes import (
        FinancialResourceStatusCodesCode,
    )

    # purpose (EligibilityResponsePurpose)
    from spark_auto_mapper_fhir.value_sets.eligibility_response_purpose import (
        EligibilityResponsePurposeCode,
    )

    # patient (Reference)
    from spark_auto_mapper_fhir.complex_types.reference import Reference

    # Imports for References for patient
    from spark_auto_mapper_fhir.resources.patient import Patient

    # servicedDate (date)
    # servicedPeriod (Period)
    from spark_auto_mapper_fhir.complex_types.period import Period

    # created (dateTime)
    # requestor (Reference)
    # Imports for References for requestor
    from spark_auto_mapper_fhir.resources.practitioner import Practitioner
    from spark_auto_mapper_fhir.resources.practitioner_role import PractitionerRole
    from spark_auto_mapper_fhir.resources.organization import Organization

    # request (Reference)
    # Imports for References for request
    from spark_auto_mapper_fhir.resources.coverage_eligibility_request import (
        CoverageEligibilityRequest,
    )

    # outcome (ClaimProcessingCodes)
    from spark_auto_mapper_fhir.value_sets.claim_processing_codes import (
        ClaimProcessingCodesCode,
    )

    # disposition (string)
    # insurer (Reference)
    # Imports for References for insurer
    # insurance (CoverageEligibilityResponse.Insurance)
    from spark_auto_mapper_fhir.backbone_elements.coverage_eligibility_response_insurance import (
        CoverageEligibilityResponseInsurance,
    )

    # preAuthRef (string)
    # form (CodeableConcept)
    from spark_auto_mapper_fhir.complex_types.codeable_concept import CodeableConcept

    # Import for CodeableConcept for form
    from spark_auto_mapper_fhir.value_sets.form_codes import FormCodesCode

    # End Import for CodeableConcept for form
    # error (CoverageEligibilityResponse.Error)
    from spark_auto_mapper_fhir.backbone_elements.coverage_eligibility_response_error import (
        CoverageEligibilityResponseError,
    )


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class CoverageEligibilityResponse(FhirResourceBase):
    """
    CoverageEligibilityResponse
    coverageeligibilityresponse.xsd
        This resource provides eligibility and plan details from the processing of an
    CoverageEligibilityRequest resource.
        If the element is present, it must have either a @value, an @id, or extensions
    """

    # noinspection PyPep8Naming
    def __init__(
        self,
        *,
        id_: Optional[FhirId] = None,
        meta: Optional[Meta] = None,
        implicitRules: Optional[FhirUri] = None,
        language: Optional[CommonLanguagesCode] = None,
        text: Optional[Narrative] = None,
        contained: Optional[FhirList[ResourceContainer]] = None,
        extension: Optional[FhirList[ExtensionBase]] = None,
        modifierExtension: Optional[FhirList[ExtensionBase]] = None,
        identifier: Optional[FhirList[Identifier]] = None,
        status: FinancialResourceStatusCodesCode,
        purpose: FhirList[EligibilityResponsePurposeCode],
        patient: Reference[Patient],
        servicedDate: Optional[FhirDate] = None,
        servicedPeriod: Optional[Period] = None,
        created: FhirDateTime,
        requestor: Optional[
            Reference[Union[Practitioner, PractitionerRole, Organization]]
        ] = None,
        request: Reference[CoverageEligibilityRequest],
        outcome: ClaimProcessingCodesCode,
        disposition: Optional[FhirString] = None,
        insurer: Reference[Organization],
        insurance: Optional[FhirList[CoverageEligibilityResponseInsurance]] = None,
        preAuthRef: Optional[FhirString] = None,
        form: Optional[CodeableConcept[FormCodesCode]] = None,
        error: Optional[FhirList[CoverageEligibilityResponseError]] = None,
    ) -> None:
        """
            This resource provides eligibility and plan details from the processing of an
        CoverageEligibilityRequest resource.
            If the element is present, it must have either a @value, an @id, or extensions

            :param id_: The logical id of the resource, as used in the URL for the resource. Once
        assigned, this value never changes.
            :param meta: The metadata about the resource. This is content that is maintained by the
        infrastructure. Changes to the content might not always be associated with
        version changes to the resource.
            :param implicitRules: A reference to a set of rules that were followed when the resource was
        constructed, and which must be understood when processing the content. Often,
        this is a reference to an implementation guide that defines the special rules
        along with other profiles etc.
            :param language: The base language in which the resource is written.
            :param text: A human-readable narrative that contains a summary of the resource and can be
        used to represent the content of the resource to a human. The narrative need
        not encode all the structured data, but is required to contain sufficient
        detail to make it "clinically safe" for a human to just read the narrative.
        Resource definitions may define what content should be represented in the
        narrative to ensure clinical safety.
            :param contained: These resources do not have an independent existence apart from the resource
        that contains them - they cannot be identified independently, and nor can they
        have their own independent transaction scope.
            :param extension: May be used to represent additional information that is not part of the basic
        definition of the resource. To make the use of extensions safe and manageable,
        there is a strict set of governance  applied to the definition and use of
        extensions. Though any implementer can define an extension, there is a set of
        requirements that SHALL be met as part of the definition of the extension.
            :param modifierExtension: May be used to represent additional information that is not part of the basic
        definition of the resource and that modifies the understanding of the element
        that contains it and/or the understanding of the containing element's
        descendants. Usually modifier elements provide negation or qualification. To
        make the use of extensions safe and manageable, there is a strict set of
        governance applied to the definition and use of extensions. Though any
        implementer is allowed to define an extension, there is a set of requirements
        that SHALL be met as part of the definition of the extension. Applications
        processing a resource are required to check for modifier extensions.

        Modifier extensions SHALL NOT change the meaning of any elements on Resource
        or DomainResource (including cannot change the meaning of modifierExtension
        itself).
            :param identifier: A unique identifier assigned to this coverage eligiblity request.
            :param status: The status of the resource instance.
            :param purpose: Code to specify whether requesting: prior authorization requirements for some
        service categories or billing codes; benefits for coverages specified or
        discovered; discovery and return of coverages for the patient; and/or
        validation that the specified coverage is in-force at the date/period
        specified or 'now' if not specified.
            :param patient: The party who is the beneficiary of the supplied coverage and for whom
        eligibility is sought.
            :param servicedDate: None
            :param servicedPeriod: None
            :param created: The date this resource was created.
            :param requestor: The provider which is responsible for the request.
            :param request: Reference to the original request resource.
            :param outcome: The outcome of the request processing.
            :param disposition: A human readable description of the status of the adjudication.
            :param insurer: The Insurer who issued the coverage in question and is the author of the
        response.
            :param insurance: Financial instruments for reimbursement for the health care products and
        services.
            :param preAuthRef: A reference from the Insurer to which these services pertain to be used on
        further communication and as proof that the request occurred.
            :param form: A code for the form to be used for printing the content.
            :param error: Errors encountered during the processing of the request.
        """
        super().__init__(
            resourceType="CoverageEligibilityResponse",
            id_=id_,
            meta=meta,
            implicitRules=implicitRules,
            language=language,
            text=text,
            contained=contained,
            extension=extension,
            modifierExtension=modifierExtension,
            identifier=identifier,
            status=status,
            purpose=purpose,
            patient=patient,
            servicedDate=servicedDate,
            servicedPeriod=servicedPeriod,
            created=created,
            requestor=requestor,
            request=request,
            outcome=outcome,
            disposition=disposition,
            insurer=insurer,
            insurance=insurance,
            preAuthRef=preAuthRef,
            form=form,
            error=error,
        )

    def get_schema(
        self, include_extension: bool
    ) -> Optional[Union[StructType, DataType]]:
        return CoverageEligibilityResponseSchema.get_schema(
            include_extension=include_extension
        )
