from __future__ import annotations
from typing import Optional, TYPE_CHECKING, Union

# noinspection PyPackageRequirements
from pyspark.sql.types import StructType, DataType
from spark_auto_mapper_fhir.fhir_types.date_time import FhirDateTime
from spark_auto_mapper_fhir.fhir_types.list import FhirList
from spark_auto_mapper_fhir.fhir_types.string import FhirString
from spark_auto_mapper_fhir.complex_types.meta import Meta
from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase
from spark_auto_mapper_fhir.fhir_types.id import FhirId
from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.base_types.fhir_resource_base import FhirResourceBase
from spark_fhir_schemas.r4.resources.immunizationevaluation import (
    ImmunizationEvaluationSchema,
)

if TYPE_CHECKING:
    pass
    # id_ (id)
    # meta (Meta)
    # implicitRules (uri)
    # language (CommonLanguages)
    from spark_auto_mapper_fhir.value_sets.common_languages import CommonLanguagesCode

    # text (Narrative)
    from spark_auto_mapper_fhir.complex_types.narrative import Narrative

    # contained (ResourceContainer)
    from spark_auto_mapper_fhir.complex_types.resource_container import (
        ResourceContainer,
    )

    # extension (Extension)
    # modifierExtension (Extension)
    # identifier (Identifier)
    from spark_auto_mapper_fhir.complex_types.identifier import Identifier

    # status (ImmunizationEvaluationStatusCodes)
    from spark_auto_mapper_fhir.value_sets.immunization_evaluation_status_codes import (
        ImmunizationEvaluationStatusCodesCode,
    )

    # patient (Reference)
    from spark_auto_mapper_fhir.complex_types.reference import Reference

    # Imports for References for patient
    from spark_auto_mapper_fhir.resources.patient import Patient

    # date (dateTime)
    # authority (Reference)
    # Imports for References for authority
    from spark_auto_mapper_fhir.resources.organization import Organization

    # targetDisease (CodeableConcept)
    from spark_auto_mapper_fhir.complex_types.codeable_concept import CodeableConcept

    # Import for CodeableConcept for targetDisease
    from spark_auto_mapper_fhir.value_sets.immunization_evaluation_target_disease_codes import (
        ImmunizationEvaluationTargetDiseaseCodesCode,
    )

    # End Import for CodeableConcept for targetDisease
    # immunizationEvent (Reference)
    # Imports for References for immunizationEvent
    from spark_auto_mapper_fhir.resources.immunization import Immunization

    # doseStatus (CodeableConcept)
    # Import for CodeableConcept for doseStatus
    from spark_auto_mapper_fhir.value_sets.immunization_evaluation_dose_status_codes import (
        ImmunizationEvaluationDoseStatusCodesCode,
    )

    # End Import for CodeableConcept for doseStatus
    # doseStatusReason (CodeableConcept)
    # Import for CodeableConcept for doseStatusReason
    from spark_auto_mapper_fhir.value_sets.immunization_evaluation_dose_status_reason_codes import (
        ImmunizationEvaluationDoseStatusReasonCodesCode,
    )

    # End Import for CodeableConcept for doseStatusReason
    # description (string)
    # series (string)
    # doseNumberPositiveInt (positiveInt)
    from spark_auto_mapper_fhir.fhir_types.positive_int import FhirPositiveInt

    # doseNumberString (string)
    # seriesDosesPositiveInt (positiveInt)
    # seriesDosesString (string)


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class ImmunizationEvaluation(FhirResourceBase):
    """
    ImmunizationEvaluation
    immunizationevaluation.xsd
        Describes a comparison of an immunization event against published
    recommendations to determine if the administration is "valid" in relation to
    those  recommendations.
        If the element is present, it must have either a @value, an @id, or extensions
    """

    # noinspection PyPep8Naming
    def __init__(
        self,
        *,
        id_: Optional[FhirId] = None,
        meta: Optional[Meta] = None,
        implicitRules: Optional[FhirUri] = None,
        language: Optional[CommonLanguagesCode] = None,
        text: Optional[Narrative] = None,
        contained: Optional[FhirList[ResourceContainer]] = None,
        extension: Optional[FhirList[ExtensionBase]] = None,
        modifierExtension: Optional[FhirList[ExtensionBase]] = None,
        identifier: Optional[FhirList[Identifier]] = None,
        status: ImmunizationEvaluationStatusCodesCode,
        patient: Reference[Patient],
        date: Optional[FhirDateTime] = None,
        authority: Optional[Reference[Organization]] = None,
        targetDisease: CodeableConcept[ImmunizationEvaluationTargetDiseaseCodesCode],
        immunizationEvent: Reference[Immunization],
        doseStatus: CodeableConcept[ImmunizationEvaluationDoseStatusCodesCode],
        doseStatusReason: Optional[
            FhirList[CodeableConcept[ImmunizationEvaluationDoseStatusReasonCodesCode]]
        ] = None,
        description: Optional[FhirString] = None,
        series: Optional[FhirString] = None,
        doseNumberPositiveInt: Optional[FhirPositiveInt] = None,
        doseNumberString: Optional[FhirString] = None,
        seriesDosesPositiveInt: Optional[FhirPositiveInt] = None,
        seriesDosesString: Optional[FhirString] = None,
    ) -> None:
        """
            Describes a comparison of an immunization event against published
        recommendations to determine if the administration is "valid" in relation to
        those  recommendations.
            If the element is present, it must have either a @value, an @id, or extensions

            :param id_: The logical id of the resource, as used in the URL for the resource. Once
        assigned, this value never changes.
            :param meta: The metadata about the resource. This is content that is maintained by the
        infrastructure. Changes to the content might not always be associated with
        version changes to the resource.
            :param implicitRules: A reference to a set of rules that were followed when the resource was
        constructed, and which must be understood when processing the content. Often,
        this is a reference to an implementation guide that defines the special rules
        along with other profiles etc.
            :param language: The base language in which the resource is written.
            :param text: A human-readable narrative that contains a summary of the resource and can be
        used to represent the content of the resource to a human. The narrative need
        not encode all the structured data, but is required to contain sufficient
        detail to make it "clinically safe" for a human to just read the narrative.
        Resource definitions may define what content should be represented in the
        narrative to ensure clinical safety.
            :param contained: These resources do not have an independent existence apart from the resource
        that contains them - they cannot be identified independently, and nor can they
        have their own independent transaction scope.
            :param extension: May be used to represent additional information that is not part of the basic
        definition of the resource. To make the use of extensions safe and manageable,
        there is a strict set of governance  applied to the definition and use of
        extensions. Though any implementer can define an extension, there is a set of
        requirements that SHALL be met as part of the definition of the extension.
            :param modifierExtension: May be used to represent additional information that is not part of the basic
        definition of the resource and that modifies the understanding of the element
        that contains it and/or the understanding of the containing element's
        descendants. Usually modifier elements provide negation or qualification. To
        make the use of extensions safe and manageable, there is a strict set of
        governance applied to the definition and use of extensions. Though any
        implementer is allowed to define an extension, there is a set of requirements
        that SHALL be met as part of the definition of the extension. Applications
        processing a resource are required to check for modifier extensions.

        Modifier extensions SHALL NOT change the meaning of any elements on Resource
        or DomainResource (including cannot change the meaning of modifierExtension
        itself).
            :param identifier: A unique identifier assigned to this immunization evaluation record.
            :param status: Indicates the current status of the evaluation of the vaccination
        administration event.
            :param patient: The individual for whom the evaluation is being done.
            :param date: The date the evaluation of the vaccine administration event was performed.
            :param authority: Indicates the authority who published the protocol (e.g. ACIP).
            :param targetDisease: The vaccine preventable disease the dose is being evaluated against.
            :param immunizationEvent: The vaccine administration event being evaluated.
            :param doseStatus: Indicates if the dose is valid or not valid with respect to the published
        recommendations.
            :param doseStatusReason: Provides an explanation as to why the vaccine administration event is valid or
        not relative to the published recommendations.
            :param description: Additional information about the evaluation.
            :param series: One possible path to achieve presumed immunity against a disease - within the
        context of an authority.
            :param doseNumberPositiveInt: None
            :param doseNumberString: None
            :param seriesDosesPositiveInt: None
            :param seriesDosesString: None
        """
        super().__init__(
            resourceType="ImmunizationEvaluation",
            id_=id_,
            meta=meta,
            implicitRules=implicitRules,
            language=language,
            text=text,
            contained=contained,
            extension=extension,
            modifierExtension=modifierExtension,
            identifier=identifier,
            status=status,
            patient=patient,
            date=date,
            authority=authority,
            targetDisease=targetDisease,
            immunizationEvent=immunizationEvent,
            doseStatus=doseStatus,
            doseStatusReason=doseStatusReason,
            description=description,
            series=series,
            doseNumberPositiveInt=doseNumberPositiveInt,
            doseNumberString=doseNumberString,
            seriesDosesPositiveInt=seriesDosesPositiveInt,
            seriesDosesString=seriesDosesString,
        )

    def get_schema(
        self, include_extension: bool
    ) -> Optional[Union[StructType, DataType]]:
        return ImmunizationEvaluationSchema.get_schema(
            include_extension=include_extension
        )
