from __future__ import annotations
from typing import Optional, TYPE_CHECKING, Union

# noinspection PyPackageRequirements
from pyspark.sql.types import StructType, DataType
from spark_auto_mapper_fhir.fhir_types.list import FhirList
from spark_auto_mapper_fhir.complex_types.meta import Meta
from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase
from spark_auto_mapper_fhir.fhir_types.id import FhirId
from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.base_types.fhir_resource_base import FhirResourceBase
from spark_fhir_schemas.r4.resources.medication import MedicationSchema

if TYPE_CHECKING:
    pass
    # id_ (id)
    # meta (Meta)
    # implicitRules (uri)
    # language (CommonLanguages)
    from spark_auto_mapper_fhir.value_sets.common_languages import CommonLanguagesCode

    # text (Narrative)
    from spark_auto_mapper_fhir.complex_types.narrative import Narrative

    # contained (ResourceContainer)
    from spark_auto_mapper_fhir.complex_types.resource_container import (
        ResourceContainer,
    )

    # extension (Extension)
    # modifierExtension (Extension)
    # identifier (Identifier)
    from spark_auto_mapper_fhir.complex_types.identifier import Identifier

    # code (CodeableConcept)
    from spark_auto_mapper_fhir.complex_types.codeable_concept import CodeableConcept

    # Import for CodeableConcept for code
    from spark_auto_mapper_fhir.value_sets.snomedct_medication_codes import (
        SNOMEDCTMedicationCodesCode,
    )

    # End Import for CodeableConcept for code
    # status (Medication Status Codes)
    from spark_auto_mapper_fhir.value_sets.medication_status_codes import (
        MedicationStatusCodesCode,
    )

    # manufacturer (Reference)
    from spark_auto_mapper_fhir.complex_types.reference import Reference

    # Imports for References for manufacturer
    from spark_auto_mapper_fhir.resources.organization import Organization

    # form (CodeableConcept)
    # Import for CodeableConcept for form
    from spark_auto_mapper_fhir.value_sets.snomedct_form_codes import (
        SNOMEDCTFormCodesCode,
    )

    # End Import for CodeableConcept for form
    # amount (Ratio)
    from spark_auto_mapper_fhir.complex_types.ratio import Ratio

    # ingredient (Medication.Ingredient)
    from spark_auto_mapper_fhir.backbone_elements.medication_ingredient import (
        MedicationIngredient,
    )

    # batch (Medication.Batch)
    from spark_auto_mapper_fhir.backbone_elements.medication_batch import (
        MedicationBatch,
    )


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class Medication(FhirResourceBase):
    """
    Medication
    medication.xsd
        This resource is primarily used for the identification and definition of a
    medication for the purposes of prescribing, dispensing, and administering a
    medication as well as for making statements about medication use.
        If the element is present, it must have either a @value, an @id, or extensions
    """

    # noinspection PyPep8Naming
    def __init__(
        self,
        *,
        id_: Optional[FhirId] = None,
        meta: Optional[Meta] = None,
        implicitRules: Optional[FhirUri] = None,
        language: Optional[CommonLanguagesCode] = None,
        text: Optional[Narrative] = None,
        contained: Optional[FhirList[ResourceContainer]] = None,
        extension: Optional[FhirList[ExtensionBase]] = None,
        modifierExtension: Optional[FhirList[ExtensionBase]] = None,
        identifier: Optional[FhirList[Identifier]] = None,
        code: Optional[CodeableConcept[SNOMEDCTMedicationCodesCode]] = None,
        status: Optional[MedicationStatusCodesCode] = None,
        manufacturer: Optional[Reference[Organization]] = None,
        form: Optional[CodeableConcept[SNOMEDCTFormCodesCode]] = None,
        amount: Optional[Ratio] = None,
        ingredient: Optional[FhirList[MedicationIngredient]] = None,
        batch: Optional[MedicationBatch] = None,
    ) -> None:
        """
            This resource is primarily used for the identification and definition of a
        medication for the purposes of prescribing, dispensing, and administering a
        medication as well as for making statements about medication use.
            If the element is present, it must have either a @value, an @id, or extensions

            :param id_: The logical id of the resource, as used in the URL for the resource. Once
        assigned, this value never changes.
            :param meta: The metadata about the resource. This is content that is maintained by the
        infrastructure. Changes to the content might not always be associated with
        version changes to the resource.
            :param implicitRules: A reference to a set of rules that were followed when the resource was
        constructed, and which must be understood when processing the content. Often,
        this is a reference to an implementation guide that defines the special rules
        along with other profiles etc.
            :param language: The base language in which the resource is written.
            :param text: A human-readable narrative that contains a summary of the resource and can be
        used to represent the content of the resource to a human. The narrative need
        not encode all the structured data, but is required to contain sufficient
        detail to make it "clinically safe" for a human to just read the narrative.
        Resource definitions may define what content should be represented in the
        narrative to ensure clinical safety.
            :param contained: These resources do not have an independent existence apart from the resource
        that contains them - they cannot be identified independently, and nor can they
        have their own independent transaction scope.
            :param extension: May be used to represent additional information that is not part of the basic
        definition of the resource. To make the use of extensions safe and manageable,
        there is a strict set of governance  applied to the definition and use of
        extensions. Though any implementer can define an extension, there is a set of
        requirements that SHALL be met as part of the definition of the extension.
            :param modifierExtension: May be used to represent additional information that is not part of the basic
        definition of the resource and that modifies the understanding of the element
        that contains it and/or the understanding of the containing element's
        descendants. Usually modifier elements provide negation or qualification. To
        make the use of extensions safe and manageable, there is a strict set of
        governance applied to the definition and use of extensions. Though any
        implementer is allowed to define an extension, there is a set of requirements
        that SHALL be met as part of the definition of the extension. Applications
        processing a resource are required to check for modifier extensions.

        Modifier extensions SHALL NOT change the meaning of any elements on Resource
        or DomainResource (including cannot change the meaning of modifierExtension
        itself).
            :param identifier: Business identifier for this medication.
            :param code: A code (or set of codes) that specify this medication, or a textual
        description if no code is available. Usage note: This could be a standard
        medication code such as a code from RxNorm, SNOMED CT, IDMP etc. It could also
        be a national or local formulary code, optionally with translations to other
        code systems.
            :param status: A code to indicate if the medication is in active use.
            :param manufacturer: Describes the details of the manufacturer of the medication product.  This is
        not intended to represent the distributor of a medication product.
            :param form: Describes the form of the item.  Powder; tablets; capsule.
            :param amount: Specific amount of the drug in the packaged product.  For example, when
        specifying a product that has the same strength (For example, Insulin glargine
        100 unit per mL solution for injection), this attribute provides additional
        clarification of the package amount (For example, 3 mL, 10mL, etc.).
            :param ingredient: Identifies a particular constituent of interest in the product.
            :param batch: Information that only applies to packages (not products).
        """
        super().__init__(
            resourceType="Medication",
            id_=id_,
            meta=meta,
            implicitRules=implicitRules,
            language=language,
            text=text,
            contained=contained,
            extension=extension,
            modifierExtension=modifierExtension,
            identifier=identifier,
            code=code,
            status=status,
            manufacturer=manufacturer,
            form=form,
            amount=amount,
            ingredient=ingredient,
            batch=batch,
        )

    def get_schema(
        self, include_extension: bool
    ) -> Optional[Union[StructType, DataType]]:
        return MedicationSchema.get_schema(include_extension=include_extension)
