from __future__ import annotations
from typing import Optional, TYPE_CHECKING, Union

# noinspection PyPackageRequirements
from pyspark.sql.types import StructType, DataType
from spark_auto_mapper_fhir.fhir_types.boolean import FhirBoolean
from spark_auto_mapper_fhir.fhir_types.list import FhirList
from spark_auto_mapper_fhir.fhir_types.string import FhirString
from spark_auto_mapper_fhir.complex_types.meta import Meta
from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase
from spark_auto_mapper_fhir.fhir_types.id import FhirId
from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.base_types.fhir_resource_base import FhirResourceBase
from spark_fhir_schemas.r4.resources.observationdefinition import (
    ObservationDefinitionSchema,
)

if TYPE_CHECKING:
    pass
    # id_ (id)
    # meta (Meta)
    # implicitRules (uri)
    # language (CommonLanguages)
    from spark_auto_mapper_fhir.value_sets.common_languages import CommonLanguagesCode

    # text (Narrative)
    from spark_auto_mapper_fhir.complex_types.narrative import Narrative

    # contained (ResourceContainer)
    from spark_auto_mapper_fhir.complex_types.resource_container import (
        ResourceContainer,
    )

    # extension (Extension)
    # modifierExtension (Extension)
    # category (CodeableConcept)
    from spark_auto_mapper_fhir.complex_types.codeable_concept import CodeableConcept

    # Import for CodeableConcept for category
    from spark_auto_mapper_fhir.value_sets.observation_category_codes import (
        ObservationCategoryCodesCode,
    )

    # End Import for CodeableConcept for category
    # code (CodeableConcept)
    # Import for CodeableConcept for code
    from spark_auto_mapper_fhir.value_sets.loinc_codes import LOINCCodesCode

    # End Import for CodeableConcept for code
    # identifier (Identifier)
    from spark_auto_mapper_fhir.complex_types.identifier import Identifier

    # permittedDataType (ObservationDataType)
    from spark_auto_mapper_fhir.value_sets.observation_data_type import (
        ObservationDataTypeCode,
    )

    # multipleResultsAllowed (boolean)
    # method (CodeableConcept)
    # Import for CodeableConcept for method
    from spark_auto_mapper_fhir.value_sets.observation_methods import (
        ObservationMethodsCode,
    )

    # End Import for CodeableConcept for method
    # preferredReportName (string)
    # quantitativeDetails (ObservationDefinition.QuantitativeDetails)
    from spark_auto_mapper_fhir.backbone_elements.observation_definition_quantitative_details import (
        ObservationDefinitionQuantitativeDetails,
    )

    # qualifiedInterval (ObservationDefinition.QualifiedInterval)
    from spark_auto_mapper_fhir.backbone_elements.observation_definition_qualified_interval import (
        ObservationDefinitionQualifiedInterval,
    )

    # validCodedValueSet (Reference)
    from spark_auto_mapper_fhir.complex_types.reference import Reference

    # Imports for References for validCodedValueSet
    from spark_auto_mapper_fhir.resources.value_set import ValueSet

    # normalCodedValueSet (Reference)
    # Imports for References for normalCodedValueSet
    # abnormalCodedValueSet (Reference)
    # Imports for References for abnormalCodedValueSet
    # criticalCodedValueSet (Reference)
    # Imports for References for criticalCodedValueSet


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class ObservationDefinition(FhirResourceBase):
    """
    ObservationDefinition
    observationdefinition.xsd
        Set of definitional characteristics for a kind of observation or measurement
    produced or consumed by an orderable health care service.
        If the element is present, it must have either a @value, an @id, or extensions
    """

    # noinspection PyPep8Naming
    def __init__(
        self,
        *,
        id_: Optional[FhirId] = None,
        meta: Optional[Meta] = None,
        implicitRules: Optional[FhirUri] = None,
        language: Optional[CommonLanguagesCode] = None,
        text: Optional[Narrative] = None,
        contained: Optional[FhirList[ResourceContainer]] = None,
        extension: Optional[FhirList[ExtensionBase]] = None,
        modifierExtension: Optional[FhirList[ExtensionBase]] = None,
        category: Optional[
            FhirList[CodeableConcept[ObservationCategoryCodesCode]]
        ] = None,
        code: CodeableConcept[LOINCCodesCode],
        identifier: Optional[FhirList[Identifier]] = None,
        permittedDataType: Optional[FhirList[ObservationDataTypeCode]] = None,
        multipleResultsAllowed: Optional[FhirBoolean] = None,
        method: Optional[CodeableConcept[ObservationMethodsCode]] = None,
        preferredReportName: Optional[FhirString] = None,
        quantitativeDetails: Optional[ObservationDefinitionQuantitativeDetails] = None,
        qualifiedInterval: Optional[
            FhirList[ObservationDefinitionQualifiedInterval]
        ] = None,
        validCodedValueSet: Optional[Reference[ValueSet]] = None,
        normalCodedValueSet: Optional[Reference[ValueSet]] = None,
        abnormalCodedValueSet: Optional[Reference[ValueSet]] = None,
        criticalCodedValueSet: Optional[Reference[ValueSet]] = None,
    ) -> None:
        """
            Set of definitional characteristics for a kind of observation or measurement
        produced or consumed by an orderable health care service.
            If the element is present, it must have either a @value, an @id, or extensions

            :param id_: The logical id of the resource, as used in the URL for the resource. Once
        assigned, this value never changes.
            :param meta: The metadata about the resource. This is content that is maintained by the
        infrastructure. Changes to the content might not always be associated with
        version changes to the resource.
            :param implicitRules: A reference to a set of rules that were followed when the resource was
        constructed, and which must be understood when processing the content. Often,
        this is a reference to an implementation guide that defines the special rules
        along with other profiles etc.
            :param language: The base language in which the resource is written.
            :param text: A human-readable narrative that contains a summary of the resource and can be
        used to represent the content of the resource to a human. The narrative need
        not encode all the structured data, but is required to contain sufficient
        detail to make it "clinically safe" for a human to just read the narrative.
        Resource definitions may define what content should be represented in the
        narrative to ensure clinical safety.
            :param contained: These resources do not have an independent existence apart from the resource
        that contains them - they cannot be identified independently, and nor can they
        have their own independent transaction scope.
            :param extension: May be used to represent additional information that is not part of the basic
        definition of the resource. To make the use of extensions safe and manageable,
        there is a strict set of governance  applied to the definition and use of
        extensions. Though any implementer can define an extension, there is a set of
        requirements that SHALL be met as part of the definition of the extension.
            :param modifierExtension: May be used to represent additional information that is not part of the basic
        definition of the resource and that modifies the understanding of the element
        that contains it and/or the understanding of the containing element's
        descendants. Usually modifier elements provide negation or qualification. To
        make the use of extensions safe and manageable, there is a strict set of
        governance applied to the definition and use of extensions. Though any
        implementer is allowed to define an extension, there is a set of requirements
        that SHALL be met as part of the definition of the extension. Applications
        processing a resource are required to check for modifier extensions.

        Modifier extensions SHALL NOT change the meaning of any elements on Resource
        or DomainResource (including cannot change the meaning of modifierExtension
        itself).
            :param category: A code that classifies the general type of observation.
            :param code: Describes what will be observed. Sometimes this is called the observation
        "name".
            :param identifier: A unique identifier assigned to this ObservationDefinition artifact.
            :param permittedDataType: The data types allowed for the value element of the instance observations
        conforming to this ObservationDefinition.
            :param multipleResultsAllowed: Multiple results allowed for observations conforming to this
        ObservationDefinition.
            :param method: The method or technique used to perform the observation.
            :param preferredReportName: The preferred name to be used when reporting the results of observations
        conforming to this ObservationDefinition.
            :param quantitativeDetails: Characteristics for quantitative results of this observation.
            :param qualifiedInterval: Multiple  ranges of results qualified by different contexts for ordinal or
        continuous observations conforming to this ObservationDefinition.
            :param validCodedValueSet: The set of valid coded results for the observations  conforming to this
        ObservationDefinition.
            :param normalCodedValueSet: The set of normal coded results for the observations conforming to this
        ObservationDefinition.
            :param abnormalCodedValueSet: The set of abnormal coded results for the observation conforming to this
        ObservationDefinition.
            :param criticalCodedValueSet: The set of critical coded results for the observation conforming to this
        ObservationDefinition.
        """
        super().__init__(
            resourceType="ObservationDefinition",
            id_=id_,
            meta=meta,
            implicitRules=implicitRules,
            language=language,
            text=text,
            contained=contained,
            extension=extension,
            modifierExtension=modifierExtension,
            category=category,
            code=code,
            identifier=identifier,
            permittedDataType=permittedDataType,
            multipleResultsAllowed=multipleResultsAllowed,
            method=method,
            preferredReportName=preferredReportName,
            quantitativeDetails=quantitativeDetails,
            qualifiedInterval=qualifiedInterval,
            validCodedValueSet=validCodedValueSet,
            normalCodedValueSet=normalCodedValueSet,
            abnormalCodedValueSet=abnormalCodedValueSet,
            criticalCodedValueSet=criticalCodedValueSet,
        )

    def get_schema(
        self, include_extension: bool
    ) -> Optional[Union[StructType, DataType]]:
        return ObservationDefinitionSchema.get_schema(
            include_extension=include_extension
        )
