from __future__ import annotations
from typing import Optional, TYPE_CHECKING, Union

# noinspection PyPackageRequirements
from pyspark.sql.types import StructType, DataType
from spark_auto_mapper_fhir.fhir_types.date import FhirDate
from spark_auto_mapper_fhir.fhir_types.date_time import FhirDateTime
from spark_auto_mapper_fhir.fhir_types.list import FhirList
from spark_auto_mapper_fhir.fhir_types.string import FhirString
from spark_auto_mapper_fhir.complex_types.meta import Meta
from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase
from spark_auto_mapper_fhir.fhir_types.id import FhirId
from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.base_types.fhir_resource_base import FhirResourceBase
from spark_fhir_schemas.r4.resources.paymentreconciliation import (
    PaymentReconciliationSchema,
)

if TYPE_CHECKING:
    pass
    # id_ (id)
    # meta (Meta)
    # implicitRules (uri)
    # language (CommonLanguages)
    from spark_auto_mapper_fhir.value_sets.common_languages import CommonLanguagesCode

    # text (Narrative)
    from spark_auto_mapper_fhir.complex_types.narrative import Narrative

    # contained (ResourceContainer)
    from spark_auto_mapper_fhir.complex_types.resource_container import (
        ResourceContainer,
    )

    # extension (Extension)
    # modifierExtension (Extension)
    # identifier (Identifier)
    from spark_auto_mapper_fhir.complex_types.identifier import Identifier

    # status (FinancialResourceStatusCodes)
    from spark_auto_mapper_fhir.value_sets.financial_resource_status_codes import (
        FinancialResourceStatusCodesCode,
    )

    # period (Period)
    from spark_auto_mapper_fhir.complex_types.period import Period

    # created (dateTime)
    # paymentIssuer (Reference)
    from spark_auto_mapper_fhir.complex_types.reference import Reference

    # Imports for References for paymentIssuer
    from spark_auto_mapper_fhir.resources.organization import Organization

    # request (Reference)
    # Imports for References for request
    from spark_auto_mapper_fhir.resources.task import Task

    # requestor (Reference)
    # Imports for References for requestor
    from spark_auto_mapper_fhir.resources.practitioner import Practitioner
    from spark_auto_mapper_fhir.resources.practitioner_role import PractitionerRole

    # outcome (ClaimProcessingCodes)
    from spark_auto_mapper_fhir.value_sets.claim_processing_codes import (
        ClaimProcessingCodesCode,
    )

    # disposition (string)
    # paymentDate (date)
    # paymentAmount (Money)
    from spark_auto_mapper_fhir.complex_types.money import Money

    # paymentIdentifier (Identifier)
    # detail (PaymentReconciliation.Detail)
    from spark_auto_mapper_fhir.backbone_elements.payment_reconciliation_detail import (
        PaymentReconciliationDetail,
    )

    # formCode (CodeableConcept)
    from spark_auto_mapper_fhir.complex_types.codeable_concept import CodeableConcept

    # Import for CodeableConcept for formCode
    from spark_auto_mapper_fhir.value_sets.form_codes import FormCodesCode

    # End Import for CodeableConcept for formCode
    # processNote (PaymentReconciliation.ProcessNote)
    from spark_auto_mapper_fhir.backbone_elements.payment_reconciliation_process_note import (
        PaymentReconciliationProcessNote,
    )


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class PaymentReconciliation(FhirResourceBase):
    """
    PaymentReconciliation
    paymentreconciliation.xsd
        This resource provides the details including amount of a payment and allocates
    the payment items being paid.
        If the element is present, it must have either a @value, an @id, or extensions
    """

    # noinspection PyPep8Naming
    def __init__(
        self,
        *,
        id_: Optional[FhirId] = None,
        meta: Optional[Meta] = None,
        implicitRules: Optional[FhirUri] = None,
        language: Optional[CommonLanguagesCode] = None,
        text: Optional[Narrative] = None,
        contained: Optional[FhirList[ResourceContainer]] = None,
        extension: Optional[FhirList[ExtensionBase]] = None,
        modifierExtension: Optional[FhirList[ExtensionBase]] = None,
        identifier: Optional[FhirList[Identifier]] = None,
        status: FinancialResourceStatusCodesCode,
        period: Optional[Period] = None,
        created: FhirDateTime,
        paymentIssuer: Optional[Reference[Organization]] = None,
        request: Optional[Reference[Task]] = None,
        requestor: Optional[
            Reference[Union[Practitioner, PractitionerRole, Organization]]
        ] = None,
        outcome: Optional[ClaimProcessingCodesCode] = None,
        disposition: Optional[FhirString] = None,
        paymentDate: FhirDate,
        paymentAmount: Money,
        paymentIdentifier: Optional[Identifier] = None,
        detail: Optional[FhirList[PaymentReconciliationDetail]] = None,
        formCode: Optional[CodeableConcept[FormCodesCode]] = None,
        processNote: Optional[FhirList[PaymentReconciliationProcessNote]] = None,
    ) -> None:
        """
            This resource provides the details including amount of a payment and allocates
        the payment items being paid.
            If the element is present, it must have either a @value, an @id, or extensions

            :param id_: The logical id of the resource, as used in the URL for the resource. Once
        assigned, this value never changes.
            :param meta: The metadata about the resource. This is content that is maintained by the
        infrastructure. Changes to the content might not always be associated with
        version changes to the resource.
            :param implicitRules: A reference to a set of rules that were followed when the resource was
        constructed, and which must be understood when processing the content. Often,
        this is a reference to an implementation guide that defines the special rules
        along with other profiles etc.
            :param language: The base language in which the resource is written.
            :param text: A human-readable narrative that contains a summary of the resource and can be
        used to represent the content of the resource to a human. The narrative need
        not encode all the structured data, but is required to contain sufficient
        detail to make it "clinically safe" for a human to just read the narrative.
        Resource definitions may define what content should be represented in the
        narrative to ensure clinical safety.
            :param contained: These resources do not have an independent existence apart from the resource
        that contains them - they cannot be identified independently, and nor can they
        have their own independent transaction scope.
            :param extension: May be used to represent additional information that is not part of the basic
        definition of the resource. To make the use of extensions safe and manageable,
        there is a strict set of governance  applied to the definition and use of
        extensions. Though any implementer can define an extension, there is a set of
        requirements that SHALL be met as part of the definition of the extension.
            :param modifierExtension: May be used to represent additional information that is not part of the basic
        definition of the resource and that modifies the understanding of the element
        that contains it and/or the understanding of the containing element's
        descendants. Usually modifier elements provide negation or qualification. To
        make the use of extensions safe and manageable, there is a strict set of
        governance applied to the definition and use of extensions. Though any
        implementer is allowed to define an extension, there is a set of requirements
        that SHALL be met as part of the definition of the extension. Applications
        processing a resource are required to check for modifier extensions.

        Modifier extensions SHALL NOT change the meaning of any elements on Resource
        or DomainResource (including cannot change the meaning of modifierExtension
        itself).
            :param identifier: A unique identifier assigned to this payment reconciliation.
            :param status: The status of the resource instance.
            :param period: The period of time for which payments have been gathered into this bulk
        payment for settlement.
            :param created: The date when the resource was created.
            :param paymentIssuer: The party who generated the payment.
            :param request: Original request resource reference.
            :param requestor: The practitioner who is responsible for the services rendered to the patient.
            :param outcome: The outcome of a request for a reconciliation.
            :param disposition: A human readable description of the status of the request for the
        reconciliation.
            :param paymentDate: The date of payment as indicated on the financial instrument.
            :param paymentAmount: Total payment amount as indicated on the financial instrument.
            :param paymentIdentifier: Issuer's unique identifier for the payment instrument.
            :param detail: Distribution of the payment amount for a previously acknowledged payable.
            :param formCode: A code for the form to be used for printing the content.
            :param processNote: A note that describes or explains the processing in a human readable form.
        """
        super().__init__(
            resourceType="PaymentReconciliation",
            id_=id_,
            meta=meta,
            implicitRules=implicitRules,
            language=language,
            text=text,
            contained=contained,
            extension=extension,
            modifierExtension=modifierExtension,
            identifier=identifier,
            status=status,
            period=period,
            created=created,
            paymentIssuer=paymentIssuer,
            request=request,
            requestor=requestor,
            outcome=outcome,
            disposition=disposition,
            paymentDate=paymentDate,
            paymentAmount=paymentAmount,
            paymentIdentifier=paymentIdentifier,
            detail=detail,
            formCode=formCode,
            processNote=processNote,
        )

    def get_schema(
        self, include_extension: bool
    ) -> Optional[Union[StructType, DataType]]:
        return PaymentReconciliationSchema.get_schema(
            include_extension=include_extension
        )
