from __future__ import annotations
from typing import Optional, TYPE_CHECKING, Union

# noinspection PyPackageRequirements
from pyspark.sql.types import StructType, DataType
from spark_auto_mapper_fhir.fhir_types.date_time import FhirDateTime
from spark_auto_mapper_fhir.fhir_types.list import FhirList
from spark_auto_mapper_fhir.fhir_types.string import FhirString
from spark_auto_mapper_fhir.complex_types.meta import Meta
from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase
from spark_auto_mapper_fhir.fhir_types.id import FhirId
from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.base_types.fhir_resource_base import FhirResourceBase
from spark_fhir_schemas.r4.resources.testreport import TestReportSchema

if TYPE_CHECKING:
    pass
    # id_ (id)
    # meta (Meta)
    # implicitRules (uri)
    # language (CommonLanguages)
    from spark_auto_mapper_fhir.value_sets.common_languages import CommonLanguagesCode

    # text (Narrative)
    from spark_auto_mapper_fhir.complex_types.narrative import Narrative

    # contained (ResourceContainer)
    from spark_auto_mapper_fhir.complex_types.resource_container import (
        ResourceContainer,
    )

    # extension (Extension)
    # modifierExtension (Extension)
    # identifier (Identifier)
    from spark_auto_mapper_fhir.complex_types.identifier import Identifier

    # name (string)
    # status (TestReportStatus)
    from spark_auto_mapper_fhir.value_sets.test_report_status import (
        TestReportStatusCode,
    )

    # testScript (Reference)
    from spark_auto_mapper_fhir.complex_types.reference import Reference

    # Imports for References for testScript
    from spark_auto_mapper_fhir.resources.test_script import TestScript

    # result (TestReportResult)
    from spark_auto_mapper_fhir.value_sets.test_report_result import (
        TestReportResultCode,
    )

    # score (decimal)
    from spark_auto_mapper_fhir.fhir_types.decimal import FhirDecimal

    # tester (string)
    # issued (dateTime)
    # participant (TestReport.Participant)
    from spark_auto_mapper_fhir.backbone_elements.test_report_participant import (
        TestReportParticipant,
    )

    # setup (TestReport.Setup)
    from spark_auto_mapper_fhir.backbone_elements.test_report_setup import (
        TestReportSetup,
    )

    # test (TestReport.Test)
    from spark_auto_mapper_fhir.backbone_elements.test_report_test import TestReportTest

    # teardown (TestReport.Teardown)
    from spark_auto_mapper_fhir.backbone_elements.test_report_teardown import (
        TestReportTeardown,
    )


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class TestReport(FhirResourceBase):
    """
    TestReport
    testreport.xsd
        A summary of information based on the results of executing a TestScript.
        If the element is present, it must have either a @value, an @id, or extensions
    """

    # noinspection PyPep8Naming
    def __init__(
        self,
        *,
        id_: Optional[FhirId] = None,
        meta: Optional[Meta] = None,
        implicitRules: Optional[FhirUri] = None,
        language: Optional[CommonLanguagesCode] = None,
        text: Optional[Narrative] = None,
        contained: Optional[FhirList[ResourceContainer]] = None,
        extension: Optional[FhirList[ExtensionBase]] = None,
        modifierExtension: Optional[FhirList[ExtensionBase]] = None,
        identifier: Optional[Identifier] = None,
        name: Optional[FhirString] = None,
        status: TestReportStatusCode,
        testScript: Reference[TestScript],
        result: TestReportResultCode,
        score: Optional[FhirDecimal] = None,
        tester: Optional[FhirString] = None,
        issued: Optional[FhirDateTime] = None,
        participant: Optional[FhirList[TestReportParticipant]] = None,
        setup: Optional[TestReportSetup] = None,
        test: Optional[FhirList[TestReportTest]] = None,
        teardown: Optional[TestReportTeardown] = None,
    ) -> None:
        """
            A summary of information based on the results of executing a TestScript.
            If the element is present, it must have either a @value, an @id, or extensions

            :param id_: The logical id of the resource, as used in the URL for the resource. Once
        assigned, this value never changes.
            :param meta: The metadata about the resource. This is content that is maintained by the
        infrastructure. Changes to the content might not always be associated with
        version changes to the resource.
            :param implicitRules: A reference to a set of rules that were followed when the resource was
        constructed, and which must be understood when processing the content. Often,
        this is a reference to an implementation guide that defines the special rules
        along with other profiles etc.
            :param language: The base language in which the resource is written.
            :param text: A human-readable narrative that contains a summary of the resource and can be
        used to represent the content of the resource to a human. The narrative need
        not encode all the structured data, but is required to contain sufficient
        detail to make it "clinically safe" for a human to just read the narrative.
        Resource definitions may define what content should be represented in the
        narrative to ensure clinical safety.
            :param contained: These resources do not have an independent existence apart from the resource
        that contains them - they cannot be identified independently, and nor can they
        have their own independent transaction scope.
            :param extension: May be used to represent additional information that is not part of the basic
        definition of the resource. To make the use of extensions safe and manageable,
        there is a strict set of governance  applied to the definition and use of
        extensions. Though any implementer can define an extension, there is a set of
        requirements that SHALL be met as part of the definition of the extension.
            :param modifierExtension: May be used to represent additional information that is not part of the basic
        definition of the resource and that modifies the understanding of the element
        that contains it and/or the understanding of the containing element's
        descendants. Usually modifier elements provide negation or qualification. To
        make the use of extensions safe and manageable, there is a strict set of
        governance applied to the definition and use of extensions. Though any
        implementer is allowed to define an extension, there is a set of requirements
        that SHALL be met as part of the definition of the extension. Applications
        processing a resource are required to check for modifier extensions.

        Modifier extensions SHALL NOT change the meaning of any elements on Resource
        or DomainResource (including cannot change the meaning of modifierExtension
        itself).
            :param identifier: Identifier for the TestScript assigned for external purposes outside the
        context of FHIR.
            :param name: A free text natural language name identifying the executed TestScript.
            :param status: The current state of this test report.
            :param testScript: Ideally this is an absolute URL that is used to identify the version-specific
        TestScript that was executed, matching the `TestScript.url`.
            :param result: The overall result from the execution of the TestScript.
            :param score: The final score (percentage of tests passed) resulting from the execution of
        the TestScript.
            :param tester: Name of the tester producing this report (Organization or individual).
            :param issued: When the TestScript was executed and this TestReport was generated.
            :param participant: A participant in the test execution, either the execution engine, a client, or
        a server.
            :param setup: The results of the series of required setup operations before the tests were
        executed.
            :param test: A test executed from the test script.
            :param teardown: The results of the series of operations required to clean up after all the
        tests were executed (successfully or otherwise).
        """
        super().__init__(
            resourceType="TestReport",
            id_=id_,
            meta=meta,
            implicitRules=implicitRules,
            language=language,
            text=text,
            contained=contained,
            extension=extension,
            modifierExtension=modifierExtension,
            identifier=identifier,
            name=name,
            status=status,
            testScript=testScript,
            result=result,
            score=score,
            tester=tester,
            issued=issued,
            participant=participant,
            setup=setup,
            test=test,
            teardown=teardown,
        )

    def get_schema(
        self, include_extension: bool
    ) -> Optional[Union[StructType, DataType]]:
        return TestReportSchema.get_schema(include_extension=include_extension)
