from __future__ import annotations
from typing import Optional, TYPE_CHECKING, Union

# noinspection PyPackageRequirements
from pyspark.sql.types import StructType, DataType
from spark_auto_mapper_fhir.fhir_types.boolean import FhirBoolean
from spark_auto_mapper_fhir.fhir_types.date_time import FhirDateTime
from spark_auto_mapper_fhir.fhir_types.list import FhirList
from spark_auto_mapper_fhir.fhir_types.string import FhirString
from spark_auto_mapper_fhir.complex_types.meta import Meta
from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase
from spark_auto_mapper_fhir.fhir_types.id import FhirId
from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.base_types.fhir_resource_base import FhirResourceBase
from spark_fhir_schemas.r4.resources.testscript import TestScriptSchema

if TYPE_CHECKING:
    pass
    # id_ (id)
    # meta (Meta)
    # implicitRules (uri)
    # language (CommonLanguages)
    from spark_auto_mapper_fhir.value_sets.common_languages import CommonLanguagesCode

    # text (Narrative)
    from spark_auto_mapper_fhir.complex_types.narrative import Narrative

    # contained (ResourceContainer)
    from spark_auto_mapper_fhir.complex_types.resource_container import (
        ResourceContainer,
    )

    # extension (Extension)
    # modifierExtension (Extension)
    # url (uri)
    # identifier (Identifier)
    from spark_auto_mapper_fhir.complex_types.identifier import Identifier

    # version (string)
    # name (string)
    # title (string)
    # status (PublicationStatus)
    from spark_auto_mapper_fhir.value_sets.publication_status import (
        PublicationStatusCode,
    )

    # experimental (boolean)
    # date (dateTime)
    # publisher (string)
    # contact (ContactDetail)
    from spark_auto_mapper_fhir.complex_types.contact_detail import ContactDetail

    # description (markdown)
    from spark_auto_mapper_fhir.fhir_types.markdown import FhirMarkdown

    # useContext (UsageContext)
    from spark_auto_mapper_fhir.complex_types.usage_context import UsageContext

    # jurisdiction (CodeableConcept)
    from spark_auto_mapper_fhir.complex_types.codeable_concept import CodeableConcept

    # Import for CodeableConcept for jurisdiction
    from spark_auto_mapper_fhir.value_sets.jurisdiction_value_set import (
        JurisdictionValueSetCode,
    )

    # End Import for CodeableConcept for jurisdiction
    # purpose (markdown)
    # copyright (markdown)
    # origin (TestScript.Origin)
    from spark_auto_mapper_fhir.backbone_elements.test_script_origin import (
        TestScriptOrigin,
    )

    # destination (TestScript.Destination)
    from spark_auto_mapper_fhir.backbone_elements.test_script_destination import (
        TestScriptDestination,
    )

    # metadata (TestScript.Metadata)
    from spark_auto_mapper_fhir.backbone_elements.test_script_metadata import (
        TestScriptMetadata,
    )

    # fixture (TestScript.Fixture)
    from spark_auto_mapper_fhir.backbone_elements.test_script_fixture import (
        TestScriptFixture,
    )

    # profile (Reference)
    from spark_auto_mapper_fhir.complex_types.reference import Reference

    # Imports for References for profile
    from spark_auto_mapper_fhir.resources.resource import Resource

    # variable (TestScript.Variable)
    from spark_auto_mapper_fhir.backbone_elements.test_script_variable import (
        TestScriptVariable,
    )

    # setup (TestScript.Setup)
    from spark_auto_mapper_fhir.backbone_elements.test_script_setup import (
        TestScriptSetup,
    )

    # test (TestScript.Test)
    from spark_auto_mapper_fhir.backbone_elements.test_script_test import TestScriptTest

    # teardown (TestScript.Teardown)
    from spark_auto_mapper_fhir.backbone_elements.test_script_teardown import (
        TestScriptTeardown,
    )


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class TestScript(FhirResourceBase):
    """
    TestScript
    testscript.xsd
        A structured set of tests against a FHIR server or client implementation to
    determine compliance against the FHIR specification.
        If the element is present, it must have either a @value, an @id, or extensions
    """

    # noinspection PyPep8Naming
    def __init__(
        self,
        *,
        id_: Optional[FhirId] = None,
        meta: Optional[Meta] = None,
        implicitRules: Optional[FhirUri] = None,
        language: Optional[CommonLanguagesCode] = None,
        text: Optional[Narrative] = None,
        contained: Optional[FhirList[ResourceContainer]] = None,
        extension: Optional[FhirList[ExtensionBase]] = None,
        modifierExtension: Optional[FhirList[ExtensionBase]] = None,
        url: FhirUri,
        identifier: Optional[Identifier] = None,
        version: Optional[FhirString] = None,
        name: FhirString,
        title: Optional[FhirString] = None,
        status: PublicationStatusCode,
        experimental: Optional[FhirBoolean] = None,
        date: Optional[FhirDateTime] = None,
        publisher: Optional[FhirString] = None,
        contact: Optional[FhirList[ContactDetail]] = None,
        description: Optional[FhirMarkdown] = None,
        useContext: Optional[FhirList[UsageContext]] = None,
        jurisdiction: Optional[
            FhirList[CodeableConcept[JurisdictionValueSetCode]]
        ] = None,
        purpose: Optional[FhirMarkdown] = None,
        copyright: Optional[FhirMarkdown] = None,
        origin: Optional[FhirList[TestScriptOrigin]] = None,
        destination: Optional[FhirList[TestScriptDestination]] = None,
        metadata: Optional[TestScriptMetadata] = None,
        fixture: Optional[FhirList[TestScriptFixture]] = None,
        profile: Optional[FhirList[Reference[Resource]]] = None,
        variable: Optional[FhirList[TestScriptVariable]] = None,
        setup: Optional[TestScriptSetup] = None,
        test: Optional[FhirList[TestScriptTest]] = None,
        teardown: Optional[TestScriptTeardown] = None,
    ) -> None:
        """
            A structured set of tests against a FHIR server or client implementation to
        determine compliance against the FHIR specification.
            If the element is present, it must have either a @value, an @id, or extensions

            :param id_: The logical id of the resource, as used in the URL for the resource. Once
        assigned, this value never changes.
            :param meta: The metadata about the resource. This is content that is maintained by the
        infrastructure. Changes to the content might not always be associated with
        version changes to the resource.
            :param implicitRules: A reference to a set of rules that were followed when the resource was
        constructed, and which must be understood when processing the content. Often,
        this is a reference to an implementation guide that defines the special rules
        along with other profiles etc.
            :param language: The base language in which the resource is written.
            :param text: A human-readable narrative that contains a summary of the resource and can be
        used to represent the content of the resource to a human. The narrative need
        not encode all the structured data, but is required to contain sufficient
        detail to make it "clinically safe" for a human to just read the narrative.
        Resource definitions may define what content should be represented in the
        narrative to ensure clinical safety.
            :param contained: These resources do not have an independent existence apart from the resource
        that contains them - they cannot be identified independently, and nor can they
        have their own independent transaction scope.
            :param extension: May be used to represent additional information that is not part of the basic
        definition of the resource. To make the use of extensions safe and manageable,
        there is a strict set of governance  applied to the definition and use of
        extensions. Though any implementer can define an extension, there is a set of
        requirements that SHALL be met as part of the definition of the extension.
            :param modifierExtension: May be used to represent additional information that is not part of the basic
        definition of the resource and that modifies the understanding of the element
        that contains it and/or the understanding of the containing element's
        descendants. Usually modifier elements provide negation or qualification. To
        make the use of extensions safe and manageable, there is a strict set of
        governance applied to the definition and use of extensions. Though any
        implementer is allowed to define an extension, there is a set of requirements
        that SHALL be met as part of the definition of the extension. Applications
        processing a resource are required to check for modifier extensions.

        Modifier extensions SHALL NOT change the meaning of any elements on Resource
        or DomainResource (including cannot change the meaning of modifierExtension
        itself).
            :param url: An absolute URI that is used to identify this test script when it is
        referenced in a specification, model, design or an instance; also called its
        canonical identifier. This SHOULD be globally unique and SHOULD be a literal
        address at which at which an authoritative instance of this test script is (or
        will be) published. This URL can be the target of a canonical reference. It
        SHALL remain the same when the test script is stored on different servers.
            :param identifier: A formal identifier that is used to identify this test script when it is
        represented in other formats, or referenced in a specification, model, design
        or an instance.
            :param version: The identifier that is used to identify this version of the test script when
        it is referenced in a specification, model, design or instance. This is an
        arbitrary value managed by the test script author and is not expected to be
        globally unique. For example, it might be a timestamp (e.g. yyyymmdd) if a
        managed version is not available. There is also no expectation that versions
        can be placed in a lexicographical sequence.
            :param name: A natural language name identifying the test script. This name should be
        usable as an identifier for the module by machine processing applications such
        as code generation.
            :param title: A short, descriptive, user-friendly title for the test script.
            :param status: The status of this test script. Enables tracking the life-cycle of the
        content.
            :param experimental: A Boolean value to indicate that this test script is authored for testing
        purposes (or education/evaluation/marketing) and is not intended to be used
        for genuine usage.
            :param date: The date  (and optionally time) when the test script was published. The date
        must change when the business version changes and it must change if the status
        code changes. In addition, it should change when the substantive content of
        the test script changes.
            :param publisher: The name of the organization or individual that published the test script.
            :param contact: Contact details to assist a user in finding and communicating with the
        publisher.
            :param description: A free text natural language description of the test script from a consumer's
        perspective.
            :param useContext: The content was developed with a focus and intent of supporting the contexts
        that are listed. These contexts may be general categories (gender, age, ...)
        or may be references to specific programs (insurance plans, studies, ...) and
        may be used to assist with indexing and searching for appropriate test script
        instances.
            :param jurisdiction: A legal or geographic region in which the test script is intended to be used.
            :param purpose: Explanation of why this test script is needed and why it has been designed as
        it has.
            :param copyright: A copyright statement relating to the test script and/or its contents.
        Copyright statements are generally legal restrictions on the use and
        publishing of the test script.
            :param origin: An abstract server used in operations within this test script in the origin
        element.
            :param destination: An abstract server used in operations within this test script in the
        destination element.
            :param metadata: The required capability must exist and are assumed to function correctly on
        the FHIR server being tested.
            :param fixture: Fixture in the test script - by reference (uri). All fixtures are required for
        the test script to execute.
            :param profile: Reference to the profile to be used for validation.
            :param variable: Variable is set based either on element value in response body or on header
        field value in the response headers.
            :param setup: A series of required setup operations before tests are executed.
            :param test: A test in this script.
            :param teardown: A series of operations required to clean up after all the tests are executed
        (successfully or otherwise).
        """
        super().__init__(
            resourceType="TestScript",
            id_=id_,
            meta=meta,
            implicitRules=implicitRules,
            language=language,
            text=text,
            contained=contained,
            extension=extension,
            modifierExtension=modifierExtension,
            url=url,
            identifier=identifier,
            version=version,
            name=name,
            title=title,
            status=status,
            experimental=experimental,
            date=date,
            publisher=publisher,
            contact=contact,
            description=description,
            useContext=useContext,
            jurisdiction=jurisdiction,
            purpose=purpose,
            copyright=copyright,
            origin=origin,
            destination=destination,
            metadata=metadata,
            fixture=fixture,
            profile=profile,
            variable=variable,
            setup=setup,
            test=test,
            teardown=teardown,
        )

    def get_schema(
        self, include_extension: bool
    ) -> Optional[Union[StructType, DataType]]:
        return TestScriptSchema.get_schema(include_extension=include_extension)
