from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class ActClassROI(GenericTypeCode):
    """
    v3.ActClassROI
    From: http://terminology.hl7.org/ValueSet/v3-ActClassROI in v3-codesystems.xml
         Regions of Interest (ROI) within a subject Act. Primarily used for making
    secondary observations on a subset of a subject observation. The relationship
    between a ROI and its referenced Act is specified through an ActRelationship
    of type "subject" (SUBJ), which must always be present.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/v3-ActClass
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/v3-ActClass"


class ActClassROIValues:
    """
    A record of something that is being done, has been done, can be done, or is
    intended or requested to be done.


                               Examples:The kinds of acts that are common in
    health care are (1) a clinical observation, (2) an assessment of health
    condition (such as problems and diagnoses), (3) healthcare goals, (4)
    treatment services (such as medication, surgery, physical and psychological
    therapy), (5) assisting, monitoring or attending, (6) training and education
    services to patients and their next of kin, (7) and notary services (such as
    advanced directives or living will), (8)  editing and maintaining documents,
    and many others.


                               Discussion and Rationale: Acts are the pivot of the
    RIM; all domain information and processes are represented primarily in Acts.
    Any profession or business, including healthcare, is primarily constituted of
    intentional and occasionally non-intentional actions, performed and recorded
    by responsible actors. An Act-instance is a record of such an action.

                            Acts connect to Entities in their Roles through
    Participations and connect to other Acts through ActRelationships.
    Participations are the authors, performers and other responsible parties as
    well as subjects and beneficiaries (which includes tools and material used in
    the performance of the act, which are also subjects). The moodCode
    distinguishes between Acts that are meant as factual records, vs. records of
    intended or ordered services, and the other modalities in which act can
    appear.

                            One of the Participations that all acts have (at least
    implicitly) is a primary author, who is responsible of the Act and who "owns"
    the act. Responsibility for the act means responsibility for what is being
    stated in the Act and as what it is stated. Ownership of the act is assumed in
    the sense of who may operationally modify the same act. Ownership and
    responsibility of the Act is not the same as ownership or responsibility of
    what the Act-object refers to in the real world. The same real world activity
    can be described by two people, each being the author of their Act, describing
    the same real world activity. Yet one can be a witness while the other can be
    a principal performer. The performer has responsibilities for the physical
    actions; the witness only has responsibility for making a true statement to
    the best of his or her ability. The two Act-instances may even disagree, but
    because each is properly attributed to its author, such disagreements can
    exist side by side and left to arbitration by a recipient of these Act-
    instances.

                            In this sense, an Act-instance represents a
    "statement" according to Rector and Nowlan (1991) [Foundations for an
    electronic medical record. Methods Inf Med. 30.]  Rector and Nowlan have
    emphasized the importance of understanding the medical record not as a
    collection of facts, but "a faithful record of what clinicians have heard,
    seen, thought, and done." Rector and Nowlan go on saying that "the other
    requirements for a medical record, e.g., that it be attributable and
    permanent, follow naturally from this view." Indeed the Act class is this
    attributable statement, and the rules of updating acts (discussed in the
    state-transition model, see Act.statusCode) versus generating new Act-
    instances are designed according to this principle of permanent attributable
    statements.

                            Rector and Nolan focus on the electronic medical
    record as a collection of statements, while attributed statements, these are
    still mostly factual statements. However, the Act class goes beyond this
    limitation to attributed factual statements, representing what is known as
    "speech-acts" in linguistics and philosophy.  The notion of speech-act
    includes that there is pragmatic meaning in language utterances, aside from
    just factual statements; and that these utterances interact with the real
    world to change the state of affairs, even directly cause physical activities
    to happen. For example, an order is a speech act that (provided it is issued
    adequately) will cause the ordered action to be physically performed. The
    speech act theory has culminated in the seminal work by Austin (1962) [How to
    do things with words. Oxford University Press].

                            An activity in the real world may progress from
    defined, through planned and ordered to executed, which is represented as the
    mood of the Act. Even though one might think of a single activity as
    progressing from planned to executed, this progression is reflected by
    multiple Act-instances, each having one and only one mood that will not change
    along the Act-instance life cycle.  This is because the attribution and
    content of speech acts along this progression of an activity may be different,
    and it is often critical that a permanent and faithful record be maintained of
    this progression. The specification of orders or promises or plans must not be
    overwritten by the specification of what was actually done, so as to allow
    comparing actions with their earlier specifications. Act-instances that
    describe this progression of the same real world activity are linked through
    the ActRelationships (of the relationship category "sequel").

                            Act as statements or speech-acts are the only
    representation of real world facts or processes in the HL7 RIM. The truth
    about the real world is constructed through a combination (and arbitration) of
    such attributed statements only, and there is no class in the RIM whose
    objects represent "objective state of affairs" or "real processes" independent
    from attributed statements. As such, there is no distinction between an
    activity and its documentation. Every Act includes both to varying degrees.
    For example, a factual statement made about recent (but past) activities,
    authored (and signed) by the performer of such activities, is commonly known
    as a procedure report or original documentation (e.g., surgical procedure
    report, clinic note etc.). Conversely, a status update on an activity that is
    presently in progress, authored by the performer (or a close observer) is
    considered to capture that activity (and is later superceded by a full
    procedure report). However, both status update and procedure report are acts
    of the same kind, only distinguished by mood and state (see statusCode) and
    completeness of the information.
    From: http://terminology.hl7.org/CodeSystem/v3-ActClass in v3-codesystems.xml
    """

    Act = ActClassROI("ACT")
    """
    From: http://terminology.hl7.org/CodeSystem/v3-ActClass in v3-codesystems.xml
    """
    DOCCNTNT = ActClassROI("DOCCNTNT")
    """
    From: http://terminology.hl7.org/CodeSystem/v3-ActClass in v3-codesystems.xml
    """
    DOCLIST = ActClassROI("DOCLIST")
    """
    From: http://terminology.hl7.org/CodeSystem/v3-ActClass in v3-codesystems.xml
    """
    DOCLSTITM = ActClassROI("DOCLSTITM")
    """
    From: http://terminology.hl7.org/CodeSystem/v3-ActClass in v3-codesystems.xml
    """
    DOCPARA = ActClassROI("DOCPARA")
    """
    From: http://terminology.hl7.org/CodeSystem/v3-ActClass in v3-codesystems.xml
    """
    DOCTBL = ActClassROI("DOCTBL")
    """
    From: http://terminology.hl7.org/CodeSystem/v3-ActClass in v3-codesystems.xml
    """
    LINKHTML = ActClassROI("LINKHTML")
    """
    From: http://terminology.hl7.org/CodeSystem/v3-ActClass in v3-codesystems.xml
    """
    LOCALATTR = ActClassROI("LOCALATTR")
    """
    From: http://terminology.hl7.org/CodeSystem/v3-ActClass in v3-codesystems.xml
    """
    LOCALMRKP = ActClassROI("LOCALMRKP")
    """
    From: http://terminology.hl7.org/CodeSystem/v3-ActClass in v3-codesystems.xml
    """
    Ordered = ActClassROI("ordered")
    """
    From: http://terminology.hl7.org/CodeSystem/v3-ActClass in v3-codesystems.xml
    """
    REFR = ActClassROI("REFR")
    """
    From: http://terminology.hl7.org/CodeSystem/v3-ActClass in v3-codesystems.xml
    """
    TBLCOL = ActClassROI("TBLCOL")
    """
    From: http://terminology.hl7.org/CodeSystem/v3-ActClass in v3-codesystems.xml
    """
    TBLCOLGP = ActClassROI("TBLCOLGP")
    """
    From: http://terminology.hl7.org/CodeSystem/v3-ActClass in v3-codesystems.xml
    """
    TBLDATA = ActClassROI("TBLDATA")
    """
    From: http://terminology.hl7.org/CodeSystem/v3-ActClass in v3-codesystems.xml
    """
    TBLHDR = ActClassROI("TBLHDR")
    """
    From: http://terminology.hl7.org/CodeSystem/v3-ActClass in v3-codesystems.xml
    """
    TBLROW = ActClassROI("TBLROW")
    """
    From: http://terminology.hl7.org/CodeSystem/v3-ActClass in v3-codesystems.xml
    """
    Tbody = ActClassROI("tbody")
    """
    From: http://terminology.hl7.org/CodeSystem/v3-ActClass in v3-codesystems.xml
    """
    Tfoot = ActClassROI("tfoot")
    """
    From: http://terminology.hl7.org/CodeSystem/v3-ActClass in v3-codesystems.xml
    """
    Thead = ActClassROI("thead")
    """
    From: http://terminology.hl7.org/CodeSystem/v3-ActClass in v3-codesystems.xml
    """
    Unordered = ActClassROI("unordered")
