from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class ActPriority(GenericTypeCode):
    """
    v3.ActPriority
    From: http://terminology.hl7.org/ValueSet/v3-ActPriority in v3-codesystems.xml
         A set of codes (e.g., for routine, emergency), specifying the urgency under
    which the Act happened, can happen, is happening, is intended to happen, or is
    requested/demanded to happen.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/v3-ActPriority
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/v3-ActPriority"


class ActPriorityValues:
    """
    As soon as possible, next highest priority after stat.
    From: http://terminology.hl7.org/CodeSystem/v3-ActPriority in v3-codesystems.xml
    """

    ASAP = ActPriority("A")
    """
    Filler should contact the placer as soon as results are available, even for
    preliminary results.  (Was "C" in HL7 version 2.3's reporting priority.)
    From: http://terminology.hl7.org/CodeSystem/v3-ActPriority in v3-codesystems.xml
    """
    CallbackResults = ActPriority("CR")
    """
    Filler should contact the placer (or target) to schedule the service.  (Was
    "C" in HL7 version 2.3's TQ-priority component.)
    From: http://terminology.hl7.org/CodeSystem/v3-ActPriority in v3-codesystems.xml
    """
    CallbackForScheduling = ActPriority("CS")
    """
    Beneficial to the patient but not essential for survival.
    From: http://terminology.hl7.org/CodeSystem/v3-ActPriority in v3-codesystems.xml
    """
    Elective = ActPriority("EL")
    """
    An unforeseen combination of circumstances or the resulting state that calls
    for immediate action.
    From: http://terminology.hl7.org/CodeSystem/v3-ActPriority in v3-codesystems.xml
    """
    Emergency = ActPriority("EM")
    """
    Used to indicate that a service is to be performed prior to a scheduled
    surgery.  When ordering a service and using the pre-op priority, a check is
    done to see the amount of time that must be allowed for performance of the
    service.  When the order is placed, a message can be generated indicating the
    time needed for the service so that it is not ordered in conflict with a
    scheduled operation.
    From: http://terminology.hl7.org/CodeSystem/v3-ActPriority in v3-codesystems.xml
    """
    Preop = ActPriority("P")
    """
    An "as needed" order should be accompanied by a description of what
    constitutes a need. This description is represented by an observation service
    predicate as a precondition.
    From: http://terminology.hl7.org/CodeSystem/v3-ActPriority in v3-codesystems.xml
    """
    AsNeeded = ActPriority("PRN")
    """
    Routine service, do at usual work hours.
    From: http://terminology.hl7.org/CodeSystem/v3-ActPriority in v3-codesystems.xml
    """
    Routine = ActPriority("R")
    """
    A report should be prepared and sent as quickly as possible.
    From: http://terminology.hl7.org/CodeSystem/v3-ActPriority in v3-codesystems.xml
    """
    RushReporting = ActPriority("RR")
    """
    With highest priority (e.g., emergency).
    From: http://terminology.hl7.org/CodeSystem/v3-ActPriority in v3-codesystems.xml
    """
    Stat = ActPriority("S")
    """
    It is critical to come as close as possible to the requested time (e.g., for a
    through antimicrobial level).
    From: http://terminology.hl7.org/CodeSystem/v3-ActPriority in v3-codesystems.xml
    """
    TimingCritical = ActPriority("T")
    """
    Drug is to be used as directed by the prescriber.
    From: http://terminology.hl7.org/CodeSystem/v3-ActPriority in v3-codesystems.xml
    """
    UseAsDirected = ActPriority("UD")
    """
    Calls for prompt action.
    From: http://terminology.hl7.org/CodeSystem/v3-ActPriority in v3-codesystems.xml
    """
    Urgent = ActPriority("UR")
