from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class ActionGroupingBehaviorCode(GenericTypeCode):
    """
    ActionGroupingBehavior
    From: http://hl7.org/fhir/action-grouping-behavior in valuesets.xml
        Defines organization behavior of a group.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/action-grouping-behavior
    """
    codeset: FhirUri = "http://hl7.org/fhir/action-grouping-behavior"


class ActionGroupingBehaviorCodeValues:
    """
    Any group marked with this behavior should be displayed as a visual group to
    the end user.
    From: http://hl7.org/fhir/action-grouping-behavior in valuesets.xml
    """

    VisualGroup = ActionGroupingBehaviorCode("visual-group")
    """
    A group with this behavior logically groups its sub-elements, and may be shown
    as a visual group to the end user, but it is not required to do so.
    From: http://hl7.org/fhir/action-grouping-behavior in valuesets.xml
    """
    LogicalGroup = ActionGroupingBehaviorCode("logical-group")
    """
    A group of related alternative actions is a sentence group if the target
    referenced by the action is the same in all the actions and each action simply
    constitutes a different variation on how to specify the details for the
    target. For example, two actions that could be in a SentenceGroup are
    "aspirin, 500 mg, 2 times per day" and "aspirin, 300 mg, 3 times per day". In
    both cases, aspirin is the target referenced by the action, and the two
    actions represent different options for how aspirin might be ordered for the
    patient. Note that a SentenceGroup would almost always have an associated
    selection behavior of "AtMostOne", unless it's a required action, in which
    case, it would be "ExactlyOne".
    From: http://hl7.org/fhir/action-grouping-behavior in valuesets.xml
    """
    SentenceGroup = ActionGroupingBehaviorCode("sentence-group")
