from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class ActionRelationshipTypeCode(GenericTypeCode):
    """
    ActionRelationshipType
    From: http://hl7.org/fhir/action-relationship-type in valuesets.xml
        Defines the types of relationships between actions.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/action-relationship-type
    """
    codeset: FhirUri = "http://hl7.org/fhir/action-relationship-type"


class ActionRelationshipTypeCodeValues:
    """
    The action must be performed before the start of the related action.
    From: http://hl7.org/fhir/action-relationship-type in valuesets.xml
    """

    BeforeStart = ActionRelationshipTypeCode("before-start")
    """
    The action must be performed before the related action.
    From: http://hl7.org/fhir/action-relationship-type in valuesets.xml
    """
    Before = ActionRelationshipTypeCode("before")
    """
    The action must be performed before the end of the related action.
    From: http://hl7.org/fhir/action-relationship-type in valuesets.xml
    """
    BeforeEnd = ActionRelationshipTypeCode("before-end")
    """
    The action must be performed concurrent with the start of the related action.
    From: http://hl7.org/fhir/action-relationship-type in valuesets.xml
    """
    ConcurrentWithStart = ActionRelationshipTypeCode("concurrent-with-start")
    """
    The action must be performed concurrent with the related action.
    From: http://hl7.org/fhir/action-relationship-type in valuesets.xml
    """
    Concurrent = ActionRelationshipTypeCode("concurrent")
    """
    The action must be performed concurrent with the end of the related action.
    From: http://hl7.org/fhir/action-relationship-type in valuesets.xml
    """
    ConcurrentWithEnd = ActionRelationshipTypeCode("concurrent-with-end")
    """
    The action must be performed after the start of the related action.
    From: http://hl7.org/fhir/action-relationship-type in valuesets.xml
    """
    AfterStart = ActionRelationshipTypeCode("after-start")
    """
    The action must be performed after the related action.
    From: http://hl7.org/fhir/action-relationship-type in valuesets.xml
    """
    After = ActionRelationshipTypeCode("after")
    """
    The action must be performed after the end of the related action.
    From: http://hl7.org/fhir/action-relationship-type in valuesets.xml
    """
    AfterEnd = ActionRelationshipTypeCode("after-end")
