from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class ActionSelectionBehaviorCode(GenericTypeCode):
    """
    ActionSelectionBehavior
    From: http://hl7.org/fhir/action-selection-behavior in valuesets.xml
        Defines selection behavior of a group.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/action-selection-behavior
    """
    codeset: FhirUri = "http://hl7.org/fhir/action-selection-behavior"


class ActionSelectionBehaviorCodeValues:
    """
    Any number of the actions in the group may be chosen, from zero to all.
    From: http://hl7.org/fhir/action-selection-behavior in valuesets.xml
    """

    Any = ActionSelectionBehaviorCode("any")
    """
    All the actions in the group must be selected as a single unit.
    From: http://hl7.org/fhir/action-selection-behavior in valuesets.xml
    """
    All = ActionSelectionBehaviorCode("all")
    """
    All the actions in the group are meant to be chosen as a single unit: either
    all must be selected by the end user, or none may be selected.
    From: http://hl7.org/fhir/action-selection-behavior in valuesets.xml
    """
    AllOrNone = ActionSelectionBehaviorCode("all-or-none")
    """
    The end user must choose one and only one of the selectable actions in the
    group. The user SHALL NOT choose none of the actions in the group.
    From: http://hl7.org/fhir/action-selection-behavior in valuesets.xml
    """
    ExactlyOne = ActionSelectionBehaviorCode("exactly-one")
    """
    The end user may choose zero or at most one of the actions in the group.
    From: http://hl7.org/fhir/action-selection-behavior in valuesets.xml
    """
    AtMostOne = ActionSelectionBehaviorCode("at-most-one")
    """
    The end user must choose a minimum of one, and as many additional as desired.
    From: http://hl7.org/fhir/action-selection-behavior in valuesets.xml
    """
    OneOrMore = ActionSelectionBehaviorCode("one-or-more")
