from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class AdverseEventCategoryCode(GenericTypeCode):
    """
    AdverseEventCategory
    From: http://terminology.hl7.org/CodeSystem/adverse-event-category in valuesets.xml
        Overall categorization of the event, e.g. product-related or situational.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/adverse-event-category
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/adverse-event-category"


class AdverseEventCategoryCodeValues:
    """
    The adverse event pertains to a product problem.
    From: http://terminology.hl7.org/CodeSystem/adverse-event-category in valuesets.xml
    """

    ProductProblem = AdverseEventCategoryCode("product-problem")
    """
    The adverse event pertains to product quality.
    From: http://terminology.hl7.org/CodeSystem/adverse-event-category in valuesets.xml
    """
    ProductQuality = AdverseEventCategoryCode("product-quality")
    """
    The adverse event pertains to a product use error.
    From: http://terminology.hl7.org/CodeSystem/adverse-event-category in valuesets.xml
    """
    ProductUseError = AdverseEventCategoryCode("product-use-error")
    """
    The adverse event pertains to a medical device use error.
    From: http://terminology.hl7.org/CodeSystem/adverse-event-category in valuesets.xml
    """
    MedicalDeviceUseError = AdverseEventCategoryCode("medical-device-use-error")
    """
    The adverse event pertains to a problem with a different manufacturer of the
    same medication.
    From: http://terminology.hl7.org/CodeSystem/adverse-event-category in valuesets.xml
    """
    ProblemWithDifferentManufacturerOfSameMedicine = AdverseEventCategoryCode(
        "problem-different-manufacturer"
    )
    """
    The adverse event pertains to an unsafe physical environment.
    From: http://terminology.hl7.org/CodeSystem/adverse-event-category in valuesets.xml
    """
    UnsafePhysicalEnvironment = AdverseEventCategoryCode("unsafe-physical-environment")
