from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class AppointmentStatusCode(GenericTypeCode):
    """
    AppointmentStatus
    From: http://hl7.org/fhir/appointmentstatus in valuesets.xml
        The free/busy status of an appointment.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/appointmentstatus
    """
    codeset: FhirUri = "http://hl7.org/fhir/appointmentstatus"


class AppointmentStatusCodeValues:
    """
    None of the participant(s) have finalized their acceptance of the appointment
    request, and the start/end time might not be set yet.
    From: http://hl7.org/fhir/appointmentstatus in valuesets.xml
    """

    Proposed = AppointmentStatusCode("proposed")
    """
    Some or all of the participant(s) have not finalized their acceptance of the
    appointment request.
    From: http://hl7.org/fhir/appointmentstatus in valuesets.xml
    """
    Pending = AppointmentStatusCode("pending")
    """
    All participant(s) have been considered and the appointment is confirmed to go
    ahead at the date/times specified.
    From: http://hl7.org/fhir/appointmentstatus in valuesets.xml
    """
    Booked = AppointmentStatusCode("booked")
    """
    The patient/patients has/have arrived and is/are waiting to be seen.
    From: http://hl7.org/fhir/appointmentstatus in valuesets.xml
    """
    Arrived = AppointmentStatusCode("arrived")
    """
    The planning stages of the appointment are now complete, the encounter
    resource will exist and will track further status changes. Note that an
    encounter may exist before the appointment status is fulfilled for many
    reasons.
    From: http://hl7.org/fhir/appointmentstatus in valuesets.xml
    """
    Fulfilled = AppointmentStatusCode("fulfilled")
    """
    The appointment has been cancelled.
    From: http://hl7.org/fhir/appointmentstatus in valuesets.xml
    """
    Cancelled = AppointmentStatusCode("cancelled")
    """
    Some or all of the participant(s) have not/did not appear for the appointment
    (usually the patient).
    From: http://hl7.org/fhir/appointmentstatus in valuesets.xml
    """
    NoShow = AppointmentStatusCode("noshow")
    """
    This instance should not have been part of this patient's medical record.
    From: http://hl7.org/fhir/appointmentstatus in valuesets.xml
    """
    EnteredInError = AppointmentStatusCode("entered-in-error")
    """
    When checked in, all pre-encounter administrative work is complete, and the
    encounter may begin. (where multiple patients are involved, they are all
    present).
    From: http://hl7.org/fhir/appointmentstatus in valuesets.xml
    """
    CheckedIn = AppointmentStatusCode("checked-in")
    """
    The appointment has been placed on a waitlist, to be scheduled/confirmed in
    the future when a slot/service is available.
    A specific time might or might not be pre-allocated.
    From: http://hl7.org/fhir/appointmentstatus in valuesets.xml
    """
    Waitlisted = AppointmentStatusCode("waitlist")
