from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class AuditEventEntityRoleCode(GenericTypeCode):
    """
    AuditEventEntityRole
    From: http://terminology.hl7.org/CodeSystem/object-role in valuesets.xml
        Code representing the role the entity played in the audit event.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/object-role
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/object-role"


class AuditEventEntityRoleCodeValues:
    """
    This object is the patient that is the subject of care related to this event.
    It is identifiable by patient ID or equivalent.  The patient may be either
    human or animal.
    From: http://terminology.hl7.org/CodeSystem/object-role in valuesets.xml
    """

    Patient = AuditEventEntityRoleCode("1")
    """
    This is a location identified as related to the event.  This is usually the
    location where the event took place.  Note that for shipping, the usual events
    are arrival at a location or departure from a location.
    From: http://terminology.hl7.org/CodeSystem/object-role in valuesets.xml
    """
    Location = AuditEventEntityRoleCode("2")
    """
    This object is any kind of persistent document created as a result of the
    event.  This could be a paper report, film, electronic report, DICOM Study,
    etc.  Issues related to medical records life cycle management are conveyed
    elsewhere.
    From: http://terminology.hl7.org/CodeSystem/object-role in valuesets.xml
    """
    Report = AuditEventEntityRoleCode("3")
    """
    A logical object related to a health record event.  This is any healthcare
    specific resource (object) not restricted to FHIR defined Resources.
    From: http://terminology.hl7.org/CodeSystem/object-role in valuesets.xml
    """
    DomainResource = AuditEventEntityRoleCode("4")
    """
    This is any configurable file used to control creation of documents.  Examples
    include the objects maintained by the HL7 Master File transactions, Value
    Sets, etc.
    From: http://terminology.hl7.org/CodeSystem/object-role in valuesets.xml
    """
    MasterFile = AuditEventEntityRoleCode("5")
    """
    A human participant not otherwise identified by some other category.
    From: http://terminology.hl7.org/CodeSystem/object-role in valuesets.xml
    """
    User = AuditEventEntityRoleCode("6")
    """
    (deprecated).
    From: http://terminology.hl7.org/CodeSystem/object-role in valuesets.xml
    """
    List_ = AuditEventEntityRoleCode("7")
    """
    Typically, a licensed person who is providing or performing care related to
    the event, generally a physician.   The key distinction between doctor and
    practitioner is with regards to their role, not the licensing.  The doctor is
    the human who actually performed the work.  The practitioner is the human or
    organization that is responsible for the work.
    From: http://terminology.hl7.org/CodeSystem/object-role in valuesets.xml
    """
    Doctor = AuditEventEntityRoleCode("8")
    """
    A person or system that is being notified as part of the event.  This is
    relevant in situations where automated systems provide notifications to other
    parties when an event took place.
    From: http://terminology.hl7.org/CodeSystem/object-role in valuesets.xml
    """
    Subscriber = AuditEventEntityRoleCode("9")
    """
    Insurance company, or any other organization who accepts responsibility for
    paying for the healthcare event.
    From: http://terminology.hl7.org/CodeSystem/object-role in valuesets.xml
    """
    Guarantor = AuditEventEntityRoleCode("10")
    """
    A person or active system object involved in the event with a security role.
    From: http://terminology.hl7.org/CodeSystem/object-role in valuesets.xml
    """
    SecurityUserEntity = AuditEventEntityRoleCode("11")
    """
    A person or system object involved in the event with the authority to modify
    security roles of other objects.
    From: http://terminology.hl7.org/CodeSystem/object-role in valuesets.xml
    """
    SecurityUserGroup = AuditEventEntityRoleCode("12")
    """
    A passive object, such as a role table, that is relevant to the event.
    From: http://terminology.hl7.org/CodeSystem/object-role in valuesets.xml
    """
    SecurityResource = AuditEventEntityRoleCode("13")
    """
    (deprecated)  Relevant to certain RBAC security methodologies.
    From: http://terminology.hl7.org/CodeSystem/object-role in valuesets.xml
    """
    SecurityGranularityDefinition = AuditEventEntityRoleCode("14")
    """
    Any person or organization responsible for providing care.  This encompasses
    all forms of care, licensed or otherwise, and all sorts of teams and care
    groups. Note the distinction between practitioner and the doctor that actually
    provided the care to the patient.
    From: http://terminology.hl7.org/CodeSystem/object-role in valuesets.xml
    """
    Practitioner = AuditEventEntityRoleCode("15")
    """
    The source or destination for data transfer, when it does not match some other
    role.
    From: http://terminology.hl7.org/CodeSystem/object-role in valuesets.xml
    """
    DataDestination = AuditEventEntityRoleCode("16")
    """
    A source or destination for data transfer that acts as an archive, database,
    or similar role.
    From: http://terminology.hl7.org/CodeSystem/object-role in valuesets.xml
    """
    DataRepository = AuditEventEntityRoleCode("17")
    """
    An object that holds schedule information.  This could be an appointment book,
    availability information, etc.
    From: http://terminology.hl7.org/CodeSystem/object-role in valuesets.xml
    """
    Schedule = AuditEventEntityRoleCode("18")
    """
    An organization or person that is the recipient of services.  This could be an
    organization that is buying services for a patient, or a person that is buying
    services for an animal.
    From: http://terminology.hl7.org/CodeSystem/object-role in valuesets.xml
    """
    Customer = AuditEventEntityRoleCode("19")
    """
    An order, task, work item, procedure step, or other description of work to be
    performed; e.g. a particular instance of an MPPS.
    From: http://terminology.hl7.org/CodeSystem/object-role in valuesets.xml
    """
    Job = AuditEventEntityRoleCode("20")
    """
    A list of jobs or a system that provides lists of jobs; e.g. an MWL SCP.
    From: http://terminology.hl7.org/CodeSystem/object-role in valuesets.xml
    """
    JobStream = AuditEventEntityRoleCode("21")
    """
    (Deprecated).
    From: http://terminology.hl7.org/CodeSystem/object-role in valuesets.xml
    """
    Table = AuditEventEntityRoleCode("22")
    """
    An object that specifies or controls the routing or delivery of items.  For
    example, a distribution list is the routing criteria for mail.  The items
    delivered may be documents, jobs, or other objects.
    From: http://terminology.hl7.org/CodeSystem/object-role in valuesets.xml
    """
    RoutingCriteria = AuditEventEntityRoleCode("23")
    """
    The contents of a query.  This is used to capture the contents of any kind of
    query.  For security surveillance purposes knowing the queries being made is
    very important.
    From: http://terminology.hl7.org/CodeSystem/object-role in valuesets.xml
    """
    Query = AuditEventEntityRoleCode("24")
