from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class BasicResourceTypesCode(GenericTypeCode):
    """
    BasicResourceTypes
    From: http://terminology.hl7.org/CodeSystem/basic-resource-type in valuesets.xml
        This value set defines codes for resources not yet supported by (or which will
    never be supported by) FHIR.  Many of the codes listed here will eventually be
    turned into official resources.  However, there is no guarantee that any
    particular resource will be created nor that the scope will be exactly as
    defined by the codes presented here.  Codes in this set will be deprecated
    if/when formal resources are defined that encompass these concepts.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/basic-resource-type
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/basic-resource-type"


class BasicResourceTypesCodeValues:
    """
    An assertion of permission for an activity or set of activities to occur,
    possibly subject to particular limitations; e.g. surgical consent, information
    disclosure consent, etc.
    From: http://terminology.hl7.org/CodeSystem/basic-resource-type in valuesets.xml
    """

    Consent = BasicResourceTypesCode("consent")
    """
    A request that care of a particular type be provided to a patient.  Could
    involve the transfer of care, a consult, etc.
    From: http://terminology.hl7.org/CodeSystem/basic-resource-type in valuesets.xml
    """
    Referral = BasicResourceTypesCode("referral")
    """
    An undesired reaction caused by exposure to some agent (e.g. a medication,
    immunization, food, or environmental agent).
    From: http://terminology.hl7.org/CodeSystem/basic-resource-type in valuesets.xml
    """
    AdverseEvent = BasicResourceTypesCode("advevent")
    """
    A request that a time be scheduled for a type of service for a specified
    patient, potentially subject to other constraints
    From: http://terminology.hl7.org/CodeSystem/basic-resource-type in valuesets.xml
    """
    AppointmentRequest = BasicResourceTypesCode("aptmtreq")
    """
    The transition of a patient or set of material from one location to another
    From: http://terminology.hl7.org/CodeSystem/basic-resource-type in valuesets.xml
    """
    Transfer = BasicResourceTypesCode("transfer")
    """
    The specification of a set of food and/or other nutritional material to be
    delivered to a patient.
    From: http://terminology.hl7.org/CodeSystem/basic-resource-type in valuesets.xml
    """
    Diet = BasicResourceTypesCode("diet")
    """
    An occurrence of a non-care-related event in the healthcare domain, such as
    approvals, reviews, etc.
    From: http://terminology.hl7.org/CodeSystem/basic-resource-type in valuesets.xml
    """
    AdministrativeActivity = BasicResourceTypesCode("adminact")
    """
    Record of a situation where a subject was exposed to a substance.  Usually of
    interest to public health.
    From: http://terminology.hl7.org/CodeSystem/basic-resource-type in valuesets.xml
    """
    Exposure = BasicResourceTypesCode("exposure")
    """
    A formalized inquiry into the circumstances surrounding a particular unplanned
    event or potential event for the purposes of identifying possible causes and
    contributing factors for the event
    From: http://terminology.hl7.org/CodeSystem/basic-resource-type in valuesets.xml
    """
    Investigation = BasicResourceTypesCode("investigation")
    """
    A financial instrument used to track costs, charges or other amounts.
    From: http://terminology.hl7.org/CodeSystem/basic-resource-type in valuesets.xml
    """
    Account = BasicResourceTypesCode("account")
    """
    A request for payment for goods and/or services.  Includes the idea of a
    healthcare insurance claim.
    From: http://terminology.hl7.org/CodeSystem/basic-resource-type in valuesets.xml
    """
    Invoice = BasicResourceTypesCode("invoice")
    """
    The determination of what will be paid against a particular invoice based on
    coverage, plan rules, etc.
    From: http://terminology.hl7.org/CodeSystem/basic-resource-type in valuesets.xml
    """
    InvoiceAdjudication = BasicResourceTypesCode("adjudicat")
    """
    A request for a pre-determination of the cost that would be paid under an
    insurance plan for a hypothetical claim for goods or services
    From: http://terminology.hl7.org/CodeSystem/basic-resource-type in valuesets.xml
    """
    Pre_determinationRequest = BasicResourceTypesCode("predetreq")
    """
    An adjudication of what would be paid under an insurance plan for a
    hypothetical claim for goods or services
    From: http://terminology.hl7.org/CodeSystem/basic-resource-type in valuesets.xml
    """
    Predetermination = BasicResourceTypesCode("predetermine")
    """
    An investigation to determine information about a particular therapy or
    product
    From: http://terminology.hl7.org/CodeSystem/basic-resource-type in valuesets.xml
    """
    Study = BasicResourceTypesCode("study")
    """
    A set of (possibly conditional) steps to be taken to achieve some aim.
    Includes study protocols, treatment protocols, emergency protocols, etc.
    From: http://terminology.hl7.org/CodeSystem/basic-resource-type in valuesets.xml
    """
    Protocol = BasicResourceTypesCode("protocol")
