from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class BenefitCategoryCodesCode(GenericTypeCode):
    """
    BenefitCategoryCodes
    From: http://terminology.hl7.org/CodeSystem/ex-benefitcategory in valuesets.xml
        This value set includes examples of Benefit Category codes.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/ex-benefitcategory
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/ex-benefitcategory"


class BenefitCategoryCodesCodeValues:
    """
    Medical Care.
    From: http://terminology.hl7.org/CodeSystem/ex-benefitcategory in valuesets.xml
    """

    MedicalCare = BenefitCategoryCodesCode("1")
    """
    Surgical.
    From: http://terminology.hl7.org/CodeSystem/ex-benefitcategory in valuesets.xml
    """
    Surgical = BenefitCategoryCodesCode("2")
    """
    Consultation.
    From: http://terminology.hl7.org/CodeSystem/ex-benefitcategory in valuesets.xml
    """
    Consultation = BenefitCategoryCodesCode("3")
    """
    Diagnostic XRay.
    From: http://terminology.hl7.org/CodeSystem/ex-benefitcategory in valuesets.xml
    """
    DiagnosticXRay = BenefitCategoryCodesCode("4")
    """
    Diagnostic Lab.
    From: http://terminology.hl7.org/CodeSystem/ex-benefitcategory in valuesets.xml
    """
    DiagnosticLab = BenefitCategoryCodesCode("5")
    """
    Renal Supplies excluding Dialysis.
    From: http://terminology.hl7.org/CodeSystem/ex-benefitcategory in valuesets.xml
    """
    RenalSupplies = BenefitCategoryCodesCode("14")
    """
    Diagnostic Dental.
    From: http://terminology.hl7.org/CodeSystem/ex-benefitcategory in valuesets.xml
    """
    DiagnosticDental = BenefitCategoryCodesCode("23")
    """
    Periodontics.
    From: http://terminology.hl7.org/CodeSystem/ex-benefitcategory in valuesets.xml
    """
    Periodontics = BenefitCategoryCodesCode("24")
    """
    Restorative.
    From: http://terminology.hl7.org/CodeSystem/ex-benefitcategory in valuesets.xml
    """
    Restorative = BenefitCategoryCodesCode("25")
    """
    Endodontics.
    From: http://terminology.hl7.org/CodeSystem/ex-benefitcategory in valuesets.xml
    """
    Endodontics = BenefitCategoryCodesCode("26")
    """
    Maxillofacial Prosthetics.
    From: http://terminology.hl7.org/CodeSystem/ex-benefitcategory in valuesets.xml
    """
    MaxillofacialProsthetics = BenefitCategoryCodesCode("27")
    """
    Adjunctive Dental Services.
    From: http://terminology.hl7.org/CodeSystem/ex-benefitcategory in valuesets.xml
    """
    AdjunctiveDentalServices = BenefitCategoryCodesCode("28")
    """
    Health Benefit Plan Coverage.
    From: http://terminology.hl7.org/CodeSystem/ex-benefitcategory in valuesets.xml
    """
    HealthBenefitPlanCoverage = BenefitCategoryCodesCode("30")
    """
    Dental Care.
    From: http://terminology.hl7.org/CodeSystem/ex-benefitcategory in valuesets.xml
    """
    DentalCare = BenefitCategoryCodesCode("35")
    """
    Dental Crowns.
    From: http://terminology.hl7.org/CodeSystem/ex-benefitcategory in valuesets.xml
    """
    DentalCrowns = BenefitCategoryCodesCode("36")
    """
    Dental Accident.
    From: http://terminology.hl7.org/CodeSystem/ex-benefitcategory in valuesets.xml
    """
    DentalAccident = BenefitCategoryCodesCode("37")
    """
    Hospital Room and Board.
    From: http://terminology.hl7.org/CodeSystem/ex-benefitcategory in valuesets.xml
    """
    HospitalRoomAndBoard = BenefitCategoryCodesCode("49")
    """
    Major Medical.
    From: http://terminology.hl7.org/CodeSystem/ex-benefitcategory in valuesets.xml
    """
    MajorMedical = BenefitCategoryCodesCode("55")
    """
    Medically Related Transportation.
    From: http://terminology.hl7.org/CodeSystem/ex-benefitcategory in valuesets.xml
    """
    MedicallyRelatedTransportation = BenefitCategoryCodesCode("56")
    """
    In-vitro Fertilization.
    From: http://terminology.hl7.org/CodeSystem/ex-benefitcategory in valuesets.xml
    """
    In_vitroFertilization = BenefitCategoryCodesCode("61")
    """
    MRI Scan.
    From: http://terminology.hl7.org/CodeSystem/ex-benefitcategory in valuesets.xml
    """
    MRIScan = BenefitCategoryCodesCode("62")
    """
    Donor Procedures such as organ harvest.
    From: http://terminology.hl7.org/CodeSystem/ex-benefitcategory in valuesets.xml
    """
    DonorProcedures = BenefitCategoryCodesCode("63")
    """
    Maternity.
    From: http://terminology.hl7.org/CodeSystem/ex-benefitcategory in valuesets.xml
    """
    Maternity = BenefitCategoryCodesCode("69")
    """
    Renal dialysis.
    From: http://terminology.hl7.org/CodeSystem/ex-benefitcategory in valuesets.xml
    """
    RenalDialysis = BenefitCategoryCodesCode("76")
    """
    Medical Coverage.
    From: http://terminology.hl7.org/CodeSystem/ex-benefitcategory in valuesets.xml
    """
    MedicalCoverage = BenefitCategoryCodesCode("F1")
    """
    Dental Coverage.
    From: http://terminology.hl7.org/CodeSystem/ex-benefitcategory in valuesets.xml
    """
    DentalCoverage = BenefitCategoryCodesCode("F3")
    """
    Hearing Coverage.
    From: http://terminology.hl7.org/CodeSystem/ex-benefitcategory in valuesets.xml
    """
    HearingCoverage = BenefitCategoryCodesCode("F4")
    """
    Vision Coverage.
    From: http://terminology.hl7.org/CodeSystem/ex-benefitcategory in valuesets.xml
    """
    VisionCoverage = BenefitCategoryCodesCode("F6")
