from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class BundleTypeCode(GenericTypeCode):
    """
    BundleType
    From: http://hl7.org/fhir/bundle-type in valuesets.xml
        Indicates the purpose of a bundle - how it is intended to be used.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/bundle-type
    """
    codeset: FhirUri = "http://hl7.org/fhir/bundle-type"


class BundleTypeCodeValues:
    """
    The bundle is a document. The first resource is a Composition.
    From: http://hl7.org/fhir/bundle-type in valuesets.xml
    """

    Document = BundleTypeCode("document")
    """
    The bundle is a message. The first resource is a MessageHeader.
    From: http://hl7.org/fhir/bundle-type in valuesets.xml
    """
    Message = BundleTypeCode("message")
    """
    The bundle is a transaction - intended to be processed by a server as an
    atomic commit.
    From: http://hl7.org/fhir/bundle-type in valuesets.xml
    """
    Transaction = BundleTypeCode("transaction")
    """
    The bundle is a transaction response. Because the response is a transaction
    response, the transaction has succeeded, and all responses are error free.
    From: http://hl7.org/fhir/bundle-type in valuesets.xml
    """
    TransactionResponse = BundleTypeCode("transaction-response")
    """
    The bundle is a set of actions - intended to be processed by a server as a
    group of independent actions.
    From: http://hl7.org/fhir/bundle-type in valuesets.xml
    """
    Batch = BundleTypeCode("batch")
    """
    The bundle is a batch response. Note that as a batch, some responses may
    indicate failure and others success.
    From: http://hl7.org/fhir/bundle-type in valuesets.xml
    """
    BatchResponse = BundleTypeCode("batch-response")
    """
    The bundle is a list of resources from a history interaction on a server.
    From: http://hl7.org/fhir/bundle-type in valuesets.xml
    """
    HistoryList = BundleTypeCode("history")
    """
    The bundle is a list of resources returned as a result of a search/query
    interaction, operation, or message.
    From: http://hl7.org/fhir/bundle-type in valuesets.xml
    """
    SearchResults = BundleTypeCode("searchset")
    """
    The bundle is a set of resources collected into a single package for ease of
    distribution that imposes no processing obligations or behavioral rules beyond
    persistence.
    From: http://hl7.org/fhir/bundle-type in valuesets.xml
    """
    Collection = BundleTypeCode("collection")
