from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class CarePlanActivityStatusCode(GenericTypeCode):
    """
    CarePlanActivityStatus
    From: http://hl7.org/fhir/care-plan-activity-status in valuesets.xml
        Codes that reflect the current state of a care plan activity within its
    overall life cycle.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/care-plan-activity-status
    """
    codeset: FhirUri = "http://hl7.org/fhir/care-plan-activity-status"


class CarePlanActivityStatusCodeValues:
    """
    Care plan activity is planned but no action has yet been taken.
    From: http://hl7.org/fhir/care-plan-activity-status in valuesets.xml
    """

    NotStarted = CarePlanActivityStatusCode("not-started")
    """
    Appointment or other booking has occurred but activity has not yet begun.
    From: http://hl7.org/fhir/care-plan-activity-status in valuesets.xml
    """
    Scheduled = CarePlanActivityStatusCode("scheduled")
    """
    Care plan activity has been started but is not yet complete.
    From: http://hl7.org/fhir/care-plan-activity-status in valuesets.xml
    """
    InProgress = CarePlanActivityStatusCode("in-progress")
    """
    Care plan activity was started but has temporarily ceased with an expectation
    of resumption at a future time.
    From: http://hl7.org/fhir/care-plan-activity-status in valuesets.xml
    """
    OnHold = CarePlanActivityStatusCode("on-hold")
    """
    Care plan activity has been completed (more or less) as planned.
    From: http://hl7.org/fhir/care-plan-activity-status in valuesets.xml
    """
    Completed = CarePlanActivityStatusCode("completed")
    """
    The planned care plan activity has been withdrawn.
    From: http://hl7.org/fhir/care-plan-activity-status in valuesets.xml
    """
    Cancelled = CarePlanActivityStatusCode("cancelled")
    """
    The current state of the care plan activity is not known.  Note: This concept
    is not to be used for "other" - one of the listed statuses is presumed to
    apply, but the authoring/source system does not know which one.
    From: http://hl7.org/fhir/care-plan-activity-status in valuesets.xml
    """
    Unknown = CarePlanActivityStatusCode("unknown")
    """
    Care plan activity was entered in error and voided.
    From: http://hl7.org/fhir/care-plan-activity-status in valuesets.xml
    """
    EnteredInError = CarePlanActivityStatusCode("entered-in-error")
