from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class CertaintySubcomponentTypeCode(GenericTypeCode):
    """
    CertaintySubcomponentType
    From: http://terminology.hl7.org/CodeSystem/certainty-subcomponent-type in valuesets.xml
        The subcomponent classification of quality of evidence rating systems.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/certainty-subcomponent-type
    """
    codeset: FhirUri = (
        "http://terminology.hl7.org/CodeSystem/certainty-subcomponent-type"
    )


class CertaintySubcomponentTypeCodeValues:
    """
    methodologic concerns reducing internal validity.
    From: http://terminology.hl7.org/CodeSystem/certainty-subcomponent-type in valuesets.xml
    """

    RiskOfBias = CertaintySubcomponentTypeCode("RiskOfBias")
    """
    concerns that findings are not similar enough to support certainty.
    From: http://terminology.hl7.org/CodeSystem/certainty-subcomponent-type in valuesets.xml
    """
    Inconsistency = CertaintySubcomponentTypeCode("Inconsistency")
    """
    concerns reducing external validity.
    From: http://terminology.hl7.org/CodeSystem/certainty-subcomponent-type in valuesets.xml
    """
    Indirectness = CertaintySubcomponentTypeCode("Indirectness")
    """
    High quality evidence.
    From: http://terminology.hl7.org/CodeSystem/certainty-subcomponent-type in valuesets.xml
    """
    Imprecision = CertaintySubcomponentTypeCode("Imprecision")
    """
    likelihood that what is published misrepresents what is available to publish.
    From: http://terminology.hl7.org/CodeSystem/certainty-subcomponent-type in valuesets.xml
    """
    PublicationBias = CertaintySubcomponentTypeCode("PublicationBias")
    """
    higher certainty due to dose response relationship.
    From: http://terminology.hl7.org/CodeSystem/certainty-subcomponent-type in valuesets.xml
    """
    DoseResponseGradient = CertaintySubcomponentTypeCode("DoseResponseGradient")
    """
    higher certainty due to risk of bias in opposite direction.
    From: http://terminology.hl7.org/CodeSystem/certainty-subcomponent-type in valuesets.xml
    """
    PlausibleConfounding = CertaintySubcomponentTypeCode("PlausibleConfounding")
    """
    higher certainty due to large effect size.
    From: http://terminology.hl7.org/CodeSystem/certainty-subcomponent-type in valuesets.xml
    """
    LargeEffect = CertaintySubcomponentTypeCode("LargeEffect")
