from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class CodingRationale(GenericTypeCode):
    """
    v3.CodingRationale
    From: http://terminology.hl7.org/ValueSet/v3-CodingRationale in v3-codesystems.xml
         Identifies how to interpret the instance of the code, codeSystem value in a
    set of translations.  Since HL7 (or a government body) may mandate that codes
    from certain code systems be sent in conformant messages, other synonyms that
    are sent in the translation set need to be distinguished among the originally
    captured source, the HL7 specified code, or some future role.  When this code
    is NULL, it indicates that the translation is an undefined type.  When valued,
    this property must contain one of the following values: SRC - Source (or
    original) code HL7 - HL7 Specified or Mandated SH - both HL7 mandated and the
    original code (precoordination) There may be additional values added to this
    value set as we work through the use of codes in messages and determine other
    Use Cases requiring special interpretation of the translations.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/v3-CodingRationale
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/v3-CodingRationale"


class CodingRationaleValues:
    """
    Description: Originally produced code.
    From: http://terminology.hl7.org/CodeSystem/v3-CodingRationale in v3-codesystems.xml
    """

    OriginallyProducedCode = CodingRationale("O")
    """
    Originally produced code, required by the specification describing the use of
    the coded concept.
    From: http://terminology.hl7.org/CodeSystem/v3-CodingRationale in v3-codesystems.xml
    """
    OriginalAndRequired = CodingRationale("OR")
    """
    Description: Post-coded from free text source</description>
    From: http://terminology.hl7.org/CodeSystem/v3-CodingRationale in v3-codesystems.xml
    """
    Post_coded = CodingRationale("P")
    """
    Post-coded from free text source, required by the specification describing the
    use of the coded concept.
    From: http://terminology.hl7.org/CodeSystem/v3-CodingRationale in v3-codesystems.xml
    """
    Post_codedAndRequired = CodingRationale("PR")
    """
    Description: Required standard code for HL7.
    From: http://terminology.hl7.org/CodeSystem/v3-CodingRationale in v3-codesystems.xml
    """
    Required = CodingRationale("R")
    """
    HL7 Specified or Mandated
    From: http://terminology.hl7.org/CodeSystem/v3-CodingRationale in v3-codesystems.xml
    """
    HL7SpecifiedOrMandated = CodingRationale("HL7")
    """
    Both HL7 mandated and the original code (precoordination)
    From: http://terminology.hl7.org/CodeSystem/v3-CodingRationale in v3-codesystems.xml
    """
    BothHL7MandatedAndTheOriginalCode = CodingRationale("SH")
    """
    Source (or original) code
    From: http://terminology.hl7.org/CodeSystem/v3-CodingRationale in v3-codesystems.xml
    """
    Source_orOriginal_Code = CodingRationale("SRC")
