from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class CompositionStatusCode(GenericTypeCode):
    """
    CompositionStatus
    From: http://hl7.org/fhir/composition-status in valuesets.xml
        The workflow/clinical status of the composition.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/composition-status
    """
    codeset: FhirUri = "http://hl7.org/fhir/composition-status"


class CompositionStatusCodeValues:
    """
    This is a preliminary composition or document (also known as initial or
    interim). The content may be incomplete or unverified.
    From: http://hl7.org/fhir/composition-status in valuesets.xml
    """

    Preliminary = CompositionStatusCode("preliminary")
    """
    This version of the composition is complete and verified by an appropriate
    person and no further work is planned. Any subsequent updates would be on a
    new version of the composition.
    From: http://hl7.org/fhir/composition-status in valuesets.xml
    """
    Final = CompositionStatusCode("final")
    """
    The composition content or the referenced resources have been modified (edited
    or added to) subsequent to being released as "final" and the composition is
    complete and verified by an authorized person.
    From: http://hl7.org/fhir/composition-status in valuesets.xml
    """
    Amended = CompositionStatusCode("amended")
    """
    The composition or document was originally created/issued in error, and this
    is an amendment that marks that the entire series should not be considered as
    valid.
    From: http://hl7.org/fhir/composition-status in valuesets.xml
    """
    EnteredInError = CompositionStatusCode("entered-in-error")
