from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class ConceptSubsumptionOutcomeCode(GenericTypeCode):
    """
    ConceptSubsumptionOutcome
    From: http://hl7.org/fhir/concept-subsumption-outcome in valuesets.xml
        The subsumption relationship between code/Coding "A" and code/Coding "B".
    There are 4 possible codes to be returned: equivalent, subsumes, subsumed-by,
    and not-subsumed. If the server is unable to determine the relationship
    between the codes/Codings, then it returns an error (i.e. an
    OperationOutcome).
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/concept-subsumption-outcome
    """
    codeset: FhirUri = "http://hl7.org/fhir/concept-subsumption-outcome"


class ConceptSubsumptionOutcomeCodeValues:
    """
    The two concepts are equivalent (have the same properties).
    From: http://hl7.org/fhir/concept-subsumption-outcome in valuesets.xml
    """

    Equivalent = ConceptSubsumptionOutcomeCode("equivalent")
    """
    Coding/code "A" subsumes Coding/code "B" (e.g. B has all the properties A has,
    and some of it's own).
    From: http://hl7.org/fhir/concept-subsumption-outcome in valuesets.xml
    """
    Subsumes = ConceptSubsumptionOutcomeCode("subsumes")
    """
    Coding/code "A" is subsumed by Coding/code "B" (e.g. A has all the properties
    B has, and some of it's own).
    From: http://hl7.org/fhir/concept-subsumption-outcome in valuesets.xml
    """
    Subsumed_By = ConceptSubsumptionOutcomeCode("subsumed-by")
    """
    Coding/code "A" and Coding/code "B" are disjoint (e.g. each has propeties that
    the other doesn't have).
    From: http://hl7.org/fhir/concept-subsumption-outcome in valuesets.xml
    """
    Not_Subsumed = ConceptSubsumptionOutcomeCode("not-subsumed")
