from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class ConsentStateCode(GenericTypeCode):
    """
    ConsentState
    From: http://hl7.org/fhir/consent-state-codes in valuesets.xml
        Indicates the state of the consent.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/consent-state-codes
    """
    codeset: FhirUri = "http://hl7.org/fhir/consent-state-codes"


class ConsentStateCodeValues:
    """
    The consent is in development or awaiting use but is not yet intended to be
    acted upon.
    From: http://hl7.org/fhir/consent-state-codes in valuesets.xml
    """

    Pending = ConsentStateCode("draft")
    """
    The consent has been proposed but not yet agreed to by all parties. The
    negotiation stage.
    From: http://hl7.org/fhir/consent-state-codes in valuesets.xml
    """
    Proposed = ConsentStateCode("proposed")
    """
    The consent is to be followed and enforced.
    From: http://hl7.org/fhir/consent-state-codes in valuesets.xml
    """
    Active = ConsentStateCode("active")
    """
    The consent has been rejected by one or more of the parties.
    From: http://hl7.org/fhir/consent-state-codes in valuesets.xml
    """
    Rejected = ConsentStateCode("rejected")
    """
    The consent is terminated or replaced.
    From: http://hl7.org/fhir/consent-state-codes in valuesets.xml
    """
    Inactive = ConsentStateCode("inactive")
    """
    The consent was created wrongly (e.g. wrong patient) and should be ignored.
    From: http://hl7.org/fhir/consent-state-codes in valuesets.xml
    """
    EnteredInError = ConsentStateCode("entered-in-error")
