from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class ContactPointSystemCode(GenericTypeCode):
    """
    ContactPointSystem
    From: http://hl7.org/fhir/contact-point-system in valuesets.xml
        Telecommunications form for contact point.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/contact-point-system
    """
    codeset: FhirUri = "http://hl7.org/fhir/contact-point-system"


class ContactPointSystemCodeValues:
    """
    The value is a telephone number used for voice calls. Use of full
    international numbers starting with + is recommended to enable automatic
    dialing support but not required.
    From: http://hl7.org/fhir/contact-point-system in valuesets.xml
    """

    Phone = ContactPointSystemCode("phone")
    """
    The value is a fax machine. Use of full international numbers starting with +
    is recommended to enable automatic dialing support but not required.
    From: http://hl7.org/fhir/contact-point-system in valuesets.xml
    """
    Fax = ContactPointSystemCode("fax")
    """
    The value is an email address.
    From: http://hl7.org/fhir/contact-point-system in valuesets.xml
    """
    Email = ContactPointSystemCode("email")
    """
    The value is a pager number. These may be local pager numbers that are only
    usable on a particular pager system.
    From: http://hl7.org/fhir/contact-point-system in valuesets.xml
    """
    Pager = ContactPointSystemCode("pager")
    """
    A contact that is not a phone, fax, pager or email address and is expressed as
    a URL.  This is intended for various institutional or personal contacts
    including web sites, blogs, Skype, Twitter, Facebook, etc. Do not use for
    email addresses.
    From: http://hl7.org/fhir/contact-point-system in valuesets.xml
    """
    URL = ContactPointSystemCode("url")
    """
    A contact that can be used for sending an sms message (e.g. mobile phones,
    some landlines).
    From: http://hl7.org/fhir/contact-point-system in valuesets.xml
    """
    SMS = ContactPointSystemCode("sms")
    """
    A contact that is not a phone, fax, page or email address and is not
    expressible as a URL.  E.g. Internal mail address.  This SHOULD NOT be used
    for contacts that are expressible as a URL (e.g. Skype, Twitter, Facebook,
    etc.)  Extensions may be used to distinguish "other" contact types.
    From: http://hl7.org/fhir/contact-point-system in valuesets.xml
    """
    Other = ContactPointSystemCode("other")
