from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class ContactPointUseCode(GenericTypeCode):
    """
    ContactPointUse
    From: http://hl7.org/fhir/contact-point-use in valuesets.xml
        Use of contact point.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/contact-point-use
    """
    codeset: FhirUri = "http://hl7.org/fhir/contact-point-use"


class ContactPointUseCodeValues:
    """
    A communication contact point at a home; attempted contacts for business
    purposes might intrude privacy and chances are one will contact family or
    other household members instead of the person one wishes to call. Typically
    used with urgent cases, or if no other contacts are available.
    From: http://hl7.org/fhir/contact-point-use in valuesets.xml
    """

    Home = ContactPointUseCode("home")
    """
    An office contact point. First choice for business related contacts during
    business hours.
    From: http://hl7.org/fhir/contact-point-use in valuesets.xml
    """
    Work = ContactPointUseCode("work")
    """
    A temporary contact point. The period can provide more detailed information.
    From: http://hl7.org/fhir/contact-point-use in valuesets.xml
    """
    Temp = ContactPointUseCode("temp")
    """
    This contact point is no longer in use (or was never correct, but retained for
    records).
    From: http://hl7.org/fhir/contact-point-use in valuesets.xml
    """
    Old = ContactPointUseCode("old")
    """
    A telecommunication device that moves and stays with its owner. May have
    characteristics of all other use codes, suitable for urgent matters, not the
    first choice for routine business.
    From: http://hl7.org/fhir/contact-point-use in valuesets.xml
    """
    Mobile = ContactPointUseCode("mobile")
