from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class ContextControl(GenericTypeCode):
    """
    v3.ContextControl
    From: http://terminology.hl7.org/ValueSet/v3-ContextControl in v3-codesystems.xml
         A code that specifies how an ActRelationship or Participation contributes to
    the context of an Act, and whether it may be propagated to descendent Acts
    whose association allows such propagation (see also attributes
    Participation.contextControlCode, ActRelationship.contextControlCode,
    ActRelationship.contextConductionInd).
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/v3-ContextControl
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/v3-ContextControl"


class ContextControlValues:
    """
    The association adds to the existing context associated with the Act.  Both
    this association and any associations propagated from ancestor Acts are
    interpreted as being related to this Act.
    From: http://terminology.hl7.org/CodeSystem/v3-ContextControl in v3-codesystems.xml
    """

    ContextControlAdditive = ContextControl("_ContextControlAdditive")
    """
    The association applies only to the current Act and will not propagate to any
    child Acts that are related via a conducting ActRelationship (refer to
    contextConductionInd).
    From: http://terminology.hl7.org/CodeSystem/v3-ContextControl in v3-codesystems.xml
    """
    ContextControlNonPropagating = ContextControl("_ContextControlNonPropagating")
    """
    The association adds to the existing context associated with the Act, but
    replaces associations propagated from ancestor Acts whose typeCodes are the
    same or more specific.
    From: http://terminology.hl7.org/CodeSystem/v3-ContextControl in v3-codesystems.xml
    """
    ContextControlOverriding = ContextControl("_ContextControlOverriding")
    """
    The association propagates to any child Acts that are related via a conducting
    ActRelationship (refer to contextConductionInd).
    From: http://terminology.hl7.org/CodeSystem/v3-ContextControl in v3-codesystems.xml
    """
    ContextControlPropagating = ContextControl("_ContextControlPropagating")
