from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class FhirDataType(GenericTypeCode):
    """
    DataType
    From: http://hl7.org/fhir/data-types in valuesets.xml
        A version specific list of the data types defined by the FHIR specification
    for use as an element  type (any of the FHIR defined data types).
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/data-types
    """
    codeset: FhirUri = "http://hl7.org/fhir/data-types"


class FhirDataTypeValues:
    """
    An address expressed using postal conventions (as opposed to GPS or other
    location definition formats).  This data type may be used to convey addresses
    for use in delivering mail as well as for visiting locations which might not
    be valid for mail delivery.  There are a variety of postal address formats
    defined around the world.
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """

    Address = FhirDataType("Address")
    """
    A duration of time during which an organism (or a process) has existed.
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    Age = FhirDataType("Age")
    """
    A  text note which also  contains information about who made the statement and
    when.
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    Annotation = FhirDataType("Annotation")
    """
    For referring to data content defined in other formats.
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    Attachment = FhirDataType("Attachment")
    """
    Base definition for all elements that are defined inside a resource - but not
    those in a data type.
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    BackboneElement = FhirDataType("BackboneElement")
    """
    A concept that may be defined by a formal reference to a terminology or
    ontology or may be provided by text.
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    CodeableConcept = FhirDataType("CodeableConcept")
    """
    A reference to a code defined by a terminology system.
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    Coding = FhirDataType("Coding")
    """
    Specifies contact information for a person or organization.
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    ContactDetail = FhirDataType("ContactDetail")
    """
    Details for all kinds of technology mediated contact points for a person or
    organization, including telephone, email, etc.
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    ContactPoint = FhirDataType("ContactPoint")
    """
    A contributor to the content of a knowledge asset, including authors, editors,
    reviewers, and endorsers.
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    Contributor = FhirDataType("Contributor")
    """
    A measured amount (or an amount that can potentially be measured). Note that
    measured amounts include amounts that are not precisely quantified, including
    amounts involving arbitrary units and floating currencies.
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    Count = FhirDataType("Count")
    """
    Describes a required data item for evaluation in terms of the type of data,
    and optional code or date-based filters of the data.
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    DataRequirement = FhirDataType("DataRequirement")
    """
    A length - a value with a unit that is a physical distance.
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    Distance = FhirDataType("Distance")
    """
    Indicates how the medication is/was taken or should be taken by the patient.
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    Dosage = FhirDataType("Dosage")
    """
    A length of time.
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    Duration = FhirDataType("Duration")
    """
    Base definition for all elements in a resource.
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    Element = FhirDataType("Element")
    """
    Captures constraints on each element within the resource, profile, or
    extension.
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    ElementDefinition = FhirDataType("ElementDefinition")
    """
    A expression that is evaluated in a specified context and returns a value. The
    context of use of the expression must specify the context in which the
    expression is evaluated, and how the result of the expression is used.
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    Expression = FhirDataType("Expression")
    """
    Optional Extension Element - found in all resources.
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    Extension = FhirDataType("Extension")
    """
    A human's name with the ability to identify parts and usage.
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    HumanName = FhirDataType("HumanName")
    """
    An identifier - identifies some entity uniquely and unambiguously. Typically
    this is used for business identifiers.
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    Identifier = FhirDataType("Identifier")
    """
    The marketing status describes the date when a medicinal product is actually
    put on the market or the date as of which it is no longer available.
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    MarketingStatus = FhirDataType("MarketingStatus")
    """
    The metadata about a resource. This is content in the resource that is
    maintained by the infrastructure. Changes to the content might not always be
    associated with version changes to the resource.
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    Meta = FhirDataType("Meta")
    """
    An amount of economic utility in some recognized currency.
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    Money = FhirDataType("Money")
    """
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    MoneyQuantity = FhirDataType("MoneyQuantity")
    """
    A human-readable summary of the resource conveying the essential clinical and
    business information for the resource.
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    Narrative = FhirDataType("Narrative")
    """
    The parameters to the module. This collection specifies both the input and
    output parameters. Input parameters are provided by the caller as part of the
    $evaluate operation. Output parameters are included in the GuidanceResponse.
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    ParameterDefinition = FhirDataType("ParameterDefinition")
    """
    A time period defined by a start and end date and optionally time.
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    Period = FhirDataType("Period")
    """
    A populatioof people with some set of grouping criteria.
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    Population = FhirDataType("Population")
    """
    The marketing status describes the date when a medicinal product is actually
    put on the market or the date as of which it is no longer available.
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    ProdCharacteristic = FhirDataType("ProdCharacteristic")
    """
    The shelf-life and storage information for a medicinal product item or
    container can be described using this class.
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    ProductShelfLife = FhirDataType("ProductShelfLife")
    """
    A measured amount (or an amount that can potentially be measured). Note that
    measured amounts include amounts that are not precisely quantified, including
    amounts involving arbitrary units and floating currencies.
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    Quantity = FhirDataType("Quantity")
    """
    A set of ordered Quantities defined by a low and high limit.
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    Range = FhirDataType("Range")
    """
    A relationship of two Quantity values - expressed as a numerator and a
    denominator.
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    Ratio = FhirDataType("Ratio")
    """
    A reference from one resource to another.
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    Reference = FhirDataType("Reference")
    """
    Related artifacts such as additional documentation, justification, or
    bibliographic references.
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    RelatedArtifact = FhirDataType("RelatedArtifact")
    """
    A series of measurements taken by a device, with upper and lower limits. There
    may be more than one dimension in the data.
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    SampledData = FhirDataType("SampledData")
    """
    A signature along with supporting context. The signature may be a digital
    signature that is cryptographic in nature, or some other signature acceptable
    to the domain. This other signature may be as simple as a graphical image
    representing a hand-written signature, or a signature ceremony Different
    signature approaches have different utilities.
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    Signature = FhirDataType("Signature")
    """
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    SimpleQuantity = FhirDataType("SimpleQuantity")
    """
    Chemical substances are a single substance type whose primary defining element
    is the molecular structure. Chemical substances shall be defined on the basis
    of their complete covalent molecular structure; the presence of a salt
    (counter-ion) and/or solvates (water, alcohols) is also captured. Purity,
    grade, physical form or particle size are not taken into account in the
    definition of a chemical substance or in the assignment of a Substance ID.
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    SubstanceAmount = FhirDataType("SubstanceAmount")
    """
    Specifies an event that may occur multiple times. Timing schedules are used to
    record when things are planned, expected or requested to occur. The most
    common usage is in dosage instructions for medications. They are also used
    when planning care of various kinds, and may be used for reporting the
    schedule to which past regular activities were carried out.
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    Timing = FhirDataType("Timing")
    """
    A description of a triggering event. Triggering events can be named events,
    data events, or periodic, as determined by the type element.
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    TriggerDefinition = FhirDataType("TriggerDefinition")
    """
    Specifies clinical/business/etc. metadata that can be used to retrieve, index
    and/or categorize an artifact. This metadata can either be specific to the
    applicable population (e.g., age category, DRG) or the specific context of
    care (e.g., venue, care setting, provider of care).
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    UsageContext = FhirDataType("UsageContext")
    """
    A stream of bytes
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    Base64Binary = FhirDataType("base64Binary")
    """
    Value of "true" or "false"
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    Boolean = FhirDataType("boolean")
    """
    A URI that is a reference to a canonical URL on a FHIR resource
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    Canonical = FhirDataType("canonical")
    """
    A string which has at least one character and no leading or trailing
    whitespace and where there is no whitespace other than single spaces in the
    contents
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    Code = FhirDataType("code")
    """
    A date or partial date (e.g. just year or year + month). There is no time
    zone. The format is a union of the schema types gYear, gYearMonth and date.
    Dates SHALL be valid dates.
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    Date = FhirDataType("date")
    """
    A date, date-time or partial date (e.g. just year or year + month).  If hours
    and minutes are specified, a time zone SHALL be populated. The format is a
    union of the schema types gYear, gYearMonth, date and dateTime. Seconds must
    be provided due to schema type constraints but may be zero-filled and may be
    ignored.                 Dates SHALL be valid dates.
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    DateTime = FhirDataType("dateTime")
    """
    A rational number with implicit precision
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    Decimal = FhirDataType("decimal")
    """
    Any combination of letters, numerals, "-" and ".", with a length limit of 64
    characters.  (This might be an integer, an unprefixed OID, UUID or any other
    identifier pattern that meets these constraints.)  Ids are case-insensitive.
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    Id = FhirDataType("id")
    """
    An instant in time - known at least to the second
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    Instant = FhirDataType("instant")
    """
    A whole number
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    Integer = FhirDataType("integer")
    """
    A string that may contain Github Flavored Markdown syntax for optional
    processing by a mark down presentation engine
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    Markdown = FhirDataType("markdown")
    """
    An OID represented as a URI
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    Oid = FhirDataType("oid")
    """
    An integer with a value that is positive (e.g. >0)
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    PositiveInt = FhirDataType("positiveInt")
    """
    A sequence of Unicode characters
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    String = FhirDataType("string")
    """
    A time during the day, with no date specified
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    Time = FhirDataType("time")
    """
    An integer with a value that is not negative (e.g. >= 0)
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    UnsignedInt = FhirDataType("unsignedInt")
    """
    String of characters used to identify a name or a resource
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    Uri = FhirDataType("uri")
    """
    A URI that is a literal reference
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    Url = FhirDataType("url")
    """
    A UUID, represented as a URI
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    Uuid = FhirDataType("uuid")
    """
    XHTML format, as defined by W3C, but restricted usage (mainly, no active
    content)
    From: http://hl7.org/fhir/data-types in valuesets.xml
    """
    XHTML = FhirDataType("xhtml")
