from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class DeviceDefinitionParameterGroupCode(GenericTypeCode):
    """
    DeviceDefinitionParameterGroup
    From: http://terminology.hl7.org/CodeSystem/parameter-group in valuesets.xml
        Codes identifying groupings of parameters; e.g. Cardiovascular.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/parameter-group
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/parameter-group"


class DeviceDefinitionParameterGroupCodeValues:
    """
    Haemodynamic Parameter Group - MDC_PGRP_HEMO.
    From: http://terminology.hl7.org/CodeSystem/parameter-group in valuesets.xml
    """

    HaemodynamicParameterGroup = DeviceDefinitionParameterGroupCode("haemodynamic")
    """
    ECG Parameter Group - MDC_PGRP_ECG.
    From: http://terminology.hl7.org/CodeSystem/parameter-group in valuesets.xml
    """
    ECGParameterGroup = DeviceDefinitionParameterGroupCode("ecg")
    """
    Respiratory Parameter Group - MDC_PGRP_RESP.
    From: http://terminology.hl7.org/CodeSystem/parameter-group in valuesets.xml
    """
    RespiratoryParameterGroup = DeviceDefinitionParameterGroupCode("respiratory")
    """
    Ventilation Parameter Group - MDC_PGRP_VENT.
    From: http://terminology.hl7.org/CodeSystem/parameter-group in valuesets.xml
    """
    VentilationParameterGroup = DeviceDefinitionParameterGroupCode("ventilation")
    """
    Neurological Parameter Group - MDC_PGRP_NEURO.
    From: http://terminology.hl7.org/CodeSystem/parameter-group in valuesets.xml
    """
    NeurologicalParameterGroup = DeviceDefinitionParameterGroupCode("neurological")
    """
    Drug Delivery Parameter Group - MDC_PGRP_DRUG.
    From: http://terminology.hl7.org/CodeSystem/parameter-group in valuesets.xml
    """
    DrugDeliveryParameterGroup = DeviceDefinitionParameterGroupCode("drug-delivery")
    """
    Fluid Chemistry Parameter Group - MDC_PGRP_FLUID.
    From: http://terminology.hl7.org/CodeSystem/parameter-group in valuesets.xml
    """
    FluidChemistryParameterGroup = DeviceDefinitionParameterGroupCode("fluid-chemistry")
    """
    Blood Chemistry Parameter Group - MDC_PGRP_BLOOD_CHEM.
    From: http://terminology.hl7.org/CodeSystem/parameter-group in valuesets.xml
    """
    BloodChemistryParameterGroup = DeviceDefinitionParameterGroupCode("blood-chemistry")
    """
    Miscellaneous Parameter Group - MDC_PGRP_MISC.
    From: http://terminology.hl7.org/CodeSystem/parameter-group in valuesets.xml
    """
    MiscellaneousParameterGroup = DeviceDefinitionParameterGroupCode("miscellaneous")
