from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class DeviceUseStatementStatusCode(GenericTypeCode):
    """
    DeviceUseStatementStatus
    From: http://hl7.org/fhir/device-statement-status in valuesets.xml
        A coded concept indicating the current status of the Device Usage.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/device-statement-status
    """
    codeset: FhirUri = "http://hl7.org/fhir/device-statement-status"


class DeviceUseStatementStatusCodeValues:
    """
    The device is still being used.
    From: http://hl7.org/fhir/device-statement-status in valuesets.xml
    """

    Active = DeviceUseStatementStatusCode("active")
    """
    The device is no longer being used.
    From: http://hl7.org/fhir/device-statement-status in valuesets.xml
    """
    Completed = DeviceUseStatementStatusCode("completed")
    """
    The statement was recorded incorrectly.
    From: http://hl7.org/fhir/device-statement-status in valuesets.xml
    """
    EnteredInError = DeviceUseStatementStatusCode("entered-in-error")
    """
    The device may be used at some time in the future.
    From: http://hl7.org/fhir/device-statement-status in valuesets.xml
    """
    Intended = DeviceUseStatementStatusCode("intended")
    """
    Actions implied by the statement have been permanently halted, before all of
    them occurred.
    From: http://hl7.org/fhir/device-statement-status in valuesets.xml
    """
    Stopped = DeviceUseStatementStatusCode("stopped")
    """
    Actions implied by the statement have been temporarily halted, but are
    expected to continue later. May also be called "suspended".
    From: http://hl7.org/fhir/device-statement-status in valuesets.xml
    """
    OnHold = DeviceUseStatementStatusCode("on-hold")
