from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class DietCode(GenericTypeCode):
    """
    Diet
    From: http://terminology.hl7.org/CodeSystem/diet in valuesets.xml
        This value set defines a set of codes that can be used to indicate dietary
    preferences or restrictions a patient may have.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/diet
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/diet"


class DietCodeValues:
    """
    Food without meat, poultry or seafood.
    From: http://terminology.hl7.org/CodeSystem/diet in valuesets.xml
    """

    Vegetarian = DietCode("vegetarian")
    """
    Excludes dairy products.
    From: http://terminology.hl7.org/CodeSystem/diet in valuesets.xml
    """
    DairyFree = DietCode("dairy-free")
    """
    Excludes ingredients containing nuts.
    From: http://terminology.hl7.org/CodeSystem/diet in valuesets.xml
    """
    NutFree = DietCode("nut-free")
    """
    Excludes ingredients containing gluten.
    From: http://terminology.hl7.org/CodeSystem/diet in valuesets.xml
    """
    GlutenFree = DietCode("gluten-free")
    """
    Food without meat, poultry, seafood, eggs, dairy products and other animal-
    derived substances.
    From: http://terminology.hl7.org/CodeSystem/diet in valuesets.xml
    """
    Vegan = DietCode("vegan")
    """
    Foods that conform to Islamic law.
    From: http://terminology.hl7.org/CodeSystem/diet in valuesets.xml
    """
    Halal = DietCode("halal")
    """
    Foods that conform to Jewish dietary law.
    From: http://terminology.hl7.org/CodeSystem/diet in valuesets.xml
    """
    Kosher = DietCode("kosher")
