from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class DischargeDispositionCode(GenericTypeCode):
    """
    DischargeDisposition
    From: http://terminology.hl7.org/CodeSystem/discharge-disposition in valuesets.xml
        This value set defines a set of codes that can be used to where the patient
    left the hospital.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/discharge-disposition
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/discharge-disposition"


class DischargeDispositionCodeValues:
    """
    The patient was dicharged and has indicated that they are going to return home
    afterwards.
    From: http://terminology.hl7.org/CodeSystem/discharge-disposition in valuesets.xml
    """

    Home = DischargeDispositionCode("home")
    """
    The patient was discharged and has indicated that they are going to return
    home afterwards, but not the patient's home - e.g. a family member's home.
    From: http://terminology.hl7.org/CodeSystem/discharge-disposition in valuesets.xml
    """
    AlternativeHome = DischargeDispositionCode("alt-home")
    """
    The patient was transferred to another healthcare facility.
    From: http://terminology.hl7.org/CodeSystem/discharge-disposition in valuesets.xml
    """
    OtherHealthcareFacility = DischargeDispositionCode("other-hcf")
    """
    The patient has been discharged into palliative care.
    From: http://terminology.hl7.org/CodeSystem/discharge-disposition in valuesets.xml
    """
    Hospice = DischargeDispositionCode("hosp")
    """
    The patient has been discharged into long-term care where is likely to be
    monitored through an ongoing episode-of-care.
    From: http://terminology.hl7.org/CodeSystem/discharge-disposition in valuesets.xml
    """
    Long_termCare = DischargeDispositionCode("long")
    """
    The patient self discharged against medical advice.
    From: http://terminology.hl7.org/CodeSystem/discharge-disposition in valuesets.xml
    """
    LeftAgainstAdvice = DischargeDispositionCode("aadvice")
    """
    The patient has deceased during this encounter.
    From: http://terminology.hl7.org/CodeSystem/discharge-disposition in valuesets.xml
    """
    Expired = DischargeDispositionCode("exp")
    """
    The patient has been transferred to a psychiatric facility.
    From: http://terminology.hl7.org/CodeSystem/discharge-disposition in valuesets.xml
    """
    PsychiatricHospital = DischargeDispositionCode("psy")
    """
    The patient was discharged and is to receive post acute care rehabilitation
    services.
    From: http://terminology.hl7.org/CodeSystem/discharge-disposition in valuesets.xml
    """
    Rehabilitation = DischargeDispositionCode("rehab")
    """
    The patient has been discharged to a skilled nursing facility for the patient
    to receive additional care.
    From: http://terminology.hl7.org/CodeSystem/discharge-disposition in valuesets.xml
    """
    SkilledNursingFacility = DischargeDispositionCode("snf")
    """
    The discharge disposition has not otherwise defined.
    From: http://terminology.hl7.org/CodeSystem/discharge-disposition in valuesets.xml
    """
    Other = DischargeDispositionCode("oth")
