from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class EncounterStatusCode(GenericTypeCode):
    """
    EncounterStatus
    From: http://hl7.org/fhir/encounter-status in valuesets.xml
        Current state of the encounter.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/encounter-status
    """
    codeset: FhirUri = "http://hl7.org/fhir/encounter-status"


class EncounterStatusCodeValues:
    """
    The Encounter has not yet started.
    From: http://hl7.org/fhir/encounter-status in valuesets.xml
    """

    Planned = EncounterStatusCode("planned")
    """
    The Patient is present for the encounter, however is not currently meeting
    with a practitioner.
    From: http://hl7.org/fhir/encounter-status in valuesets.xml
    """
    Arrived = EncounterStatusCode("arrived")
    """
    The patient has been assessed for the priority of their treatment based on the
    severity of their condition.
    From: http://hl7.org/fhir/encounter-status in valuesets.xml
    """
    Triaged = EncounterStatusCode("triaged")
    """
    The Encounter has begun and the patient is present / the practitioner and the
    patient are meeting.
    From: http://hl7.org/fhir/encounter-status in valuesets.xml
    """
    InProgress = EncounterStatusCode("in-progress")
    """
    The Encounter has begun, but the patient is temporarily on leave.
    From: http://hl7.org/fhir/encounter-status in valuesets.xml
    """
    OnLeave = EncounterStatusCode("onleave")
    """
    The Encounter has ended.
    From: http://hl7.org/fhir/encounter-status in valuesets.xml
    """
    Finished = EncounterStatusCode("finished")
    """
    The Encounter has ended before it has begun.
    From: http://hl7.org/fhir/encounter-status in valuesets.xml
    """
    Cancelled = EncounterStatusCode("cancelled")
    """
    This instance should not have been part of this patient's medical record.
    From: http://hl7.org/fhir/encounter-status in valuesets.xml
    """
    EnteredInError = EncounterStatusCode("entered-in-error")
    """
    The encounter status is unknown. Note that "unknown" is a value of last resort
    and every attempt should be made to provide a meaningful value other than
    "unknown".
    From: http://hl7.org/fhir/encounter-status in valuesets.xml
    """
    Unknown = EncounterStatusCode("unknown")
