from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class EndpointStatusCode(GenericTypeCode):
    """
    EndpointStatus
    From: http://hl7.org/fhir/endpoint-status in valuesets.xml
        The status of the endpoint.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/endpoint-status
    """
    codeset: FhirUri = "http://hl7.org/fhir/endpoint-status"


class EndpointStatusCodeValues:
    """
    This endpoint is expected to be active and can be used.
    From: http://hl7.org/fhir/endpoint-status in valuesets.xml
    """

    Active = EndpointStatusCode("active")
    """
    This endpoint is temporarily unavailable.
    From: http://hl7.org/fhir/endpoint-status in valuesets.xml
    """
    Suspended = EndpointStatusCode("suspended")
    """
    This endpoint has exceeded connectivity thresholds and is considered in an
    error state and should no longer be attempted to connect to until corrective
    action is taken.
    From: http://hl7.org/fhir/endpoint-status in valuesets.xml
    """
    Error = EndpointStatusCode("error")
    """
    This endpoint is no longer to be used.
    From: http://hl7.org/fhir/endpoint-status in valuesets.xml
    """
    Off = EndpointStatusCode("off")
    """
    This instance should not have been part of this patient's medical record.
    From: http://hl7.org/fhir/endpoint-status in valuesets.xml
    """
    EnteredInError = EndpointStatusCode("entered-in-error")
    """
    This endpoint is not intended for production usage.
    From: http://hl7.org/fhir/endpoint-status in valuesets.xml
    """
    Test = EndpointStatusCode("test")
