from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class EnteralFormulaTypeCodesCode(GenericTypeCode):
    """
    EnteralFormulaTypeCodes
    From: http://hl7.org/fhir/ValueSet/entformula-type in valuesets.xml
        EnteralFormulaType : Codes for type of enteral formula to be administered to
    patient.  This value set is composed of SNOMED CT (US Extension) Concepts from
    SCTID 470581016 (Enteral+supplement feeds hierarchy (product)) and is provided
    as a suggestive example.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://snomed.info/sct
    """
    codeset: FhirUri = "http://snomed.info/sct"


class EnteralFormulaTypeCodesCodeValues:
    """
    From: http://hl7.org/fhir/ValueSet/entformula-type in valuesets.xml
    """

    AdultCriticalCareFormula = EnteralFormulaTypeCodesCode("443031000124106")
    """
    From: http://hl7.org/fhir/ValueSet/entformula-type in valuesets.xml
    """
    AdultDiabetesSpecialtyFormula = EnteralFormulaTypeCodesCode("443051000124104")
    """
    From: http://hl7.org/fhir/ValueSet/entformula-type in valuesets.xml
    """
    AdultElementalFormula = EnteralFormulaTypeCodesCode("442911000124109")
    """
    From: http://hl7.org/fhir/ValueSet/entformula-type in valuesets.xml
    """
    AdultHepaticSpecialtyFormula = EnteralFormulaTypeCodesCode("443021000124108")
    """
    From: http://hl7.org/fhir/ValueSet/entformula-type in valuesets.xml
    """
    AdultHighEnergyFormula = EnteralFormulaTypeCodesCode("442971000124100")
    """
    From: http://hl7.org/fhir/ValueSet/entformula-type in valuesets.xml
    """
    AdultHydrolyzedProteinFormula = EnteralFormulaTypeCodesCode("442981000124102")
    """
    From: http://hl7.org/fhir/ValueSet/entformula-type in valuesets.xml
    """
    AdultHighProteinFormula = EnteralFormulaTypeCodesCode("442991000124104")
    """
    From: http://hl7.org/fhir/ValueSet/entformula-type in valuesets.xml
    """
    AdultHighProteinHighFiberFormula = EnteralFormulaTypeCodesCode("443011000124100")
    """
    From: http://hl7.org/fhir/ValueSet/entformula-type in valuesets.xml
    """
    AdultLowCarbohydrateFormula = EnteralFormulaTypeCodesCode("442961000124107")
    """
    From: http://hl7.org/fhir/ValueSet/entformula-type in valuesets.xml
    """
    AdultPulmonarySpecialtyFormula = EnteralFormulaTypeCodesCode("442951000124105")
    """
    From: http://hl7.org/fhir/ValueSet/entformula-type in valuesets.xml
    """
    AdultRenalSpecialtyFormula = EnteralFormulaTypeCodesCode("442941000124108")
    """
    From: http://hl7.org/fhir/ValueSet/entformula-type in valuesets.xml
    """
    AdultStandardFormula = EnteralFormulaTypeCodesCode("442921000124101")
    """
    From: http://hl7.org/fhir/ValueSet/entformula-type in valuesets.xml
    """
    AdultSoyProteinIsolateFormula = EnteralFormulaTypeCodesCode("442931000124103")
    """
    From: http://hl7.org/fhir/ValueSet/entformula-type in valuesets.xml
    """
    PediatricFormula = EnteralFormulaTypeCodesCode("443361000124100")
    """
    From: http://hl7.org/fhir/ValueSet/entformula-type in valuesets.xml
    """
    PediatricElementalFormula = EnteralFormulaTypeCodesCode("443401000124105")
    """
    From: http://hl7.org/fhir/ValueSet/entformula-type in valuesets.xml
    """
    PediatricHighEnergyFormula = EnteralFormulaTypeCodesCode("443491000124103")
    """
    From: http://hl7.org/fhir/ValueSet/entformula-type in valuesets.xml
    """
    PediatricHighEnergyFormulaWithIncreasedFiber = EnteralFormulaTypeCodesCode(
        "443501000124106"
    )
    """
    From: http://hl7.org/fhir/ValueSet/entformula-type in valuesets.xml
    """
    PediatricHydrolyzedProteinFormula = EnteralFormulaTypeCodesCode("443421000124100")
    """
    From: http://hl7.org/fhir/ValueSet/entformula-type in valuesets.xml
    """
    PediatricIncreasedFiberFormula = EnteralFormulaTypeCodesCode("443471000124104")
    """
    From: http://hl7.org/fhir/ValueSet/entformula-type in valuesets.xml
    """
    PediatricReducedEnergyFormula = EnteralFormulaTypeCodesCode("444431000124104")
    """
    From: http://hl7.org/fhir/ValueSet/entformula-type in valuesets.xml
    """
    PediatricStandardFormula = EnteralFormulaTypeCodesCode("443451000124109")
    """
    From: http://hl7.org/fhir/ValueSet/entformula-type in valuesets.xml
    """
    StandardEnteralFormulaWithFiber = EnteralFormulaTypeCodesCode("441561000124106")
    """
    From: http://hl7.org/fhir/ValueSet/entformula-type in valuesets.xml
    """
    StandardFormula = EnteralFormulaTypeCodesCode("443461000124106")
    """
    From: http://hl7.org/fhir/ValueSet/entformula-type in valuesets.xml
    """
    StandardEnteralFormula = EnteralFormulaTypeCodesCode("441531000124102")
    """
    From: http://hl7.org/fhir/ValueSet/entformula-type in valuesets.xml
    """
    SoyBasedFormula = EnteralFormulaTypeCodesCode("443561000124107")
    """
    From: http://hl7.org/fhir/ValueSet/entformula-type in valuesets.xml
    """
    RenalFormula = EnteralFormulaTypeCodesCode("443481000124101")
    """
    From: http://hl7.org/fhir/ValueSet/entformula-type in valuesets.xml
    """
    HighEnergyEnteralFormulaWithFiber = EnteralFormulaTypeCodesCode("441571000124104")
    """
    From: http://hl7.org/fhir/ValueSet/entformula-type in valuesets.xml
    """
    DiabeticEnteralFormulaWithFiber = EnteralFormulaTypeCodesCode("441591000124103")
    """
    From: http://hl7.org/fhir/ValueSet/entformula-type in valuesets.xml
    """
    DiabeticHighCalorieHighProteinEnteralFormulaWithFiber = EnteralFormulaTypeCodesCode(
        "441601000124106"
    )
    """
    From: http://hl7.org/fhir/ValueSet/entformula-type in valuesets.xml
    """
    IncreasedFiberFormula = EnteralFormulaTypeCodesCode("443351000124102")
    """
    From: http://hl7.org/fhir/ValueSet/entformula-type in valuesets.xml
    """
    HydrolyzedProteinFormula = EnteralFormulaTypeCodesCode("443771000124106")
    """
    From: http://hl7.org/fhir/ValueSet/entformula-type in valuesets.xml
    """
    HydrolyzedPeptide_basedHighProteinEnteralFormula = EnteralFormulaTypeCodesCode(
        "441671000124100"
    )
    """
    From: http://hl7.org/fhir/ValueSet/entformula-type in valuesets.xml
    """
    HighProteinFormula = EnteralFormulaTypeCodesCode("443111000124101")
    """
    From: http://hl7.org/fhir/ValueSet/entformula-type in valuesets.xml
    """
    HighEnergyFormula = EnteralFormulaTypeCodesCode("443431000124102")
    """
    From: http://hl7.org/fhir/ValueSet/entformula-type in valuesets.xml
    """
    ElementalFormula = EnteralFormulaTypeCodesCode("443411000124108")
    """
    From: http://hl7.org/fhir/ValueSet/entformula-type in valuesets.xml
    """
    AdultFormula = EnteralFormulaTypeCodesCode("442651000124102")
