from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class EntityHandling(GenericTypeCode):
    """
    v3.EntityHandling
    From: http://terminology.hl7.org/ValueSet/v3-EntityHandling in v3-codesystems.xml
        **** MISSING DEFINITIONS ****
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/v3-EntityHandling
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/v3-EntityHandling"


class EntityHandlingValues:
    """
    Keep at ambient temperature, 22 +/- 2C
    From: http://terminology.hl7.org/CodeSystem/v3-EntityHandling in v3-codesystems.xml
    """

    AmbientTemperature = EntityHandling("AMB")
    """
    Critical to keep at body temperature 36-38C
    From: http://terminology.hl7.org/CodeSystem/v3-EntityHandling in v3-codesystems.xml
    """
    BodyTemperature = EntityHandling("C37")
    """
    Critical ambient - must not be refrigerated or frozen.
    From: http://terminology.hl7.org/CodeSystem/v3-EntityHandling in v3-codesystems.xml
    """
    CriticalAmbientTemperature = EntityHandling("CAMB")
    """
    Critical. Do not expose to atmosphere.  Do not uncap.
    From: http://terminology.hl7.org/CodeSystem/v3-EntityHandling in v3-codesystems.xml
    """
    ProtectFromAir = EntityHandling("CATM")
    """
    Critical frozen. Specimen must not be allowed to thaw until immediately prior
    to testing.
    From: http://terminology.hl7.org/CodeSystem/v3-EntityHandling in v3-codesystems.xml
    """
    CriticalFrozen = EntityHandling("CFRZ")
    """
    Critical refrigerated - must not be allowed to freeze or warm until imediately
    prior to testing.
    From: http://terminology.hl7.org/CodeSystem/v3-EntityHandling in v3-codesystems.xml
    """
    CriticalRefrigeratedTemperature = EntityHandling("CREF")
    """
    Deep Frozen -16 to -20C.
    From: http://terminology.hl7.org/CodeSystem/v3-EntityHandling in v3-codesystems.xml
    """
    DeepFrozen = EntityHandling("DFRZ")
    """
    Keep in a dry environment
    From: http://terminology.hl7.org/CodeSystem/v3-EntityHandling in v3-codesystems.xml
    """
    Dry = EntityHandling("DRY")
    """
    Keep frozen below 0 ?C
    From: http://terminology.hl7.org/CodeSystem/v3-EntityHandling in v3-codesystems.xml
    """
    Frozen = EntityHandling("FRZ")
    """
    Container is free of heavy metals, including lead.
    From: http://terminology.hl7.org/CodeSystem/v3-EntityHandling in v3-codesystems.xml
    """
    MetalFree = EntityHandling("MTLF")
    """
    Keep in liquid nitrogen
    From: http://terminology.hl7.org/CodeSystem/v3-EntityHandling in v3-codesystems.xml
    """
    Nitrogen = EntityHandling("NTR")
    """
    Protect from light (eg. Wrap in aluminum foil).
    From: http://terminology.hl7.org/CodeSystem/v3-EntityHandling in v3-codesystems.xml
    """
    ProtectFromLight = EntityHandling("PRTL")
    """
    Do not shake
    From: http://terminology.hl7.org/CodeSystem/v3-EntityHandling in v3-codesystems.xml
    """
    DoNotShake = EntityHandling("PSA")
    """
    Protect against shock
    From: http://terminology.hl7.org/CodeSystem/v3-EntityHandling in v3-codesystems.xml
    """
    NoShock = EntityHandling("PSO")
    """
    Keep at refrigerated temperature:4-8C Accidental warming or freezing is of
    little consequence.
    From: http://terminology.hl7.org/CodeSystem/v3-EntityHandling in v3-codesystems.xml
    """
    RefrigeratedTemperature = EntityHandling("REF")
    """
    Shake thoroughly before using
    From: http://terminology.hl7.org/CodeSystem/v3-EntityHandling in v3-codesystems.xml
    """
    ShakeBeforeUse = EntityHandling("SBU")
    """
    Ultra cold frozen -75 to -85C.  Ultra cold freezer is typically at temperature
    of dry ice.
    From: http://terminology.hl7.org/CodeSystem/v3-EntityHandling in v3-codesystems.xml
    """
    UltraFrozen = EntityHandling("UFRZ")
    """
    Keep upright, do not turn upside down
    From: http://terminology.hl7.org/CodeSystem/v3-EntityHandling in v3-codesystems.xml
    """
    Upright = EntityHandling("UPR")
