from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class EntityRisk(GenericTypeCode):
    """
    v3.EntityRisk
    From: http://terminology.hl7.org/ValueSet/v3-EntityRisk in v3-codesystems.xml
         Kinds of risks associated with the handling of the material..
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/v3-EntityRisk
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/v3-EntityRisk"


class EntityRiskValues:
    """
    A danger that can be associated with certain living subjects, including
    humans.
    From: http://terminology.hl7.org/CodeSystem/v3-EntityRisk in v3-codesystems.xml
    """

    Aggressive = EntityRisk("AGG")
    """
    The dangers associated with normal biological materials. I.e. potential risk
    of unknown infections.  Routine biological materials from living subjects.
    From: http://terminology.hl7.org/CodeSystem/v3-EntityRisk in v3-codesystems.xml
    """
    Biological = EntityRisk("BIO")
    """
    Material is corrosive and may cause severe injury to skin, mucous membranes
    and eyes. Avoid any unprotected contact.
    From: http://terminology.hl7.org/CodeSystem/v3-EntityRisk in v3-codesystems.xml
    """
    Corrosive = EntityRisk("COR")
    """
    The entity is at risk for escaping from containment or control.
    From: http://terminology.hl7.org/CodeSystem/v3-EntityRisk in v3-codesystems.xml
    """
    EscapeRisk = EntityRisk("ESC")
    """
    Material is highly inflammable and in certain mixtures (with air) may lead to
    explosions.  Keep away from fire, sparks and excessive heat.
    From: http://terminology.hl7.org/CodeSystem/v3-EntityRisk in v3-codesystems.xml
    """
    Inflammable = EntityRisk("IFL")
    """
    Material known to be infectious with human pathogenic microorganisms.  Those
    who handle this material must take precautions for their protection.
    From: http://terminology.hl7.org/CodeSystem/v3-EntityRisk in v3-codesystems.xml
    """
    Infectious = EntityRisk("INF")
    """
    Material is solid and sharp (e.g., cannulas).  Dispose in hard container.
    From: http://terminology.hl7.org/CodeSystem/v3-EntityRisk in v3-codesystems.xml
    """
    InjuryHazard = EntityRisk("INJ")
    """
    Material is poisonous to humans and/or animals.  Special care must be taken to
    avoid incorporation, even of small amounts.
    From: http://terminology.hl7.org/CodeSystem/v3-EntityRisk in v3-codesystems.xml
    """
    Poison = EntityRisk("POI")
    """
    Material is a source for ionizing radiation and must be handled with special
    care to avoid injury of those who handle it and to avoid environmental
    hazards.
    From: http://terminology.hl7.org/CodeSystem/v3-EntityRisk in v3-codesystems.xml
    """
    Radioactive = EntityRisk("RAD")
