from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class Ethnicity(GenericTypeCode):
    """
    v3.Ethnicity
    From: http://terminology.hl7.org/ValueSet/v3-Ethnicity in v3-codesystems.xml
         In the United States, federal standards for classifying data on ethnicity
    determine the categories used by federal agencies and exert a strong influence
    on categorization by state and local agencies and private sector
    organizations. The federal standards do not conceptually define ethnicity, and
    they recognize the absence of an anthropological or scientific basis for
    ethnicity classification.  Instead, the federal standards acknowledge that
    ethnicity is a social-political construct in which an individual's own
    identification with a particular ethnicity is preferred to observer
    identification.  The standards specify two minimum ethnicity categories:
    Hispanic or Latino, and Not Hispanic or Latino.  The standards define a
    Hispanic or Latino as a person of "Mexican, Puerto Rican, Cuban, South or
    Central America, or other Spanish culture or origin, regardless of race." The
    standards stipulate that ethnicity data need not be limited to the two minimum
    categories, but any expansion must be collapsible to those categories.  In
    addition, the standards stipulate that an individual can be Hispanic or Latino
    or can be Not Hispanic or Latino, but cannot be both.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/v3-Ethnicity
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/v3-Ethnicity"


class EthnicityValues:
    """
    Hispanic or Latino
    From: http://terminology.hl7.org/CodeSystem/v3-Ethnicity in v3-codesystems.xml
    """

    HispanicOrLatino = Ethnicity("2135-2")
    """
    Note that this term remains in the table for completeness, even though within
    HL7, the notion of "not otherwise coded" term is deprecated.
    From: http://terminology.hl7.org/CodeSystem/v3-Ethnicity in v3-codesystems.xml
    """
    NotHispanicOrLatino = Ethnicity("2186-5")
