from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class EventTimingCode(GenericTypeCode):
    """
    EventTiming
    From: http://hl7.org/fhir/event-timing in valuesets.xml
        Real world event relating to the schedule.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/event-timing
    """
    codeset: FhirUri = "http://hl7.org/fhir/event-timing"


class EventTimingCodeValues:
    """
    Event occurs during the morning. The exact time is unspecified and established
    by institution convention or patient interpretation.
    From: http://hl7.org/fhir/event-timing in valuesets.xml
    """

    Morning = EventTimingCode("MORN")
    """
    Event occurs during the early morning. The exact time is unspecified and
    established by institution convention or patient interpretation.
    From: http://hl7.org/fhir/event-timing in valuesets.xml
    """
    EarlyMorning = EventTimingCode("MORN.early")
    """
    Event occurs during the late morning. The exact time is unspecified and
    established by institution convention or patient interpretation.
    From: http://hl7.org/fhir/event-timing in valuesets.xml
    """
    LateMorning = EventTimingCode("MORN.late")
    """
    Event occurs around 12:00pm. The exact time is unspecified and established by
    institution convention or patient interpretation.
    From: http://hl7.org/fhir/event-timing in valuesets.xml
    """
    Noon = EventTimingCode("NOON")
    """
    Event occurs during the afternoon. The exact time is unspecified and
    established by institution convention or patient interpretation.
    From: http://hl7.org/fhir/event-timing in valuesets.xml
    """
    Afternoon = EventTimingCode("AFT")
    """
    Event occurs during the early afternoon. The exact time is unspecified and
    established by institution convention or patient interpretation.
    From: http://hl7.org/fhir/event-timing in valuesets.xml
    """
    EarlyAfternoon = EventTimingCode("AFT.early")
    """
    Event occurs during the late afternoon. The exact time is unspecified and
    established by institution convention or patient interpretation.
    From: http://hl7.org/fhir/event-timing in valuesets.xml
    """
    LateAfternoon = EventTimingCode("AFT.late")
    """
    Event occurs during the evening. The exact time is unspecified and established
    by institution convention or patient interpretation.
    From: http://hl7.org/fhir/event-timing in valuesets.xml
    """
    Evening = EventTimingCode("EVE")
    """
    Event occurs during the early evening. The exact time is unspecified and
    established by institution convention or patient interpretation.
    From: http://hl7.org/fhir/event-timing in valuesets.xml
    """
    EarlyEvening = EventTimingCode("EVE.early")
    """
    Event occurs during the late evening. The exact time is unspecified and
    established by institution convention or patient interpretation.
    From: http://hl7.org/fhir/event-timing in valuesets.xml
    """
    LateEvening = EventTimingCode("EVE.late")
    """
    Event occurs during the night. The exact time is unspecified and established
    by institution convention or patient interpretation.
    From: http://hl7.org/fhir/event-timing in valuesets.xml
    """
    Night = EventTimingCode("NIGHT")
    """
    Event occurs [offset] after subject goes to sleep. The exact time is
    unspecified and established by institution convention or patient
    interpretation.
    From: http://hl7.org/fhir/event-timing in valuesets.xml
    """
    AfterSleep = EventTimingCode("PHS")
