from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class ExampleDiagnosisTypeCodesCode(GenericTypeCode):
    """
    ExampleDiagnosisTypeCodes
    From: http://terminology.hl7.org/CodeSystem/ex-diagnosistype in valuesets.xml
        This value set includes example Diagnosis Type codes.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/ex-diagnosistype
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/ex-diagnosistype"


class ExampleDiagnosisTypeCodesCodeValues:
    """
    The diagnosis given as the reason why the patient was admitted to the
    hospital.
    From: http://terminology.hl7.org/CodeSystem/ex-diagnosistype in valuesets.xml
    """

    AdmittingDiagnosis = ExampleDiagnosisTypeCodesCode("admitting")
    """
    A diagnosis made on the basis of medical signs and patient-reported symptoms,
    rather than diagnostic tests.
    From: http://terminology.hl7.org/CodeSystem/ex-diagnosistype in valuesets.xml
    """
    ClinicalDiagnosis = ExampleDiagnosisTypeCodesCode("clinical")
    """
    One of a set of the possible diagnoses that could be connected to the signs,
    symptoms, and lab findings.
    From: http://terminology.hl7.org/CodeSystem/ex-diagnosistype in valuesets.xml
    """
    DifferentialDiagnosis = ExampleDiagnosisTypeCodesCode("differential")
    """
    The diagnosis given when the patient is discharged from the hospital.
    From: http://terminology.hl7.org/CodeSystem/ex-diagnosistype in valuesets.xml
    """
    DischargeDiagnosis = ExampleDiagnosisTypeCodesCode("discharge")
    """
    A diagnosis based significantly on laboratory reports or test results, rather
    than the physical examination of the patient.
    From: http://terminology.hl7.org/CodeSystem/ex-diagnosistype in valuesets.xml
    """
    LaboratoryDiagnosis = ExampleDiagnosisTypeCodesCode("laboratory")
    """
    A diagnosis which identifies people's responses to situations in their lives,
    such as a readiness to change or a willingness to accept assistance.
    From: http://terminology.hl7.org/CodeSystem/ex-diagnosistype in valuesets.xml
    """
    NursingDiagnosis = ExampleDiagnosisTypeCodesCode("nursing")
    """
    A diagnosis determined prior to birth.
    From: http://terminology.hl7.org/CodeSystem/ex-diagnosistype in valuesets.xml
    """
    PrenatalDiagnosis = ExampleDiagnosisTypeCodesCode("prenatal")
    """
    The single medical diagnosis that is most relevant to the patient's chief
    complaint or need for treatment.
    From: http://terminology.hl7.org/CodeSystem/ex-diagnosistype in valuesets.xml
    """
    PrincipalDiagnosis = ExampleDiagnosisTypeCodesCode("principal")
    """
    A diagnosis based primarily on the results from medical imaging studies.
    From: http://terminology.hl7.org/CodeSystem/ex-diagnosistype in valuesets.xml
    """
    RadiologyDiagnosis = ExampleDiagnosisTypeCodesCode("radiology")
    """
    A diagnosis determined using telemedicine techniques.
    From: http://terminology.hl7.org/CodeSystem/ex-diagnosistype in valuesets.xml
    """
    RemoteDiagnosis = ExampleDiagnosisTypeCodesCode("remote")
    """
    The labeling of an illness in a specific historical event using modern
    knowledge, methods and disease classifications.
    From: http://terminology.hl7.org/CodeSystem/ex-diagnosistype in valuesets.xml
    """
    RetrospectiveDiagnosis = ExampleDiagnosisTypeCodesCode("retrospective")
    """
    A diagnosis determined by the patient.
    From: http://terminology.hl7.org/CodeSystem/ex-diagnosistype in valuesets.xml
    """
    SelfDiagnosis = ExampleDiagnosisTypeCodesCode("self")
