from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class ExampleServicePlaceCodesCode(GenericTypeCode):
    """
    ExampleServicePlaceCodes
    From: http://terminology.hl7.org/CodeSystem/ex-serviceplace in valuesets.xml
        This value set includes a smattering of Service Place codes.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/ex-serviceplace
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/ex-serviceplace"


class ExampleServicePlaceCodesCodeValues:
    """
    A facility or location where drugs and other medically related items and
    services are sold, dispensed, or otherwise provided directly to patients.
    From: http://terminology.hl7.org/CodeSystem/ex-serviceplace in valuesets.xml
    """

    Pharmacy = ExampleServicePlaceCodesCode("01")
    """
    A facility whose primary purpose is education.
    From: http://terminology.hl7.org/CodeSystem/ex-serviceplace in valuesets.xml
    """
    School = ExampleServicePlaceCodesCode("03")
    """
    A facility or location whose primary purpose is to provide temporary housing
    to homeless individuals (e.g., emergency shelters, individual or family
    shelters).
    From: http://terminology.hl7.org/CodeSystem/ex-serviceplace in valuesets.xml
    """
    HomelessShelter = ExampleServicePlaceCodesCode("04")
    """
    A facility or location, owned and operated by the Indian Health Service, which
    provides diagnostic, therapeutic (surgical and nonsurgical), and
    rehabilitation services to American Indians and Alaska Natives who do not
    require hospitalization.
    From: http://terminology.hl7.org/CodeSystem/ex-serviceplace in valuesets.xml
    """
    IndianHealthServiceFree_standingFacility = ExampleServicePlaceCodesCode("05")
    """
    A facility or location, owned and operated by the Indian Health Service, which
    provides diagnostic, therapeutic (surgical and nonsurgical), and
    rehabilitation services rendered by, or under the supervision of, physicians
    to American Indians and Alaska Natives admitted as inpatients or outpatients.
    From: http://terminology.hl7.org/CodeSystem/ex-serviceplace in valuesets.xml
    """
    IndianHealthServiceProvider_basedFacility = ExampleServicePlaceCodesCode("06")
    """
    A facility or location owned and operated by a federally recognized American
    Indian or Alaska Native tribe or tribal organization under a 638 agreement,
    which provides diagnostic, therapeutic (surgical and nonsurgical), and
    rehabilitation services to tribal members who do not require hospitalization.
    From: http://terminology.hl7.org/CodeSystem/ex-serviceplace in valuesets.xml
    """
    Tribal638Free_StandingFacility = ExampleServicePlaceCodesCode("07")
    """
    A facility or location owned and operated by a federally recognized American
    Indian or Alaska Native tribe or tribal organization under a 638 agreement,
    which provides diagnostic, therapeutic (surgical and nonsurgical), and
    rehabilitation services to tribal members admitted as inpatients or
    outpatients.
    From: http://terminology.hl7.org/CodeSystem/ex-serviceplace in valuesets.xml
    """
    Tribal638Provider_BasedFacility = ExampleServicePlaceCodesCode("08")
    """
    A prison, jail, reformatory, work farm, detention center, or any other similar
    facility maintained by either Federal, State or local authorities for the
    purpose of confinement or rehabilitation of adult or juvenile criminal
    offenders.
    From: http://terminology.hl7.org/CodeSystem/ex-serviceplace in valuesets.xml
    """
    Prison_CorrectionalFacility = ExampleServicePlaceCodesCode("09")
    """
    Location, other than a hospital, skilled nursing facility (SNF), military
    treatment facility, community health center, State or local public health
    clinic, or intermediate care facility (ICF), where the health professional
    routinely provides health examinations, diagnosis, and treatment of illness or
    injury on an ambulatory basis.
    From: http://terminology.hl7.org/CodeSystem/ex-serviceplace in valuesets.xml
    """
    Office = ExampleServicePlaceCodesCode("11")
    """
    Location, other than a hospital or other facility, where the patient receives
    care in a private residence.
    From: http://terminology.hl7.org/CodeSystem/ex-serviceplace in valuesets.xml
    """
    Home = ExampleServicePlaceCodesCode("12")
    """
    Congregate residential facility with self-contained living units providing
    assessment of each resident's needs and on-site support 24 hours a day, 7 days
    a week, with the capacity to deliver or arrange for services including some
    health care and other services.
    From: http://terminology.hl7.org/CodeSystem/ex-serviceplace in valuesets.xml
    """
    AssistedLivingFa = ExampleServicePlaceCodesCode("13")
    """
    A residence, with shared living areas, where clients receive supervision and
    other services such as social and/or behavioral services, custodial service,
    and minimal services (e.g., medication administration).
    From: http://terminology.hl7.org/CodeSystem/ex-serviceplace in valuesets.xml
    """
    GroupHome = ExampleServicePlaceCodesCode("14")
    """
    A facility/unit that moves from place-to-place equipped to provide preventive,
    screening, diagnostic, and/or treatment services.
    From: http://terminology.hl7.org/CodeSystem/ex-serviceplace in valuesets.xml
    """
    MobileUnit = ExampleServicePlaceCodesCode("15")
    """
    portion of an off-campus hospital provider-based department which provides
    diagnostic, therapeutic (both surgical and nonsurgical), and rehabilitation
    services to sick or injured persons who do not require hospitalization or
    institutionalization.
    From: http://terminology.hl7.org/CodeSystem/ex-serviceplace in valuesets.xml
    """
    OffCampus_OutpatientHospital = ExampleServicePlaceCodesCode("19")
    """
    Location, distinct from a hospital emergency room, an office, or a clinic,
    whose purpose is to diagnose and treat illness or injury for unscheduled,
    ambulatory patients seeking immediate medical attention.
    From: http://terminology.hl7.org/CodeSystem/ex-serviceplace in valuesets.xml
    """
    UrgentCareFacility = ExampleServicePlaceCodesCode("20")
    """
    A facility, other than psychiatric, which primarily provides diagnostic,
    therapeutic (both surgical and nonsurgical), and rehabilitation services by,
    or under, the supervision of physicians to patients admitted for a variety of
    medical conditions.
    From: http://terminology.hl7.org/CodeSystem/ex-serviceplace in valuesets.xml
    """
    InpatientHospital = ExampleServicePlaceCodesCode("21")
    """
    A land vehicle specifically designed, equipped and staffed for lifesaving and
    transporting the sick or injured.
    From: http://terminology.hl7.org/CodeSystem/ex-serviceplace in valuesets.xml
    """
    Ambulance_Land = ExampleServicePlaceCodesCode("41")
