from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class FacilityTypeCodeValueSetCode(GenericTypeCode):
    """
    FacilityTypeCodeValueSet
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
        This is the code representing the type of organizational setting where the
    clinical encounter, service, interaction, or treatment occurred. The value set
    used for Healthcare Facility Type has been defined by HITSP to be the value
    set reproduced from HITSP C80 Table 2-147.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://snomed.info/sct
    """
    codeset: FhirUri = "http://snomed.info/sct"


class FacilityTypeCodeValueSetCodeValues:
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """

    Hospital_children_s = FacilityTypeCodeValueSetCode("82242000")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    Hospital_community = FacilityTypeCodeValueSetCode("225732001")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    Hospital_government = FacilityTypeCodeValueSetCode("79993009")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    Hospital_longTermCare = FacilityTypeCodeValueSetCode("32074000")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    Hospital_militaryField = FacilityTypeCodeValueSetCode("4322002")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    Hospital_prison = FacilityTypeCodeValueSetCode("224687002")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    Hospital_psychiatric = FacilityTypeCodeValueSetCode("62480006")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    Hospital_rehabilitation = FacilityTypeCodeValueSetCode("80522000")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    Hospital_traumaCenter = FacilityTypeCodeValueSetCode("36125001")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    Hospital_Veterans_Administration = FacilityTypeCodeValueSetCode("48311003")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    HospiceFacility = FacilityTypeCodeValueSetCode("284546000")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    NursingHome = FacilityTypeCodeValueSetCode("42665001")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    SkilledNursingFacility = FacilityTypeCodeValueSetCode("45618002")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    DialysisUnit_hospital = FacilityTypeCodeValueSetCode("418518002")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    EmergencyDepartment_hospital = FacilityTypeCodeValueSetCode("73770003")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    HospitalAmbulatorySurgeryFacility = FacilityTypeCodeValueSetCode("69362002")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    HospitalBirthingCenter = FacilityTypeCodeValueSetCode("52668009")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    HospitalOutpatientAllergyClinic = FacilityTypeCodeValueSetCode("360957003")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    HospitalOutpatientDentalClinic = FacilityTypeCodeValueSetCode("10206005")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    HospitalOutpatientDermatologyClinic = FacilityTypeCodeValueSetCode("37550003")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    HospitalOutpatientEndocrinologyClinic = FacilityTypeCodeValueSetCode("73644007")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    HospitalOutpatientFamilyMedicineClinic = FacilityTypeCodeValueSetCode("31628002")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    HospitalOutpatientGastroenterologyClinic = FacilityTypeCodeValueSetCode("58482006")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    HospitalOutpatientGeneralSurgeryClinic = FacilityTypeCodeValueSetCode("90484001")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    HospitalOutpatientGeriatricHealthCenter = FacilityTypeCodeValueSetCode("1814000")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    HospitalOutpatientGynecologyClinic = FacilityTypeCodeValueSetCode("22549003")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    HospitalOutpatientHematologyClinic = FacilityTypeCodeValueSetCode("56293002")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    HospitalOutpatientImmunologyClinic = FacilityTypeCodeValueSetCode("360966004")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    HospitalOutpatientInfectiousDiseaseClinic = FacilityTypeCodeValueSetCode("2849009")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    HospitalOutpatientMentalHealthCenter = FacilityTypeCodeValueSetCode("14866005")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    HospitalOutpatientNeurologyClinic = FacilityTypeCodeValueSetCode("38238005")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    HospitalOutpatientObstetricalClinic = FacilityTypeCodeValueSetCode("56189001")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    HospitalOutpatientOncologyClinic = FacilityTypeCodeValueSetCode("89972002")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    HospitalOutpatientOphthalmologyClinic = FacilityTypeCodeValueSetCode("78088001")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    HospitalOutpatientOrthopedicsClinic = FacilityTypeCodeValueSetCode("78001009")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    HospitalOutpatientOtorhinolaryngologyClinic = FacilityTypeCodeValueSetCode(
        "23392004"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    HospitalOutpatientPainClinic = FacilityTypeCodeValueSetCode("36293008")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    HospitalOutpatientPediatricClinic = FacilityTypeCodeValueSetCode("3729002")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    HospitalOutpatientPeripheralVascularClinic = FacilityTypeCodeValueSetCode("5584006")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    HospitalOutpatientRehabilitationClinic = FacilityTypeCodeValueSetCode("37546005")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    HospitalOutpatientRespiratoryDiseaseClinic = FacilityTypeCodeValueSetCode(
        "57159002"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    HospitalOutpatientRheumatologyClinic = FacilityTypeCodeValueSetCode("331006")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    HospitalOutpatientUrologyClinic = FacilityTypeCodeValueSetCode("50569004")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    HospitalRadiologyFacility = FacilityTypeCodeValueSetCode("79491001")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    Hospital_basedOutpatientClinicOrDepartment_OTHER_NOTLISTED = (
        FacilityTypeCodeValueSetCode("33022008")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    Fee_for_servicePrivatePhysicians_GroupOffice = FacilityTypeCodeValueSetCode(
        "19602009"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    PrivatePhysicians_GroupOffice = FacilityTypeCodeValueSetCode("39350007")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    SoloPracticePrivateOffice = FacilityTypeCodeValueSetCode("83891005")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    IndependentAmbulatoryCareProviderSite_OTHER_NOTLISTED = (
        FacilityTypeCodeValueSetCode("394759007")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    AmbulatorySurgeryCenter = FacilityTypeCodeValueSetCode("405607001")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    CareOfTheElderlyDayHospital = FacilityTypeCodeValueSetCode("309900005")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    ElderlyAssessmentClinic = FacilityTypeCodeValueSetCode("275576008")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    Free_standingAmbulatorySurgeryFacility = FacilityTypeCodeValueSetCode("10531005")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    Free_standingBirthingCenter = FacilityTypeCodeValueSetCode("91154008")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    Free_standingGeriatricHealthCenter = FacilityTypeCodeValueSetCode("41844007")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    Free_standingLaboratoryFacility = FacilityTypeCodeValueSetCode("45899008")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    Free_standingMentalHealthCenter = FacilityTypeCodeValueSetCode("51563005")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    Free_standingRadiologyFacility = FacilityTypeCodeValueSetCode("1773006")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    HealthMaintenanceOrganization = FacilityTypeCodeValueSetCode("72311000")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    LocalCommunityHealthCenter = FacilityTypeCodeValueSetCode("6827000")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    PsychogeriatricDayHospital = FacilityTypeCodeValueSetCode("309898008")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    ResidentialSchoolInfirmary = FacilityTypeCodeValueSetCode("39913001")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    RuralHealthCenter = FacilityTypeCodeValueSetCode("77931003")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    SexuallyTransmittedDiseaseHealthCenter = FacilityTypeCodeValueSetCode("25681007")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    SubstanceAbuseTreatmentCenter = FacilityTypeCodeValueSetCode("20078004")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    VaccinationClinic = FacilityTypeCodeValueSetCode("46224007")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    Walk_inClinic = FacilityTypeCodeValueSetCode("81234003")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    AmbulatoryCareSite_OTHER_NOTLISTED = FacilityTypeCodeValueSetCode("35971002")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    Ambulance_basedCare = FacilityTypeCodeValueSetCode("11424001")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    ContainedCasualtySetting = FacilityTypeCodeValueSetCode("409519008")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    Helicopter_basedCare = FacilityTypeCodeValueSetCode("901005")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    HospitalShip = FacilityTypeCodeValueSetCode("2081004")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    Traveler_sAidClinic = FacilityTypeCodeValueSetCode("59374000")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    AdultDayCareCenter = FacilityTypeCodeValueSetCode("413456002")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    ChildDayCareCenter = FacilityTypeCodeValueSetCode("413817003")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    PrivateResidentialHome = FacilityTypeCodeValueSetCode("310205006")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    ResidentialInstitution = FacilityTypeCodeValueSetCode("419955002")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    SportsFacility = FacilityTypeCodeValueSetCode("272501009")
    """
    From: http://hl7.org/fhir/ValueSet/c80-facilitycodes in valuesets.xml
    """
    HealthEncounterSite_NOTLISTED = FacilityTypeCodeValueSetCode("394777002")
