from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class FeedingDeviceCodesCode(GenericTypeCode):
    """
    FeedingDeviceCodes
    From: http://hl7.org/fhir/feeding-device in valuesets.xml
        Materials used or needed to feed the patient.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/feeding-device
    """
    codeset: FhirUri = "http://hl7.org/fhir/feeding-device"


class FeedingDeviceCodesCodeValues:
    """
    Standard nipple definition:
    From: http://hl7.org/fhir/feeding-device in valuesets.xml
    """

    StandardNipple = FeedingDeviceCodesCode("standard-nipple")
    """
    Preemie nipple definition:
    From: http://hl7.org/fhir/feeding-device in valuesets.xml
    """
    PreemieNipple = FeedingDeviceCodesCode("preemie-nipple")
    """
    Orthodontic nipple definition:
    From: http://hl7.org/fhir/feeding-device in valuesets.xml
    """
    OrthodonticNipple = FeedingDeviceCodesCode("ortho-nipple")
    """
    Slow flow nipple definition:
    From: http://hl7.org/fhir/feeding-device in valuesets.xml
    """
    SlowFlowNipple = FeedingDeviceCodesCode("sloflo-nipple")
    """
    Middle flow nipple definition:
    From: http://hl7.org/fhir/feeding-device in valuesets.xml
    """
    MiddleFlowNipple = FeedingDeviceCodesCode("midflo-nipple")
    """
    Enlarged, cross-cut nipple definition:
    From: http://hl7.org/fhir/feeding-device in valuesets.xml
    """
    Enlarged_Cross_cutNipple = FeedingDeviceCodesCode("bigcut-nipple")
    """
    Haberman bottle definition:
    From: http://hl7.org/fhir/feeding-device in valuesets.xml
    """
    HabermanBottle = FeedingDeviceCodesCode("haberman-bottle")
    """
    Sippy cup with valve definition:
    From: http://hl7.org/fhir/feeding-device in valuesets.xml
    """
    SippyCupWithValve = FeedingDeviceCodesCode("sippy-valve")
    """
    Sippy cup without valve definition:
    From: http://hl7.org/fhir/feeding-device in valuesets.xml
    """
    SippyCupWithoutValve = FeedingDeviceCodesCode("sippy-no-valve")
    """
    Provale Cup definition:
    From: http://hl7.org/fhir/feeding-device in valuesets.xml
    """
    ProvaleCup = FeedingDeviceCodesCode("provale-cup")
    """
    Glass with lid/sippy cup definition:
    From: http://hl7.org/fhir/feeding-device in valuesets.xml
    """
    GlassWithLid_sippyCup = FeedingDeviceCodesCode("glass-lid")
    """
    Double handhold on glass/cup definition:
    From: http://hl7.org/fhir/feeding-device in valuesets.xml
    """
    DoubleHandholdOnGlass_cup = FeedingDeviceCodesCode("handhold-cup")
    """
    Rubber matting under tray definition:
    From: http://hl7.org/fhir/feeding-device in valuesets.xml
    """
    RubberMattingUnderTray = FeedingDeviceCodesCode("rubber-mat")
    """
    Straw definition:
    From: http://hl7.org/fhir/feeding-device in valuesets.xml
    """
    Straw = FeedingDeviceCodesCode("straw")
    """
    Nose cup definition:
    From: http://hl7.org/fhir/feeding-device in valuesets.xml
    """
    NoseCup = FeedingDeviceCodesCode("nose-cup")
    """
    Scoop plate definition:
    From: http://hl7.org/fhir/feeding-device in valuesets.xml
    """
    ScoopPlate = FeedingDeviceCodesCode("scoop-plate")
    """
    Hand wrap utensil holder definition:
    From: http://hl7.org/fhir/feeding-device in valuesets.xml
    """
    HandWrapUtensilHolder = FeedingDeviceCodesCode("utensil-holder")
    """
    Foam handle utensils definition:
    From: http://hl7.org/fhir/feeding-device in valuesets.xml
    """
    FoamHandleUtensils = FeedingDeviceCodesCode("foam-handle")
    """
    Angled utensils definition:
    From: http://hl7.org/fhir/feeding-device in valuesets.xml
    """
    AngledUtensils = FeedingDeviceCodesCode("angled-utensil")
    """
    Spout cup definition:
    From: http://hl7.org/fhir/feeding-device in valuesets.xml
    """
    SpoutCup = FeedingDeviceCodesCode("spout-cup")
    """
    Automated feeding devices definition:
    From: http://hl7.org/fhir/feeding-device in valuesets.xml
    """
    AutomatedFeedingDevices = FeedingDeviceCodesCode("autofeeding-device")
    """
    Rocker knife definition:
    From: http://hl7.org/fhir/feeding-device in valuesets.xml
    """
    RockerKnife = FeedingDeviceCodesCode("rocker-knife")
