from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class FHIRDeviceStatusCode(GenericTypeCode):
    """
    FHIRDeviceStatus
    From: http://hl7.org/fhir/device-definition-status in valuesets.xml
        Codes representing the current status of the device - on, off, suspended, etc.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/device-definition-status
    """
    codeset: FhirUri = "http://hl7.org/fhir/device-definition-status"


class FHIRDeviceStatusCodeValues:
    """
    The device is available for use.  Note: For *implanted devices*  this means
    that the device is implanted in the patient.
    From: http://hl7.org/fhir/device-definition-status in valuesets.xml
    """

    Active = FHIRDeviceStatusCode("active")
    """
    The device is no longer available for use (e.g. lost, expired, damaged).
    Note: For *implanted devices*  this means that the device has been removed
    from the patient.
    From: http://hl7.org/fhir/device-definition-status in valuesets.xml
    """
    Inactive = FHIRDeviceStatusCode("inactive")
    """
    The device was entered in error and voided.
    From: http://hl7.org/fhir/device-definition-status in valuesets.xml
    """
    EnteredInError = FHIRDeviceStatusCode("entered-in-error")
    """
    The status of the device has not been determined.
    From: http://hl7.org/fhir/device-definition-status in valuesets.xml
    """
    Unknown = FHIRDeviceStatusCode("unknown")
