from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class FHIRRestfulInteractionsCode(GenericTypeCode):
    """
    FHIR Restful Interactions
    From: http://hl7.org/fhir/restful-interaction in valuesets.xml
        The set of interactions defined by the RESTful part of the FHIR specification.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/restful-interaction
    """
    codeset: FhirUri = "http://hl7.org/fhir/restful-interaction"


class FHIRRestfulInteractionsCodeValues:
    """
    Read the current state of the resource.
    From: http://hl7.org/fhir/restful-interaction in valuesets.xml
    """

    Read = FHIRRestfulInteractionsCode("read")
    """
    Read the state of a specific version of the resource.
    From: http://hl7.org/fhir/restful-interaction in valuesets.xml
    """
    Vread = FHIRRestfulInteractionsCode("vread")
    """
    Update an existing resource by its id (or create it if it is new).
    From: http://hl7.org/fhir/restful-interaction in valuesets.xml
    """
    Update = FHIRRestfulInteractionsCode("update")
    """
    Update an existing resource by posting a set of changes to it.
    From: http://hl7.org/fhir/restful-interaction in valuesets.xml
    """
    Patch = FHIRRestfulInteractionsCode("patch")
    """
    Delete a resource.
    From: http://hl7.org/fhir/restful-interaction in valuesets.xml
    """
    Delete = FHIRRestfulInteractionsCode("delete")
    """
    Retrieve the change history for a particular resource, type of resource, or
    the entire system.
    From: http://hl7.org/fhir/restful-interaction in valuesets.xml
    """
    History = FHIRRestfulInteractionsCode("history")
    """
    Create a new resource with a server assigned id.
    From: http://hl7.org/fhir/restful-interaction in valuesets.xml
    """
    Create = FHIRRestfulInteractionsCode("create")
    """
    Search a resource type or all resources based on some filter criteria.
    From: http://hl7.org/fhir/restful-interaction in valuesets.xml
    """
    Search = FHIRRestfulInteractionsCode("search")
    """
    Get a Capability Statement for the system.
    From: http://hl7.org/fhir/restful-interaction in valuesets.xml
    """
    Capabilities = FHIRRestfulInteractionsCode("capabilities")
    """
    Update, create or delete a set of resources as a single transaction.
    From: http://hl7.org/fhir/restful-interaction in valuesets.xml
    """
    Transaction = FHIRRestfulInteractionsCode("transaction")
    """
    perform a set of a separate interactions in a single http operation
    From: http://hl7.org/fhir/restful-interaction in valuesets.xml
    """
    Batch = FHIRRestfulInteractionsCode("batch")
    """
    Perform an operation as defined by an OperationDefinition.
    From: http://hl7.org/fhir/restful-interaction in valuesets.xml
    """
    Operation = FHIRRestfulInteractionsCode("operation")
