from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class GenderIdentityCode(GenericTypeCode):
    """
    GenderIdentity
    From: http://hl7.org/fhir/gender-identity in valuesets.xml
        This example value set defines a set of codes that can be used to indicate a
    patient's gender identity.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/gender-identity
    """
    codeset: FhirUri = "http://hl7.org/fhir/gender-identity"


class GenderIdentityCodeValues:
    """
    the patient identifies as transgender male-to-female
    From: http://hl7.org/fhir/gender-identity in valuesets.xml
    """

    TransgenderFemale = GenderIdentityCode("transgender-female")
    """
    the patient identifies as transgender female-to-male
    From: http://hl7.org/fhir/gender-identity in valuesets.xml
    """
    TransgenderMale = GenderIdentityCode("transgender-male")
    """
    the patient identifies with neither/both female and male
    From: http://hl7.org/fhir/gender-identity in valuesets.xml
    """
    Non_binary = GenderIdentityCode("non-binary")
    """
    the patient identifies as male
    From: http://hl7.org/fhir/gender-identity in valuesets.xml
    """
    Male = GenderIdentityCode("male")
    """
    the patient identifies as female
    From: http://hl7.org/fhir/gender-identity in valuesets.xml
    """
    Female = GenderIdentityCode("female")
    """
    other gender identity
    From: http://hl7.org/fhir/gender-identity in valuesets.xml
    """
    Other = GenderIdentityCode("other")
    """
    the patient does not wish to disclose his gender identity
    From: http://hl7.org/fhir/gender-identity in valuesets.xml
    """
    DoesNotWishToDisclose = GenderIdentityCode("non-disclose")
