from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class GoalRelationshipTypeCode(GenericTypeCode):
    """
    GoalRelationshipType
    From: http://terminology.hl7.org/CodeSystem/goal-relationship-type in valuesets.xml
        Types of relationships between two goals.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/goal-relationship-type
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/goal-relationship-type"


class GoalRelationshipTypeCodeValues:
    """
    Indicates that the target goal is one which must be met before striving for
    the current goal.
    From: http://terminology.hl7.org/CodeSystem/goal-relationship-type in valuesets.xml
    """

    Predecessor = GoalRelationshipTypeCode("predecessor")
    """
    Indicates that the target goal is a desired objective once the current goal is
    met.
    From: http://terminology.hl7.org/CodeSystem/goal-relationship-type in valuesets.xml
    """
    Successor = GoalRelationshipTypeCode("successor")
    """
    Indicates that this goal has been replaced by the target goal.
    From: http://terminology.hl7.org/CodeSystem/goal-relationship-type in valuesets.xml
    """
    Replacement = GoalRelationshipTypeCode("replacement")
    """
    Indicates that the target goal is considered to be a "piece" of attaining this
    goal.
    From: http://terminology.hl7.org/CodeSystem/goal-relationship-type in valuesets.xml
    """
    Milestone = GoalRelationshipTypeCode("milestone")
    """
    Indicates that the relationship is not covered by one of the pre-defined
    codes.  (An extension may convey more information about the meaning of the
    relationship.).
    From: http://terminology.hl7.org/CodeSystem/goal-relationship-type in valuesets.xml
    """
    Other = GoalRelationshipTypeCode("other")
