from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class GroupMeasureCode(GenericTypeCode):
    """
    GroupMeasure
    From: http://hl7.org/fhir/group-measure in valuesets.xml
        Possible group measure aggregates (E.g. Mean, Median).
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/group-measure
    """
    codeset: FhirUri = "http://hl7.org/fhir/group-measure"


class GroupMeasureCodeValues:
    """
    Aggregated using Mean of participant values.
    From: http://hl7.org/fhir/group-measure in valuesets.xml
    """

    Mean = GroupMeasureCode("mean")
    """
    Aggregated using Median of participant values.
    From: http://hl7.org/fhir/group-measure in valuesets.xml
    """
    Median = GroupMeasureCode("median")
    """
    Aggregated using Mean of study mean values.
    From: http://hl7.org/fhir/group-measure in valuesets.xml
    """
    MeanOfStudyMeans = GroupMeasureCode("mean-of-mean")
    """
    Aggregated using Mean of study median values.
    From: http://hl7.org/fhir/group-measure in valuesets.xml
    """
    MeanOfStudyMedins = GroupMeasureCode("mean-of-median")
    """
    Aggregated using Median of study mean values.
    From: http://hl7.org/fhir/group-measure in valuesets.xml
    """
    MedianOfStudyMeans = GroupMeasureCode("median-of-mean")
    """
    Aggregated using Median of study median values.
    From: http://hl7.org/fhir/group-measure in valuesets.xml
    """
    MedianOfStudyMedians = GroupMeasureCode("median-of-median")
