from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class GTSAbbreviation(GenericTypeCode):
    """
    v3.GTSAbbreviation
    From: http://terminology.hl7.org/ValueSet/v3-GTSAbbreviation in v3-codesystems.xml
          Open Issue:
    It appears that the printnames are suboptimal and should be improved for many
    of the existing codes.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/v3-GTSAbbreviation
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/v3-GTSAbbreviation"


class GTSAbbreviationValues:
    """
    Every morning at institution specified times.
    From: http://terminology.hl7.org/CodeSystem/v3-GTSAbbreviation in v3-codesystems.xml
    """

    AM = GTSAbbreviation("AM")
    """
    At bedtime (institution specified time).
    From: http://terminology.hl7.org/CodeSystem/v3-GTSAbbreviation in v3-codesystems.xml
    """
    AtBedtime = GTSAbbreviation("BED")
    """
    Two times a day at institution specified time
    From: http://terminology.hl7.org/CodeSystem/v3-GTSAbbreviation in v3-codesystems.xml
    """
    BID = GTSAbbreviation("BID")
    """
    Regular business days (Monday to Friday excluding holidays)
    From: http://terminology.hl7.org/CodeSystem/v3-GTSAbbreviation in v3-codesystems.xml
    """
    JB = GTSAbbreviation("JB")
    """
    Regular weekends (Saturday and Sunday excluding holidays)
    From: http://terminology.hl7.org/CodeSystem/v3-GTSAbbreviation in v3-codesystems.xml
    """
    JE = GTSAbbreviation("JE")
    """
    Holidays
    From: http://terminology.hl7.org/CodeSystem/v3-GTSAbbreviation in v3-codesystems.xml
    """
    GTSAbbreviationHolidays = GTSAbbreviation("JH")
    """
    Monthly at institution specified time.
    From: http://terminology.hl7.org/CodeSystem/v3-GTSAbbreviation in v3-codesystems.xml
    """
    Monthly = GTSAbbreviation("MO")
    """
    Every afternoon at institution specified times.
    From: http://terminology.hl7.org/CodeSystem/v3-GTSAbbreviation in v3-codesystems.xml
    """
    PM = GTSAbbreviation("PM")
    """
    Every hour at institution specified times.
    From: http://terminology.hl7.org/CodeSystem/v3-GTSAbbreviation in v3-codesystems.xml
    """
    EveryHour = GTSAbbreviation("Q1H")
    """
    Every 2 hours at institution specified times.
    From: http://terminology.hl7.org/CodeSystem/v3-GTSAbbreviation in v3-codesystems.xml
    """
    Every2Hours = GTSAbbreviation("Q2H")
    """
    Every 3 hours at institution specified times.
    From: http://terminology.hl7.org/CodeSystem/v3-GTSAbbreviation in v3-codesystems.xml
    """
    Every3Hours = GTSAbbreviation("Q3H")
    """
    Every 4 hours at institution specified time
    From: http://terminology.hl7.org/CodeSystem/v3-GTSAbbreviation in v3-codesystems.xml
    """
    Q4H = GTSAbbreviation("Q4H")
    """
    Every 6 hours at institution specified time
    From: http://terminology.hl7.org/CodeSystem/v3-GTSAbbreviation in v3-codesystems.xml
    """
    Q6H = GTSAbbreviation("Q6H")
    """
    Every 8 hours at institution specified times.
    From: http://terminology.hl7.org/CodeSystem/v3-GTSAbbreviation in v3-codesystems.xml
    """
    Every8Hours = GTSAbbreviation("Q8H")
    """
    Every day at institution specified times.
    From: http://terminology.hl7.org/CodeSystem/v3-GTSAbbreviation in v3-codesystems.xml
    """
    QD = GTSAbbreviation("QD")
    """
    Four times a day at institution specified time
    From: http://terminology.hl7.org/CodeSystem/v3-GTSAbbreviation in v3-codesystems.xml
    """
    QID = GTSAbbreviation("QID")
    """
    Every other day at institution specified times.
    From: http://terminology.hl7.org/CodeSystem/v3-GTSAbbreviation in v3-codesystems.xml
    """
    QOD = GTSAbbreviation("QOD")
    """
    Three times a day at institution specified time
    From: http://terminology.hl7.org/CodeSystem/v3-GTSAbbreviation in v3-codesystems.xml
    """
    TID = GTSAbbreviation("TID")
    """
    Weekly at institution specified time.
    From: http://terminology.hl7.org/CodeSystem/v3-GTSAbbreviation in v3-codesystems.xml
    """
    Weekly = GTSAbbreviation("WK")
