from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class GuidanceResponseStatusCode(GenericTypeCode):
    """
    GuidanceResponseStatus
    From: http://hl7.org/fhir/guidance-response-status in valuesets.xml
        The status of a guidance response.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/guidance-response-status
    """
    codeset: FhirUri = "http://hl7.org/fhir/guidance-response-status"


class GuidanceResponseStatusCodeValues:
    """
    The request was processed successfully.
    From: http://hl7.org/fhir/guidance-response-status in valuesets.xml
    """

    Success = GuidanceResponseStatusCode("success")
    """
    The request was processed successfully, but more data may result in a more
    complete evaluation.
    From: http://hl7.org/fhir/guidance-response-status in valuesets.xml
    """
    DataRequested = GuidanceResponseStatusCode("data-requested")
    """
    The request was processed, but more data is required to complete the
    evaluation.
    From: http://hl7.org/fhir/guidance-response-status in valuesets.xml
    """
    DataRequired = GuidanceResponseStatusCode("data-required")
    """
    The request is currently being processed.
    From: http://hl7.org/fhir/guidance-response-status in valuesets.xml
    """
    InProgress = GuidanceResponseStatusCode("in-progress")
    """
    The request was not processed successfully.
    From: http://hl7.org/fhir/guidance-response-status in valuesets.xml
    """
    Failure = GuidanceResponseStatusCode("failure")
    """
    The response was entered in error.
    From: http://hl7.org/fhir/guidance-response-status in valuesets.xml
    """
    EnteredInError = GuidanceResponseStatusCode("entered-in-error")
