from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class GuidePageGenerationCode(GenericTypeCode):
    """
    GuidePageGeneration
    From: http://hl7.org/fhir/guide-page-generation in valuesets.xml
        A code that indicates how the page is generated.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/guide-page-generation
    """
    codeset: FhirUri = "http://hl7.org/fhir/guide-page-generation"


class GuidePageGenerationCodeValues:
    """
    Page is proper xhtml with no templating.  Will be brought across unchanged for
    standard post-processing.
    From: http://hl7.org/fhir/guide-page-generation in valuesets.xml
    """

    HTML = GuidePageGenerationCode("html")
    """
    Page is markdown with templating.  Will use the template to create a file that
    imports the markdown file prior to post-processing.
    From: http://hl7.org/fhir/guide-page-generation in valuesets.xml
    """
    Markdown = GuidePageGenerationCode("markdown")
    """
    Page is xml with templating.  Will use the template to create a file that
    imports the source file and run the nominated XSLT transform (see parameters)
    if present prior to post-processing.
    From: http://hl7.org/fhir/guide-page-generation in valuesets.xml
    """
    XML = GuidePageGenerationCode("xml")
    """
    Page will be generated by the publication process - no source to bring across.
    From: http://hl7.org/fhir/guide-page-generation in valuesets.xml
    """
    Generated = GuidePageGenerationCode("generated")
