from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class Hl7ApprovalStatus(GenericTypeCode):
    """
    v3.hl7ApprovalStatus
    From: http://terminology.hl7.org/ValueSet/v3-hl7ApprovalStatus in v3-codesystems.xml
          Description:
    Codes for concepts describing the approval level of HL7 artifacts.  This code
    system reflects the concepts expressed in HL7's Governance & Operations Manual
    (GOM) past and present.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/v3-hl7ApprovalStatus
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/v3-hl7ApprovalStatus"


class Hl7ApprovalStatusValues:
    """
    Description: Content that is being presented to an international affiliate for
    consideration as a realm-specific draft standard for trial use.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7ApprovalStatus in v3-codesystems.xml
    """

    AffiliateBallot_DSTU = Hl7ApprovalStatus("affd")
    """
    Description: Content that is being presented to an international affiliate for
    consideration as a realm-specific informative standard.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7ApprovalStatus in v3-codesystems.xml
    """
    AffiliateBallot_Informative = Hl7ApprovalStatus("affi")
    """
    Description: Content that is being presented to an international affiliate for
    consideration as a realm-specific normative standard.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7ApprovalStatus in v3-codesystems.xml
    """
    AffiliateBallot_Normative = Hl7ApprovalStatus("affn")
    """
    Description: Content that has passed ballot as a realm-specific draft standard
    for trial use.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7ApprovalStatus in v3-codesystems.xml
    """
    ApprovedAffiliateDSTU = Hl7ApprovalStatus("appad")
    """
    Description: Content that has passed ballot as a realm-specific informative
    standard.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7ApprovalStatus in v3-codesystems.xml
    """
    ApprovedAffiliateInformative = Hl7ApprovalStatus("appai")
    """
    Description: Content that has passed ballot as a realm-specific normative
    standard
    From: http://terminology.hl7.org/CodeSystem/v3-hl7ApprovalStatus in v3-codesystems.xml
    """
    ApprovedAffiliateNormative = Hl7ApprovalStatus("appan")
    """
    Description: Content that has passed ballot as a draft standard for trial use.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7ApprovalStatus in v3-codesystems.xml
    """
    ApprovedDSTU = Hl7ApprovalStatus("appd")
    """
    Description: Content that has passed ballot as a normative standard.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7ApprovalStatus in v3-codesystems.xml
    """
    ApprovedInformative = Hl7ApprovalStatus("appi")
    """
    Description: Content that has passed ballot as a normative standard.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7ApprovalStatus in v3-codesystems.xml
    """
    ApprovedNormative = Hl7ApprovalStatus("appn")
    """
    Description: Content prepared by a committee and submitted for internal
    consideration as an informative standard.
    
    
    
                                  Deprecation Comment
                                No longer supported as ballot statuses within the
    HL7 Governance and Operations Manual.  Use normative or informative variants
    instead.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7ApprovalStatus in v3-codesystems.xml
    """
    CommitteeBallot_Informative = Hl7ApprovalStatus("comi")
    """
    Description: Content prepared by a committee and submitted for internal
    consideration as an informative standard.
    
    
    
                                  Deprecation Comment
                                No longer supported as ballot statuses within the
    HL7 Governance and Operations Manual.  Use normative or informative variants
    instead.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7ApprovalStatus in v3-codesystems.xml
    """
    CommitteeBallot_Normative = Hl7ApprovalStatus("comn")
    """
    Description: Content that is under development and is not intended to be used.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7ApprovalStatus in v3-codesystems.xml
    """
    Draft = Hl7ApprovalStatus("draft")
    """
    Description: Content that represents an adaption of a implementable balloted
    material to represent the needs or capabilities of a particular installation.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7ApprovalStatus in v3-codesystems.xml
    """
    LocalizedAdaptation = Hl7ApprovalStatus("loc")
    """
    Description: Content prepared by a committee and submitted for membership
    consideration as a draft standard for trial use.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7ApprovalStatus in v3-codesystems.xml
    """
    MembershipBallot_DSTU = Hl7ApprovalStatus("memd")
    """
    Description: Content prepared by a committee and submitted for membership
    consideration as an informative standard.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7ApprovalStatus in v3-codesystems.xml
    """
    MembershipBallot_Informative = Hl7ApprovalStatus("memi")
    """
    Description: Content prepared by a committee and submitted for membership
    consideration as a normative standard.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7ApprovalStatus in v3-codesystems.xml
    """
    MembershipBallot_Normative = Hl7ApprovalStatus("memn")
    """
    Description: Content developed independently by an organization or individual
    that is declared to be 'usable' but for which there is no present intention to
    submit through the standards submission and review process.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7ApprovalStatus in v3-codesystems.xml
    """
    Non_standard_AvailableForUse = Hl7ApprovalStatus("ns")
    """
    Description: Content submitted to a committee for consideration for future
    inclusion in the standard.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7ApprovalStatus in v3-codesystems.xml
    """
    Proposal = Hl7ApprovalStatus("prop")
    """
    Description: Content intended to support other content that is subject to
    approval, but which is not itself subject to formal approval.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7ApprovalStatus in v3-codesystems.xml
    """
    Reference = Hl7ApprovalStatus("ref")
    """
    Description: Content that represents an item that was at one point a normative
    or informative standard, but was subsequently withdrawn.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7ApprovalStatus in v3-codesystems.xml
    """
    Withdrawn = Hl7ApprovalStatus("wd")
