from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class Hl7PublishingDomain(GenericTypeCode):
    """
    v3.hl7PublishingDomain
    From: http://terminology.hl7.org/ValueSet/v3-hl7PublishingDomain in v3-codesystems.xml
          Description:
    Codes for HL7 publishing domains (specific content area)
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/v3-hl7PublishingDomain
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/v3-hl7PublishingDomain"


class Hl7PublishingDomainValues:
    """
    Description: Represents the HL7 content "domain" that supports accounting and
    billing functions - and "provides support for the creation and management of
    patient billing accounts and the post of financial transactions against
    patient billing accounts for the purpose of aggregating financial transactions
    that will be submitted as claims or invoices for reimbursemen"


                               UsageNote: V3 Specifications are published in a set
    of "domains", which contain interactions and related specifications for a
    single area of health care within which can be supported by a single, coherent
    set of interoperability specifications.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7PublishingDomain in v3-codesystems.xml
    """

    Accounting_Billing = Hl7PublishingDomain("AB")
    """
    Description: Represents the HL7 content "domain" that supports trigger event
    control act infrastructure - and "covers the alternate structures of the
    message Trigger Event Control Acts in the HL7 Composite Message."
    
    
                               UsageNote: V3 Specifications are published in a set
    of "domains", which contain interactions and related specifications for a
    single area of health care within which can be supported by a single, coherent
    set of interoperability specifications.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7PublishingDomain in v3-codesystems.xml
    """
    TriggerEventControlActInfrastructure = Hl7PublishingDomain("AI")
    """
    Description: Represents the HL7 content "domain" that was defined as an
    "artificial listing" domain to support publication testing.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7PublishingDomain in v3-codesystems.xml
    """
    ArtificialListingForTestPurposes_FauxDomainForTesting = Hl7PublishingDomain("AL")
    """
    Description: Represents the HL7 content "domain" that supports blood tissue
    and organ domain - and "comprises the models, messages, and other artIfacts
    that are needed to support messaging related to the process of blood, tissue,
    and organ banking operations such as donations, eligibility, storage,
    dispense, administration/transfusion, explantation, and implantation. "
    
    
                               UsageNote: V3 Specifications are published in a set
    of "domains", which contain interactions and related specifications for a
    single area of health care within which can be supported by a single, coherent
    set of interoperability specifications.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7PublishingDomain in v3-codesystems.xml
    """
    BloodTissueAndOrgan = Hl7PublishingDomain("BB")
    """
    Description: Represents the HL7 content "domain" that supports the clinical
    document architecture.
    
    
                               UsageNote: V3 Specifications are published in a set
    of "domains", which contain interactions and related specifications for a
    single area of health care within which can be supported by a single, coherent
    set of interoperability specifications.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7PublishingDomain in v3-codesystems.xml
    """
    ClinicalDocumentArchitecture = Hl7PublishingDomain("CD")
    """
    Description: Represents the HL7 content "domain" that supports clinical
    genomics - and includes " standards to enable the exchange of interrelated
    clinical and personalized genomic data between interested parties."
    
    
                               UsageNote: V3 Specifications are published in a set
    of "domains", which contain interactions and related specifications for a
    single area of health care within which can be supported by a single, coherent
    set of interoperability specifications.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7PublishingDomain in v3-codesystems.xml
    """
    ClinicalGenomics = Hl7PublishingDomain("CG")
    """
    Description: Represents the HL7 content "domain" that supports transmission
    infrastructure - and " is primarily concerned with the data content of
    exchanges between healthcare applications, the sequence or interrelationships
    in the flow of messages and the communication of significant application level
    exceptions or error conditions."
    
    
                               UsageNote: V3 Specifications are published in a set
    of "domains", which contain interactions and related specifications for a
    single area of health care within which can be supported by a single, coherent
    set of interoperability specifications.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7PublishingDomain in v3-codesystems.xml
    """
    TransmissionInfrastructure = Hl7PublishingDomain("CI")
    """
    Description: Represents the HL7 content "domain" that supports Coverage - and
    provides support for managing health care coverage in the reimbursement
    system(s).
    
    
                               UsageNote: V3 Specifications are published in a set
    of "domains", which contain interactions and related specifications for a
    single area of health care within which can be supported by a single, coherent
    set of interoperability specifications.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7PublishingDomain in v3-codesystems.xml
    """
    Coverage = Hl7PublishingDomain("CO")
    """
    Description: Represents the HL7 content "domain" that supports the common
    product model - which "is used to improve the alignment between the different
    representations of products used within the body of HL7 Version 3 models."
    
    
                               UsageNote: V3 Specifications are published in a set
    of "domains", which contain interactions and related specifications for a
    single area of health care within which can be supported by a single, coherent
    set of interoperability specifications.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7PublishingDomain in v3-codesystems.xml
    """
    CommonProductModel = Hl7PublishingDomain("CP")
    """
    Description: Represents the HL7 content "domain" that supports Claims and
    Reimbursement - and "provides support for Generic, Pharmacy, Preferred
    Accommodation, Physician, Oral Health Vision Care and Hospital claims for
    eligibility, authorization, coverage extension, pre-determination, invoice
    adjudication, payment advice and Statement of Financial Activity (SOFA)
    Release 3 of this document adds claims messaging support for Physician, Oral
    Health Vision Care and Hospital claims."
    
    
                               UsageNote: V3 Specifications are published in a set
    of "domains", which contain interactions and related specifications for a
    single area of health care within which can be supported by a single, coherent
    set of interoperability specifications.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7PublishingDomain in v3-codesystems.xml
    """
    ClaimsAndReimbursement = Hl7PublishingDomain("CR")
    """
    Description: Represents the HL7 content "domain" that supports a common
    clinical statement pattern - and "is a 'pattern' designed to be used within
    multiple HL7 Version 3 domain models. This pattern is intended to facilitate
    the consistent design of communications that convey clinical information to
    meet specific use cases."
    
    
                               UsageNote: V3 Specifications are published in a set
    of "domains", which contain interactions and related specifications for a
    single area of health care within which can be supported by a single, coherent
    set of interoperability specifications.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7PublishingDomain in v3-codesystems.xml
    """
    ClinicalStatement = Hl7PublishingDomain("CS")
    """
    Description: Represents the HL7 content "domain" that supports common model
    types - and "are a work product produced by a particular committee for
    expressing a common, useful and reusable concept."
    
    
                               UsageNote: V3 Specifications are published in a set
    of "domains", which contain interactions and related specifications for a
    single area of health care within which can be supported by a single, coherent
    set of interoperability specifications.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7PublishingDomain in v3-codesystems.xml
    """
    CommonTypes = Hl7PublishingDomain("CT")
    """
    Description: Represents the HL7 content "domain" that was created to support
    testing and initial set-up functions.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7PublishingDomain in v3-codesystems.xml
    """
    DummyDomain = Hl7PublishingDomain("DD")
    """
    Description: This domain has been retired in favor of "imaging integration"
    (II).
    From: http://terminology.hl7.org/CodeSystem/v3-hl7PublishingDomain in v3-codesystems.xml
    """
    DiagnosticImaging = Hl7PublishingDomain("DI")
    """
    Description: Represents the HL7 content "domain" that provides decision
    support.
    
    
                               UsageNote: V3 Specifications are published in a set
    of "domains", which contain interactions and related specifications for a
    single area of health care within which can be supported by a single, coherent
    set of interoperability specifications.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7PublishingDomain in v3-codesystems.xml
    """
    DecisionSupport = Hl7PublishingDomain("DS")
    """
    Description: Represents the HL7 content "domain" that supports Emergency
    Medical Services.
    
    
                               UsageNote: V3 Specifications are published in a set
    of "domains", which contain interactions and related specifications for a
    single area of health care within which can be supported by a single, coherent
    set of interoperability specifications.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7PublishingDomain in v3-codesystems.xml
    """
    EmergencyMedicalServices = Hl7PublishingDomain("EM")
    """
    Description: Represents the HL7 content "domain" that supports imaging
    integration - and is "comprises the models, implementation guides, sample
    documents and images that are needed to illustrate the transformation of DICOM
    structured reports to CDA Release 2 as well as the creation of CDA diagnostic
    imaging reports."
    
    
                               UsageNote: V3 Specifications are published in a set
    of "domains", which contain interactions and related specifications for a
    single area of health care within which can be supported by a single, coherent
    set of interoperability specifications.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7PublishingDomain in v3-codesystems.xml
    """
    ImagingIntegration = Hl7PublishingDomain("II")
    """
    Description: Represents the HL7 content "domain" that supports immunization -
    and "describes communication of information about immunization: the
    administration of vaccines (and/or antisera) to individuals to prevent
    infectious disease."
    
    
                               UsageNote: V3 Specifications are published in a set
    of "domains", which contain interactions and related specifications for a
    single area of health care within which can be supported by a single, coherent
    set of interoperability specifications.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7PublishingDomain in v3-codesystems.xml
    """
    Immunization = Hl7PublishingDomain("IZ")
    """
    Description: Represents the HL7 content "domain" that supports clinical
    laboratory functions - and is "comprises the models, messages, and other
    artifacts that are needed to support messaging related to laboratory tests or
    observations. "
    
    
                               UsageNote: V3 Specifications are published in a set
    of "domains", which contain interactions and related specifications for a
    single area of health care within which can be supported by a single, coherent
    set of interoperability specifications.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7PublishingDomain in v3-codesystems.xml
    """
    Laboratory = Hl7PublishingDomain("LB")
    """
    Description: Represents the HL7 content "domain" that supports medication -
    and  "deals with the description of a medicine for the purposes of messaging
    information about medicines" and the applications of these descriptions.
    
    
                               UsageNote: V3 Specifications are published in a set
    of "domains", which contain interactions and related specifications for a
    single area of health care within which can be supported by a single, coherent
    set of interoperability specifications.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7PublishingDomain in v3-codesystems.xml
    """
    Medication = Hl7PublishingDomain("ME")
    """
    Description: Represents the HL7 content "domain" that supports master file
    infrastructure - and is "comprises the classes and attributes needed to
    support Master Files and Registries."
    
    
                               UsageNote: V3 Specifications are published in a set
    of "domains", which contain interactions and related specifications for a
    single area of health care within which can be supported by a single, coherent
    set of interoperability specifications.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7PublishingDomain in v3-codesystems.xml
    """
    MasterfileInfrastructure = Hl7PublishingDomain("MI")
    """
    Description: Represents the HL7 content "domain" that supports Materials
    Management - and is "supports the simple scenario of a Materials Management
    application sending requests, notifications and queries to an auxiliary
    application. The intent is to establish a standard for the minimum
    functionality that is useful and comprehensive enough to explore the important
    concepts relative to inventory management."
    
    
                               UsageNote: V3 Specifications are published in a set
    of "domains", which contain interactions and related specifications for a
    single area of health care within which can be supported by a single, coherent
    set of interoperability specifications.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7PublishingDomain in v3-codesystems.xml
    """
    MaterialsManagement = Hl7PublishingDomain("MM")
    """
    Description: Represents the HL7 content "domain" that supports medical records
    - and is "supports clinical document management, and document querying."
    
    
                               UsageNote: V3 Specifications are published in a set
    of "domains", which contain interactions and related specifications for a
    single area of health care within which can be supported by a single, coherent
    set of interoperability specifications.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7PublishingDomain in v3-codesystems.xml
    """
    MedicalRecords = Hl7PublishingDomain("MR")
    """
    Description: Represents the HL7 content "domain" that supports shared messages
    - and "are a work product produced for expressing common, useful and reusable
    message types."
    
    
                               UsageNote: V3 Specifications are published in a set
    of "domains", which contain interactions and related specifications for a
    single area of health care within which can be supported by a single, coherent
    set of interoperability specifications.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7PublishingDomain in v3-codesystems.xml
    """
    SharedMessages = Hl7PublishingDomain("MT")
    """
    Description: Represents the HL7 content "domain" that supports observations -
    and is "comprises the models, messages, and other artifacts that are needed to
    support messaging related to resulting basic healthcare diagnostic services. "
    
    
                               UsageNote: V3 Specifications are published in a set
    of "domains", which contain interactions and related specifications for a
    single area of health care within which can be supported by a single, coherent
    set of interoperability specifications.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7PublishingDomain in v3-codesystems.xml
    """
    Observations = Hl7PublishingDomain("OB")
    """
    Description: Represents the HL7 content "domain" that supports orders and
    observations - and will provide over-arching support information for the
    "Orders" (OR) and "Observations" (OB) domains.
    
    
                               UsageNote: V3 Specifications are published in a set
    of "domains", which contain interactions and related specifications for a
    single area of health care within which can be supported by a single, coherent
    set of interoperability specifications.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7PublishingDomain in v3-codesystems.xml
    """
    Orders_Observations = Hl7PublishingDomain("OO")
    """
    Description: Represents the HL7 content "domain" that supports orders - and
    "comprises the models, messages, and other artifacts that are needed to
    support messaging related to ordering basic healthcare services."
    
    
                               UsageNote: V3 Specifications are published in a set
    of "domains", which contain interactions and related specifications for a
    single area of health care within which can be supported by a single, coherent
    set of interoperability specifications.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7PublishingDomain in v3-codesystems.xml
    """
    Orders = Hl7PublishingDomain("OR")
    """
    Description: Represents the HL7 content "domain" that supports Patient
    Administration - and "defines person and patient demographics and visit
    information about patients"
    
    
                               UsageNote: V3 Specifications are published in a set
    of "domains", which contain interactions and related specifications for a
    single area of health care within which can be supported by a single, coherent
    set of interoperability specifications.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7PublishingDomain in v3-codesystems.xml
    """
    PatientAdministration = Hl7PublishingDomain("PA")
    """
    Description: Represents the HL7 content "domain" that supports Care Provision
    - and "addresses the information that is needed for the ongoing care of
    individuals, populations, and other targets of care."
    
    
                               UsageNote: V3 Specifications are published in a set
    of "domains", which contain interactions and related specifications for a
    single area of health care within which can be supported by a single, coherent
    set of interoperability specifications.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7PublishingDomain in v3-codesystems.xml
    """
    CareProvision = Hl7PublishingDomain("PC")
    """
    Description: Represents the HL7 content "domain" that supports public health -
    and is "the source of a number of Common Model Element Types (CMET) designed
    to meet the needs of public health data exchange."
    
    
                               UsageNote: V3 Specifications are published in a set
    of "domains", which contain interactions and related specifications for a
    single area of health care within which can be supported by a single, coherent
    set of interoperability specifications.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7PublishingDomain in v3-codesystems.xml
    """
    PublicHealth = Hl7PublishingDomain("PH")
    """
    Description: Represents the HL7 content "domain" that supports Personnel
    Management - and "spans a variety of clinical-administrative information
    functions associated with the organizations, individuals, animals and devices
    involved in the delivery and support of healthcare services."
    
    
                               UsageNote: V3 Specifications are published in a set
    of "domains", which contain interactions and related specifications for a
    single area of health care within which can be supported by a single, coherent
    set of interoperability specifications.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7PublishingDomain in v3-codesystems.xml
    """
    PersonnelManagement = Hl7PublishingDomain("PM")
    """
    Description: Represents the HL7 content "domain" that supports query
    infrastructure - and "specifies the formation of information queries and the
    responses to these queries to meet the needs of healthcare applications using
    the HL7 version 3 messaging standard."
    
    
                               UsageNote: V3 Specifications are published in a set
    of "domains", which contain interactions and related specifications for a
    single area of health care within which can be supported by a single, coherent
    set of interoperability specifications.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7PublishingDomain in v3-codesystems.xml
    """
    QueryInfrastructure = Hl7PublishingDomain("QI")
    """
    Description: Represents the HL7 content "domain" that supports Quality
    Measures - and "is a standard for representing a health quality measure as an
    electronic document."
    
    
                               UsageNote: V3 Specifications are published in a set
    of "domains", which contain interactions and related specifications for a
    single area of health care within which can be supported by a single, coherent
    set of interoperability specifications.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7PublishingDomain in v3-codesystems.xml
    """
    QualityMeasures = Hl7PublishingDomain("QM")
    """
    Description: Represents the HL7 content "domain" that supports Registries -
    and "collects HL7 artifacts for administrative  registries."
    
    
                               UsageNote: V3 Specifications are published in a set
    of "domains", which contain interactions and related specifications for a
    single area of health care within which can be supported by a single, coherent
    set of interoperability specifications.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7PublishingDomain in v3-codesystems.xml
    """
    Registries = Hl7PublishingDomain("RG")
    """
    Description: Represents the HL7 content "domain" that supports Informative
    Public Health.
    
    
                               UsageNote: V3 Specifications are published in a set
    of "domains", which contain interactions and related specifications for a
    single area of health care within which can be supported by a single, coherent
    set of interoperability specifications.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7PublishingDomain in v3-codesystems.xml
    """
    InformativePublicHealth = Hl7PublishingDomain("RI")
    """
    Description: Represents the HL7 content "domain" that supports Regulated
    Products - and "includes standards developed as part of the family of messages
    targeted for the exchange of information about regulated products and the
    exchange of the data needed to provide approval for such products."
    
    
                               UsageNote: V3 Specifications are published in a set
    of "domains", which contain interactions and related specifications for a
    single area of health care within which can be supported by a single, coherent
    set of interoperability specifications.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7PublishingDomain in v3-codesystems.xml
    """
    RegulatedProducts = Hl7PublishingDomain("RP")
    """
    Description: Represents the HL7 content "domain" that supports Public Health
    Reporting - and "includes messages and documents that are specifically
    designed to support managment, reporting and investigation in the public
    health context."
    
    
                               UsageNote: V3 Specifications are published in a set
    of "domains", which contain interactions and related specifications for a
    single area of health care within which can be supported by a single, coherent
    set of interoperability specifications.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7PublishingDomain in v3-codesystems.xml
    """
    PublicHealthReporting = Hl7PublishingDomain("RR")
    """
    Description: Represents the HL7 content "domain" that supports Regulated
    Studies - and is "includes standards developed as part of the family of
    messages targeted for the exchange of information about the conduct of
    regulated studies, and the exchange of the data collected during those
    studies."
    
    
                               UsageNote: V3 Specifications are published in a set
    of "domains", which contain interactions and related specifications for a
    single area of health care within which can be supported by a single, coherent
    set of interoperability specifications.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7PublishingDomain in v3-codesystems.xml
    """
    RegulatedStudies = Hl7PublishingDomain("RT")
    """
    Description: Represents the HL7 content "domain" that supports pharmacy - and
    is a "model used to derive message patterns to describe and communicate
    processes related to medication."
    
    
                               UsageNote: V3 Specifications are published in a set
    of "domains", which contain interactions and related specifications for a
    single area of health care within which can be supported by a single, coherent
    set of interoperability specifications.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7PublishingDomain in v3-codesystems.xml
    """
    Pharmacy = Hl7PublishingDomain("RX")
    """
    Description: Represents the HL7 content "domain" that supports Scheduling -
    and "offers a generic set of messages and behavior to implement any number of
    Scheduling scenarios."
    
    
                               UsageNote: V3 Specifications are published in a set
    of "domains", which contain interactions and related specifications for a
    single area of health care within which can be supported by a single, coherent
    set of interoperability specifications.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7PublishingDomain in v3-codesystems.xml
    """
    Scheduling = Hl7PublishingDomain("SC")
    """
    Description: Represents the HL7 content "domain" that supports Specimen - and
    "comprises the models and artifacts that are needed to support the creation of
    messaging related to specimen."
    
    
                               UsageNote: V3 Specifications are published in a set
    of "domains", which contain interactions and related specifications for a
    single area of health care within which can be supported by a single, coherent
    set of interoperability specifications.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7PublishingDomain in v3-codesystems.xml
    """
    Specimen = Hl7PublishingDomain("SP")
    """
    Description: Represents the HL7 content "domain" that supports Therapeutic
    Devices - and is "comprises the models, messages, and other artifacts that are
    needed to support messaging related to therapy delivery and observations made
    by a medical device. "
    
    
                               UsageNote: V3 Specifications are published in a set
    of "domains", which contain interactions and related specifications for a
    single area of health care within which can be supported by a single, coherent
    set of interoperability specifications.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7PublishingDomain in v3-codesystems.xml
    """
    TherapeuticDevices = Hl7PublishingDomain("TD")
