from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class Hl7PublishingSection(GenericTypeCode):
    """
    v3.hl7PublishingSection
    From: http://terminology.hl7.org/ValueSet/v3-hl7PublishingSection in v3-codesystems.xml
          Description:
    Codes for HL7 publishing sections (major business categories)
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/v3-hl7PublishingSection
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/v3-hl7PublishingSection"


class Hl7PublishingSectionValues:
    """
    Description: Represents the HL7 V3 publishing section that deals with the
    administration and management of health care activities and organizations.


                               UsageNote: V3 Specifications are published in a set
    of "domains", which contain interactions and related specifications for a
    single area of health care within which can be supported by a single, coherent
    set of interoperability specifications.

                            For publishing purposes, these domains are aggregated
    into sub-sections of related health care areas and these sub-sections are
    further aggregated into three major sets.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7PublishingSection in v3-codesystems.xml
    """

    AdministrativeManagement = Hl7PublishingSection("AM")
    """
    Description: Represents the HL7 V3 publishing section that deals with the
    health care provision and clinical management.
    
    
                               UsageNote: V3 Specifications are published in a set
    of "domains", which contain interactions and related specifications for a
    single area of health care within which can be supported by a single, coherent
    set of interoperability specifications.
    
                            For publishing purposes, these domains are aggregated
    into sub-sections of related health care areas and these sub-sections are
    further aggregated into three major sets.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7PublishingSection in v3-codesystems.xml
    """
    HealthAndClinicalManagement = Hl7PublishingSection("HM")
    """
    Description: Represents the HL7 V3 publishing section that deals with the
    definition and management of the computing and communication infrastructure
    necessary to support health care.
    
    
                               UsageNote: V3 Specifications are published in a set
    of "domains", which contain interactions and related specifications for a
    single area of health care within which can be supported by a single, coherent
    set of interoperability specifications.
    
                            For publishing purposes, these domains are aggregated
    into sub-sections of related health care areas and these sub-sections are
    further aggregated into three major sets.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7PublishingSection in v3-codesystems.xml
    """
    InfrastructureManagement = Hl7PublishingSection("IM")
    """
    Description: Represents the HL7 V3 publishing section that holds
    specifications that are unassigned - that have not yet been assigned to one of
    the formal publishing sections.
    
    
                               UsageNote: V3 Specifications are published in a set
    of "domains", which contain interactions and related specifications for a
    single area of health care within which can be supported by a single, coherent
    set of interoperability specifications.
    
                            For publishing purposes, these domains are aggregated
    into sub-sections of related health care areas and these sub-sections are
    further aggregated into three major sets.
    From: http://terminology.hl7.org/CodeSystem/v3-hl7PublishingSection in v3-codesystems.xml
    """
    Unknown = Hl7PublishingSection("UU")
