from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class HL7StandardVersionCode(GenericTypeCode):
    """
    v3.HL7StandardVersionCode
    From: http://terminology.hl7.org/ValueSet/v3-HL7StandardVersionCode in v3-codesystems.xml
         This code system holds version codes for the Version 3 standards. Values are
    to be determined by HL7 and added with each new version of the HL7 Standard.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/v3-HL7StandardVersionCode
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/v3-HL7StandardVersionCode"


class HL7StandardVersionCodeValues:
    """
    The complete set of normative, DSTU, proposed (under ballot) and draft
    artifacts as published in the ballot whose ballot cycle ended in January 2008.
    From: http://terminology.hl7.org/CodeSystem/v3-HL7StandardVersionCode in v3-codesystems.xml
    """

    Ballot2008January = HL7StandardVersionCode("Ballot2008Jan")
    """
    The complete set of normative, DSTU, proposed (under ballot) and draft
    artifacts as published in the ballot whose ballot cycle ended in May 2008.
    From: http://terminology.hl7.org/CodeSystem/v3-HL7StandardVersionCode in v3-codesystems.xml
    """
    Ballot2008May = HL7StandardVersionCode("Ballot2008May")
    """
    The complete set of normative, DSTU, proposed (under ballot) and draft
    artifacts as published in the ballot whose ballot cycle ended in September
    2008.
    From: http://terminology.hl7.org/CodeSystem/v3-HL7StandardVersionCode in v3-codesystems.xml
    """
    Ballot2008September = HL7StandardVersionCode("Ballot2008Sep")
    """
    The complete set of normative, DSTU, proposed (under ballot) and draft
    artifacts as published in the ballot whose ballot cycle ended in January 2009.
    From: http://terminology.hl7.org/CodeSystem/v3-HL7StandardVersionCode in v3-codesystems.xml
    """
    Ballot2009January = HL7StandardVersionCode("Ballot2009Jan")
    """
    The complete set of normative, DSTU, proposed (under ballot) and draft
    artifacts as published in the ballot whose ballot cycle ended in May 2009.
    From: http://terminology.hl7.org/CodeSystem/v3-HL7StandardVersionCode in v3-codesystems.xml
    """
    Ballot2009May = HL7StandardVersionCode("Ballot2009May")
    """
    The complete set of normative, DSTU, proposed (under ballot) and draft
    artifacts as published in the ballot whose ballot cycle ended in September
    2009.
    From: http://terminology.hl7.org/CodeSystem/v3-HL7StandardVersionCode in v3-codesystems.xml
    """
    Ballot2009September = HL7StandardVersionCode("Ballot2009Sep")
    """
    Definition: The complete set of normative, DSTU, proposed (under ballot) and
    draft artifacts as published in the ballot whose ballot cycle ended in January
    2010.
    From: http://terminology.hl7.org/CodeSystem/v3-HL7StandardVersionCode in v3-codesystems.xml
    """
    Ballot2010Jan = HL7StandardVersionCode("Ballot2010Jan")
    """
    Definition: The complete set of normative, DSTU, proposed (under ballot) and
    draft artifacts as published in the ballot whose ballot cycle ended in May
    2010.
    From: http://terminology.hl7.org/CodeSystem/v3-HL7StandardVersionCode in v3-codesystems.xml
    """
    Ballot2010May = HL7StandardVersionCode("Ballot2010May")
    """
    Definition: The complete set of normative, DSTU, proposed (under ballot) and
    draft artifacts as published in the ballot whose ballot cycle ended in
    September 2010.
    From: http://terminology.hl7.org/CodeSystem/v3-HL7StandardVersionCode in v3-codesystems.xml
    """
    Ballot2010Sep = HL7StandardVersionCode("Ballot2010Sep")
    """
    Definition: The complete set of normative, DSTU, proposed (under ballot) and
    draft artifacts as published in the ballot whose ballot cycle ended in January
    2011.
    From: http://terminology.hl7.org/CodeSystem/v3-HL7StandardVersionCode in v3-codesystems.xml
    """
    Ballot2011Jan = HL7StandardVersionCode("Ballot2011Jan")
    """
    Definition: The complete set of normative, DSTU, proposed (under ballot) and
    draft artifacts as published in the ballot whose ballot cycle ended in May
    2011.
    From: http://terminology.hl7.org/CodeSystem/v3-HL7StandardVersionCode in v3-codesystems.xml
    """
    Ballot2011May = HL7StandardVersionCode("Ballot2011May")
    """
    Definition: The complete set of normative, DSTU, proposed (under ballot) and
    draft artifacts as published in the ballot whose ballot cycle ended in
    September 2011.
    From: http://terminology.hl7.org/CodeSystem/v3-HL7StandardVersionCode in v3-codesystems.xml
    """
    Ballot2011Sep = HL7StandardVersionCode("Ballot2011Sep")
    """
    Definition: The complete set of normative, DSTU, proposed (under ballot) and
    draft artifacts as published in the ballot whose ballot cycle ended in January
    2012.
    From: http://terminology.hl7.org/CodeSystem/v3-HL7StandardVersionCode in v3-codesystems.xml
    """
    Ballot2012Jan = HL7StandardVersionCode("Ballot2012Jan")
    """
    Definition: The complete set of normative, DSTU, proposed (under ballot) and
    draft artifacts as published in the ballot whose ballot cycle ended in May
    2012.
    From: http://terminology.hl7.org/CodeSystem/v3-HL7StandardVersionCode in v3-codesystems.xml
    """
    Ballot2012May = HL7StandardVersionCode("Ballot2012May")
    """
    Definition: The complete set of normative, DSTU, proposed (under ballot) and
    draft artifacts as published in the ballot whose ballot cycle ended in
    September 2012.
    From: http://terminology.hl7.org/CodeSystem/v3-HL7StandardVersionCode in v3-codesystems.xml
    """
    Ballot2012Sep = HL7StandardVersionCode("Ballot2012Sep")
    """
    The consistent set of messaging artefacts as published or contained in
    repositories in December of 2003, based on the latest version of any V3 models
    or artefacts (RIM, Datatypes, CMETS, Common Messages, Vocabularies) as
    available in December of 2003. Note: This versioncode does not cover the
    version of the XML ITS.
    From: http://terminology.hl7.org/CodeSystem/v3-HL7StandardVersionCode in v3-codesystems.xml
    """
    HL7VersionV3_2003_12 = HL7StandardVersionCode("V3-2003-12")
    """
    Description:The consistent set of normative and DSTU messaging artifacts as
    published or contained in repositories in December of 2004, based on the
    latest version of any V3 models or artifacts (RIM, Datatypes, CMETS, Common
    Messages, Vocabularies) as published under the title of Normative Edition
    2005. Note: This versioncode does not cover the version of the XML ITS.
    From: http://terminology.hl7.org/CodeSystem/v3-HL7StandardVersionCode in v3-codesystems.xml
    """
    _2005NormativeEdition = HL7StandardVersionCode("V3-2005N")
    """
    Description:The consistent set of normative and DSTU messaging artifacts as
    published or contained in repositories in December of 2005, based on the
    latest version of any V3 models or artifacts (RIM, Datatypes, CMETS, Common
    Messages, Vocabularies) as published under the title of Normative Edition
    2006. Note: This versioncode does not cover the version of the XML ITS.
    From: http://terminology.hl7.org/CodeSystem/v3-HL7StandardVersionCode in v3-codesystems.xml
    """
    _2006NormativeEdition = HL7StandardVersionCode("V3-2006N")
    """
    Definition: The consistent set of normative and DSTU messaging artifacts as
    published or contained in repositories in December of 2007, based on the
    latest version of any V3 models or artifacts (RIM, Data Types, CMETS, Common
    Messages, Vocabularies) published under the title of Normative Edition 2008.
    Note: This version code does not cover the version of the XML ITS.
    From: http://terminology.hl7.org/CodeSystem/v3-HL7StandardVersionCode in v3-codesystems.xml
    """
    _2008NormativeEdition = HL7StandardVersionCode("V3-2008N")
    """
    Description: The consistent set of normative and DSTU messaging artifacts as
    published or contained in repositories in December of 2008, based on the
    latest version of any V3 models or artifacts (RIM, Data Types, CMETS, Common
    Messages, Vocabularies) published under the title of Normative Edition 2009.
    Note: This version code does not cover the version of the XML ITS.
    From: http://terminology.hl7.org/CodeSystem/v3-HL7StandardVersionCode in v3-codesystems.xml
    """
    _2009NormativeEdition = HL7StandardVersionCode("V3-2009N")
    """
    Definition: The consistent set of normative and DSTU messaging artifacts as
    published or contained in repositories in December of 2009, based on the
    latest version of any V3 models or artifacts (RIM, Data Types, CMETS, Common
    Messages, Vocabularies) published under the title of Normative Edition 2010.
    Note: This version code does not cover the version of the XML ITS.
    From: http://terminology.hl7.org/CodeSystem/v3-HL7StandardVersionCode in v3-codesystems.xml
    """
    _2010NormativeEdition = HL7StandardVersionCode("V3-2010N")
    """
    Definition: The consistent set of normative and DSTU messaging artifacts as
    published or contained in repositories in December of 2010, based on the
    latest version of any V3 models or artifacts (RIM, Data Types, CMETS, Common
    Messages, Vocabularies) published under the title of Normative Edition 2011.
    Note: This version code does not cover the version of the XML ITS.
    From: http://terminology.hl7.org/CodeSystem/v3-HL7StandardVersionCode in v3-codesystems.xml
    """
    _2011NormativeEdition = HL7StandardVersionCode("V3-2011N")
    """
    Definition: The consistent set of normative and DSTU messaging artifacts as
    published or contained in repositories in December of 2011, based on the
    latest version of any V3 models or artifacts (RIM, Data Types, CMETS, Common
    Messages, Vocabularies) published under the title of Normative Edition 2012.
    Note: This version code does not cover the version of the XML ITS.
    From: http://terminology.hl7.org/CodeSystem/v3-HL7StandardVersionCode in v3-codesystems.xml
    """
    _2012NormativeEdition = HL7StandardVersionCode("V3-2012N")
    """
    Includes all material published as part of the ballot package released for
    vote in July-August 2003.
    From: http://terminology.hl7.org/CodeSystem/v3-HL7StandardVersionCode in v3-codesystems.xml
    """
    Version3Pre_release_1 = HL7StandardVersionCode("V3PR1")
    """
    Description:The consistent set of normative and DSTU messaging artifacts as
    published or contained in repositories in December of 2006, based on the
    latest version of any V3 models or artifacts (RIM, Datatypes, CMETS, Common
    Messages, Vocabularies) published under the title of Normative Edition 2007.
    Note: This versioncode does not cover the version of the XML ITS.
    From: http://terminology.hl7.org/CodeSystem/v3-HL7StandardVersionCode in v3-codesystems.xml
    """
    _2007NormativeEdition = HL7StandardVersionCode("V3-2007N")
