from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class IdentifierReliability(GenericTypeCode):
    """
    v3.IdentifierReliability
    From: http://terminology.hl7.org/ValueSet/v3-IdentifierReliability in v3-codesystems.xml
         Specifies the reliability with which the identifier is known. This attribute
    MAY be used to assist with identifier matching algorithms.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/v3-IdentifierReliability
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/v3-IdentifierReliability"


class IdentifierReliabilityValues:
    """
    Description: The identifier was issued by the system responsible for
    constructing the instance.
    From: http://terminology.hl7.org/CodeSystem/v3-IdentifierReliability in v3-codesystems.xml
    """

    IssuedBySystem = IdentifierReliability("ISS")
    """
    Description: The identifier was provided to the system that constructed the
    instance, but has not been verified. e.g. a Drivers  license entered manually
    into a system by a user.
    From: http://terminology.hl7.org/CodeSystem/v3-IdentifierReliability in v3-codesystems.xml
    """
    UnverifiedBySystem = IdentifierReliability("UNV")
    """
    Description: The identifier was not issued by the system responsible for
    constructing the instance, but the system that captured the id has verified
    the identifier with the issuing authority, or with another system that has
    verified the identifier.
    From: http://terminology.hl7.org/CodeSystem/v3-IdentifierReliability in v3-codesystems.xml
    """
    VerifiedBySystem = IdentifierReliability("VRF")
