from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class IdentifierScope(GenericTypeCode):
    """
    v3.IdentifierScope
    From: http://terminology.hl7.org/ValueSet/v3-IdentifierScope in v3-codesystems.xml
          Description:
    Codes to specify the scope in which the identifier applies to the object with
    which it is associated, and used in the datatype property II.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/v3-IdentifierScope
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/v3-IdentifierScope"


class IdentifierScopeValues:
    """
    Description: An identifier whose scope is defined by the business practices
    associated with the object. In contrast to the other scope identifiers, the
    scope of the use of the id is not necessarily restricted to a single object,
    but may be reused for other objects closely associated with the object due to
    business practice.
    From: http://terminology.hl7.org/CodeSystem/v3-IdentifierScope in v3-codesystems.xml
    """

    BusinessIdentifier = IdentifierScope("BUSN")
    """
    Description: The identifier associated with a particular object. It remains
    consistent as the object undergoes state transitions.
    From: http://terminology.hl7.org/CodeSystem/v3-IdentifierScope in v3-codesystems.xml
    """
    ObjectIdentifier = IdentifierScope("OBJ")
    """
    Description: An identifier that references a particular object as it existed
    at a given point in time. The identifier SHALL change with each state
    transition on the object. I.e. The version identifier of an object prior to a
    'suspend' state transition is distinct from the identifier of the object after
    the state transition. Each version identifier can be tied to exactly one
    ControlAct event which brought that version into being (though the control act
    may never be instantiated).
    
    
                                NOTE: Applications that do not support versioning
    of objects must ignore and not persist these ids to avoid confusion resulting
    from leaving the same identifier on an object that undergoes changes.
    From: http://terminology.hl7.org/CodeSystem/v3-IdentifierScope in v3-codesystems.xml
    """
    VersionIdentifier = IdentifierScope("VER")
    """
    Description: An identifier that references a particular object as it existed
    at a given point in time. The identifier SHALL change with each state
    transition on the object.
    
    
                               Example The version identifier of an object prior
    to a 'suspend' state transition is distinct from the identifier of the object
    after the state transition. Each version identifier can be tied to exactly one
    ControlAct event which brought that version into being (though the control act
    may never be instantiated).
    
    
                                NOTE: Applications that do not support versioning
    of objects must ignore and not persist these ids to avoid confusion resulting
    From: http://terminology.hl7.org/CodeSystem/v3-IdentifierScope in v3-codesystems.xml
    """
    ViewSpecificIdentifier = IdentifierScope("VW")
