from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class IdentifierUseCode(GenericTypeCode):
    """
    IdentifierUse
    From: http://hl7.org/fhir/identifier-use in valuesets.xml
        Identifies the purpose for this identifier, if known .
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/identifier-use
    """
    codeset: FhirUri = "http://hl7.org/fhir/identifier-use"


class IdentifierUseCodeValues:
    """
    The identifier recommended for display and use in real-world interactions.
    From: http://hl7.org/fhir/identifier-use in valuesets.xml
    """

    Usual = IdentifierUseCode("usual")
    """
    The identifier considered to be most trusted for the identification of this
    item. Sometimes also known as "primary" and "main". The determination of
    "official" is subjective and implementation guides often provide additional
    guidelines for use.
    From: http://hl7.org/fhir/identifier-use in valuesets.xml
    """
    Official = IdentifierUseCode("official")
    """
    A temporary identifier.
    From: http://hl7.org/fhir/identifier-use in valuesets.xml
    """
    Temp = IdentifierUseCode("temp")
    """
    An identifier that was assigned in secondary use - it serves to identify the
    object in a relative context, but cannot be consistently assigned to the same
    object again in a different context.
    From: http://hl7.org/fhir/identifier-use in valuesets.xml
    """
    Secondary = IdentifierUseCode("secondary")
    """
    The identifier id no longer considered valid, but may be relevant for search
    purposes.  E.g. Changes to identifier schemes, account merges, etc.
    From: http://hl7.org/fhir/identifier-use in valuesets.xml
    """
    Old = IdentifierUseCode("old")
