from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class ImagingStudyStatusCode(GenericTypeCode):
    """
    ImagingStudyStatus
    From: http://hl7.org/fhir/imagingstudy-status in valuesets.xml
        The status of the ImagingStudy.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/imagingstudy-status
    """
    codeset: FhirUri = "http://hl7.org/fhir/imagingstudy-status"


class ImagingStudyStatusCodeValues:
    """
    The existence of the imaging study is registered, but there is nothing yet
    available.
    From: http://hl7.org/fhir/imagingstudy-status in valuesets.xml
    """

    Registered = ImagingStudyStatusCode("registered")
    """
    At least one instance has been associated with this imaging study.
    From: http://hl7.org/fhir/imagingstudy-status in valuesets.xml
    """
    Available = ImagingStudyStatusCode("available")
    """
    The imaging study is unavailable because the imaging study was not started or
    not completed (also sometimes called "aborted").
    From: http://hl7.org/fhir/imagingstudy-status in valuesets.xml
    """
    Cancelled = ImagingStudyStatusCode("cancelled")
    """
    The imaging study has been withdrawn following a previous final release.  This
    electronic record should never have existed, though it is possible that real-
    world decisions were based on it. (If real-world activity has occurred, the
    status should be "cancelled" rather than "entered-in-error".).
    From: http://hl7.org/fhir/imagingstudy-status in valuesets.xml
    """
    EnteredInError = ImagingStudyStatusCode("entered-in-error")
    """
    The system does not know which of the status values currently applies for this
    request. Note: This concept is not to be used for "other" - one of the listed
    statuses is presumed to apply, it's just not known which one.
    From: http://hl7.org/fhir/imagingstudy-status in valuesets.xml
    """
    Unknown = ImagingStudyStatusCode("unknown")
