from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class InvoicePriceComponentTypeCode(GenericTypeCode):
    """
    InvoicePriceComponentType
    From: http://hl7.org/fhir/invoice-priceComponentType in valuesets.xml
        Codes indicating the kind of the price component.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/invoice-priceComponentType
    """
    codeset: FhirUri = "http://hl7.org/fhir/invoice-priceComponentType"


class InvoicePriceComponentTypeCodeValues:
    """
    the amount is the base price used for calculating the total price before
    applying surcharges, discount or taxes.
    From: http://hl7.org/fhir/invoice-priceComponentType in valuesets.xml
    """

    BasePrice = InvoicePriceComponentTypeCode("base")
    """
    the amount is a surcharge applied on the base price.
    From: http://hl7.org/fhir/invoice-priceComponentType in valuesets.xml
    """
    Surcharge = InvoicePriceComponentTypeCode("surcharge")
    """
    the amount is a deduction applied on the base price.
    From: http://hl7.org/fhir/invoice-priceComponentType in valuesets.xml
    """
    Deduction = InvoicePriceComponentTypeCode("deduction")
    """
    the amount is a discount applied on the base price.
    From: http://hl7.org/fhir/invoice-priceComponentType in valuesets.xml
    """
    Discount = InvoicePriceComponentTypeCode("discount")
    """
    the amount is the tax component of the total price.
    From: http://hl7.org/fhir/invoice-priceComponentType in valuesets.xml
    """
    Tax = InvoicePriceComponentTypeCode("tax")
    """
    the amount is of informational character, it has not been applied in the
    calculation of the total price.
    From: http://hl7.org/fhir/invoice-priceComponentType in valuesets.xml
    """
    Informational = InvoicePriceComponentTypeCode("informational")
