from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class Iso3166_1_2Code(GenericTypeCode):
    """
    Iso3166-1-2
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
        This value set defines the ISO 3166 Part 1 2-letter codes
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    urn:iso:std:iso:3166
    """
    codeset: FhirUri = "urn:iso:std:iso:3166"


class Iso3166_1_2CodeValues:
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """

    Andorra = Iso3166_1_2Code("AD")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    UnitedArabEmirates = Iso3166_1_2Code("AE")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Afghanistan = Iso3166_1_2Code("AF")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    AntiguaAndBarbuda = Iso3166_1_2Code("AG")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Anguilla = Iso3166_1_2Code("AI")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Albania = Iso3166_1_2Code("AL")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Armenia = Iso3166_1_2Code("AM")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Angola = Iso3166_1_2Code("AO")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Antarctica = Iso3166_1_2Code("AQ")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Argentina = Iso3166_1_2Code("AR")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    AmericanSamoa = Iso3166_1_2Code("AS")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Austria = Iso3166_1_2Code("AT")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Australia = Iso3166_1_2Code("AU")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Aruba = Iso3166_1_2Code("AW")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    _landIslands = Iso3166_1_2Code("AX")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Azerbaijan = Iso3166_1_2Code("AZ")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    BosniaAndHerzegovina = Iso3166_1_2Code("BA")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Barbados = Iso3166_1_2Code("BB")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Bangladesh = Iso3166_1_2Code("BD")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Belgium = Iso3166_1_2Code("BE")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    BurkinaFaso = Iso3166_1_2Code("BF")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Bulgaria = Iso3166_1_2Code("BG")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Bahrain = Iso3166_1_2Code("BH")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Burundi = Iso3166_1_2Code("BI")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Benin = Iso3166_1_2Code("BJ")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    SaintBarth_lemy = Iso3166_1_2Code("BL")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Bermuda = Iso3166_1_2Code("BM")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    BruneiDarussalam = Iso3166_1_2Code("BN")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Bolivia_PlurinationalStateOf = Iso3166_1_2Code("BO")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Bonaire_SintEustatiusAndSaba = Iso3166_1_2Code("BQ")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Brazil = Iso3166_1_2Code("BR")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Bahamas = Iso3166_1_2Code("BS")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Bhutan = Iso3166_1_2Code("BT")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    BouvetIsland = Iso3166_1_2Code("BV")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Botswana = Iso3166_1_2Code("BW")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Belarus = Iso3166_1_2Code("BY")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Belize = Iso3166_1_2Code("BZ")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Canada = Iso3166_1_2Code("CA")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Cocos_Keeling_Islands = Iso3166_1_2Code("CC")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Congo_TheDemocraticRepublicOfThe = Iso3166_1_2Code("CD")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    CentralAfricanRepublic = Iso3166_1_2Code("CF")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Congo = Iso3166_1_2Code("CG")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Switzerland = Iso3166_1_2Code("CH")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    C_teD_Ivoire = Iso3166_1_2Code("CI")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    CookIslands = Iso3166_1_2Code("CK")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Chile = Iso3166_1_2Code("CL")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Cameroon = Iso3166_1_2Code("CM")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    China = Iso3166_1_2Code("CN")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Colombia = Iso3166_1_2Code("CO")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    CostaRica = Iso3166_1_2Code("CR")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Cuba = Iso3166_1_2Code("CU")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    CaboVerde = Iso3166_1_2Code("CV")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Cura_ao = Iso3166_1_2Code("CW")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    ChristmasIsland = Iso3166_1_2Code("CX")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Cyprus = Iso3166_1_2Code("CY")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Czechia = Iso3166_1_2Code("CZ")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Germany = Iso3166_1_2Code("DE")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Djibouti = Iso3166_1_2Code("DJ")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Denmark = Iso3166_1_2Code("DK")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Dominica = Iso3166_1_2Code("DM")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    DominicanRepublic = Iso3166_1_2Code("DO")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Algeria = Iso3166_1_2Code("DZ")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Ecuador = Iso3166_1_2Code("EC")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Estonia = Iso3166_1_2Code("EE")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Egypt = Iso3166_1_2Code("EG")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    WesternSahara = Iso3166_1_2Code("EH")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Eritrea = Iso3166_1_2Code("ER")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Spain = Iso3166_1_2Code("ES")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Ethiopia = Iso3166_1_2Code("ET")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Finland = Iso3166_1_2Code("FI")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Fiji = Iso3166_1_2Code("FJ")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    FalklandIslands_Malvinas_ = Iso3166_1_2Code("FK")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Micronesia_FederatedStatesOf = Iso3166_1_2Code("FM")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    FaroeIslands = Iso3166_1_2Code("FO")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    France = Iso3166_1_2Code("FR")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Gabon = Iso3166_1_2Code("GA")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    UnitedKingdomOfGreatBritainAndNorthernIreland = Iso3166_1_2Code("GB")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Grenada = Iso3166_1_2Code("GD")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Georgia = Iso3166_1_2Code("GE")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    FrenchGuiana = Iso3166_1_2Code("GF")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Guernsey = Iso3166_1_2Code("GG")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Ghana = Iso3166_1_2Code("GH")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Gibraltar = Iso3166_1_2Code("GI")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Greenland = Iso3166_1_2Code("GL")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Gambia = Iso3166_1_2Code("GM")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Guinea = Iso3166_1_2Code("GN")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Guadeloupe = Iso3166_1_2Code("GP")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    EquatorialGuinea = Iso3166_1_2Code("GQ")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Greece = Iso3166_1_2Code("GR")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    SouthGeorgiaAndTheSouthSandwichIslands = Iso3166_1_2Code("GS")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Guatemala = Iso3166_1_2Code("GT")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Guam = Iso3166_1_2Code("GU")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Guinea_Bissau = Iso3166_1_2Code("GW")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Guyana = Iso3166_1_2Code("GY")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    HongKong = Iso3166_1_2Code("HK")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    HeardIslandAndMcDonaldIslands = Iso3166_1_2Code("HM")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Honduras = Iso3166_1_2Code("HN")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Croatia = Iso3166_1_2Code("HR")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Haiti = Iso3166_1_2Code("HT")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Hungary = Iso3166_1_2Code("HU")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Indonesia = Iso3166_1_2Code("ID")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Ireland = Iso3166_1_2Code("IE")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Israel = Iso3166_1_2Code("IL")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    IsleOfMan = Iso3166_1_2Code("IM")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    India = Iso3166_1_2Code("IN")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    BritishIndianOceanTerritory = Iso3166_1_2Code("IO")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Iraq = Iso3166_1_2Code("IQ")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Iran_IslamicRepublicOf = Iso3166_1_2Code("IR")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Iceland = Iso3166_1_2Code("IS")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Italy = Iso3166_1_2Code("IT")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Jersey = Iso3166_1_2Code("JE")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Jamaica = Iso3166_1_2Code("JM")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Jordan = Iso3166_1_2Code("JO")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Japan = Iso3166_1_2Code("JP")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Kenya = Iso3166_1_2Code("KE")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Kyrgyzstan = Iso3166_1_2Code("KG")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Cambodia = Iso3166_1_2Code("KH")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Kiribati = Iso3166_1_2Code("KI")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Comoros = Iso3166_1_2Code("KM")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    SaintKittsAndNevis = Iso3166_1_2Code("KN")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Korea_DemocraticPeople_sRepublicOf = Iso3166_1_2Code("KP")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Korea_RepublicOf = Iso3166_1_2Code("KR")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Kuwait = Iso3166_1_2Code("KW")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    CaymanIslands = Iso3166_1_2Code("KY")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Kazakhstan = Iso3166_1_2Code("KZ")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    LaoPeople_sDemocraticRepublic = Iso3166_1_2Code("LA")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Lebanon = Iso3166_1_2Code("LB")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    SaintLucia = Iso3166_1_2Code("LC")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Liechtenstein = Iso3166_1_2Code("LI")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    SriLanka = Iso3166_1_2Code("LK")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Liberia = Iso3166_1_2Code("LR")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Lesotho = Iso3166_1_2Code("LS")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Lithuania = Iso3166_1_2Code("LT")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Luxembourg = Iso3166_1_2Code("LU")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Latvia = Iso3166_1_2Code("LV")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Libya = Iso3166_1_2Code("LY")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Morocco = Iso3166_1_2Code("MA")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Monaco = Iso3166_1_2Code("MC")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Moldova_RepublicOf = Iso3166_1_2Code("MD")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Montenegro = Iso3166_1_2Code("ME")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    SaintMartin_FrenchPart_ = Iso3166_1_2Code("MF")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Madagascar = Iso3166_1_2Code("MG")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    MarshallIslands = Iso3166_1_2Code("MH")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Macedonia_TheFormerYugoslavRepublicOf = Iso3166_1_2Code("MK")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Mali = Iso3166_1_2Code("ML")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Myanmar = Iso3166_1_2Code("MM")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Mongolia = Iso3166_1_2Code("MN")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Macao = Iso3166_1_2Code("MO")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    NorthernMarianaIslands = Iso3166_1_2Code("MP")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Martinique = Iso3166_1_2Code("MQ")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Mauritania = Iso3166_1_2Code("MR")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Montserrat = Iso3166_1_2Code("MS")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Malta = Iso3166_1_2Code("MT")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Mauritius = Iso3166_1_2Code("MU")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Maldives = Iso3166_1_2Code("MV")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Malawi = Iso3166_1_2Code("MW")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Mexico = Iso3166_1_2Code("MX")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Malaysia = Iso3166_1_2Code("MY")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Mozambique = Iso3166_1_2Code("MZ")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Namibia = Iso3166_1_2Code("NA")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    NewCaledonia = Iso3166_1_2Code("NC")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Niger = Iso3166_1_2Code("NE")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    NorfolkIsland = Iso3166_1_2Code("NF")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Nigeria = Iso3166_1_2Code("NG")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Nicaragua = Iso3166_1_2Code("NI")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Netherlands = Iso3166_1_2Code("NL")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Norway = Iso3166_1_2Code("NO")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Nepal = Iso3166_1_2Code("NP")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Nauru = Iso3166_1_2Code("NR")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Niue = Iso3166_1_2Code("NU")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    NewZealand = Iso3166_1_2Code("NZ")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Oman = Iso3166_1_2Code("OM")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Panama = Iso3166_1_2Code("PA")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Peru = Iso3166_1_2Code("PE")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    FrenchPolynesia = Iso3166_1_2Code("PF")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    PapuaNewGuinea = Iso3166_1_2Code("PG")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Philippines = Iso3166_1_2Code("PH")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Pakistan = Iso3166_1_2Code("PK")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Poland = Iso3166_1_2Code("PL")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    SaintPierreAndMiquelon = Iso3166_1_2Code("PM")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Pitcairn = Iso3166_1_2Code("PN")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    PuertoRico = Iso3166_1_2Code("PR")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Palestine_StateOf = Iso3166_1_2Code("PS")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Portugal = Iso3166_1_2Code("PT")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Palau = Iso3166_1_2Code("PW")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Paraguay = Iso3166_1_2Code("PY")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Qatar = Iso3166_1_2Code("QA")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    R_union = Iso3166_1_2Code("RE")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Romania = Iso3166_1_2Code("RO")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Serbia = Iso3166_1_2Code("RS")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    RussianFederation = Iso3166_1_2Code("RU")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Rwanda = Iso3166_1_2Code("RW")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    SaudiArabia = Iso3166_1_2Code("SA")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    SolomonIslands = Iso3166_1_2Code("SB")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Seychelles = Iso3166_1_2Code("SC")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Sudan = Iso3166_1_2Code("SD")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Sweden = Iso3166_1_2Code("SE")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Singapore = Iso3166_1_2Code("SG")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    SaintHelena_AscensionAndTristanDaCunha = Iso3166_1_2Code("SH")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Slovenia = Iso3166_1_2Code("SI")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    SvalbardAndJanMayen = Iso3166_1_2Code("SJ")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Slovakia = Iso3166_1_2Code("SK")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    SierraLeone = Iso3166_1_2Code("SL")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    SanMarino = Iso3166_1_2Code("SM")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Senegal = Iso3166_1_2Code("SN")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Somalia = Iso3166_1_2Code("SO")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Suriname = Iso3166_1_2Code("SR")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    SouthSudan = Iso3166_1_2Code("SS")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    SaoTomeAndPrincipe = Iso3166_1_2Code("ST")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    ElSalvador = Iso3166_1_2Code("SV")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    SintMaarten_DutchPart_ = Iso3166_1_2Code("SX")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    SyrianArabRepublic = Iso3166_1_2Code("SY")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Swaziland = Iso3166_1_2Code("SZ")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    TurksAndCaicosIslands = Iso3166_1_2Code("TC")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Chad = Iso3166_1_2Code("TD")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    FrenchSouthernTerritories = Iso3166_1_2Code("TF")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Togo = Iso3166_1_2Code("TG")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Thailand = Iso3166_1_2Code("TH")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Tajikistan = Iso3166_1_2Code("TJ")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Tokelau = Iso3166_1_2Code("TK")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Timor_Leste = Iso3166_1_2Code("TL")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Turkmenistan = Iso3166_1_2Code("TM")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Tunisia = Iso3166_1_2Code("TN")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Tonga = Iso3166_1_2Code("TO")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Turkey = Iso3166_1_2Code("TR")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    TrinidadAndTobago = Iso3166_1_2Code("TT")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Tuvalu = Iso3166_1_2Code("TV")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Taiwan_ProvinceOfChina = Iso3166_1_2Code("TW")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Tanzania_UnitedRepublicOf = Iso3166_1_2Code("TZ")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Ukraine = Iso3166_1_2Code("UA")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Uganda = Iso3166_1_2Code("UG")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    UnitedStatesMinorOutlyingIslands = Iso3166_1_2Code("UM")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    UnitedStatesOfAmerica = Iso3166_1_2Code("US")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Uruguay = Iso3166_1_2Code("UY")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Uzbekistan = Iso3166_1_2Code("UZ")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    HolySee = Iso3166_1_2Code("VA")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    SaintVincentAndTheGrenadines = Iso3166_1_2Code("VC")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Venezuela_BolivarianRepublicOf = Iso3166_1_2Code("VE")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    VirginIslands_British = Iso3166_1_2Code("VG")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    VirginIslands_ = Iso3166_1_2Code("VI")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    VietNam = Iso3166_1_2Code("VN")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Vanuatu = Iso3166_1_2Code("VU")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    WallisAndFutuna = Iso3166_1_2Code("WF")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Samoa = Iso3166_1_2Code("WS")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Yemen = Iso3166_1_2Code("YE")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Mayotte = Iso3166_1_2Code("YT")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    SouthAfrica = Iso3166_1_2Code("ZA")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Zambia = Iso3166_1_2Code("ZM")
    """
    From: http://hl7.org/fhir/ValueSet/iso3166-1-2 in valuesets.xml
    """
    Zimbabwe = Iso3166_1_2Code("ZW")
