from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class KnowledgeResourceTypeCode(GenericTypeCode):
    """
    KnowledgeResourceType
    From: http://hl7.org/fhir/knowledge-resource-types in valuesets.xml
        A list of all the knowledge resource types defined in this version of the FHIR
    specification.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/knowledge-resource-types
    """
    codeset: FhirUri = "http://hl7.org/fhir/knowledge-resource-types"


class KnowledgeResourceTypeCodeValues:
    """
    The definition of a specific activity to be taken, independent of any
    particular patient or context.
    From: http://hl7.org/fhir/knowledge-resource-types in valuesets.xml
    """

    ActivityDefinition = KnowledgeResourceTypeCode("ActivityDefinition")
    """
    A set of codes drawn from one or more code systems.
    From: http://hl7.org/fhir/knowledge-resource-types in valuesets.xml
    """
    CodeSystem = KnowledgeResourceTypeCode("CodeSystem")
    """
    A map from one set of concepts to one or more other concepts.
    From: http://hl7.org/fhir/knowledge-resource-types in valuesets.xml
    """
    ConceptMap = KnowledgeResourceTypeCode("ConceptMap")
    """
    Represents a library of quality improvement components.
    From: http://hl7.org/fhir/knowledge-resource-types in valuesets.xml
    """
    Library = KnowledgeResourceTypeCode("Library")
    """
    A quality measure definition.
    From: http://hl7.org/fhir/knowledge-resource-types in valuesets.xml
    """
    Measure = KnowledgeResourceTypeCode("Measure")
    """
    The definition of a plan for a series of actions, independent of any specific
    patient or context.
    From: http://hl7.org/fhir/knowledge-resource-types in valuesets.xml
    """
    PlanDefinition = KnowledgeResourceTypeCode("PlanDefinition")
    """
    Structural Definition.
    From: http://hl7.org/fhir/knowledge-resource-types in valuesets.xml
    """
    StructureDefinition = KnowledgeResourceTypeCode("StructureDefinition")
    """
    A Map of relationships between 2 structures that can be used to transform
    data.
    From: http://hl7.org/fhir/knowledge-resource-types in valuesets.xml
    """
    StructureMap = KnowledgeResourceTypeCode("StructureMap")
    """
    A set of codes drawn from one or more code systems.
    From: http://hl7.org/fhir/knowledge-resource-types in valuesets.xml
    """
    ValueSet = KnowledgeResourceTypeCode("ValueSet")
