from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class LinkTypeCode(GenericTypeCode):
    """
    LinkType
    From: http://hl7.org/fhir/link-type in valuesets.xml
        The type of link between this patient resource and another patient resource.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/link-type
    """
    codeset: FhirUri = "http://hl7.org/fhir/link-type"


class LinkTypeCodeValues:
    """
    The patient resource containing this link must no longer be used. The link
    points forward to another patient resource that must be used in lieu of the
    patient resource that contains this link.
    From: http://hl7.org/fhir/link-type in valuesets.xml
    """

    Replaced_by = LinkTypeCode("replaced-by")
    """
    The patient resource containing this link is the current active patient
    record. The link points back to an inactive patient resource that has been
    merged into this resource, and should be consulted to retrieve additional
    referenced information.
    From: http://hl7.org/fhir/link-type in valuesets.xml
    """
    Replaces = LinkTypeCode("replaces")
    """
    The patient resource containing this link is in use and valid but not
    considered the main source of information about a patient. The link points
    forward to another patient resource that should be consulted to retrieve
    additional patient information.
    From: http://hl7.org/fhir/link-type in valuesets.xml
    """
    Refer = LinkTypeCode("refer")
    """
    The patient resource containing this link is in use and valid, but points to
    another patient resource that is known to contain data about the same person.
    Data in this resource might overlap or contradict information found in the
    other patient resource. This link does not indicate any relative importance of
    the resources concerned, and both should be regarded as equally valid.
    From: http://hl7.org/fhir/link-type in valuesets.xml
    """
    SeeAlso = LinkTypeCode("seealso")
