from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class LinkageTypeCode(GenericTypeCode):
    """
    LinkageType
    From: http://hl7.org/fhir/linkage-type in valuesets.xml
        Used to distinguish different roles a resource can play within a set of linked
    resources.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/linkage-type
    """
    codeset: FhirUri = "http://hl7.org/fhir/linkage-type"


class LinkageTypeCodeValues:
    """
    The resource represents the "source of truth" (from the perspective of this
    Linkage resource) for the underlying event/condition/etc.
    From: http://hl7.org/fhir/linkage-type in valuesets.xml
    """

    SourceOfTruth = LinkageTypeCode("source")
    """
    The resource represents an alternative view of the underlying
    event/condition/etc.  The resource may still be actively maintained, even
    though it is not considered to be the source of truth.
    From: http://hl7.org/fhir/linkage-type in valuesets.xml
    """
    AlternateRecord = LinkageTypeCode("alternate")
    """
    The resource represents an obsolete record of the underlying
    event/condition/etc.  It is not expected to be actively maintained.
    From: http://hl7.org/fhir/linkage-type in valuesets.xml
    """
    Historical_ObsoleteRecord = LinkageTypeCode("historical")
