from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class ListOrderCodesCode(GenericTypeCode):
    """
    ListOrderCodes
    From: http://terminology.hl7.org/CodeSystem/list-order in valuesets.xml
        Base values for the order of the items in a list resource.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/list-order
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/list-order"


class ListOrderCodesCodeValues:
    """
    The list was sorted by a user. The criteria the user used are not specified.
    From: http://terminology.hl7.org/CodeSystem/list-order in valuesets.xml
    """

    SortedByUser = ListOrderCodesCode("user")
    """
    The list was sorted by the system. The criteria the user used are not
    specified; define additional codes to specify a particular order (or use other
    defined codes).
    From: http://terminology.hl7.org/CodeSystem/list-order in valuesets.xml
    """
    SortedBySystem = ListOrderCodesCode("system")
    """
    The list is sorted by the data of the event. This can be used when the list
    has items which are dates with past or future events.
    From: http://terminology.hl7.org/CodeSystem/list-order in valuesets.xml
    """
    SortedByEventDate = ListOrderCodesCode("event-date")
    """
    The list is sorted by the date the item was added to the list. Note that the
    date added to the list is not explicit in the list itself.
    From: http://terminology.hl7.org/CodeSystem/list-order in valuesets.xml
    """
    SortedByItemDate = ListOrderCodesCode("entry-date")
    """
    The list is sorted by priority. The exact method in which priority has been
    determined is not specified.
    From: http://terminology.hl7.org/CodeSystem/list-order in valuesets.xml
    """
    SortedByPriority = ListOrderCodesCode("priority")
    """
    The list is sorted alphabetically by an unspecified property of the items in
    the list.
    From: http://terminology.hl7.org/CodeSystem/list-order in valuesets.xml
    """
    SortedAlphabetically = ListOrderCodesCode("alphabetic")
    """
    The list is sorted categorically by an unspecified property of the items in
    the list.
    From: http://terminology.hl7.org/CodeSystem/list-order in valuesets.xml
    """
    SortedByCategory = ListOrderCodesCode("category")
    """
    The list is sorted by patient, with items for each patient grouped together.
    From: http://terminology.hl7.org/CodeSystem/list-order in valuesets.xml
    """
    SortedByPatient = ListOrderCodesCode("patient")
