from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class LocationTypeCode(GenericTypeCode):
    """
    LocationType
    From: http://terminology.hl7.org/CodeSystem/location-physical-type in valuesets.xml
        This example value set defines a set of codes that can be used to indicate the
    physical form of the Location.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/location-physical-type
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/location-physical-type"


class LocationTypeCodeValues:
    """
    A collection of buildings or other locations such as a site or a campus.
    From: http://terminology.hl7.org/CodeSystem/location-physical-type in valuesets.xml
    """

    Site = LocationTypeCode("si")
    """
    Any Building or structure. This may contain rooms, corridors, wings, etc. It
    might not have walls, or a roof, but is considered a defined/allocated space.
    From: http://terminology.hl7.org/CodeSystem/location-physical-type in valuesets.xml
    """
    Building = LocationTypeCode("bu")
    """
    A Wing within a Building, this often contains levels, rooms and corridors.
    From: http://terminology.hl7.org/CodeSystem/location-physical-type in valuesets.xml
    """
    Wing = LocationTypeCode("wi")
    """
    A Ward is a section of a medical facility that may contain rooms and other
    types of location.
    From: http://terminology.hl7.org/CodeSystem/location-physical-type in valuesets.xml
    """
    Ward = LocationTypeCode("wa")
    """
    A Level in a multi-level Building/Structure.
    From: http://terminology.hl7.org/CodeSystem/location-physical-type in valuesets.xml
    """
    Level = LocationTypeCode("lvl")
    """
    Any corridor within a Building, that may connect rooms.
    From: http://terminology.hl7.org/CodeSystem/location-physical-type in valuesets.xml
    """
    Corridor = LocationTypeCode("co")
    """
    A space that is allocated as a room, it may have walls/roof etc., but does not
    require these.
    From: http://terminology.hl7.org/CodeSystem/location-physical-type in valuesets.xml
    """
    Room = LocationTypeCode("ro")
    """
    A space that is allocated for sleeping/laying on. This is not the physical
    bed/trolley that may be moved about, but the space it may occupy.
    From: http://terminology.hl7.org/CodeSystem/location-physical-type in valuesets.xml
    """
    Bed = LocationTypeCode("bd")
    """
    A means of transportation.
    From: http://terminology.hl7.org/CodeSystem/location-physical-type in valuesets.xml
    """
    Vehicle = LocationTypeCode("ve")
    """
    A residential dwelling. Usually used to reference a location that a
    person/patient may reside.
    From: http://terminology.hl7.org/CodeSystem/location-physical-type in valuesets.xml
    """
    House = LocationTypeCode("ho")
    """
    A container that can store goods, equipment, medications or other items.
    From: http://terminology.hl7.org/CodeSystem/location-physical-type in valuesets.xml
    """
    Cabinet = LocationTypeCode("ca")
    """
    A defined path to travel between 2 points that has a known name.
    From: http://terminology.hl7.org/CodeSystem/location-physical-type in valuesets.xml
    """
    Road = LocationTypeCode("rd")
    """
    A defined physical boundary of something, such as a flood risk zone, region,
    postcode
    From: http://terminology.hl7.org/CodeSystem/location-physical-type in valuesets.xml
    """
    Area = LocationTypeCode("area")
    """
    A wide scope that covers a conceptual domain, such as a Nation (Country wide
    community or Federal Government - e.g. Ministry of Health),  Province or State
    (community or Government), Business (throughout the enterprise), Nation with a
    business scope of an agency (e.g. CDC, FDA etc.) or a Business segment (UK
    Pharmacy), not just an physical boundary
    From: http://terminology.hl7.org/CodeSystem/location-physical-type in valuesets.xml
    """
    Jurisdiction = LocationTypeCode("jdn")
