from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class MapRelationship(GenericTypeCode):
    """
    v3.MapRelationship
    From: http://terminology.hl7.org/ValueSet/v3-MapRelationship in v3-codesystems.xml
         The closeness or quality of the mapping between the HL7 concept (as
    represented by the HL7 concept identifier) and the source coding system. The
    values are patterned after the similar relationships used in the UMLS
    Metathesaurus. Because the HL7 coding sy
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/v3-MapRelationship
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/v3-MapRelationship"


class MapRelationshipValues:
    """
    The first concept is at a more abstract level than the second concept.  For
    example, Hepatitis is broader than Hepatitis A, and endocrine disease is
    broader than Diabetes Mellitus.  Broader than is the opposite of the narrower
    than relationship.
    From: http://terminology.hl7.org/CodeSystem/v3-MapRelationship in v3-codesystems.xml
    """

    BroaderThan = MapRelationship("BT")
    """
    The two concepts have identical meaning.
    From: http://terminology.hl7.org/CodeSystem/v3-MapRelationship in v3-codesystems.xml
    """
    Exact = MapRelationship("E")
    """
    The first concept is at a more detailed level than the second concept.  For
    example, Pennicillin G is narrower than Pennicillin, and vellus hair is
    narrower than hair.  Narrower than is the opposite of broader than.
    From: http://terminology.hl7.org/CodeSystem/v3-MapRelationship in v3-codesystems.xml
    """
    NarrowerThan = MapRelationship("NT")
