from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class MeasurePopulationTypeCode(GenericTypeCode):
    """
    MeasurePopulationType
    From: http://terminology.hl7.org/CodeSystem/measure-population in valuesets.xml
        The type of population.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/measure-population
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/measure-population"


class MeasurePopulationTypeCodeValues:
    """
    The initial population refers to all patients or events to be evaluated by a
    quality measure involving patients who share a common set of specified
    characterstics. All patients or events counted (for example, as numerator, as
    denominator) are drawn from the initial population.
    From: http://terminology.hl7.org/CodeSystem/measure-population in valuesets.xml
    """

    InitialPopulation = MeasurePopulationTypeCode("initial-population")
    """
    The upper portion of a fraction used to calculate a rate, proportion, or
    ratio. Also called the measure focus, it is the target process, condition,
    event, or outcome. Numerator criteria are the processes or outcomes expected
    for each patient, or event defined in the denominator. A numerator statement
    describes the clinical action that satisfies the conditions of the measure.
    From: http://terminology.hl7.org/CodeSystem/measure-population in valuesets.xml
    """
    Numerator = MeasurePopulationTypeCode("numerator")
    """
    Numerator exclusion criteria define patients or events to be removed from the
    numerator. Numerator exclusions are used in proportion and ratio measures to
    help narrow the numerator (for inverted measures).
    From: http://terminology.hl7.org/CodeSystem/measure-population in valuesets.xml
    """
    NumeratorExclusion = MeasurePopulationTypeCode("numerator-exclusion")
    """
    The lower portion of a fraction used to calculate a rate, proportion, or
    ratio. The denominator can be the same as the initial population, or a subset
    of the initial population to further constrain the population for the purpose
    of the measure.
    From: http://terminology.hl7.org/CodeSystem/measure-population in valuesets.xml
    """
    Denominator = MeasurePopulationTypeCode("denominator")
    """
    Denominator exclusion criteria define patients or events that should be
    removed from the denominator before determining if numerator criteria are met.
    Denominator exclusions are used in proportion and ratio measures to help
    narrow the denominator. For example, patients with bilateral lower extremity
    amputations would be listed as a denominator exclusion for a measure requiring
    foot exams.
    From: http://terminology.hl7.org/CodeSystem/measure-population in valuesets.xml
    """
    DenominatorExclusion = MeasurePopulationTypeCode("denominator-exclusion")
    """
    Denominator exceptions are conditions that should remove a patient or event
    from the denominator of a measure only if the numerator criteria are not met.
    Denominator exception allows for adjustment of the calculated score for those
    providers with higher risk populations. Denominator exception criteria are
    only used in proportion measures.
    From: http://terminology.hl7.org/CodeSystem/measure-population in valuesets.xml
    """
    DenominatorException = MeasurePopulationTypeCode("denominator-exception")
    """
    Measure population criteria define the patients or events for which the
    individual observation for the measure should be taken. Measure populations
    are used for continuous variable measures rather than numerator and
    denominator criteria.
    From: http://terminology.hl7.org/CodeSystem/measure-population in valuesets.xml
    """
    MeasurePopulation = MeasurePopulationTypeCode("measure-population")
    """
    Measure population criteria define the patients or events that should be
    removed from the measure population before determining the outcome of one or
    more continuous variables defined for the measure observation. Measure
    population exclusion criteria are used within continuous variable measures to
    help narrow the measure population.
    From: http://terminology.hl7.org/CodeSystem/measure-population in valuesets.xml
    """
    MeasurePopulationExclusion = MeasurePopulationTypeCode(
        "measure-population-exclusion"
    )
    """
    Defines the individual observation to be performed for each patient or event
    in the measure population. Measure observations for each case in the
    population are aggregated to determine the overall measure score for the
    population.
    From: http://terminology.hl7.org/CodeSystem/measure-population in valuesets.xml
    """
    MeasureObservation = MeasurePopulationTypeCode("measure-observation")
