from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class MedicationDispenseStatusCodesCode(GenericTypeCode):
    """
    MedicationDispense Status Codes
    From: http://terminology.hl7.org/CodeSystem/medicationdispense-status in valuesets.xml
        MedicationDispense Status Codes
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/medicationdispense-status
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/medicationdispense-status"


class MedicationDispenseStatusCodesCodeValues:
    """
    The core event has not started yet, but some staging activities have begun
    (e.g. initial compounding or packaging of medication). Preparation stages may
    be tracked for billing purposes.
    From: http://terminology.hl7.org/CodeSystem/medicationdispense-status in valuesets.xml
    """

    Preparation = MedicationDispenseStatusCodesCode("preparation")
    """
    The dispensed product is ready for pickup.
    From: http://terminology.hl7.org/CodeSystem/medicationdispense-status in valuesets.xml
    """
    InProgress = MedicationDispenseStatusCodesCode("in-progress")
    """
    The dispensed product was not and will never be picked up by the patient.
    From: http://terminology.hl7.org/CodeSystem/medicationdispense-status in valuesets.xml
    """
    Cancelled = MedicationDispenseStatusCodesCode("cancelled")
    """
    The dispense process is paused while waiting for an external event to
    reactivate the dispense.  For example, new stock has arrived or the prescriber
    has called.
    From: http://terminology.hl7.org/CodeSystem/medicationdispense-status in valuesets.xml
    """
    OnHold = MedicationDispenseStatusCodesCode("on-hold")
    """
    The dispensed product has been picked up.
    From: http://terminology.hl7.org/CodeSystem/medicationdispense-status in valuesets.xml
    """
    Completed = MedicationDispenseStatusCodesCode("completed")
    """
    The dispense was entered in error and therefore nullified.
    From: http://terminology.hl7.org/CodeSystem/medicationdispense-status in valuesets.xml
    """
    EnteredInError = MedicationDispenseStatusCodesCode("entered-in-error")
    """
    Actions implied by the dispense have been permanently halted, before all of
    them occurred.
    From: http://terminology.hl7.org/CodeSystem/medicationdispense-status in valuesets.xml
    """
    Stopped = MedicationDispenseStatusCodesCode("stopped")
    """
    The dispense was declined and not performed.
    From: http://terminology.hl7.org/CodeSystem/medicationdispense-status in valuesets.xml
    """
    Declined = MedicationDispenseStatusCodesCode("declined")
    """
    The authoring system does not know which of the status values applies for this
    medication dispense.  Note: this concept is not to be used for other - one of
    the listed statuses is presumed to apply, it's just now known which one.
    From: http://terminology.hl7.org/CodeSystem/medicationdispense-status in valuesets.xml
    """
    Unknown = MedicationDispenseStatusCodesCode("unknown")
