from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class MedicationRequestIntentCode(GenericTypeCode):
    """
    medicationRequest Intent
    From: http://hl7.org/fhir/CodeSystem/medicationrequest-intent in valuesets.xml
        MedicationRequest Intent Codes
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/CodeSystem/medicationrequest-intent
    """
    codeset: FhirUri = "http://hl7.org/fhir/CodeSystem/medicationrequest-intent"


class MedicationRequestIntentCodeValues:
    """
    The request is a suggestion made by someone/something that doesn't have an
    intention to ensure it occurs and without providing an authorization to act
    From: http://hl7.org/fhir/CodeSystem/medicationrequest-intent in valuesets.xml
    """

    Proposal = MedicationRequestIntentCode("proposal")
    """
    The request represents an intention to ensure something occurs without
    providing an authorization for others to act.
    From: http://hl7.org/fhir/CodeSystem/medicationrequest-intent in valuesets.xml
    """
    Plan = MedicationRequestIntentCode("plan")
    """
    The request represents a request/demand and authorization for action
    From: http://hl7.org/fhir/CodeSystem/medicationrequest-intent in valuesets.xml
    """
    Order = MedicationRequestIntentCode("order")
    """
    The request represents the original authorization for the medication request.
    From: http://hl7.org/fhir/CodeSystem/medicationrequest-intent in valuesets.xml
    """
    OriginalOrder = MedicationRequestIntentCode("original-order")
    """
    The request represents an automatically generated supplemental authorization
    for action based on a parent authorization together with initial results of
    the action taken against that parent authorization..
    From: http://hl7.org/fhir/CodeSystem/medicationrequest-intent in valuesets.xml
    """
    ReflexOrder = MedicationRequestIntentCode("reflex-order")
    """
    The request represents the view of an authorization instantiated by a
    fulfilling system representing the details of the fulfiller's intention to act
    upon a submitted order.
    From: http://hl7.org/fhir/CodeSystem/medicationrequest-intent in valuesets.xml
    """
    FillerOrder = MedicationRequestIntentCode("filler-order")
    """
    The request represents an instance for the particular order, for example a
    medication administration record.
    From: http://hl7.org/fhir/CodeSystem/medicationrequest-intent in valuesets.xml
    """
    InstanceOrder = MedicationRequestIntentCode("instance-order")
    """
    The request represents a component or option for a RequestGroup that
    establishes timing, conditionality and/or  other constraints among a set of
    requests.
    From: http://hl7.org/fhir/CodeSystem/medicationrequest-intent in valuesets.xml
    """
    Option = MedicationRequestIntentCode("option")
