from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class MedicationStatusCodesCode(GenericTypeCode):
    """
    Medication Status Codes
    From: http://hl7.org/fhir/CodeSystem/medication-statement-status in valuesets.xml
        Medication Status Codes
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/CodeSystem/medication-statement-status
    """
    codeset: FhirUri = "http://hl7.org/fhir/CodeSystem/medication-statement-status"


class MedicationStatusCodesCodeValues:
    """
    The medication is still being taken.
    From: http://hl7.org/fhir/CodeSystem/medication-statement-status in valuesets.xml
    """

    Active = MedicationStatusCodesCode("active")
    """
    The medication is no longer being taken.
    From: http://hl7.org/fhir/CodeSystem/medication-statement-status in valuesets.xml
    """
    Completed = MedicationStatusCodesCode("completed")
    """
    Some of the actions that are implied by the medication statement may have
    occurred.  For example, the patient may have taken some of the medication.
    Clinical decision support systems should take this status into account.
    From: http://hl7.org/fhir/CodeSystem/medication-statement-status in valuesets.xml
    """
    EnteredInError = MedicationStatusCodesCode("entered-in-error")
    """
    The medication may be taken at some time in the future.
    From: http://hl7.org/fhir/CodeSystem/medication-statement-status in valuesets.xml
    """
    Intended = MedicationStatusCodesCode("intended")
    """
    Actions implied by the statement have been permanently halted, before all of
    them occurred. This should not be used if the statement was entered in error.
    From: http://hl7.org/fhir/CodeSystem/medication-statement-status in valuesets.xml
    """
    Stopped = MedicationStatusCodesCode("stopped")
    """
    Actions implied by the statement have been temporarily halted, but are
    expected to continue later. May also be called 'suspended'.
    From: http://hl7.org/fhir/CodeSystem/medication-statement-status in valuesets.xml
    """
    OnHold = MedicationStatusCodesCode("on-hold")
    """
    The state of the medication use is not currently known.
    From: http://hl7.org/fhir/CodeSystem/medication-statement-status in valuesets.xml
    """
    Unknown = MedicationStatusCodesCode("unknown")
    """
    The medication was not consumed by the patient
    From: http://hl7.org/fhir/CodeSystem/medication-statement-status in valuesets.xml
    """
    NotTaken = MedicationStatusCodesCode("not-taken")
