from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class NameRepresentationUseCode(GenericTypeCode):
    """
    NameRepresentationUse
    From: http://hl7.org/fhir/ValueSet/name-v3-representation in valuesets.xml
        A set of codes for each different representation of a name.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/v3-EntityNameUse
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/v3-EntityNameUse"


class NameRepresentationUseCodeValues:
    """
    Identifies the different representations of a name.  The representation may
    affect how the name is used.  (E.g. use of Ideographic for formal
    communications.)
    From: http://terminology.hl7.org/CodeSystem/v3-EntityNameUse in v3-codesystems.xml
    """

    NameRepresentationUse = NameRepresentationUseCode("_NameRepresentationUse")
    """
    A name assigned to a person. Reasons some organizations assign alternate names
    may include not knowing the person's name, or to maintain anonymity. Some, but
    not necessarily all, of the name types that people call "alias" may fit into
    this category.
    From: http://terminology.hl7.org/CodeSystem/v3-EntityNameUse in v3-codesystems.xml
    """
    Assigned = NameRepresentationUseCode("ASGN")
    """
    As recorded on a license, record, certificate, etc. (only if different from
    legal name)
    From: http://terminology.hl7.org/CodeSystem/v3-EntityNameUse in v3-codesystems.xml
    """
    License = NameRepresentationUseCode("C")
    """
    e.g. Chief Red Cloud
    From: http://terminology.hl7.org/CodeSystem/v3-EntityNameUse in v3-codesystems.xml
    """
    Indigenous_Tribal = NameRepresentationUseCode("I")
    """
    Known as/conventional/the one you use
    From: http://terminology.hl7.org/CodeSystem/v3-EntityNameUse in v3-codesystems.xml
    """
    Legal = NameRepresentationUseCode("L")
    """
    A self asserted name that the person is using or has used.
    From: http://terminology.hl7.org/CodeSystem/v3-EntityNameUse in v3-codesystems.xml
    """
    Pseudonym = NameRepresentationUseCode("P")
    """
    e.g. Sister Mary Francis, Brother John
    From: http://terminology.hl7.org/CodeSystem/v3-EntityNameUse in v3-codesystems.xml
    """
    Religious = NameRepresentationUseCode("R")
    """
    A name intended for use in searching or matching.
    From: http://terminology.hl7.org/CodeSystem/v3-EntityNameUse in v3-codesystems.xml
    """
    Search = NameRepresentationUseCode("SRCH")
    """
    From: http://hl7.org/fhir/ValueSet/name-v3-representation in valuesets.xml
    """
    ABC = NameRepresentationUseCode("ABC")
    """
    From: http://hl7.org/fhir/ValueSet/name-v3-representation in valuesets.xml
    """
    IDE = NameRepresentationUseCode("IDE")
    """
    From: http://hl7.org/fhir/ValueSet/name-v3-representation in valuesets.xml
    """
    SYL = NameRepresentationUseCode("SYL")
