from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class NarrativeStatusCode(GenericTypeCode):
    """
    NarrativeStatus
    From: http://hl7.org/fhir/narrative-status in valuesets.xml
        The status of a resource narrative.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/narrative-status
    """
    codeset: FhirUri = "http://hl7.org/fhir/narrative-status"


class NarrativeStatusCodeValues:
    """
    The contents of the narrative are entirely generated from the core elements in
    the content.
    From: http://hl7.org/fhir/narrative-status in valuesets.xml
    """

    Generated = NarrativeStatusCode("generated")
    """
    The contents of the narrative are entirely generated from the core elements in
    the content and some of the content is generated from extensions. The
    narrative SHALL reflect the impact of all modifier extensions.
    From: http://hl7.org/fhir/narrative-status in valuesets.xml
    """
    Extensions = NarrativeStatusCode("extensions")
    """
    The contents of the narrative may contain additional information not found in
    the structured data. Note that there is no computable way to determine what
    the extra information is, other than by human inspection.
    From: http://hl7.org/fhir/narrative-status in valuesets.xml
    """
    Additional = NarrativeStatusCode("additional")
    """
    The contents of the narrative are some equivalent of "No human-readable text
    provided in this case".
    From: http://hl7.org/fhir/narrative-status in valuesets.xml
    """
    Empty = NarrativeStatusCode("empty")
