from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class NHINPurposeOfUseCode(GenericTypeCode):
    """
    NHIN PurposeOfUse
    From: http://healthit.gov/nhin/purposeofuse in valuesets.xml
        This value set is suitable for use with the provenance resource. It is derived
    from, but not compatible with, the HL7 v3 Purpose of use Code system.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://healthit.gov/nhin/purposeofuse
    """
    codeset: FhirUri = "http://healthit.gov/nhin/purposeofuse"


class NHINPurposeOfUseCodeValues:
    """
    Treatment
    From: http://healthit.gov/nhin/purposeofuse in valuesets.xml
    """

    Treatment = NHINPurposeOfUseCode("TREATMENT")
    """
    Payment
    From: http://healthit.gov/nhin/purposeofuse in valuesets.xml
    """
    Payment = NHINPurposeOfUseCode("PAYMENT")
    """
    Healthcare Operations
    From: http://healthit.gov/nhin/purposeofuse in valuesets.xml
    """
    Operations = NHINPurposeOfUseCode("OPERATIONS")
    """
    System Administration
    From: http://healthit.gov/nhin/purposeofuse in valuesets.xml
    """
    Sysadmin = NHINPurposeOfUseCode("SYSADMIN")
    """
    Fraud detection
    From: http://healthit.gov/nhin/purposeofuse in valuesets.xml
    """
    Fraud = NHINPurposeOfUseCode("FRAUD")
    """
    Use or disclosure of Psychotherapy Notes
    From: http://healthit.gov/nhin/purposeofuse in valuesets.xml
    """
    Psychotherapy = NHINPurposeOfUseCode("PSYCHOTHERAPY")
    """
    Use or disclosure by the covered entity for its own training programs
    From: http://healthit.gov/nhin/purposeofuse in valuesets.xml
    """
    Training = NHINPurposeOfUseCode("TRAINING")
    """
    Use or disclosure by the covered entity to defend itself in a legal action
    From: http://healthit.gov/nhin/purposeofuse in valuesets.xml
    """
    Legal = NHINPurposeOfUseCode("LEGAL")
    """
    Marketing
    From: http://healthit.gov/nhin/purposeofuse in valuesets.xml
    """
    Marketing = NHINPurposeOfUseCode("MARKETING")
    """
    Use and disclosure for facility directories
    From: http://healthit.gov/nhin/purposeofuse in valuesets.xml
    """
    Directory = NHINPurposeOfUseCode("DIRECTORY")
    """
    Disclose to a family member, other relative, or a close personal friend of the
    individual
    From: http://healthit.gov/nhin/purposeofuse in valuesets.xml
    """
    Family = NHINPurposeOfUseCode("FAMILY")
    """
    Uses and disclosures with the individual present.
    From: http://healthit.gov/nhin/purposeofuse in valuesets.xml
    """
    Present = NHINPurposeOfUseCode("PRESENT")
    """
    Permission cannot practicably be provided because of the individual's
    incapacity or an emergency.
    From: http://healthit.gov/nhin/purposeofuse in valuesets.xml
    """
    Emergency = NHINPurposeOfUseCode("EMERGENCY")
    """
    Use and disclosures for disaster relief purposes.
    From: http://healthit.gov/nhin/purposeofuse in valuesets.xml
    """
    Disaster = NHINPurposeOfUseCode("DISASTER")
    """
    Uses and disclosures for public health activities.
    From: http://healthit.gov/nhin/purposeofuse in valuesets.xml
    """
    PublicHealth = NHINPurposeOfUseCode("PUBLICHEALTH")
    """
    Disclosures about victims of abuse, neglect or domestic violence.
    From: http://healthit.gov/nhin/purposeofuse in valuesets.xml
    """
    Abuse = NHINPurposeOfUseCode("ABUSE")
    """
    Uses and disclosures for health oversight activities.
    From: http://healthit.gov/nhin/purposeofuse in valuesets.xml
    """
    Oversight = NHINPurposeOfUseCode("OVERSIGHT")
    """
    Disclosures for judicial and administrative proceedings.
    From: http://healthit.gov/nhin/purposeofuse in valuesets.xml
    """
    Judicial = NHINPurposeOfUseCode("JUDICIAL")
    """
    Disclosures for law enforcement purposes.
    From: http://healthit.gov/nhin/purposeofuse in valuesets.xml
    """
    LawEnforcement = NHINPurposeOfUseCode("LAW")
    """
    Uses and disclosures about decedents.
    From: http://healthit.gov/nhin/purposeofuse in valuesets.xml
    """
    Deceased = NHINPurposeOfUseCode("DECEASED")
    """
    Uses and disclosures for cadaveric organ,  eye or tissue donation purposes
    From: http://healthit.gov/nhin/purposeofuse in valuesets.xml
    """
    Donation = NHINPurposeOfUseCode("DONATION")
    """
    Uses and disclosures for research purposes.
    From: http://healthit.gov/nhin/purposeofuse in valuesets.xml
    """
    Research = NHINPurposeOfUseCode("RESEARCH")
    """
    Uses and disclosures to avert a serious threat to health or safety.
    From: http://healthit.gov/nhin/purposeofuse in valuesets.xml
    """
    Threat = NHINPurposeOfUseCode("THREAT")
    """
    Uses and disclosures for specialized government functions.
    From: http://healthit.gov/nhin/purposeofuse in valuesets.xml
    """
    Government = NHINPurposeOfUseCode("GOVERNMENT")
    """
    Disclosures for workers' compensation.
    From: http://healthit.gov/nhin/purposeofuse in valuesets.xml
    """
    Worker_sComp = NHINPurposeOfUseCode("WORKERSCOMP")
    """
    Disclosures for insurance or disability coverage determination
    From: http://healthit.gov/nhin/purposeofuse in valuesets.xml
    """
    Coverage = NHINPurposeOfUseCode("COVERAGE")
    """
    Request of the Individual
    From: http://healthit.gov/nhin/purposeofuse in valuesets.xml
    """
    Request = NHINPurposeOfUseCode("REQUEST")
