from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class ObservationCategory(GenericTypeCode):
    """
    v3.ObservationCategory
    From: http://terminology.hl7.org/ValueSet/v3-ObservationCategory in v3-codesystems.xml
         High level observation categories for the general type of observation being
    made. URL: http://hl7-fhir.github.io/valueset-observation-category.html This
    is an inline code system http://hl7.org/fhir/observation-category.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/v3-ObservationCategory
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/v3-ObservationCategory"


class ObservationCategoryValues:
    """
    Observations generated by physical exam findings including direct observations
    made by a clinician and use of simple instruments and the result of simple
    maneuvers performed directly on the patient's body.
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationCategory in v3-codesystems.xml
    """

    Exam = ObservationCategory("exam")
    """
    Observations generated by imaging. The scope includes observations, plain
    x-ray, ultrasound, CT, MRI, angiography, echocardiography, nuclear medicine.
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationCategory in v3-codesystems.xml
    """
    Imaging = ObservationCategory("imaging")
    """
    The results of observations generated by laboratories. Laboratory results are
    typically generated by laboratories providing analytic services in areas such
    as chemistry, hematology, serology, histology, cytology, anatomic pathology,
    microbiology, and/or virology. These observations are based on analysis of
    specimens obtained from the patient and submitted to the laboratory.
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationCategory in v3-codesystems.xml
    """
    Laboratory = ObservationCategory("laboratory")
    """
    Observations generated by other procedures. This category includes
    observations resulting from interventional and non-interventional procedures
    excluding lab and imaging (e.g. cardiology catheterization, endoscopy,
    electrodiagnostics, etc.). Procedure results are typically generated by a
    clinician to provide more granular information about component observations
    made during a procedure, such as where a gastroenterologist reports the size
    of a polyp observed during a colonoscopy.
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationCategory in v3-codesystems.xml
    """
    Procedure = ObservationCategory("procedure")
    """
    The Social History Observations define the patient's occupational, personal
    (e.g. lifestyle), social, and environmental history and health risk factors,
    as well as administrative data such as marital status, race, ethnicity and
    religious affiliation.
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationCategory in v3-codesystems.xml
    """
    SocialHistory = ObservationCategory("social-history")
    """
    Assessment tool/survey instrument observations (e.g. Apgar Scores, Montreal
    Cognitive Assessment (MoCA))
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationCategory in v3-codesystems.xml
    """
    Survey = ObservationCategory("survey")
    """
    Observations generated by non-interventional treatment protocols (e.g.
    occupational, physical, radiation, nutritional and medication therapy)
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationCategory in v3-codesystems.xml
    """
    Therapy = ObservationCategory("therapy")
    """
    Clinical observations measure the body's basic functions such as such as blood
    pressure, heart rate, respiratory rate, height, weight, body mass index, head
    circumference, pulse oximetry, temperature, and body surface area.
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationCategory in v3-codesystems.xml
    """
    VitalSigns = ObservationCategory("vital-signs")
