from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class ObservationDataTypeCode(GenericTypeCode):
    """
    ObservationDataType
    From: http://hl7.org/fhir/permitted-data-type in valuesets.xml
        Permitted data type for observation value.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/permitted-data-type
    """
    codeset: FhirUri = "http://hl7.org/fhir/permitted-data-type"


class ObservationDataTypeCodeValues:
    """
    A measured amount.
    From: http://hl7.org/fhir/permitted-data-type in valuesets.xml
    """

    Quantity = ObservationDataTypeCode("Quantity")
    """
    A coded concept from a reference terminology and/or text.
    From: http://hl7.org/fhir/permitted-data-type in valuesets.xml
    """
    CodeableConcept = ObservationDataTypeCode("CodeableConcept")
    """
    A sequence of Unicode characters.
    From: http://hl7.org/fhir/permitted-data-type in valuesets.xml
    """
    String = ObservationDataTypeCode("string")
    """
    true or false.
    From: http://hl7.org/fhir/permitted-data-type in valuesets.xml
    """
    Boolean = ObservationDataTypeCode("boolean")
    """
    A signed integer.
    From: http://hl7.org/fhir/permitted-data-type in valuesets.xml
    """
    Integer = ObservationDataTypeCode("integer")
    """
    A set of values bounded by low and high.
    From: http://hl7.org/fhir/permitted-data-type in valuesets.xml
    """
    Range = ObservationDataTypeCode("Range")
    """
    A ratio of two Quantity values - a numerator and a denominator.
    From: http://hl7.org/fhir/permitted-data-type in valuesets.xml
    """
    Ratio = ObservationDataTypeCode("Ratio")
    """
    A series of measurements taken by a device.
    From: http://hl7.org/fhir/permitted-data-type in valuesets.xml
    """
    SampledData = ObservationDataTypeCode("SampledData")
    """
    A time during the day, in the format hh:mm:ss.
    From: http://hl7.org/fhir/permitted-data-type in valuesets.xml
    """
    Time = ObservationDataTypeCode("time")
    """
    A date, date-time or partial date (e.g. just year or year + month) as used in
    human communication.
    From: http://hl7.org/fhir/permitted-data-type in valuesets.xml
    """
    DateTime = ObservationDataTypeCode("dateTime")
    """
    A time range defined by start and end date/time.
    From: http://hl7.org/fhir/permitted-data-type in valuesets.xml
    """
    Period = ObservationDataTypeCode("Period")
