from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class ObservationMethod(GenericTypeCode):
    """
    v3.ObservationMethod
    From: http://terminology.hl7.org/ValueSet/v3-ObservationMethod in v3-codesystems.xml
         A code that provides additional detail about the means or technique used to
    ascertain the observation.  Examples:
    Blood pressure measurement method: arterial puncture vs. sphygmomanometer
    (Riva-Rocci), sitting vs. supine position, etc.  OpenIssue:
    Description copied from Concept Domain of same name.  Must be verified.  Note
    that the Domain has a full discussion about use of the attribute and
    constraining that is not appropriate for the code system description.  Needs
    to be improved.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/v3-ObservationMethod
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/v3-ObservationMethod"


class ObservationMethodValues:
    """
    Provides codes for decision methods, initially for assessing the causality of
    events.
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """

    DecisionObservationMethod = ObservationMethod("_DecisionObservationMethod")
    """
    A code that provides additional detail about the means or technique used to
    ascertain the genetic analysis. Example, PCR, Micro Array
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    GeneticObservationMethod = ObservationMethod("_GeneticObservationMethod")
    """
    Provides additional detail about the aggregation methods used to compute the
    aggregated values for an observation. This is an abstract code.
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ObservationMethodAggregate = ObservationMethod("_ObservationMethodAggregate")
    """
    VerificationMethod
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    VerificationMethod = ObservationMethod("_VerificationMethod")
    """
    Complement fixation
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ComplementFixation = ObservationMethod("0001")
    """
    Computed axial tomography
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ComputedAxialTomography = ObservationMethod("0002")
    """
    Susceptibility, High Level Aminoglycoside Resistance agar test
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    HLARAgarTest = ObservationMethod("0003")
    """
    Visual, Macroscopic observation
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    MacroscopicObservation = ObservationMethod("0004")
    """
    Computed, Magnetic resonance
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    MagneticResonance = ObservationMethod("0005")
    """
    Computed, Morphometry
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Morphometry = ObservationMethod("0006")
    """
    Computed, Positron emission tomography
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    PositronEmissionTomography = ObservationMethod("0007")
    """
    SAMHSA drug assay confirmation
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    SAMHSAConfirmation = ObservationMethod("0008")
    """
    SAMHSA drug assay screening
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    SAMHSAScreening = ObservationMethod("0009")
    """
    Serum Neutralization
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    SerumNeutralization = ObservationMethod("0010")
    """
    Titration
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Titration = ObservationMethod("0011")
    """
    Ultrasound
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Ultrasound = ObservationMethod("0012")
    """
    X-ray crystallography
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    X_rayCrystallography = ObservationMethod("0013")
    """
    Agglutination
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Agglutination = ObservationMethod("0014")
    """
    Agglutination, Buffered acidified plate
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    BufferedAcidifiedPlateAgglutination = ObservationMethod("0015")
    """
    Agglutination, Card
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    CardAgglutination = ObservationMethod("0016")
    """
    Agglutination, Hemagglutination
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Hemagglutination = ObservationMethod("0017")
    """
    Agglutination, Hemagglutination inhibition
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    HemagglutinationInhibition = ObservationMethod("0018")
    """
    Agglutination, Latex
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    LatexAgglutination = ObservationMethod("0019")
    """
    Agglutination, Plate
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    PlateAgglutination = ObservationMethod("0020")
    """
    Agglutination, Rapid Plate
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    RapidAgglutination = ObservationMethod("0021")
    """
    Agglutination, RBC
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    RBCAgglutination = ObservationMethod("0022")
    """
    Agglutination, Rivanol
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    RivanolAgglutination = ObservationMethod("0023")
    """
    Agglutination, Tube
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    TubeAgglutination = ObservationMethod("0024")
    """
    Bioassay
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Bioassay = ObservationMethod("0025")
    """
    Bioassay, Animal Inoculation
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    AnimalInoculation = ObservationMethod("0026")
    """
    Bioassay, Cytotoxicity
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Cytotoxicity = ObservationMethod("0027")
    """
    Bioassay, Embryo Infective Dose 50
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    EmbryoInfectiveDose50 = ObservationMethod("0028")
    """
    Bioassay, Embryo Lethal Dose 50
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    EmbryoLethalDose50 = ObservationMethod("0029")
    """
    Bioassay, Mouse intercerebral inoculation
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    MouseIntercerebralInoculation = ObservationMethod("0030")
    """
    Bioassay, qualitative
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Bioassay_Qualitative = ObservationMethod("0031")
    """
    Bioassay, quantitative
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Bioassay_Quantitative = ObservationMethod("0032")
    """
    Chemical
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ChemicalMethod = ObservationMethod("0033")
    """
    Chemical, Differential light absorption
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    DifferentialLightAbsorptionChemicalTest = ObservationMethod("0034")
    """
    Chemical, Dipstick
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Dipstick = ObservationMethod("0035")
    """
    Chemical, Dipstick colorimetric laboratory test
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    DipstickColorimetricLaboratoryTest = ObservationMethod("0036")
    """
    Chemical, Test strip
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    TestStrip = ObservationMethod("0037")
    """
    Chromatography
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Chromatography = ObservationMethod("0038")
    """
    Chromatography, Affinity
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    AffinityChromatography = ObservationMethod("0039")
    """
    Chromatography, Gas liquid
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    GasLiquidChromatography = ObservationMethod("0040")
    """
    Chromatography, High performance liquid
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    HighPerformanceLiquidChromatography = ObservationMethod("0041")
    """
    Chromatography, Liquid
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    LiquidChromatography = ObservationMethod("0042")
    """
    Chromatography, Protein A affinity
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ProteinAAffinityChromatography = ObservationMethod("0043")
    """
    Coagulation
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Coagulation = ObservationMethod("0044")
    """
    Coagulation, Tilt tube
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    TiltTubeCoagulationTime = ObservationMethod("0045")
    """
    Coagulation, Tilt tube reptilase induced
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    TiltTubeReptilaseInducedCoagulation = ObservationMethod("0046")
    """
    Count, Automated
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    AutomatedCount = ObservationMethod("0047")
    """
    Count, Manual
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ManualCellCount = ObservationMethod("0048")
    """
    Count, Platelet, Rees-Ecker
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    PlateletCount_Rees_Ecker = ObservationMethod("0049")
    """
    Culture, Aerobic
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    AerobicCulture = ObservationMethod("0050")
    """
    Culture, Anaerobic
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    AnaerobicCulture = ObservationMethod("0051")
    """
    Culture, Chicken Embryo
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ChickenEmbryoCulture = ObservationMethod("0052")
    """
    Culture, Delayed secondary enrichment
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    DelayedSecondaryEnrichment = ObservationMethod("0053")
    """
    Culture, Microaerophilic
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    MicroaerophilicCulture = ObservationMethod("0054")
    """
    Culture, Quantitative microbial, cup
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    QuantitativeMicrobialCulture_Cup = ObservationMethod("0055")
    """
    Culture, Quantitative microbial, droplet
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    QuantitativeMicrobialCulture_Droplet = ObservationMethod("0056")
    """
    Culture, Quantitative microbial, filter paper
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    QuantitativeMicrobialCulture_FilterPaper = ObservationMethod("0057")
    """
    Culture, Quantitative microbial, pad
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    QuantitativeMicrobialCulture_PadCulture = ObservationMethod("0058")
    """
    Culture, Quantitative microbial, pour plate
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    QuantitativeMicrobialCulture_PourPlate = ObservationMethod("0059")
    """
    Culture, Quantitative microbial, surface streak
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    QuantitativeMicrobialCulture_SurfaceStreak = ObservationMethod("0060")
    """
    Culture, Somatic Cell
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    SomaticCellCulture = ObservationMethod("0061")
    """
    Diffusion, Agar
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    AgarDiffusion = ObservationMethod("0062")
    """
    Diffusion, Agar Gel Immunodiffusion
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    AgarGelImmunodiffusion = ObservationMethod("0063")
    """
    Electrophoresis
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Electrophoresis = ObservationMethod("0064")
    """
    Electrophoresis, Agaorse gel
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    AgaorseGelElectrophoresis = ObservationMethod("0065")
    """
    Electrophoresis, citrate agar
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Electrophoresis_CitrateAgar = ObservationMethod("0066")
    """
    Electrophoresis, Immuno
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Immunoelectrophoresis = ObservationMethod("0067")
    """
    Electrophoresis, Polyacrylamide gel
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    PolyacrylamideGelElectrophoresis = ObservationMethod("0068")
    """
    Electrophoresis, Starch gel
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    StarchGelElectrophoresis = ObservationMethod("0069")
    """
    ELISA
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ELISA = ObservationMethod("0070")
    """
    ELISA, antigen capture
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ELISA_AntigenCapture = ObservationMethod("0071")
    """
    ELISA, avidin biotin peroxidase complex
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ELISA_AvidinBiotinPeroxidaseComplex = ObservationMethod("0072")
    """
    ELISA, Kinetic
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    KineticELISA = ObservationMethod("0073")
    """
    ELISA, peroxidase-antiperoxidase
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ELISA_Peroxidase_antiperoxidase = ObservationMethod("0074")
    """
    Identification, API 20 Strep
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    API20Strep = ObservationMethod("0075")
    """
    Identification, API 20A
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    API20A = ObservationMethod("0076")
    """
    Identification, API 20C AUX
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    API20CAUX = ObservationMethod("0077")
    """
    Identification, API 20E
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    API20E = ObservationMethod("0078")
    """
    Identification, API 20NE
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    API20NE = ObservationMethod("0079")
    """
    Identification, API 50 CH
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    API50CH = ObservationMethod("0080")
    """
    Identification, API An-IDENT
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    APIAn_IDENT = ObservationMethod("0081")
    """
    Identification, API Coryne
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    APICoryne = ObservationMethod("0082")
    """
    Identification, API Rapid 20E
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    APIRapid20E = ObservationMethod("0083")
    """
    Identification, API Staph
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    APIStaph = ObservationMethod("0084")
    """
    Identification, API ZYM
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    APIZYM = ObservationMethod("0085")
    """
    Identification, Bacterial
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    BacterialIdentification = ObservationMethod("0086")
    """
    Identification, mini VIDAS
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    MiniVIDAS = ObservationMethod("0087")
    """
    Identification, Phage susceptibility typing
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    PhageSusceptibilityTyping = ObservationMethod("0088")
    """
    Identification, Quad-FERM+
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Quad_FERM_ = ObservationMethod("0089")
    """
    Identification, RAPIDEC Staph
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    RAPIDECStaph = ObservationMethod("0090")
    """
    Identification, Staphaurex
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Staphaurex = ObservationMethod("0091")
    """
    Identification, VIDAS
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    VIDAS = ObservationMethod("0092")
    """
    Identification, Vitek
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Vitek = ObservationMethod("0093")
    """
    Identification, VITEK 2
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    VITEK2 = ObservationMethod("0094")
    """
    Immune stain
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ImmuneStain = ObservationMethod("0095")
    """
    Immune stain, Immunofluorescent antibody, direct
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ImmunofluorescentAntibody_Direct = ObservationMethod("0096")
    """
    Immune stain, Immunofluorescent antibody, indirect
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ImmunofluorescentAntibody_Indirect = ObservationMethod("0097")
    """
    Immune stain, Immunoperoxidase, Avidin-Biotin Complex
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Immunoperoxidase_Avidin_BiotinComplex = ObservationMethod("0098")
    """
    Immune stain, Immunoperoxidase, Peroxidase anti-peroxidase complex
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Immunoperoxidase_PeroxidaseAnti_peroxidaseComplex = ObservationMethod("0099")
    """
    Immune stain, Immunoperoxidase, Protein A-peroxidase complex
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Immunoperoxidase_ProteinA_peroxidaseComplex = ObservationMethod("0100")
    """
    Immunoassay
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Immunoassay = ObservationMethod("0101")
    """
    Immunoassay, qualitative, multiple step
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Immunoassay_Qualitative_MultipleStep = ObservationMethod("0102")
    """
    Immunoassay, qualitative, single step
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Immunoassay_Qualitative_SingleStep = ObservationMethod("0103")
    """
    Immunoassay, Radioimmunoassay
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Radioimmunoassay = ObservationMethod("0104")
    """
    Immunoassay, semi-quantitative, multiple step
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Immunoassay_Semi_quantitative_MultipleStep = ObservationMethod("0105")
    """
    Immunoassay, semi-quantitative, single step
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Immunoassay_Semi_quantitative_SingleStep = ObservationMethod("0106")
    """
    Microscopy
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Microscopy = ObservationMethod("0107")
    """
    Microscopy, Darkfield
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    DarkfieldMicroscopy = ObservationMethod("0108")
    """
    Microscopy, Electron
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ElectronMicroscopy = ObservationMethod("0109")
    """
    Microscopy, Electron microscopy tomography
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ElectronMicroscopyTomography = ObservationMethod("0110")
    """
    Microscopy, Electron, negative stain
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ElectronMicroscopy_NegativeStain = ObservationMethod("0111")
    """
    Microscopy, Electron, thick section transmission
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ElectronMicroscopy_ThickSection = ObservationMethod("0112")
    """
    Microscopy, Electron, thin section transmission
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ElectronMicroscopy_ThinSection = ObservationMethod("0113")
    """
    Microscopy, Light
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Microscopy_Light = ObservationMethod("0114")
    """
    Microscopy, Polarized light
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    PolarizingLightMicroscopy = ObservationMethod("0115")
    """
    Microscopy, Scanning electron
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ScanningElectronMicroscopy = ObservationMethod("0116")
    """
    Microscopy, Transmission electron
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    TransmissionElectronMicroscopy = ObservationMethod("0117")
    """
    Microscopy, Transparent tape direct examination
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    TransparentTapeDirectExamination = ObservationMethod("0118")
    """
    Molecular, 3 Self-Sustaining Sequence Replication
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    _3Self_SustainingSequenceReplication = ObservationMethod("0119")
    """
    Molecular, Branched Chain DNA
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    BranchedChainDNA = ObservationMethod("0120")
    """
    Molecular, Hybridization Protection Assay
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    HybridizationProtectionAssay = ObservationMethod("0121")
    """
    Molecular, Immune blot
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ImmuneBlot = ObservationMethod("0122")
    """
    Molecular, In-situ hybridization
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    In_situHybridization = ObservationMethod("0123")
    """
    Molecular, Ligase Chain Reaction
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    LigaseChainReaction = ObservationMethod("0124")
    """
    Molecular, Ligation Activated Transcription
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    LigationActivatedTranscription = ObservationMethod("0125")
    """
    Molecular, Nucleic Acid Probe
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    NucleicAcidProbe = ObservationMethod("0126")
    """
    Molecular, Nucleic acid probe with amplification
    
    
    
                            Rationale: Duplicate of code 0126. Use code 0126
    instead.
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    NucleicAcidProbeWithAmplification = ObservationMethod("0128")
    """
    Molecular, Nucleic acid probe with target amplification
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    NucleicAcidProbeWithTargetAmplification = ObservationMethod("0129")
    """
    Molecular, Nucleic acid reverse transcription
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    NucleicAcidReverseTranscription = ObservationMethod("0130")
    """
    Molecular, Nucleic Acid Sequence Based Analysis
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    NucleicAcidSequenceBasedAnalysis = ObservationMethod("0131")
    """
    Molecular, Polymerase chain reaction
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    PolymeraseChainReaction = ObservationMethod("0132")
    """
    Molecular, Q-Beta Replicase or probe amplification category method
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Q_BetaReplicaseOrProbeAmplificationCategoryMethod = ObservationMethod("0133")
    """
    Molecular, Restriction Fragment Length Polymorphism
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    RestrictionFragmentLengthPolymorphism = ObservationMethod("0134")
    """
    Molecular, Southern Blot
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    SouthernBlot = ObservationMethod("0135")
    """
    Molecular, Strand Displacement Amplification
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    StrandDisplacementAmplification = ObservationMethod("0136")
    """
    Molecular, Transcription Mediated Amplification
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    TranscriptionMediatedAmplification = ObservationMethod("0137")
    """
    Molecular, Western Blot
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    WesternBlot = ObservationMethod("0138")
    """
    Precipitation, Flocculation
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Flocculation = ObservationMethod("0139")
    """
    Precipitation, Immune precipitation
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ImmunePrecipitation = ObservationMethod("0140")
    """
    Precipitation, Milk ring test
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    MilkRingTest = ObservationMethod("0141")
    """
    Precipitation, Precipitin
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Precipitin = ObservationMethod("0142")
    """
    Stain, Acid fast
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    AcidFastStain = ObservationMethod("0143")
    """
    Stain, Acid fast, fluorochrome
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    AcidFastStain_Fluorochrome = ObservationMethod("0144")
    """
    Stain, Acid fast, Kinyoun's cold carbolfuchsin
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    AcidFastStain_Kinyoun_sColdCarbolfuchsin = ObservationMethod("0145")
    """
    Stain, Acid fast, Ziehl-Neelsen
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    AcidFastStain_Ziehl_Neelsen = ObservationMethod("0146")
    """
    Stain, Acid phosphatase
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    AcidPhosphataseStain = ObservationMethod("0147")
    """
    Stain, Acridine orange
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    AcridineOrangeStain = ObservationMethod("0148")
    """
    Stain, Active brilliant orange KH
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ActiveBrilliantOrangeKHStain = ObservationMethod("0149")
    """
    Stain, Alazarin red S
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    AlazarinRedSStain = ObservationMethod("0150")
    """
    Stain, Alcian blue
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    AlcianBlueStain = ObservationMethod("0151")
    """
    Stain, Alcian blue with Periodic acid Schiff
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    AlcianBlueWithPeriodicAcidSchiffStain = ObservationMethod("0152")
    """
    Stain, Argentaffin
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ArgentaffinStain = ObservationMethod("0153")
    """
    Stain, Argentaffin silver
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ArgentaffinSilverStain = ObservationMethod("0154")
    """
    Stain, Azure-eosin
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Azure_eosinStain = ObservationMethod("0155")
    """
    Stain, Basic Fuschin
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    BasicFuschinStain = ObservationMethod("0156")
    """
    Stain, Bennhold
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    BennholdStain = ObservationMethod("0157")
    """
    Stain, Bennhold's Congo red
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Bennhold_sCongoRedStain = ObservationMethod("0158")
    """
    Stain, Bielschowsky
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    BielschowskyStain = ObservationMethod("0159")
    """
    Stain, Bielschowsky's silver
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Bielschowsky_sSilverStain = ObservationMethod("0160")
    """
    Stain, Bleach
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    BleachStain = ObservationMethod("0161")
    """
    Stain, Bodian
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    BodianStain = ObservationMethod("0162")
    """
    Stain, Brown-Brenn
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Brown_BrennStain = ObservationMethod("0163")
    """
    Stain, Butyrate-esterase
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Butyrate_esteraseStain = ObservationMethod("0164")
    """
    Stain, Calcofluor white fluorescent
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    CalcofluorWhiteFluorescentStain = ObservationMethod("0165")
    """
    Stain, Carbol-fuchsin
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Carbol_fuchsinStain = ObservationMethod("0166")
    """
    Stain, Carmine
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    CarmineStain = ObservationMethod("0167")
    """
    Stain, Churukian-Schenk
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Churukian_SchenkStain = ObservationMethod("0168")
    """
    Stain, Congo red
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    CongoRedStain = ObservationMethod("0169")
    """
    Stain, Cresyl echt violet
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    CresylEchtVioletStain = ObservationMethod("0170")
    """
    Stain, Crystal violet
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    CrystalVioletStain = ObservationMethod("0171")
    """
    Stain, De Galantha
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    DeGalanthaStain = ObservationMethod("0172")
    """
    Stain, Dieterle silver impregnation
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    DieterleSilverImpregnationStain = ObservationMethod("0173")
    """
    Stain, Fite-Farco
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Fite_FarcoStain = ObservationMethod("0174")
    """
    Stain, Fontana-Masson silver
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Fontana_MassonSilverStain = ObservationMethod("0175")
    """
    Stain, Fouchet
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    FouchetStain = ObservationMethod("0176")
    """
    Stain, Gomori
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    GomoriStain = ObservationMethod("0177")
    """
    Stain, Gomori methenamine silver
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    GomoriMethenamineSilverStain = ObservationMethod("0178")
    """
    Stain, Gomori-Wheatly trichrome
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Gomori_WheatlyTrichromeStain = ObservationMethod("0179")
    """
    Stain, Gridley
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    GridleyStain = ObservationMethod("0180")
    """
    Stain, Grimelius silver
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    GrimeliusSilverStain = ObservationMethod("0181")
    """
    Stain, Grocott
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    GrocottStain = ObservationMethod("0182")
    """
    Stain, Grocott methenamine silver
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    GrocottMethenamineSilverStain = ObservationMethod("0183")
    """
    Stain, Hale's colloidal ferric oxide
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Hale_sColloidalFerricOxideStain = ObservationMethod("0184")
    """
    Stain, Hale's colloidal iron
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Hale_sColloidalIronStain = ObservationMethod("0185")
    """
    Stain, Hansel
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    HanselStain = ObservationMethod("0186")
    """
    Stain, Harris regressive hematoxylin and eosin
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    HarrisRegressiveHematoxylinAndEosinStain = ObservationMethod("0187")
    """
    Stain, Hematoxylin and eosin
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    HematoxylinAndEosinStain = ObservationMethod("0188")
    """
    Stain, Highman
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    HighmanStain = ObservationMethod("0189")
    """
    Stain, Holzer
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    HolzerStain = ObservationMethod("0190")
    """
    Stain, Iron hematoxylin
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    IronHematoxylinStain = ObservationMethod("0191")
    """
    Stain, Jones
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    JonesStain = ObservationMethod("0192")
    """
    Stain, Jones methenamine silver
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    JonesMethenamineSilverStain = ObservationMethod("0193")
    """
    Stain, Kossa
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    KossaStain = ObservationMethod("0194")
    """
    Stain, Lawson-Van Gieson
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Lawson_VanGiesonStain = ObservationMethod("0195")
    """
    Stain, Loeffler methylene blue
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    LoefflerMethyleneBlueStain = ObservationMethod("0196")
    """
    Stain, Luxol fast blue with cresyl violet
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    LuxolFastBlueWithCresylVioletStain = ObservationMethod("0197")
    """
    Stain, Luxol fast blue with Periodic acid-Schiff
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    LuxolFastBlueWithPeriodicAcid_SchiffStain = ObservationMethod("0198")
    """
    Stain, MacNeal's tetrachrome blood
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    MacNeal_sTetrachromeBloodStain = ObservationMethod("0199")
    """
    Stain, Mallory-Heidenhain
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Mallory_HeidenhainStain = ObservationMethod("0200")
    """
    Stain, Masson trichrome
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    MassonTrichromeStain = ObservationMethod("0201")
    """
    Stain, Mayer mucicarmine
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    MayerMucicarmineStain = ObservationMethod("0202")
    """
    Stain, Mayers progressive hematoxylin and eosin
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    MayersProgressiveHematoxylinAndEosinStain = ObservationMethod("0203")
    """
    Stain, May-Grunwald Giemsa
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    May_GrunwaldGiemsaStain = ObservationMethod("0204")
    """
    Stain, Methyl green
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    MethylGreenStain = ObservationMethod("0205")
    """
    Stain, Methyl green pyronin
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    MethylGreenPyroninStain = ObservationMethod("0206")
    """
    Stain, Modified Gomori-Wheatly trichrome
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ModifiedGomori_WheatlyTrichromeStain = ObservationMethod("0207")
    """
    Stain, Modified Masson trichrome
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ModifiedMassonTrichromeStain = ObservationMethod("0208")
    """
    Stain, Modified trichrome
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ModifiedTrichromeStain = ObservationMethod("0209")
    """
    Stain, Movat pentachrome
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    MovatPentachromeStain = ObservationMethod("0210")
    """
    Stain, Mucicarmine
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    MucicarmineStain = ObservationMethod("0211")
    """
    Stain, Neutral red
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    NeutralRedStain = ObservationMethod("0212")
    """
    Stain, Night blue
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    NightBlueStain = ObservationMethod("0213")
    """
    Stain, Non-specific esterase
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Non_specificEsteraseStain = ObservationMethod("0214")
    """
    Stain, Oil red-O
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    OilRed_OStain = ObservationMethod("0215")
    """
    Stain, Orcein
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    OrceinStain = ObservationMethod("0216")
    """
    Stain, Perls'
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Perls_Stain = ObservationMethod("0217")
    """
    Stain, Phosphotungstic acid-hematoxylin
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    PhosphotungsticAcid_hematoxylinStain = ObservationMethod("0218")
    """
    Stain, Potassium ferrocyanide
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    PotassiumFerrocyanideStain = ObservationMethod("0219")
    """
    Stain, Prussian blue
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    PrussianBlueStain = ObservationMethod("0220")
    """
    Stain, Putchler modified Bennhold
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    PutchlerModifiedBennholdStain = ObservationMethod("0221")
    """
    Stain, Quinacrine fluorescent
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    QuinacrineFluorescentStain = ObservationMethod("0222")
    """
    Stain, Reticulin
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ReticulinStain = ObservationMethod("0223")
    """
    Stain, Rhodamine
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    RhodamineStain = ObservationMethod("0224")
    """
    Stain, Safranin
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    SafraninStain = ObservationMethod("0225")
    """
    Stain, Schmorl
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    SchmorlStain = ObservationMethod("0226")
    """
    Stain, Seiver-Munger
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Seiver_MungerStain = ObservationMethod("0227")
    """
    Stain, Silver
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    SilverStain = ObservationMethod("0228")
    """
    Stain, Specific esterase
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    SpecificEsteraseStain = ObservationMethod("0229")
    """
    Stain, Steiner silver
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    SteinerSilverStain = ObservationMethod("0230")
    """
    Stain, Sudan III
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    SudanIIIStain = ObservationMethod("0231")
    """
    Stain, Sudan IVI
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    SudanIVIStain = ObservationMethod("0232")
    """
    Stain, Sulfated alcian blue
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    SulfatedAlcianBlueStain = ObservationMethod("0233")
    """
    Stain, Supravital
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    SupravitalStain = ObservationMethod("0234")
    """
    Stain, Thioflavine-S
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Thioflavine_SStain = ObservationMethod("0235")
    """
    Stain, Three micron Giemsa
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ThreeMicronGiemsaStain = ObservationMethod("0236")
    """
    Stain, Vassar-Culling
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Vassar_CullingStain = ObservationMethod("0237")
    """
    Stain, Vital
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    VitalStain = ObservationMethod("0238")
    """
    Stain, von Kossa
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    VonKossaStain = ObservationMethod("0239")
    """
    Susceptibility, Minimum bactericidal concentration, macrodilution
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    MinimumBactericidalConcentrationTest_Macrodilution = ObservationMethod("0243")
    """
    Susceptibility, Minimum bactericidal concentration, microdilution
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    MinimumBactericidalConcentrationTest_Microdilution = ObservationMethod("0244")
    """
    Turbidometric
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Turbidometric = ObservationMethod("0247")
    """
    Turbidometric, Refractometric
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Refractometric = ObservationMethod("0248")
    """
    Chromatography, Thin Layer
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ThinLayerChromatography_TLC_ = ObservationMethod("0249")
    """
    Immunoassay, enzyme-multiplied technique (EMIT)
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    EMIT = ObservationMethod("0250")
    """
    Flow Cytometry
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    FlowCytometry_FC_ = ObservationMethod("0251")
    """
    Radial Immunodiffusion
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    RadialImmunodiffusion_RID_ = ObservationMethod("0252")
    """
    Immunoassay, Fluorescence Polarization
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    FluorescencePolarizationImmunoassay_FPIA_ = ObservationMethod("0253")
    """
    Electrophoresis, Immunofixation
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ImmunofixationElectrophoresis_IFE_ = ObservationMethod("0254")
    """
    Dialysis, Direct Equilibrium
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    EquilibriumDialysis = ObservationMethod("0255")
    """
    Acid Elution, Kleihauer-Betke Method
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Kleihauer_BetkeAcidElution = ObservationMethod("0256")
    """
    Immunofluorescence, Anti-Complement
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Anti_complementImmunofluorescence_ACIF_ = ObservationMethod("0257")
    """
    Gas Chromatography/Mass Spectroscopy
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    GC_MS = ObservationMethod("0258")
    """
    Light Scatter, Nephelometry
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Nephelometry = ObservationMethod("0259")
    """
    Immunoassay, IgE Antibody Test
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    IgEImmunoassayAntibody = ObservationMethod("0260")
    """
    Lymphocyte Microcytotoxicity Assay
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    LymphocyteMicrocytotoxicityAssay = ObservationMethod("0261")
    """
    Spectrophotometry
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Spectrophotometry = ObservationMethod("0262")
    """
    Spectrophotometry, Atomic Absorption
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    AtomicAbsorptionSpectrophotometry_AAS_ = ObservationMethod("0263")
    """
    Electrochemical, Ion Selective Electrode
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    IonSelectiveElectrode_ISE_ = ObservationMethod("0264")
    """
    Chromatography, Gas
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    GasChromatography_GC_ = ObservationMethod("0265")
    """
    Isoelectric Focusing
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    IsoelectricFocusing_IEF_ = ObservationMethod("0266")
    """
    Immunoassay, Chemiluminescent
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Immunochemiluminescence = ObservationMethod("0267")
    """
    Immunoassay, Microparticle Enzyme
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    MicroparticleEnzymeImmunoassay_MEIA_ = ObservationMethod("0268")
    """
    Inductively-Coupled Plasma/Mass Spectrometry
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ICP_MS = ObservationMethod("0269")
    """
    Immunoassay, Immunoradiometric Assay
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ImmunoradiometricAssay_IRMA_ = ObservationMethod("0270")
    """
    Coagulation, Photo Optical Clot Detection
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    PhotoOpticalClotDetection = ObservationMethod("0271")
    """
    Test methods designed to determine a microorganismaTMs susceptibility to being
    killed by an antibiotic.
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    SusceptibilityTesting = ObservationMethod("0280")
    """
    Molecular, Nucleic acid probe
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    NucleicAcidProbe = ObservationMethod("0127")
