from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class OralSiteCodesCode(GenericTypeCode):
    """
    OralSiteCodes
    From: http://terminology.hl7.org/CodeSystem/ex-tooth in valuesets.xml
        This value set includes a smattering of FDI oral site codes.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/ex-tooth
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/ex-tooth"


class OralSiteCodesCodeValues:
    """
    Oral cavity.
    From: http://terminology.hl7.org/CodeSystem/ex-tooth in valuesets.xml
    """

    OralCavity = OralSiteCodesCode("0")
    """
    Permanent teeth Maxillary right.
    From: http://terminology.hl7.org/CodeSystem/ex-tooth in valuesets.xml
    """
    _1 = OralSiteCodesCode("1")
    """
    Permanent teeth Maxillary left.
    From: http://terminology.hl7.org/CodeSystem/ex-tooth in valuesets.xml
    """
    _2 = OralSiteCodesCode("2")
    """
    Permanent teeth Mandibular right.
    From: http://terminology.hl7.org/CodeSystem/ex-tooth in valuesets.xml
    """
    _3 = OralSiteCodesCode("3")
    """
    Permanent teeth Mandibular left.
    From: http://terminology.hl7.org/CodeSystem/ex-tooth in valuesets.xml
    """
    _4 = OralSiteCodesCode("4")
    """
    Deciduous teeth Maxillary right.
    From: http://terminology.hl7.org/CodeSystem/ex-tooth in valuesets.xml
    """
    _5 = OralSiteCodesCode("5")
    """
    Deciduous teeth Maxillary left.
    From: http://terminology.hl7.org/CodeSystem/ex-tooth in valuesets.xml
    """
    _6 = OralSiteCodesCode("6")
    """
    Deciduous teeth Mandibular right.
    From: http://terminology.hl7.org/CodeSystem/ex-tooth in valuesets.xml
    """
    _7 = OralSiteCodesCode("7")
    """
    Deciduous teeth Mandibular left.
    From: http://terminology.hl7.org/CodeSystem/ex-tooth in valuesets.xml
    """
    _8 = OralSiteCodesCode("8")
    """
    Upper Right Tooth 1 from the central axis, permanent dentition.
    From: http://terminology.hl7.org/CodeSystem/ex-tooth in valuesets.xml
    """
    _11 = OralSiteCodesCode("11")
    """
    Upper Right Tooth 2 from the central axis, permanent dentition.
    From: http://terminology.hl7.org/CodeSystem/ex-tooth in valuesets.xml
    """
    _12 = OralSiteCodesCode("12")
    """
    Upper Right Tooth 3 from the central axis, permanent dentition.
    From: http://terminology.hl7.org/CodeSystem/ex-tooth in valuesets.xml
    """
    _13 = OralSiteCodesCode("13")
    """
    Upper Right Tooth 4 from the central axis, permanent dentition.
    From: http://terminology.hl7.org/CodeSystem/ex-tooth in valuesets.xml
    """
    _14 = OralSiteCodesCode("14")
    """
    Upper Right Tooth 5 from the central axis, permanent dentition.
    From: http://terminology.hl7.org/CodeSystem/ex-tooth in valuesets.xml
    """
    _15 = OralSiteCodesCode("15")
    """
    Upper Right Tooth 6 from the central axis, permanent dentition.
    From: http://terminology.hl7.org/CodeSystem/ex-tooth in valuesets.xml
    """
    _16 = OralSiteCodesCode("16")
    """
    Upper Right Tooth 7 from the central axis, permanent dentition.
    From: http://terminology.hl7.org/CodeSystem/ex-tooth in valuesets.xml
    """
    _17 = OralSiteCodesCode("17")
    """
    Upper Right Tooth 8 from the central axis, permanent dentition.
    From: http://terminology.hl7.org/CodeSystem/ex-tooth in valuesets.xml
    """
    _18 = OralSiteCodesCode("18")
    """
    Upper Left Tooth 1 from the central axis, permanent dentition.
    From: http://terminology.hl7.org/CodeSystem/ex-tooth in valuesets.xml
    """
    _21 = OralSiteCodesCode("21")
    """
    Upper Left Tooth 2 from the central axis, permanent dentition.
    From: http://terminology.hl7.org/CodeSystem/ex-tooth in valuesets.xml
    """
    _22 = OralSiteCodesCode("22")
    """
    Upper Left Tooth 3 from the central axis, permanent dentition.
    From: http://terminology.hl7.org/CodeSystem/ex-tooth in valuesets.xml
    """
    _23 = OralSiteCodesCode("23")
    """
    Upper Left Tooth 4 from the central axis, permanent dentition.
    From: http://terminology.hl7.org/CodeSystem/ex-tooth in valuesets.xml
    """
    _24 = OralSiteCodesCode("24")
    """
    Upper Left Tooth 5 from the central axis, permanent dentition.
    From: http://terminology.hl7.org/CodeSystem/ex-tooth in valuesets.xml
    """
    _25 = OralSiteCodesCode("25")
    """
    Upper Left Tooth 6 from the central axis, permanent dentition.
    From: http://terminology.hl7.org/CodeSystem/ex-tooth in valuesets.xml
    """
    _26 = OralSiteCodesCode("26")
    """
    Upper Left Tooth 7 from the central axis, permanent dentition.
    From: http://terminology.hl7.org/CodeSystem/ex-tooth in valuesets.xml
    """
    _27 = OralSiteCodesCode("27")
    """
    Upper Left Tooth 8 from the central axis, permanent dentition.
    From: http://terminology.hl7.org/CodeSystem/ex-tooth in valuesets.xml
    """
    _28 = OralSiteCodesCode("28")
    """
    Lower Left Tooth 1 from the central axis, permanent dentition.
    From: http://terminology.hl7.org/CodeSystem/ex-tooth in valuesets.xml
    """
    _31 = OralSiteCodesCode("31")
    """
    Lower Left Tooth 2 from the central axis, permanent dentition.
    From: http://terminology.hl7.org/CodeSystem/ex-tooth in valuesets.xml
    """
    _32 = OralSiteCodesCode("32")
    """
    Lower Left Tooth 3 from the central axis, permanent dentition.
    From: http://terminology.hl7.org/CodeSystem/ex-tooth in valuesets.xml
    """
    _33 = OralSiteCodesCode("33")
    """
    Lower Left Tooth 4 from the central axis, permanent dentition.
    From: http://terminology.hl7.org/CodeSystem/ex-tooth in valuesets.xml
    """
    _34 = OralSiteCodesCode("34")
    """
    Lower Left Tooth 5 from the central axis, permanent dentition.
    From: http://terminology.hl7.org/CodeSystem/ex-tooth in valuesets.xml
    """
    _35 = OralSiteCodesCode("35")
    """
    Lower Left Tooth 6 from the central axis, permanent dentition.
    From: http://terminology.hl7.org/CodeSystem/ex-tooth in valuesets.xml
    """
    _36 = OralSiteCodesCode("36")
    """
    Lower Left Tooth 7 from the central axis, permanent dentition.
    From: http://terminology.hl7.org/CodeSystem/ex-tooth in valuesets.xml
    """
    _37 = OralSiteCodesCode("37")
    """
    Lower Left Tooth 8 from the central axis, permanent dentition.
    From: http://terminology.hl7.org/CodeSystem/ex-tooth in valuesets.xml
    """
    _38 = OralSiteCodesCode("38")
    """
    Lower Right Tooth 1 from the central axis, permanent dentition.
    From: http://terminology.hl7.org/CodeSystem/ex-tooth in valuesets.xml
    """
    _41 = OralSiteCodesCode("41")
    """
    Lower Right Tooth 2 from the central axis, permanent dentition.
    From: http://terminology.hl7.org/CodeSystem/ex-tooth in valuesets.xml
    """
    _42 = OralSiteCodesCode("42")
    """
    Lower Right Tooth 3 from the central axis, permanent dentition.
    From: http://terminology.hl7.org/CodeSystem/ex-tooth in valuesets.xml
    """
    _43 = OralSiteCodesCode("43")
    """
    Lower Right Tooth 4 from the central axis, permanent dentition.
    From: http://terminology.hl7.org/CodeSystem/ex-tooth in valuesets.xml
    """
    _44 = OralSiteCodesCode("44")
    """
    Lower Right Tooth 5 from the central axis, permanent dentition.
    From: http://terminology.hl7.org/CodeSystem/ex-tooth in valuesets.xml
    """
    _45 = OralSiteCodesCode("45")
    """
    Lower Right Tooth 6 from the central axis, permanent dentition.
    From: http://terminology.hl7.org/CodeSystem/ex-tooth in valuesets.xml
    """
    _46 = OralSiteCodesCode("46")
    """
    Lower Right Tooth 7 from the central axis, permanent dentition.
    From: http://terminology.hl7.org/CodeSystem/ex-tooth in valuesets.xml
    """
    _47 = OralSiteCodesCode("47")
    """
    Lower Right Tooth 8 from the central axis, permanent dentition.
    From: http://terminology.hl7.org/CodeSystem/ex-tooth in valuesets.xml
    """
    _48 = OralSiteCodesCode("48")
