from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class ParticipationFunction(GenericTypeCode):
    """
    v3.ParticipationFunction
    From: http://terminology.hl7.org/ValueSet/v3-ParticipationFunction in v3-codesystems.xml
         This code is used to specify the exact function an actor had in a service in
    all necessary detail. This domain may include local extensions (CWE).
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/v3-ParticipationFunction
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/v3-ParticipationFunction"


class ParticipationFunctionValues:
    """
    This code is used to specify the exact function an actor is authorized to have
    in a service in all necessary detail.
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationFunction in v3-codesystems.xml
    """

    AuthorizedParticipationFunction = ParticipationFunction(
        "_AuthorizedParticipationFunction"
    )
    """
    Definition: Set of codes indicating the manner in which sponsors,
    underwriters, and payers participate in a policy or program.
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationFunction in v3-codesystems.xml
    """
    CoverageParticipationFunction = ParticipationFunction(
        "_CoverageParticipationFunction"
    )
    """
    A physician who admitted a patient to a hospital or other care unit that is
    the context of this service.
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationFunction in v3-codesystems.xml
    """
    AdmittingPhysician = ParticipationFunction("ADMPHYS")
    """
    In a typical anesthesia setting an anesthesiologist or anesthesia resident in
    charge of the anesthesia and life support, but only a witness to the surgical
    procedure itself.  To clarify responsibilities anesthesia should always be
    represented as a separate service related to the surgery.
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationFunction in v3-codesystems.xml
    """
    Anesthesist = ParticipationFunction("ANEST")
    """
    In a typical anesthesia setting the nurse principally assisting the
    anesthesiologist during the critical periods.
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationFunction in v3-codesystems.xml
    """
    AnesthesiaNurse = ParticipationFunction("ANRS")
    """
    A device that operates independently of an author on custodian's algorithms
    for data extraction of existing information for purpose of generating a new
    artifact.
                               UsageConstraint: ASSEMBLER ParticipationFunction
    should be used with DEV (device) ParticipationType.
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationFunction in v3-codesystems.xml
    """
    AssemblySoftware = ParticipationFunction("ASSEMBLER")
    """
    A physician who is primarily responsible for a patient during the
    hospitalization, which is the context of the service.
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationFunction in v3-codesystems.xml
    """
    AttendingPhysician = ParticipationFunction("ATTPHYS")
    """
    A device used by an author to record new information, which may also be used
    by the author to select existing information for aggregation with newly
    recorded information for the purpose of generating a new artifact.
                               UsageConstraint: COMPOSER ParticipationFunction
    should be used with DEV (device) ParticipationType.
    
    
                               Usage Note: This code will enable implementers to
    more specifically represent the manner in which a Device participated in and
    facilitated the generation of a CDA Clinical Document or a CDA Entry by the
    responsible Author, which is comprised of the Author's newly entered content,
    and may include the pre-existing content selected by the Author, for the
    purpose of establishing the provenance and accountability for these acts.
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationFunction in v3-codesystems.xml
    """
    ComposerSoftware = ParticipationFunction("COMPOSER")
    """
    A physician who discharged a patient from a hospital or other care unit that
    is the context of this service.
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationFunction in v3-codesystems.xml
    """
    DischargingPhysician = ParticipationFunction("DISPHYS")
    """
    In a typical surgery setting the assistant facing the primary surgeon.  The
    first assistant performs parts of the operation and assists in others (e.g.,
    incision, approach, electrocoutering, ligatures, sutures).
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationFunction in v3-codesystems.xml
    """
    FirstAssistantSurgeon = ParticipationFunction("FASST")
    """
    A person (usually female) helping a woman deliver a baby. Responsibilities
    vary locally, ranging from a mere optional assistant to a full required
    participant, responsible for (normal) births and pre- and post-natal care for
    both mother and baby.
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationFunction in v3-codesystems.xml
    """
    Midwife = ParticipationFunction("MDWF")
    """
    In a typical surgery setting the non-sterile nurse handles material supply
    from the stock, forwards specimen to pathology, and helps with other non-
    sterile tasks (e.g., phone calls, etc.).
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationFunction in v3-codesystems.xml
    """
    NurseAssistant = ParticipationFunction("NASST")
    """
    The healthcare provider that holds primary responsibility for the overall care
    of a patient.
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationFunction in v3-codesystems.xml
    """
    PrimaryCarePhysician = ParticipationFunction("PCP")
    """
    In a typical surgery setting the primary performing surgeon.
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationFunction in v3-codesystems.xml
    """
    PrimarySurgeon = ParticipationFunction("PRISURG")
    """
    A verifier who is accountable for reviewing and asserting that the
    verification of an Act complies with jurisdictional or organizational policy.
    
    
                               UsageConstraint: UsageConstraint:  Specifies the
    exact function that an actor is authorized to have as a verifier of an Act.
    Connotes that a specialized verifier asserts compliance for veracity of the
    review per jurisdictional or organizational policy.  E.g., The Provider who
    takes responsibility for authenticity of a record submitted to a payer.
    
                            REVIEW ParticipationFunction should be used with VFR
    (verifier)
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationFunction in v3-codesystems.xml
    """
    Reviewer = ParticipationFunction("REVIEWER")
    """
    A physician who made rounds on a patient in a hospital or other care center.
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationFunction in v3-codesystems.xml
    """
    RoundingPhysician = ParticipationFunction("RNDPHYS")
    """
    In a typical surgery setting the assistant who primarily holds the hooks.
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationFunction in v3-codesystems.xml
    """
    SecondAssistantSurgeon = ParticipationFunction("SASST")
    """
    In a typical surgery setting the nurse in charge of the instrumentation.
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationFunction in v3-codesystems.xml
    """
    ScrubNurse = ParticipationFunction("SNRS")
    """
    In a typical surgery setting there is rarely a third assistant (e.g., in some
    Hip operations the third assistant postures the affected leg).
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationFunction in v3-codesystems.xml
    """
    ThirdAssistant = ParticipationFunction("TASST")
