from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class ParticipationMode(GenericTypeCode):
    """
    v3.ParticipationMode
    From: http://terminology.hl7.org/ValueSet/v3-ParticipationMode in v3-codesystems.xml
         A set of codes specifying the modality by which the Entity playing the Role
    is participating in the Act.  Examples:
    Physically present, over the telephone, written communication.  Rationale:
    Particularly for author (originator) participants this is used to specify
    whether the information represented by the act was initially provided
    verbally, (hand-)written, or electronically.  Open Issue:
    There needs to be a reexamination of the hierarchies as there seems to be some
    muddling between ELECTRONIC and other concepts that involve electronic
    communication that are in other hierarchies.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/v3-ParticipationMode
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/v3-ParticipationMode"


class ParticipationModeValues:
    """
    Participation by non-human-languaged based electronic signal
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationMode in v3-codesystems.xml
    """

    ElectronicData = ParticipationMode("ELECTRONIC")
    """
    Participation by direct action where subject and actor are in the same
    location. (The participation involves more than communication.)
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationMode in v3-codesystems.xml
    """
    PhysicalPresence = ParticipationMode("PHYSICAL")
    """
    Participation by direct action where subject and actor are in separate
    locations, and the actions of the actor are transmitted by electronic or
    mechanical means. (The participation involves more than communication.)
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationMode in v3-codesystems.xml
    """
    RemotePresence = ParticipationMode("REMOTE")
    """
    Participation by voice communication
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationMode in v3-codesystems.xml
    """
    Verbal = ParticipationMode("VERBAL")
    """
    Participation by human language recorded on a physical material
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationMode in v3-codesystems.xml
    """
    Written = ParticipationMode("WRITTEN")
