from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class ParticipationRoleTypeCode(GenericTypeCode):
    """
    ParticipationRoleType
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
        This FHIR value set is comprised of Actor participation Type codes, which can
    be used to value FHIR agents, actors, and other role         elements. The
    FHIR Actor participation type value set is based on    DICOM Audit Message,
    C402;   ASTM Standard, E1762-95 [2013]; selected codes and          derived
    actor roles from HL7 RoleClass OID 2.16.840.1.113883.5.110;    HL7 Role Code
    2.16.840.1.113883.5.111, including AgentRoleType;          HL7
    ParticipationType OID: 2.16.840.1.113883.5.90; and    HL7
    ParticipationFunction codes OID: 2.16.840.1.113883.5.88.           This value
    set includes, by reference, role codes from external code systems: NUCC Health
    Care Provider Taxonomy OID: 2.16.840.1.113883.6.101;          North American
    Industry Classification System [NAICS]OID: 2.16.840.1.113883.6.85;
    IndustryClassificationSystem 2.16.840.1.113883.1.11.16039;          and US
    Census Occupation Code OID: 2.16.840.1.113883.6.243 for relevant recipient or
    custodian codes not included in this value set.            If no source is
    indicated in the definition comments, then these are example FHIR codes.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/v3-RoleClass
    """
    codeset_v3_RoleClass: FhirUri = "http://terminology.hl7.org/CodeSystem/v3-RoleClass"
    """
    http://terminology.hl7.org/CodeSystem/v3-ParticipationFunction
    """
    codeset_v3_ParticipationFunction: FhirUri = (
        "http://terminology.hl7.org/CodeSystem/v3-ParticipationFunction"
    )
    """
    http://terminology.hl7.org/CodeSystem/extra-security-role-type
    """
    codeset_extra_security_role_type: FhirUri = (
        "http://terminology.hl7.org/CodeSystem/extra-security-role-type"
    )
    """
    http://terminology.hl7.org/CodeSystem/v3-ParticipationType
    """
    codeset_v3_ParticipationType: FhirUri = (
        "http://terminology.hl7.org/CodeSystem/v3-ParticipationType"
    )
    """
    http://terminology.hl7.org/CodeSystem/contractsignertypecodes
    """
    codeset_contractsignertypecodes: FhirUri = (
        "http://terminology.hl7.org/CodeSystem/contractsignertypecodes"
    )
    """
    http://terminology.hl7.org/CodeSystem/v3-RoleCode
    """
    codeset_v3_RoleCode: FhirUri = "http://terminology.hl7.org/CodeSystem/v3-RoleCode"
    """
    http://dicom.nema.org/resources/ontology/DCM
    """
    codeset_DCM: FhirUri = "http://dicom.nema.org/resources/ontology/DCM"


class ParticipationRoleTypeCodeValues:
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """

    AMENDER = ParticipationRoleTypeCode("AMENDER")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    COAUTH = ParticipationRoleTypeCode("COAUTH")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    CONT = ParticipationRoleTypeCode("CONT")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    EVTWIT = ParticipationRoleTypeCode("EVTWIT")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    PRIMAUTH = ParticipationRoleTypeCode("PRIMAUTH")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    REVIEWER = ParticipationRoleTypeCode("REVIEWER")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    SOURCE = ParticipationRoleTypeCode("SOURCE")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    TRANS = ParticipationRoleTypeCode("TRANS")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    VALID = ParticipationRoleTypeCode("VALID")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    VERF = ParticipationRoleTypeCode("VERF")
    """
    Corresponds to the Role class
    From: http://terminology.hl7.org/CodeSystem/v3-RoleClass in v3-codesystems.xml
    """
    Role = ParticipationRoleTypeCode("ROL")
    """
    The player of the role is a child of the scoping entity, in a generic sense.
    From: http://terminology.hl7.org/CodeSystem/v3-RoleClass in v3-codesystems.xml
    """
    Child = ParticipationRoleTypeCode("CHILD")
    """
    A role played by an entity that receives credentials from the scoping entity.
    From: http://terminology.hl7.org/CodeSystem/v3-RoleClass in v3-codesystems.xml
    """
    CredentialedEntity = ParticipationRoleTypeCode("CRED")
    """
    nurse practitioner
    From: http://terminology.hl7.org/CodeSystem/v3-RoleClass in v3-codesystems.xml
    """
    NursePractitioner = ParticipationRoleTypeCode("NURPRAC")
    """
    nurse
    From: http://terminology.hl7.org/CodeSystem/v3-RoleClass in v3-codesystems.xml
    """
    Nurse = ParticipationRoleTypeCode("NURS")
    """
    physician assistant
    From: http://terminology.hl7.org/CodeSystem/v3-RoleClass in v3-codesystems.xml
    """
    PhysicianAssistant = ParticipationRoleTypeCode("PA")
    """
    physician
    From: http://terminology.hl7.org/CodeSystem/v3-RoleClass in v3-codesystems.xml
    """
    Physician = ParticipationRoleTypeCode("PHYS")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    AFFL = ParticipationRoleTypeCode("AFFL")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    AGNT = ParticipationRoleTypeCode("AGNT")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    ASSIGNED = ParticipationRoleTypeCode("ASSIGNED")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    CLAIM = ParticipationRoleTypeCode("CLAIM")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    COVPTY = ParticipationRoleTypeCode("COVPTY")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    DEPEN = ParticipationRoleTypeCode("DEPEN")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    ECON = ParticipationRoleTypeCode("ECON")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    EMP = ParticipationRoleTypeCode("EMP")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    GUARD = ParticipationRoleTypeCode("GUARD")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    INVSBJ = ParticipationRoleTypeCode("INVSBJ")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    NAMED = ParticipationRoleTypeCode("NAMED")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    NOK = ParticipationRoleTypeCode("NOK")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    PAT = ParticipationRoleTypeCode("PAT")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    PROV = ParticipationRoleTypeCode("PROV")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    NOT = ParticipationRoleTypeCode("NOT")
    """
    Concepts characterizing the type of association formed by player and scoper
    when there is a recognized Affiliate role by which the two parties are
    related.
    
    
                               Examples: Business Partner, Business Associate,
    Colleague
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    AffiliationRoleType = ParticipationRoleTypeCode("_AffiliationRoleType")
    """
    AssignedRoleType
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    AssignedRoleType = ParticipationRoleTypeCode("_AssignedRoleType")
    """
    Defines types of certifications for all entities
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    CertifiedEntityType = ParticipationRoleTypeCode("_CertifiedEntityType")
    """
    A role type used to qualify a person's legal status within a country or
    nation.
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    CitizenRoleType = ParticipationRoleTypeCode("_CitizenRoleType")
    """
    Types of contact for Role code "CON"
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    ContactRoleType = ParticipationRoleTypeCode("_ContactRoleType")
    """
    Definition: A code representing the type of identifier that has been assigned
    to the identified entity (IDENT).
    
    
                               Examples: Example values include Social Insurance
    Number, Product Catalog ID, Product Model Number.
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    IdentifiedEntityType = ParticipationRoleTypeCode("_IdentifiedEntityType")
    """
    Code indicating the primary use for which a living subject is bred or grown
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    LivingSubjectProductionClass = ParticipationRoleTypeCode(
        "_LivingSubjectProductionClass"
    )
    """
    Identifies the specific hierarchical relationship between the playing and
    scoping medications.
    
    
                               Examples: Generic, Generic Formulation, Therapeutic
    Class, etc.
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    MedicationGeneralizationRoleType = ParticipationRoleTypeCode(
        "_MedicationGeneralizationRoleType"
    )
    """
    Types of membership for Role code "MBR"
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    MemberRoleType = ParticipationRoleTypeCode("_MemberRoleType")
    """
    PersonalRelationshipRoleType
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    PersonalRelationshipRoleType = ParticipationRoleTypeCode(
        "_PersonalRelationshipRoleType"
    )
    """
    Description: A role recognized through the eligibility of an identified party
    for benefits covered under an insurance policy or a program based on meeting
    eligibility criteria.
    
                            Eligibility as a covered party may be conditioned on
    the party meeting criteria to qualify for coverage under a policy or program,
    which may be mandated by law.  These criteria may be:
    
    
    
                                  The sole basis for coverage, e.g., being
    differently abled may qualify a person for disability coverage
    
    
    
                                  May more fully qualify a covered party role e.g,
    being differently abled may qualify an adult child as a dependent
    
    
    
                                  May impact the level of coverage for a covered
    party under a policy or program, e.g., being differently abled may qualify a
    program eligible for additional benefits.
    
    
    
    
                               Discussion:  The Abstract Value Set
    "CoverageRoleType", which was developed for use in the Canadian realm "pre-
    coordinate" coverage roles with other roles that a covered party must play in
    order to be eligible for coverage, e.g., "handicapped dependent".   These
    role.codes may only be used with COVPTY to avoid overlapping concepts that
    would result from using them to specify the specializations of COVPTY, e.g.,
    the role.class DEPEN should not be used with the role.code family dependent
    because that relationship has overlapping concepts due to the role.code
    precoodination and is conveyed in FICO with the personal relationship role
    that has a PART role link to the covered party role.  For the same reasons,
    the role.class DEPEN should not be used with the role.code HANDIC (handicapped
    dependent); the role.code DIFFABLE (differently abled) should be used instead.
    
                            In summary, the coded concepts in the Abstract Value
    Set "CoveredPartyRoleType" can be "post-coordinated" with the
    "RoleClassCoveredParty" Abstract Value Set.  Decoupling these concepts is
    intended to support an expansive range of covered party concepts and their
    semantic comparability.
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    PolicyOrProgramCoverageRoleType = ParticipationRoleTypeCode(
        "_PolicyOrProgramCoverageRoleType"
    )
    """
    Specifies the administrative functionality within a formal experimental design
    for which the ResearchSubject role was established.  Examples: screening -
    role is used for pre-enrollment evaluation portion of the design; enrolled -
    role is used for subjects admitted to the active treatment portion of the
    design.
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    ResearchSubjectRoleBasis = ParticipationRoleTypeCode("_ResearchSubjectRoleBasis")
    """
    A role of a place that further classifies the setting (e.g., accident site,
    road side, work site, community location) in which services are delivered.
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    ServiceDeliveryLocationRoleType = ParticipationRoleTypeCode(
        "_ServiceDeliveryLocationRoleType"
    )
    """
    SpecimenRoleType
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    SpecimenRoleType = ParticipationRoleTypeCode("_SpecimenRoleType")
    """
    A party that makes a claim for coverage under a policy.
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    Claimant = ParticipationRoleTypeCode("CLAIM")
    """
    Community Laboratory
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    CommunityLaboratory = ParticipationRoleTypeCode("communityLaboratory")
    """
    An individual or organization that makes or gives a promise, assurance, pledge
    to pay or has paid the healthcare service provider.
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    Guarantor = ParticipationRoleTypeCode("GT")
    """
    Home Health
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    HomeHealth = ParticipationRoleTypeCode("homeHealth")
    """
    Laboratory
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    Laboratory = ParticipationRoleTypeCode("laboratory")
    """
    Pathologist
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    Pathologist = ParticipationRoleTypeCode("pathologist")
    """
    Policy holder for the insurance policy.
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    PolicyHolder = ParticipationRoleTypeCode("PH")
    """
    Phlebotomist
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    Phlebotomist = ParticipationRoleTypeCode("phlebotomist")
    """
    A party that meets the eligibility criteria for coverage under a program.
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    ProgramEligible = ParticipationRoleTypeCode("PROG")
    """
    The recipient for the service(s) and/or product(s) when they are not the
    covered party.
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    Patient = ParticipationRoleTypeCode("PT")
    """
    Self
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    Self = ParticipationRoleTypeCode("subject")
    """
    Third Party
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    ThirdParty = ParticipationRoleTypeCode("thirdParty")
    """
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    DEP = ParticipationRoleTypeCode("DEP")
    """
    A party covered under a policy based on association with a subscriber.
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    Dependent = ParticipationRoleTypeCode("DEPEN")
    """
    A member of the covered party's family. This could be the spouse, a parent, a
    grand parent, a sibling, etc.
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    FamilyMember = ParticipationRoleTypeCode("FM")
    """
    A party covered under a policy as the policyholder.
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    Individual = ParticipationRoleTypeCode("INDIV")
    """
    A party to an insurance policy to whom the insurer agrees to indemnify for
    losses, provides benefits for, or renders services.
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    NamedInsured = ParticipationRoleTypeCode("NAMED")
    """
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    PSYCHCF = ParticipationRoleTypeCode("PSYCHCF")
    """
    A party covered under a policy based on association with a sponsor who is the
    policy holder, and whose association may provide for the eligibility of
    dependents for coverage
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    Subscriber = ParticipationRoleTypeCode("SUBSCR")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    CLASSIFIER = ParticipationRoleTypeCode("CLASSIFIER")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    CONSENTER = ParticipationRoleTypeCode("CONSENTER")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    CONSWIT = ParticipationRoleTypeCode("CONSWIT")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    COPART = ParticipationRoleTypeCode("COPART")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    DECLASSIFIER = ParticipationRoleTypeCode("DECLASSIFIER")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    DELEGATEE = ParticipationRoleTypeCode("DELEGATEE")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    DELEGATOR = ParticipationRoleTypeCode("DELEGATOR")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    DOWNGRDER = ParticipationRoleTypeCode("DOWNGRDER")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    DPOWATT = ParticipationRoleTypeCode("DPOWATT")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    EXCEST = ParticipationRoleTypeCode("EXCEST")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    GRANTEE = ParticipationRoleTypeCode("GRANTEE")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    GRANTOR = ParticipationRoleTypeCode("GRANTOR")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    GT = ParticipationRoleTypeCode("GT")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    GUADLTM = ParticipationRoleTypeCode("GUADLTM")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    HPOWATT = ParticipationRoleTypeCode("HPOWATT")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    INTPRTER = ParticipationRoleTypeCode("INTPRTER")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    POWATT = ParticipationRoleTypeCode("POWATT")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    RESPRSN = ParticipationRoleTypeCode("RESPRSN")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    SPOWATT = ParticipationRoleTypeCode("SPOWATT")
    """
    Concepts characterizing the type of association formed by player and scoper
    when there is a recognized Affiliate role by which the two parties are
    related.
    
    
                               Examples: Business Partner, Business Associate,
    Colleague
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    AffiliationRoleType = ParticipationRoleTypeCode("_AffiliationRoleType")
    """
    AssignedRoleType
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    AssignedRoleType = ParticipationRoleTypeCode("_AssignedRoleType")
    """
    Defines types of certifications for all entities
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    CertifiedEntityType = ParticipationRoleTypeCode("_CertifiedEntityType")
    """
    A role type used to qualify a person's legal status within a country or
    nation.
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    CitizenRoleType = ParticipationRoleTypeCode("_CitizenRoleType")
    """
    Types of contact for Role code "CON"
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    ContactRoleType = ParticipationRoleTypeCode("_ContactRoleType")
    """
    Definition: A code representing the type of identifier that has been assigned
    to the identified entity (IDENT).
    
    
                               Examples: Example values include Social Insurance
    Number, Product Catalog ID, Product Model Number.
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    IdentifiedEntityType = ParticipationRoleTypeCode("_IdentifiedEntityType")
    """
    Code indicating the primary use for which a living subject is bred or grown
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    LivingSubjectProductionClass = ParticipationRoleTypeCode(
        "_LivingSubjectProductionClass"
    )
    """
    Identifies the specific hierarchical relationship between the playing and
    scoping medications.
    
    
                               Examples: Generic, Generic Formulation, Therapeutic
    Class, etc.
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    MedicationGeneralizationRoleType = ParticipationRoleTypeCode(
        "_MedicationGeneralizationRoleType"
    )
    """
    Types of membership for Role code "MBR"
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    MemberRoleType = ParticipationRoleTypeCode("_MemberRoleType")
    """
    PersonalRelationshipRoleType
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    PersonalRelationshipRoleType = ParticipationRoleTypeCode(
        "_PersonalRelationshipRoleType"
    )
    """
    Description: A role recognized through the eligibility of an identified party
    for benefits covered under an insurance policy or a program based on meeting
    eligibility criteria.
    
                            Eligibility as a covered party may be conditioned on
    the party meeting criteria to qualify for coverage under a policy or program,
    which may be mandated by law.  These criteria may be:
    
    
    
                                  The sole basis for coverage, e.g., being
    differently abled may qualify a person for disability coverage
    
    
    
                                  May more fully qualify a covered party role e.g,
    being differently abled may qualify an adult child as a dependent
    
    
    
                                  May impact the level of coverage for a covered
    party under a policy or program, e.g., being differently abled may qualify a
    program eligible for additional benefits.
    
    
    
    
                               Discussion:  The Abstract Value Set
    "CoverageRoleType", which was developed for use in the Canadian realm "pre-
    coordinate" coverage roles with other roles that a covered party must play in
    order to be eligible for coverage, e.g., "handicapped dependent".   These
    role.codes may only be used with COVPTY to avoid overlapping concepts that
    would result from using them to specify the specializations of COVPTY, e.g.,
    the role.class DEPEN should not be used with the role.code family dependent
    because that relationship has overlapping concepts due to the role.code
    precoodination and is conveyed in FICO with the personal relationship role
    that has a PART role link to the covered party role.  For the same reasons,
    the role.class DEPEN should not be used with the role.code HANDIC (handicapped
    dependent); the role.code DIFFABLE (differently abled) should be used instead.
    
                            In summary, the coded concepts in the Abstract Value
    Set "CoveredPartyRoleType" can be "post-coordinated" with the
    "RoleClassCoveredParty" Abstract Value Set.  Decoupling these concepts is
    intended to support an expansive range of covered party concepts and their
    semantic comparability.
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    PolicyOrProgramCoverageRoleType = ParticipationRoleTypeCode(
        "_PolicyOrProgramCoverageRoleType"
    )
    """
    Specifies the administrative functionality within a formal experimental design
    for which the ResearchSubject role was established.  Examples: screening -
    role is used for pre-enrollment evaluation portion of the design; enrolled -
    role is used for subjects admitted to the active treatment portion of the
    design.
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    ResearchSubjectRoleBasis = ParticipationRoleTypeCode("_ResearchSubjectRoleBasis")
    """
    A role of a place that further classifies the setting (e.g., accident site,
    road side, work site, community location) in which services are delivered.
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    ServiceDeliveryLocationRoleType = ParticipationRoleTypeCode(
        "_ServiceDeliveryLocationRoleType"
    )
    """
    SpecimenRoleType
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    SpecimenRoleType = ParticipationRoleTypeCode("_SpecimenRoleType")
    """
    A party that makes a claim for coverage under a policy.
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    Claimant = ParticipationRoleTypeCode("CLAIM")
    """
    Community Laboratory
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    CommunityLaboratory = ParticipationRoleTypeCode("communityLaboratory")
    """
    An individual or organization that makes or gives a promise, assurance, pledge
    to pay or has paid the healthcare service provider.
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    Guarantor = ParticipationRoleTypeCode("GT")
    """
    Home Health
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    HomeHealth = ParticipationRoleTypeCode("homeHealth")
    """
    Laboratory
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    Laboratory = ParticipationRoleTypeCode("laboratory")
    """
    Pathologist
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    Pathologist = ParticipationRoleTypeCode("pathologist")
    """
    Policy holder for the insurance policy.
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    PolicyHolder = ParticipationRoleTypeCode("PH")
    """
    Phlebotomist
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    Phlebotomist = ParticipationRoleTypeCode("phlebotomist")
    """
    A party that meets the eligibility criteria for coverage under a program.
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    ProgramEligible = ParticipationRoleTypeCode("PROG")
    """
    The recipient for the service(s) and/or product(s) when they are not the
    covered party.
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    Patient = ParticipationRoleTypeCode("PT")
    """
    Self
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    Self = ParticipationRoleTypeCode("subject")
    """
    Third Party
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    ThirdParty = ParticipationRoleTypeCode("thirdParty")
    """
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    DEP = ParticipationRoleTypeCode("DEP")
    """
    A party covered under a policy based on association with a subscriber.
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    Dependent = ParticipationRoleTypeCode("DEPEN")
    """
    A member of the covered party's family. This could be the spouse, a parent, a
    grand parent, a sibling, etc.
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    FamilyMember = ParticipationRoleTypeCode("FM")
    """
    A party covered under a policy as the policyholder.
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    Individual = ParticipationRoleTypeCode("INDIV")
    """
    A party to an insurance policy to whom the insurer agrees to indemnify for
    losses, provides benefits for, or renders services.
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    NamedInsured = ParticipationRoleTypeCode("NAMED")
    """
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    PSYCHCF = ParticipationRoleTypeCode("PSYCHCF")
    """
    A party covered under a policy based on association with a sponsor who is the
    policy holder, and whose association may provide for the eligibility of
    dependents for coverage
    From: http://terminology.hl7.org/CodeSystem/v3-RoleCode in v3-codesystems.xml
    """
    Subscriber = ParticipationRoleTypeCode("SUBSCR")
    """
    This code is used to specify the exact function an actor is authorized to have
    in a service in all necessary detail.
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationFunction in v3-codesystems.xml
    """
    AuthorizedParticipationFunction = ParticipationRoleTypeCode(
        "_AuthorizedParticipationFunction"
    )
    """
    Definition: Set of codes indicating the manner in which sponsors,
    underwriters, and payers participate in a policy or program.
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationFunction in v3-codesystems.xml
    """
    CoverageParticipationFunction = ParticipationRoleTypeCode(
        "_CoverageParticipationFunction"
    )
    """
    A physician who admitted a patient to a hospital or other care unit that is
    the context of this service.
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationFunction in v3-codesystems.xml
    """
    AdmittingPhysician = ParticipationRoleTypeCode("ADMPHYS")
    """
    In a typical anesthesia setting an anesthesiologist or anesthesia resident in
    charge of the anesthesia and life support, but only a witness to the surgical
    procedure itself.  To clarify responsibilities anesthesia should always be
    represented as a separate service related to the surgery.
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationFunction in v3-codesystems.xml
    """
    Anesthesist = ParticipationRoleTypeCode("ANEST")
    """
    In a typical anesthesia setting the nurse principally assisting the
    anesthesiologist during the critical periods.
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationFunction in v3-codesystems.xml
    """
    AnesthesiaNurse = ParticipationRoleTypeCode("ANRS")
    """
    A device that operates independently of an author on custodian's algorithms
    for data extraction of existing information for purpose of generating a new
    artifact.
                               UsageConstraint: ASSEMBLER ParticipationFunction
    should be used with DEV (device) ParticipationType.
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationFunction in v3-codesystems.xml
    """
    AssemblySoftware = ParticipationRoleTypeCode("ASSEMBLER")
    """
    A physician who is primarily responsible for a patient during the
    hospitalization, which is the context of the service.
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationFunction in v3-codesystems.xml
    """
    AttendingPhysician = ParticipationRoleTypeCode("ATTPHYS")
    """
    A device used by an author to record new information, which may also be used
    by the author to select existing information for aggregation with newly
    recorded information for the purpose of generating a new artifact.
                               UsageConstraint: COMPOSER ParticipationFunction
    should be used with DEV (device) ParticipationType.
    
    
                               Usage Note: This code will enable implementers to
    more specifically represent the manner in which a Device participated in and
    facilitated the generation of a CDA Clinical Document or a CDA Entry by the
    responsible Author, which is comprised of the Author's newly entered content,
    and may include the pre-existing content selected by the Author, for the
    purpose of establishing the provenance and accountability for these acts.
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationFunction in v3-codesystems.xml
    """
    ComposerSoftware = ParticipationRoleTypeCode("COMPOSER")
    """
    A physician who discharged a patient from a hospital or other care unit that
    is the context of this service.
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationFunction in v3-codesystems.xml
    """
    DischargingPhysician = ParticipationRoleTypeCode("DISPHYS")
    """
    In a typical surgery setting the assistant facing the primary surgeon.  The
    first assistant performs parts of the operation and assists in others (e.g.,
    incision, approach, electrocoutering, ligatures, sutures).
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationFunction in v3-codesystems.xml
    """
    FirstAssistantSurgeon = ParticipationRoleTypeCode("FASST")
    """
    A person (usually female) helping a woman deliver a baby. Responsibilities
    vary locally, ranging from a mere optional assistant to a full required
    participant, responsible for (normal) births and pre- and post-natal care for
    both mother and baby.
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationFunction in v3-codesystems.xml
    """
    Midwife = ParticipationRoleTypeCode("MDWF")
    """
    In a typical surgery setting the non-sterile nurse handles material supply
    from the stock, forwards specimen to pathology, and helps with other non-
    sterile tasks (e.g., phone calls, etc.).
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationFunction in v3-codesystems.xml
    """
    NurseAssistant = ParticipationRoleTypeCode("NASST")
    """
    The healthcare provider that holds primary responsibility for the overall care
    of a patient.
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationFunction in v3-codesystems.xml
    """
    PrimaryCarePhysician = ParticipationRoleTypeCode("PCP")
    """
    In a typical surgery setting the primary performing surgeon.
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationFunction in v3-codesystems.xml
    """
    PrimarySurgeon = ParticipationRoleTypeCode("PRISURG")
    """
    A verifier who is accountable for reviewing and asserting that the
    verification of an Act complies with jurisdictional or organizational policy.
    
    
                               UsageConstraint: UsageConstraint:  Specifies the
    exact function that an actor is authorized to have as a verifier of an Act.
    Connotes that a specialized verifier asserts compliance for veracity of the
    review per jurisdictional or organizational policy.  E.g., The Provider who
    takes responsibility for authenticity of a record submitted to a payer.
    
                            REVIEW ParticipationFunction should be used with VFR
    (verifier)
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationFunction in v3-codesystems.xml
    """
    Reviewer = ParticipationRoleTypeCode("REVIEWER")
    """
    A physician who made rounds on a patient in a hospital or other care center.
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationFunction in v3-codesystems.xml
    """
    RoundingPhysician = ParticipationRoleTypeCode("RNDPHYS")
    """
    In a typical surgery setting the assistant who primarily holds the hooks.
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationFunction in v3-codesystems.xml
    """
    SecondAssistantSurgeon = ParticipationRoleTypeCode("SASST")
    """
    In a typical surgery setting the nurse in charge of the instrumentation.
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationFunction in v3-codesystems.xml
    """
    ScrubNurse = ParticipationRoleTypeCode("SNRS")
    """
    In a typical surgery setting there is rarely a third assistant (e.g., in some
    Hip operations the third assistant postures the affected leg).
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationFunction in v3-codesystems.xml
    """
    ThirdAssistant = ParticipationRoleTypeCode("TASST")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    AUCG = ParticipationRoleTypeCode("AUCG")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    AULR = ParticipationRoleTypeCode("AULR")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    AUTM = ParticipationRoleTypeCode("AUTM")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    AUWA = ParticipationRoleTypeCode("AUWA")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    PROMSK = ParticipationRoleTypeCode("PROMSK")
    """
    Indicates that the target of the participation is involved in some manner in
    the act, but does not qualify how.
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationType in v3-codesystems.xml
    """
    Participation = ParticipationRoleTypeCode("PART")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    AUT = ParticipationRoleTypeCode("AUT")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    CST = ParticipationRoleTypeCode("CST")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    INF = ParticipationRoleTypeCode("INF")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    IRCP = ParticipationRoleTypeCode("IRCP")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    LA = ParticipationRoleTypeCode("LA")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    IRCP = ParticipationRoleTypeCode("IRCP")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    TRC = ParticipationRoleTypeCode("TRC")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    WIT = ParticipationRoleTypeCode("WIT")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    _110150 = ParticipationRoleTypeCode("110150")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    _110151 = ParticipationRoleTypeCode("110151")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    _110152 = ParticipationRoleTypeCode("110152")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    _110153 = ParticipationRoleTypeCode("110153")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    _110154 = ParticipationRoleTypeCode("110154")
    """
    From: http://hl7.org/fhir/ValueSet/participation-role-type in valuesets.xml
    """
    _110155 = ParticipationRoleTypeCode("110155")
