from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class ParticipationSignature(GenericTypeCode):
    """
    v3.ParticipationSignature
    From: http://terminology.hl7.org/ValueSet/v3-ParticipationSignature in v3-codesystems.xml
         A set of codes specifying whether and how the participant has attested his
    participation through a signature and or whether such a signature is needed.
    Examples:
    A surgical Procedure act object (representing a procedure report) requires a
    signature of the performing and responsible surgeon, and possibly other
    participants. (See also: Participation.signatureText.)
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/v3-ParticipationSignature
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/v3-ParticipationSignature"


class ParticipationSignatureValues:
    """
    The particpant intends to provide a signature.
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationSignature in v3-codesystems.xml
    """

    Intended = ParticipationSignature("I")
    """
    Signature has been affixed, either written on file, or electronic (incl.
    digital) signature in Participation.signatureText.
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationSignature in v3-codesystems.xml
    """
    Signed = ParticipationSignature("S")
    """
    A signature for the service is required of this actor.
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationSignature in v3-codesystems.xml
    """
    Required = ParticipationSignature("X")
