from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class PaymentTerms(GenericTypeCode):
    """
    v3.PaymentTerms
    From: http://terminology.hl7.org/ValueSet/v3-PaymentTerms in v3-codesystems.xml
         Describes payment terms for a financial transaction, used in an invoice. This
    is typically expressed as a responsibility of the acceptor or payor of an
    invoice.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/v3-PaymentTerms
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/v3-PaymentTerms"


class PaymentTermsValues:
    """
    Payment in full for products and/or services is required as soon as the
    service is performed or goods delivered.
    From: http://terminology.hl7.org/CodeSystem/v3-PaymentTerms in v3-codesystems.xml
    """

    CashOnDelivery = PaymentTerms("COD")
    """
    Payment in full for products and/or services is required 30 days from the time
    the service is performed or goods delivered.
    From: http://terminology.hl7.org/CodeSystem/v3-PaymentTerms in v3-codesystems.xml
    """
    Net30Days = PaymentTerms("N30")
    """
    Payment in full for products and/or services is required 60 days from the time
    the service is performed or goods delivered.
    From: http://terminology.hl7.org/CodeSystem/v3-PaymentTerms in v3-codesystems.xml
    """
    Net60Days = PaymentTerms("N60")
    """
    Payment in full for products and/or services is required 90 days from the time
    the service is performed or goods delivered.
    From: http://terminology.hl7.org/CodeSystem/v3-PaymentTerms in v3-codesystems.xml
    """
    Net90Days = PaymentTerms("N90")
