from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class PostalAddressUseCode(GenericTypeCode):
    """
    PostalAddressUse
    From: http://hl7.org/fhir/ValueSet/postal-address-use in valuesets.xml
        Uses of an address not included in Address.use.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/v3-AddressUse
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/v3-AddressUse"


class PostalAddressUseCodeValues:
    """
    Description: Address uses that can apply to both postal and telecommunication
    addresses.
    From: http://terminology.hl7.org/CodeSystem/v3-AddressUse in v3-codesystems.xml
    """

    _GeneralAddressUse = PostalAddressUseCode("_GeneralAddressUse")
    """
    Description: Address uses that only apply to postal addresses, not
    telecommunication addresses.
    From: http://terminology.hl7.org/CodeSystem/v3-AddressUse in v3-codesystems.xml
    """
    _PostalAddressUse = PostalAddressUseCode("_PostalAddressUse")
    """
    Description: Address uses that only apply to telecommunication addresses, not
    postal addresses.
    From: http://terminology.hl7.org/CodeSystem/v3-AddressUse in v3-codesystems.xml
    """
    _TelecommunicationAddressUse = PostalAddressUseCode("_TelecommunicationAddressUse")
    """
    From: http://hl7.org/fhir/ValueSet/postal-address-use in valuesets.xml
    """
    BadAddress = PostalAddressUseCode("BAD")
    """
    From: http://hl7.org/fhir/ValueSet/postal-address-use in valuesets.xml
    """
    ConfidentialAddress = PostalAddressUseCode("CONF")
    """
    From: http://hl7.org/fhir/ValueSet/postal-address-use in valuesets.xml
    """
    PrimaryHome = PostalAddressUseCode("HP")
    """
    From: http://hl7.org/fhir/ValueSet/postal-address-use in valuesets.xml
    """
    VacationHome = PostalAddressUseCode("HV")
    """
    From: http://hl7.org/fhir/ValueSet/postal-address-use in valuesets.xml
    """
    Direct = PostalAddressUseCode("DIR")
    """
    From: http://hl7.org/fhir/ValueSet/postal-address-use in valuesets.xml
    """
    Public = PostalAddressUseCode("PUB")
    """
    From: http://hl7.org/fhir/ValueSet/postal-address-use in valuesets.xml
    """
    PhysicalVisitAddress = PostalAddressUseCode("PHYS")
    """
    From: http://hl7.org/fhir/ValueSet/postal-address-use in valuesets.xml
    """
    PostalAddress = PostalAddressUseCode("PST")
