from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class PropertyTypeCode(GenericTypeCode):
    """
    PropertyType
    From: http://hl7.org/fhir/concept-property-type in valuesets.xml
        The type of a property value.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/concept-property-type
    """
    codeset: FhirUri = "http://hl7.org/fhir/concept-property-type"


class PropertyTypeCodeValues:
    """
    The property value is a code that identifies a concept defined in the code
    system.
    From: http://hl7.org/fhir/concept-property-type in valuesets.xml
    """

    Code_internalReference_ = PropertyTypeCode("code")
    """
    The property  value is a code defined in an external code system. This may be
    used for translations, but is not the intent.
    From: http://hl7.org/fhir/concept-property-type in valuesets.xml
    """
    Coding_externalReference_ = PropertyTypeCode("Coding")
    """
    The property value is a string.
    From: http://hl7.org/fhir/concept-property-type in valuesets.xml
    """
    String = PropertyTypeCode("string")
    """
    The property value is a string (often used to assign ranking values to
    concepts for supporting score assessments).
    From: http://hl7.org/fhir/concept-property-type in valuesets.xml
    """
    Integer = PropertyTypeCode("integer")
    """
    The property value is a boolean true | false.
    From: http://hl7.org/fhir/concept-property-type in valuesets.xml
    """
    Boolean = PropertyTypeCode("boolean")
    """
    The property is a date or a date + time.
    From: http://hl7.org/fhir/concept-property-type in valuesets.xml
    """
    DateTime = PropertyTypeCode("dateTime")
    """
    The property value is a decimal number.
    From: http://hl7.org/fhir/concept-property-type in valuesets.xml
    """
    Decimal = PropertyTypeCode("decimal")
