from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class ProvenanceEventCurrentState_AS(GenericTypeCode):
    """
    v3.ProvenanceEventCurrentState-AS
    From: http://terminology.hl7.org/ValueSet/v3-ProvenanceEventCurrentState-AS in v3-codesystems.xml
         Specifies the state change of a target Act, using ActStatus codes, from its
    previous state as a predecessor Act. For example, if the target Act is the
    result of a predecessor Act being "obsoleted" and replaced with the target
    Act, the source ProvenanceEventCurrentState Act code would be "obsoleted".
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/v3-ActStatus
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/v3-ActStatus"


class ProvenanceEventCurrentState_ASValues:
    """
    Encompasses the expected states of an Act, but excludes "nullified" and
    "obsolete" which represent unusual terminal states for the life-cycle.
    From: http://terminology.hl7.org/CodeSystem/v3-ActStatus in v3-codesystems.xml
    """

    Normal = ProvenanceEventCurrentState_AS("normal")
    """
    This Act instance was created in error and has been 'removed' and is treated
    as though it never existed.  A record is retained for audit purposes only.
    From: http://terminology.hl7.org/CodeSystem/v3-ActStatus in v3-codesystems.xml
    """
    Nullified = ProvenanceEventCurrentState_AS("nullified")
    """
    This Act instance has been replaced by a new instance.
    From: http://terminology.hl7.org/CodeSystem/v3-ActStatus in v3-codesystems.xml
    """
    Obsolete = ProvenanceEventCurrentState_AS("obsolete")
