from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class ProvenanceParticipantRoleCode(GenericTypeCode):
    """
    ProvenanceParticipantRole
    From: http://hl7.org/fhir/provenance-participant-role in valuesets.xml
        The role that a provenance participant played
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/provenance-participant-role
    """
    codeset: FhirUri = "http://hl7.org/fhir/provenance-participant-role"


class ProvenanceParticipantRoleCodeValues:
    """
    A person entering the data into the originating system
    From: http://hl7.org/fhir/provenance-participant-role in valuesets.xml
    """

    Enterer = ProvenanceParticipantRoleCode("enterer")
    """
    A person, animal, organization or device that who actually and principally
    carries out the activity
    From: http://hl7.org/fhir/provenance-participant-role in valuesets.xml
    """
    Performer = ProvenanceParticipantRoleCode("performer")
    """
    A party that originates the resource and therefore has responsibility for the
    information given in the resource and ownership of this resource
    From: http://hl7.org/fhir/provenance-participant-role in valuesets.xml
    """
    Author = ProvenanceParticipantRoleCode("author")
    """
    A person who verifies the correctness and appropriateness of activity
    From: http://hl7.org/fhir/provenance-participant-role in valuesets.xml
    """
    Verifier = ProvenanceParticipantRoleCode("verifier")
    """
    A verifier who attests to the accuracy of the resource
    From: http://hl7.org/fhir/provenance-participant-role in valuesets.xml
    """
    Attester = ProvenanceParticipantRoleCode("attester")
    """
    A person who reported information that contributed to the resource
    From: http://hl7.org/fhir/provenance-participant-role in valuesets.xml
    """
    Informant = ProvenanceParticipantRoleCode("informant")
    """
    The entity that is accountable for maintaining a true an accurate copy of the
    original record
    From: http://hl7.org/fhir/provenance-participant-role in valuesets.xml
    """
    Custodian = ProvenanceParticipantRoleCode("custodian")
    """
    A device that operates independently of an author on custodian's algorithms
    for data extraction of existing information for purpose of generating a new
    artifact.
    From: http://hl7.org/fhir/provenance-participant-role in valuesets.xml
    """
    Assembler = ProvenanceParticipantRoleCode("assembler")
    """
    A device used by an author to record new information, which may also be used
    by the author to select existing information for aggregation with newly
    recorded information for the purpose of generating a new artifact.
    From: http://hl7.org/fhir/provenance-participant-role in valuesets.xml
    """
    Composer = ProvenanceParticipantRoleCode("composer")
