from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class QuestionnaireItemUsageModeCode(GenericTypeCode):
    """
    QuestionnaireItemUsageMode
    From: http://terminology.hl7.org/CodeSystem/questionnaire-usage-mode in valuesets.xml
        Identifies the modes of usage of a questionnaire that should enable a
    particular questionnaire item.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/questionnaire-usage-mode
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/questionnaire-usage-mode"


class QuestionnaireItemUsageModeCodeValues:
    """
    Render the item regardless of usage mode.
    From: http://terminology.hl7.org/CodeSystem/questionnaire-usage-mode in valuesets.xml
    """

    Capture_Display = QuestionnaireItemUsageModeCode("capture-display")
    """
    Render the item only when capturing data.
    From: http://terminology.hl7.org/CodeSystem/questionnaire-usage-mode in valuesets.xml
    """
    CaptureOnly = QuestionnaireItemUsageModeCode("capture")
    """
    Render the item only when displaying a completed form.
    From: http://terminology.hl7.org/CodeSystem/questionnaire-usage-mode in valuesets.xml
    """
    DisplayOnly = QuestionnaireItemUsageModeCode("display")
    """
    Render the item only when displaying a completed form and the item has been
    answered (or has child items that have been answered).
    From: http://terminology.hl7.org/CodeSystem/questionnaire-usage-mode in valuesets.xml
    """
    DisplayWhenAnswered = QuestionnaireItemUsageModeCode("display-non-empty")
    """
    Render the item when capturing data or when displaying a completed form and
    the item has been answered (or has child items that have been answered).
    From: http://terminology.hl7.org/CodeSystem/questionnaire-usage-mode in valuesets.xml
    """
    CaptureOr_IfAnswered_Display = QuestionnaireItemUsageModeCode(
        "capture-display-non-empty"
    )
