from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class QuestionnaireResponseModeCode(GenericTypeCode):
    """
    QuestionnaireResponseMode
    From: http://hl7.org/fhir/ValueSet/questionnaireresponse-mode in valuesets.xml
        Codes describing how the QuestionnaireResponse was populated
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/v3-ParticipationMode
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/v3-ParticipationMode"


class QuestionnaireResponseModeCodeValues:
    """
    Participation by non-human-languaged based electronic signal
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationMode in v3-codesystems.xml
    """

    ElectronicData = QuestionnaireResponseModeCode("ELECTRONIC")
    """
    Participation by direct action where subject and actor are in the same
    location. (The participation involves more than communication.)
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationMode in v3-codesystems.xml
    """
    PhysicalPresence = QuestionnaireResponseModeCode("PHYSICAL")
    """
    Participation by direct action where subject and actor are in separate
    locations, and the actions of the actor are transmitted by electronic or
    mechanical means. (The participation involves more than communication.)
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationMode in v3-codesystems.xml
    """
    RemotePresence = QuestionnaireResponseModeCode("REMOTE")
    """
    Participation by voice communication
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationMode in v3-codesystems.xml
    """
    Verbal = QuestionnaireResponseModeCode("VERBAL")
    """
    Participation by human language recorded on a physical material
    From: http://terminology.hl7.org/CodeSystem/v3-ParticipationMode in v3-codesystems.xml
    """
    Written = QuestionnaireResponseModeCode("WRITTEN")
    """
    From: http://hl7.org/fhir/ValueSet/questionnaireresponse-mode in valuesets.xml
    """
    ELECTRONIC = QuestionnaireResponseModeCode("ELECTRONIC")
    """
    From: http://hl7.org/fhir/ValueSet/questionnaireresponse-mode in valuesets.xml
    """
    VERBAL = QuestionnaireResponseModeCode("VERBAL")
    """
    From: http://hl7.org/fhir/ValueSet/questionnaireresponse-mode in valuesets.xml
    """
    WRITTEN = QuestionnaireResponseModeCode("WRITTEN")
