from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class Race(GenericTypeCode):
    """
    v3.Race
    From: http://terminology.hl7.org/ValueSet/v3-Race in v3-codesystems.xml
         In the United States, federal standards for classifying data on race
    determine the categories used by federal agencies and exert a strong influence
    on categorization by state and local agencies and private sector
    organizations.  The federal standards do not conceptually define race, and
    they recognize the absence of an anthropological or scientific basis for
    racial classification.  Instead, the federal standards acknowledge that race
    is a social-political construct in which an individual's own identification
    with one more race categories is preferred to observer identification. The
    standards use a variety of features to define five minimum race categories.
    Among these features are descent from "the original peoples" of a specified
    region or nation.  The minimum race categories are American Indian or Alaska
    Native, Asian, Black or African American, Native Hawaiian or Other Pacific
    Islander, and White.  The federal standards stipulate that race data need not
    be limited to the five minimum categories, but any expansion must be
    collapsible to those categories.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/v3-Race
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/v3-Race"


class RaceValues:
    """
    American Indian or Alaska Native
    From: http://terminology.hl7.org/CodeSystem/v3-Race in v3-codesystems.xml
    """

    AmericanIndianOrAlaskaNative = Race("1002-5")
    """
    Asian
    From: http://terminology.hl7.org/CodeSystem/v3-Race in v3-codesystems.xml
    """
    Asian = Race("2028-9")
    """
    Black or African American
    From: http://terminology.hl7.org/CodeSystem/v3-Race in v3-codesystems.xml
    """
    BlackOrAfricanAmerican = Race("2054-5")
    """
    Native Hawaiian or Other Pacific Islander
    From: http://terminology.hl7.org/CodeSystem/v3-Race in v3-codesystems.xml
    """
    NativeHawaiianOrOtherPacificIslander = Race("2076-8")
    """
    White
    From: http://terminology.hl7.org/CodeSystem/v3-Race in v3-codesystems.xml
    """
    White = Race("2106-3")
    """
    Note that this term remains in the table for completeness, even though within
    HL7, the notion of Other code is deprecated.
    From: http://terminology.hl7.org/CodeSystem/v3-Race in v3-codesystems.xml
    """
    OtherRace = Race("2131-1")
