from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class ReferenceHandlingPolicyCode(GenericTypeCode):
    """
    ReferenceHandlingPolicy
    From: http://hl7.org/fhir/reference-handling-policy in valuesets.xml
        A set of flags that defines how references are supported.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/reference-handling-policy
    """
    codeset: FhirUri = "http://hl7.org/fhir/reference-handling-policy"


class ReferenceHandlingPolicyCodeValues:
    """
    The server supports and populates Literal references (i.e. using
    Reference.reference) where they are known (this code does not guarantee that
    all references are literal; see 'enforced').
    From: http://hl7.org/fhir/reference-handling-policy in valuesets.xml
    """

    LiteralReferences = ReferenceHandlingPolicyCode("literal")
    """
    The server allows logical references (i.e. using Reference.identifier).
    From: http://hl7.org/fhir/reference-handling-policy in valuesets.xml
    """
    LogicalReferences = ReferenceHandlingPolicyCode("logical")
    """
    The server will attempt to resolve logical references to literal references -
    i.e. converting Reference.identifier to Reference.reference (if resolution
    fails, the server may still accept resources; see logical).
    From: http://hl7.org/fhir/reference-handling-policy in valuesets.xml
    """
    ResolvesReferences = ReferenceHandlingPolicyCode("resolves")
    """
    The server enforces that references have integrity - e.g. it ensures that
    references can always be resolved. This is typically the case for clinical
    record systems, but often not the case for middleware/proxy systems.
    From: http://hl7.org/fhir/reference-handling-policy in valuesets.xml
    """
    ReferenceIntegrityEnforced = ReferenceHandlingPolicyCode("enforced")
    """
    The server does not support references that point to other servers.
    From: http://hl7.org/fhir/reference-handling-policy in valuesets.xml
    """
    LocalReferencesOnly = ReferenceHandlingPolicyCode("local")
