from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class RequestIntentCode(GenericTypeCode):
    """
    RequestIntent
    From: http://hl7.org/fhir/request-intent in valuesets.xml
        Codes indicating the degree of authority/intentionality associated with a
    request.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/request-intent
    """
    codeset: FhirUri = "http://hl7.org/fhir/request-intent"


class RequestIntentCodeValues:
    """
    The request is a suggestion made by someone/something that does not have an
    intention to ensure it occurs and without providing an authorization to act.
    From: http://hl7.org/fhir/request-intent in valuesets.xml
    """

    Proposal = RequestIntentCode("proposal")
    """
    The request represents an intention to ensure something occurs without
    providing an authorization for others to act.
    From: http://hl7.org/fhir/request-intent in valuesets.xml
    """
    Plan = RequestIntentCode("plan")
    """
    The request represents a legally binding instruction authored by a Patient or
    RelatedPerson.
    From: http://hl7.org/fhir/request-intent in valuesets.xml
    """
    Directive = RequestIntentCode("directive")
    """
    The request represents a request/demand and authorization for action by a
    Practitioner.
    From: http://hl7.org/fhir/request-intent in valuesets.xml
    """
    Order = RequestIntentCode("order")
    """
    The request represents a component or option for a RequestGroup that
    establishes timing, conditionality and/or other constraints among a set of
    requests.  Refer to [[[RequestGroup]]] for additional information on how this
    status is used.
    From: http://hl7.org/fhir/request-intent in valuesets.xml
    """
    Option = RequestIntentCode("option")
