from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class ResearchSubjectStatusCode(GenericTypeCode):
    """
    ResearchSubjectStatus
    From: http://hl7.org/fhir/research-subject-status in valuesets.xml
        Indicates the progression of a study subject through a study.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/research-subject-status
    """
    codeset: FhirUri = "http://hl7.org/fhir/research-subject-status"


class ResearchSubjectStatusCodeValues:
    """
    An identified person that can be considered for inclusion in a study.
    From: http://hl7.org/fhir/research-subject-status in valuesets.xml
    """

    Candidate = ResearchSubjectStatusCode("candidate")
    """
    A person that has met the eligibility criteria for inclusion in a study.
    From: http://hl7.org/fhir/research-subject-status in valuesets.xml
    """
    Eligible = ResearchSubjectStatusCode("eligible")
    """
    A person is no longer receiving study intervention and/or being evaluated with
    tests and procedures according to the protocol, but they are being monitored
    on a protocol-prescribed schedule.
    From: http://hl7.org/fhir/research-subject-status in valuesets.xml
    """
    Follow_up = ResearchSubjectStatusCode("follow-up")
    """
    A person who did not meet one or more criteria required for participation in a
    study is considered to have failed screening or
    is ineligible for the study.
    From: http://hl7.org/fhir/research-subject-status in valuesets.xml
    """
    Ineligible = ResearchSubjectStatusCode("ineligible")
    """
    A person for whom registration was not completed.
    From: http://hl7.org/fhir/research-subject-status in valuesets.xml
    """
    NotRegistered = ResearchSubjectStatusCode("not-registered")
    """
    A person that has ended their participation on a study either because their
    treatment/observation is complete or through not
    responding, withdrawal, non-compliance and/or adverse event.
    From: http://hl7.org/fhir/research-subject-status in valuesets.xml
    """
    Off_study = ResearchSubjectStatusCode("off-study")
    """
    A person that is enrolled or registered on a study.
    From: http://hl7.org/fhir/research-subject-status in valuesets.xml
    """
    On_study = ResearchSubjectStatusCode("on-study")
    """
    The person is receiving the treatment or participating in an activity (e.g.
    yoga, diet, etc.) that the study is evaluating.
    From: http://hl7.org/fhir/research-subject-status in valuesets.xml
    """
    On_study_intervention = ResearchSubjectStatusCode("on-study-intervention")
    """
    The subject is being evaluated via tests and assessments according to the
    study calendar, but is not receiving any intervention. Note that this state is
    study-dependent and might not exist in all studies.  A synonym for this is
    "short-term follow-up".
    From: http://hl7.org/fhir/research-subject-status in valuesets.xml
    """
    On_study_observation = ResearchSubjectStatusCode("on-study-observation")
    """
    A person is pre-registered for a study.
    From: http://hl7.org/fhir/research-subject-status in valuesets.xml
    """
    PendingOn_study = ResearchSubjectStatusCode("pending-on-study")
    """
    A person that is potentially eligible for participation in the study.
    From: http://hl7.org/fhir/research-subject-status in valuesets.xml
    """
    PotentialCandidate = ResearchSubjectStatusCode("potential-candidate")
    """
    A person who is being evaluated for eligibility for a study.
    From: http://hl7.org/fhir/research-subject-status in valuesets.xml
    """
    Screening = ResearchSubjectStatusCode("screening")
    """
    The person has withdrawn their participation in the study before registration.
    From: http://hl7.org/fhir/research-subject-status in valuesets.xml
    """
    Withdrawn = ResearchSubjectStatusCode("withdrawn")
