from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class ResponseLevel(GenericTypeCode):
    """
    v3.ResponseLevel
    From: http://terminology.hl7.org/ValueSet/v3-ResponseLevel in v3-codesystems.xml
         Specifies whether a response is expected from the addressee of this
    interaction and what level of detail that response should include
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/v3-ResponseLevel
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/v3-ResponseLevel"


class ResponseLevelValues:
    """
    Respond with exceptions and a notification of completion
    From: http://terminology.hl7.org/CodeSystem/v3-ResponseLevel in v3-codesystems.xml
    """

    Completion = ResponseLevel("C")
    """
    Respond with exceptions, completion, modifications and include more detail
    information (if applicable)
    From: http://terminology.hl7.org/CodeSystem/v3-ResponseLevel in v3-codesystems.xml
    """
    Detail = ResponseLevel("D")
    """
    Respond with exceptions only
    From: http://terminology.hl7.org/CodeSystem/v3-ResponseLevel in v3-codesystems.xml
    """
    Exception = ResponseLevel("E")
    """
    Respond with exceptions, completion, and modification with detail (as above),
    and send positive confirmations even if no modifications are being made.
    From: http://terminology.hl7.org/CodeSystem/v3-ResponseLevel in v3-codesystems.xml
    """
    Confirmation = ResponseLevel("F")
    """
    Respond only with message level acknowledgements, i.e., only notify acceptance
    or rejection of the message, do not include any application-level detail
    From: http://terminology.hl7.org/CodeSystem/v3-ResponseLevel in v3-codesystems.xml
    """
    Message_control = ResponseLevel("N")
    """
    Respond with exceptions, completions and modifications or revisions done
    before completion
    From: http://terminology.hl7.org/CodeSystem/v3-ResponseLevel in v3-codesystems.xml
    """
    Modification = ResponseLevel("R")
    """
    Do not send any kind of response
    From: http://terminology.hl7.org/CodeSystem/v3-ResponseLevel in v3-codesystems.xml
    """
    None_ = ResponseLevel("X")
