from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class RiskEstimateTypeCode(GenericTypeCode):
    """
    RiskEstimateType
    From: http://terminology.hl7.org/CodeSystem/risk-estimate-type in valuesets.xml
        Whether the risk estimate is dichotomous, continuous or qualitative and the
    specific type of risk estimate (eg proportion or median).
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/risk-estimate-type
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/risk-estimate-type"


class RiskEstimateTypeCodeValues:
    """
    dichotomous measure (present or absent) reported as a ratio compared to the
    denominator of 1 (A percentage is a proportion with denominator of 100).
    From: http://terminology.hl7.org/CodeSystem/risk-estimate-type in valuesets.xml
    """

    Proportion = RiskEstimateTypeCode("proportion")
    """
    A special use case where the proportion is derived from a formula rather than
    derived from summary evidence.
    From: http://terminology.hl7.org/CodeSystem/risk-estimate-type in valuesets.xml
    """
    DerivedProportion = RiskEstimateTypeCode("derivedProportion")
    """
    continuous numerical measure reported as an average.
    From: http://terminology.hl7.org/CodeSystem/risk-estimate-type in valuesets.xml
    """
    Mean = RiskEstimateTypeCode("mean")
    """
    continuous numerical measure reported as the middle of the range.
    From: http://terminology.hl7.org/CodeSystem/risk-estimate-type in valuesets.xml
    """
    Median = RiskEstimateTypeCode("median")
    """
    descriptive measure reported as total number of items.
    From: http://terminology.hl7.org/CodeSystem/risk-estimate-type in valuesets.xml
    """
    Count = RiskEstimateTypeCode("count")
    """
    descriptive measure reported as narrative.
    From: http://terminology.hl7.org/CodeSystem/risk-estimate-type in valuesets.xml
    """
    Descriptive = RiskEstimateTypeCode("descriptive")
