from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class RoleClassMutualRelationship(GenericTypeCode):
    """
    v3.RoleClassMutualRelationship
    From: http://terminology.hl7.org/ValueSet/v3-RoleClassMutualRelationship in v3-codesystems.xml
         A relationship that is based on mutual behavior of the two Entities as being
    related. The basis of such relationship may be agreements (e.g., spouses,
    contract parties) or they may bede facto
    behavior (e.g. friends) or may be an incidental involvement with each other
    (e.g. parties over a dispute, siblings, children).
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/v3-RoleClass
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/v3-RoleClass"


class RoleClassMutualRelationshipValues:
    """
    Corresponds to the Role class
    From: http://terminology.hl7.org/CodeSystem/v3-RoleClass in v3-codesystems.xml
    """

    Role = RoleClassMutualRelationship("ROL")
    """
    The player of the role is a child of the scoping entity, in a generic sense.
    From: http://terminology.hl7.org/CodeSystem/v3-RoleClass in v3-codesystems.xml
    """
    Child = RoleClassMutualRelationship("CHILD")
    """
    A role played by an entity that receives credentials from the scoping entity.
    From: http://terminology.hl7.org/CodeSystem/v3-RoleClass in v3-codesystems.xml
    """
    CredentialedEntity = RoleClassMutualRelationship("CRED")
    """
    nurse practitioner
    From: http://terminology.hl7.org/CodeSystem/v3-RoleClass in v3-codesystems.xml
    """
    NursePractitioner = RoleClassMutualRelationship("NURPRAC")
    """
    nurse
    From: http://terminology.hl7.org/CodeSystem/v3-RoleClass in v3-codesystems.xml
    """
    Nurse = RoleClassMutualRelationship("NURS")
    """
    physician assistant
    From: http://terminology.hl7.org/CodeSystem/v3-RoleClass in v3-codesystems.xml
    """
    PhysicianAssistant = RoleClassMutualRelationship("PA")
    """
    physician
    From: http://terminology.hl7.org/CodeSystem/v3-RoleClass in v3-codesystems.xml
    """
    Physician = RoleClassMutualRelationship("PHYS")
