from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class RoleClassPartitive(GenericTypeCode):
    """
    v3.RoleClassPartitive
    From: http://terminology.hl7.org/ValueSet/v3-RoleClassPartitive in v3-codesystems.xml
         An association between two Entities where the playing Entity is considered in
    some way "part" of the scoping Entity, e.g., as a member, component,
    ingredient, or content. Being "part" in the broadest sense of the word can
    mean anything from being an integral structural component to a mere incidental
    temporary association of a playing Entity with a (generally larger) scoping
    Entity.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/v3-RoleClass
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/v3-RoleClass"


class RoleClassPartitiveValues:
    """
    Corresponds to the Role class
    From: http://terminology.hl7.org/CodeSystem/v3-RoleClass in v3-codesystems.xml
    """

    Role = RoleClassPartitive("ROL")
    """
    The player of the role is a child of the scoping entity, in a generic sense.
    From: http://terminology.hl7.org/CodeSystem/v3-RoleClass in v3-codesystems.xml
    """
    Child = RoleClassPartitive("CHILD")
    """
    A role played by an entity that receives credentials from the scoping entity.
    From: http://terminology.hl7.org/CodeSystem/v3-RoleClass in v3-codesystems.xml
    """
    CredentialedEntity = RoleClassPartitive("CRED")
    """
    nurse practitioner
    From: http://terminology.hl7.org/CodeSystem/v3-RoleClass in v3-codesystems.xml
    """
    NursePractitioner = RoleClassPartitive("NURPRAC")
    """
    nurse
    From: http://terminology.hl7.org/CodeSystem/v3-RoleClass in v3-codesystems.xml
    """
    Nurse = RoleClassPartitive("NURS")
    """
    physician assistant
    From: http://terminology.hl7.org/CodeSystem/v3-RoleClass in v3-codesystems.xml
    """
    PhysicianAssistant = RoleClassPartitive("PA")
    """
    physician
    From: http://terminology.hl7.org/CodeSystem/v3-RoleClass in v3-codesystems.xml
    """
    Physician = RoleClassPartitive("PHYS")
