from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class SearchModifierCodeCode(GenericTypeCode):
    """
    SearchModifierCode
    From: http://hl7.org/fhir/search-modifier-code in valuesets.xml
        A supported modifier for a search parameter.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/search-modifier-code
    """
    codeset: FhirUri = "http://hl7.org/fhir/search-modifier-code"


class SearchModifierCodeCodeValues:
    """
    The search parameter returns resources that have a value or not.
    From: http://hl7.org/fhir/search-modifier-code in valuesets.xml
    """

    Missing = SearchModifierCodeCode("missing")
    """
    The search parameter returns resources that have a value that exactly matches
    the supplied parameter (the whole string, including casing and accents).
    From: http://hl7.org/fhir/search-modifier-code in valuesets.xml
    """
    Exact = SearchModifierCodeCode("exact")
    """
    The search parameter returns resources that include the supplied parameter
    value anywhere within the field being searched.
    From: http://hl7.org/fhir/search-modifier-code in valuesets.xml
    """
    Contains = SearchModifierCodeCode("contains")
    """
    The search parameter returns resources that do not contain a match.
    From: http://hl7.org/fhir/search-modifier-code in valuesets.xml
    """
    Not = SearchModifierCodeCode("not")
    """
    The search parameter is processed as a string that searches text associated
    with the code/value - either CodeableConcept.text, Coding.display, or
    Identifier.type.text.
    From: http://hl7.org/fhir/search-modifier-code in valuesets.xml
    """
    Text = SearchModifierCodeCode("text")
    """
    The search parameter is a URI (relative or absolute) that identifies a value
    set, and the search parameter tests whether the coding is in the specified
    value set.
    From: http://hl7.org/fhir/search-modifier-code in valuesets.xml
    """
    In = SearchModifierCodeCode("in")
    """
    The search parameter is a URI (relative or absolute) that identifies a value
    set, and the search parameter tests whether the coding is not in the specified
    value set.
    From: http://hl7.org/fhir/search-modifier-code in valuesets.xml
    """
    NotIn = SearchModifierCodeCode("not-in")
    """
    The search parameter tests whether the value in a resource is subsumed by the
    specified value (is-a, or hierarchical relationships).
    From: http://hl7.org/fhir/search-modifier-code in valuesets.xml
    """
    Below = SearchModifierCodeCode("below")
    """
    The search parameter tests whether the value in a resource subsumes the
    specified value (is-a, or hierarchical relationships).
    From: http://hl7.org/fhir/search-modifier-code in valuesets.xml
    """
    Above = SearchModifierCodeCode("above")
    """
    The search parameter only applies to the Resource Type specified as a modifier
    (e.g. the modifier is not actually :type, but :Patient etc.).
    From: http://hl7.org/fhir/search-modifier-code in valuesets.xml
    """
    Type = SearchModifierCodeCode("type")
    """
    The search parameter applies to the identifier on the resource, not the
    reference.
    From: http://hl7.org/fhir/search-modifier-code in valuesets.xml
    """
    Identifier = SearchModifierCodeCode("identifier")
    """
    The search parameter has the format system|code|value, where the system and
    code refer to an Identifier.type.coding.system and .code, and match if any of
    the type codes match. All 3 parts must be present.
    From: http://hl7.org/fhir/search-modifier-code in valuesets.xml
    """
    OfType = SearchModifierCodeCode("ofType")
