from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class SearchParamTypeCode(GenericTypeCode):
    """
    SearchParamType
    From: http://hl7.org/fhir/search-param-type in valuesets.xml
        Data types allowed to be used for search parameters.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/search-param-type
    """
    codeset: FhirUri = "http://hl7.org/fhir/search-param-type"


class SearchParamTypeCodeValues:
    """
    Search parameter SHALL be a number (a whole number, or a decimal).
    From: http://hl7.org/fhir/search-param-type in valuesets.xml
    """

    Number = SearchParamTypeCode("number")
    """
    Search parameter is on a date/time. The date format is the standard XML
    format, though other formats may be supported.
    From: http://hl7.org/fhir/search-param-type in valuesets.xml
    """
    Date_DateTime = SearchParamTypeCode("date")
    """
    Search parameter is a simple string, like a name part. Search is case-
    insensitive and accent-insensitive. May match just the start of a string.
    String parameters may contain spaces.
    From: http://hl7.org/fhir/search-param-type in valuesets.xml
    """
    String = SearchParamTypeCode("string")
    """
    Search parameter on a coded element or identifier. May be used to search
    through the text, display, code and code/codesystem (for codes) and label,
    system and key (for identifier). Its value is either a string or a pair of
    namespace and value, separated by a "|", depending on the modifier used.
    From: http://hl7.org/fhir/search-param-type in valuesets.xml
    """
    Token = SearchParamTypeCode("token")
    """
    A reference to another resource (Reference or canonical).
    From: http://hl7.org/fhir/search-param-type in valuesets.xml
    """
    Reference = SearchParamTypeCode("reference")
    """
    A composite search parameter that combines a search on two values together.
    From: http://hl7.org/fhir/search-param-type in valuesets.xml
    """
    Composite = SearchParamTypeCode("composite")
    """
    A search parameter that searches on a quantity.
    From: http://hl7.org/fhir/search-param-type in valuesets.xml
    """
    Quantity = SearchParamTypeCode("quantity")
    """
    A search parameter that searches on a URI (RFC 3986).
    From: http://hl7.org/fhir/search-param-type in valuesets.xml
    """
    URI = SearchParamTypeCode("uri")
    """
    Special logic applies to this parameter per the description of the search
    parameter.
    From: http://hl7.org/fhir/search-param-type in valuesets.xml
    """
    Special = SearchParamTypeCode("special")
