from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class SecurityIntegrityObservationValue(GenericTypeCode):
    """
    v3.SecurityIntegrityObservationValue
    From: http://terminology.hl7.org/ValueSet/v3-SecurityIntegrityObservationValue in v3-codesystems.xml
        No Description Provided
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/v3-ObservationValue
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/v3-ObservationValue"


class SecurityIntegrityObservationValueValues:
    """
    Codes specify the category of observation, evidence, or document used to
    assess for services, e.g., discharge planning, or to establish eligibility for
    coverage under a policy or program. The type of evidence is coded as
    observation values.
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationValue in v3-codesystems.xml
    """

    ActCoverageAssessmentObservationValue = SecurityIntegrityObservationValue(
        "_ActCoverageAssessmentObservationValue"
    )
    """
    Indicates the result of a particular allergy test.  E.g. Negative, Mild,
    Moderate, Severe
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationValue in v3-codesystems.xml
    """
    AllergyTestValue = SecurityIntegrityObservationValue("_AllergyTestValue")
    """
    Observation values that communicate the method used in a quality measure to
    combine the component measure results included in an composite measure.
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationValue in v3-codesystems.xml
    """
    CompositeMeasureScoring = SecurityIntegrityObservationValue(
        "_CompositeMeasureScoring"
    )
    """
    Description:Coded observation values for coverage limitations, for e.g., types
    of claims or types of parties covered under a policy or program.
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationValue in v3-codesystems.xml
    """
    CoverageLimitObservationValue = SecurityIntegrityObservationValue(
        "_CoverageLimitObservationValue"
    )
    """
    A clinical judgment as to the worst case result of a future exposure
    (including substance administration). When the worst case result is assessed
    to have a life-threatening or organ system threatening potential, it is
    considered to be of high criticality.
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationValue in v3-codesystems.xml
    """
    CriticalityObservationValue = SecurityIntegrityObservationValue(
        "_CriticalityObservationValue"
    )
    """
    Concepts representing whether a person does or does not currently have a job
    or is not currently in the labor pool seeking employment.
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationValue in v3-codesystems.xml
    """
    _EmploymentStatus = SecurityIntegrityObservationValue("_EmploymentStatus")
    """
    Description: The domain contains genetic analysis specific observation values,
    e.g. Homozygote, Heterozygote, etc.
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationValue in v3-codesystems.xml
    """
    GeneticObservationValue = SecurityIntegrityObservationValue(
        "_GeneticObservationValue"
    )
    """
    Observation values used to indicate the type of scoring (e.g. proportion,
    ratio) used by a health quality measure.
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationValue in v3-codesystems.xml
    """
    ObservationMeasureScoring = SecurityIntegrityObservationValue(
        "_ObservationMeasureScoring"
    )
    """
    Observation values used to indicate what kind of health quality measure is
    used.
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationValue in v3-codesystems.xml
    """
    ObservationMeasureType = SecurityIntegrityObservationValue(
        "_ObservationMeasureType"
    )
    """
    Observation values used to assert various populations that a subject falls
    into.
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationValue in v3-codesystems.xml
    """
    ObservationPopulationInclusion = SecurityIntegrityObservationValue(
        "_ObservationPopulationInclusion"
    )
    """
    PartialCompletionScale
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationValue in v3-codesystems.xml
    """
    PartialCompletionScale = SecurityIntegrityObservationValue(
        "_PartialCompletionScale"
    )
    """
    Observation values used to indicate security observation metadata.
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationValue in v3-codesystems.xml
    """
    SecurityObservationValue = SecurityIntegrityObservationValue(
        "_SecurityObservationValue"
    )
    """
    Potential values for observations of severity.
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationValue in v3-codesystems.xml
    """
    SeverityObservation = SecurityIntegrityObservationValue("_SeverityObservation")
    """
    Contains codes for defining the observed, physical position of a subject, such
    as during an observation, assessment, collection of a specimen, etc.  ECG
    waveforms and vital signs, such as blood pressure, are two examples where a
    general, observed position typically needs to be noted.
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationValue in v3-codesystems.xml
    """
    _SubjectBodyPosition = SecurityIntegrityObservationValue("_SubjectBodyPosition")
    """
    Values for observations of verification act results
    
    
                               Examples: Verified, not verified, verified with
    warning.
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationValue in v3-codesystems.xml
    """
    VerificationOutcome = SecurityIntegrityObservationValue("_VerificationOutcomeValue")
    """
    Concepts that describe an individual's typical arrangement of working hours
    for an occupation.
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationValue in v3-codesystems.xml
    """
    _WorkSchedule = SecurityIntegrityObservationValue("_WorkSchedule")
    """
    AnnotationValue
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationValue in v3-codesystems.xml
    """
    AnnotationValue = SecurityIntegrityObservationValue("_AnnotationValue")
    """
    Description:Used in a patient care message to value simple clinical (non-lab)
    observations.
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationValue in v3-codesystems.xml
    """
    CommonClinicalObservation = SecurityIntegrityObservationValue(
        "_CommonClinicalObservationValue"
    )
    """
    This domain is established as a parent to a variety of value domains being
    defined to support the communication of Individual Case Safety Reports to
    regulatory bodies. Arguably, this aggregation is not taxonomically pure, but
    the grouping will facilitate the management of these domains.
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationValue in v3-codesystems.xml
    """
    IndividualCaseSafetyReportValueDomains = SecurityIntegrityObservationValue(
        "_IndividualCaseSafetyReportValueDomains"
    )
    """
    Indicates the specific observation result which is the reason for the action
    (prescription, lab test, etc.). E.g. Headache, Ear infection, planned
    diagnostic image (requiring contrast agent), etc.
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationValue in v3-codesystems.xml
    """
    IndicationValue = SecurityIntegrityObservationValue("_IndicationValue")
