from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class SecurityRoleTypeCode(GenericTypeCode):
    """
    SecurityRoleType
    From: http://terminology.hl7.org/CodeSystem/extra-security-role-type in valuesets.xml
        This CodeSystem contains Additional FHIR-defined Security Role types not
    defined elsewhere
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/extra-security-role-type
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/extra-security-role-type"


class SecurityRoleTypeCodeValues:
    """
    An entity providing authorization services to enable the electronic sharing of
    health-related information based on resource owner's preapproved permissions.
    For example, an UMA Authorization Server[UMA]
    From: http://terminology.hl7.org/CodeSystem/extra-security-role-type in valuesets.xml
    """

    AuthorizationServer = SecurityRoleTypeCode("authserver")
    """
    An entity that collects information over which the data subject may have
    certain rights under policy or law to control that information's management
    and distribution by data collectors, including the right to access, retrieve,
    distribute, or delete that information.
    From: http://terminology.hl7.org/CodeSystem/extra-security-role-type in valuesets.xml
    """
    DataCollector = SecurityRoleTypeCode("datacollector")
    """
    An entity that processes collected information over which the data subject may
    have certain rights under policy or law to control that information's
    management and distribution by data processors, including the right to access,
    retrieve, distribute, or delete that information.
    From: http://terminology.hl7.org/CodeSystem/extra-security-role-type in valuesets.xml
    """
    DataProcessor = SecurityRoleTypeCode("dataprocessor")
    """
    A person whose personal information is collected or processed, and who may
    have certain rights under policy or law to control that information's
    management and distribution by data collectors or processors, including the
    right to access, retrieve, distribute, or delete that information.
    From: http://terminology.hl7.org/CodeSystem/extra-security-role-type in valuesets.xml
    """
    DataSubject = SecurityRoleTypeCode("datasubject")
    """
    The human user that has participated.
    From: http://terminology.hl7.org/CodeSystem/extra-security-role-type in valuesets.xml
    """
    HumanUser = SecurityRoleTypeCode("humanuser")
