from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class ServiceCategoryCode(GenericTypeCode):
    """
    ServiceCategory
    From: http://terminology.hl7.org/CodeSystem/service-category in valuesets.xml
        This value set defines an example set of codes that can be used to classify
    groupings of service-types/specialties.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/service-category
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/service-category"


class ServiceCategoryCodeValues:
    """
    Adoption
    From: http://terminology.hl7.org/CodeSystem/service-category in valuesets.xml
    """

    Adoption = ServiceCategoryCode("1")
    """
    Aged Care
    From: http://terminology.hl7.org/CodeSystem/service-category in valuesets.xml
    """
    AgedCare = ServiceCategoryCode("2")
    """
    Allied Health
    From: http://terminology.hl7.org/CodeSystem/service-category in valuesets.xml
    """
    AlliedHealth = ServiceCategoryCode("34")
    """
    Alternative & Complementary Therapies
    From: http://terminology.hl7.org/CodeSystem/service-category in valuesets.xml
    """
    Alternative_ComplementaryTherapies = ServiceCategoryCode("3")
    """
    Child Care and/or Kindergarten
    From: http://terminology.hl7.org/CodeSystem/service-category in valuesets.xml
    """
    ChildCare_Kindergarten = ServiceCategoryCode("4")
    """
    Child Development
    From: http://terminology.hl7.org/CodeSystem/service-category in valuesets.xml
    """
    ChildDevelopment = ServiceCategoryCode("5")
    """
    Child Protection & Family Services
    From: http://terminology.hl7.org/CodeSystem/service-category in valuesets.xml
    """
    ChildProtection_FamilyServices = ServiceCategoryCode("6")
    """
    Community Health Care
    From: http://terminology.hl7.org/CodeSystem/service-category in valuesets.xml
    """
    CommunityHealthCare = ServiceCategoryCode("7")
    """
    Counselling
    From: http://terminology.hl7.org/CodeSystem/service-category in valuesets.xml
    """
    Counselling = ServiceCategoryCode("8")
    """
    Crisis Line (GPAH use only)
    From: http://terminology.hl7.org/CodeSystem/service-category in valuesets.xml
    """
    CrisisLine_GPAHUseOnly_ = ServiceCategoryCode("36")
    """
    Death Services
    From: http://terminology.hl7.org/CodeSystem/service-category in valuesets.xml
    """
    DeathServices = ServiceCategoryCode("9")
    """
    Dental
    From: http://terminology.hl7.org/CodeSystem/service-category in valuesets.xml
    """
    Dental = ServiceCategoryCode("10")
    """
    Disability Support
    From: http://terminology.hl7.org/CodeSystem/service-category in valuesets.xml
    """
    DisabilitySupport = ServiceCategoryCode("11")
    """
    Drug/Alcohol
    From: http://terminology.hl7.org/CodeSystem/service-category in valuesets.xml
    """
    Drug_Alcohol = ServiceCategoryCode("12")
    """
    Education & Learning
    From: http://terminology.hl7.org/CodeSystem/service-category in valuesets.xml
    """
    Education_Learning = ServiceCategoryCode("13")
    """
    Emergency Department
    From: http://terminology.hl7.org/CodeSystem/service-category in valuesets.xml
    """
    EmergencyDepartment = ServiceCategoryCode("14")
    """
    Employment
    From: http://terminology.hl7.org/CodeSystem/service-category in valuesets.xml
    """
    Employment = ServiceCategoryCode("15")
    """
    Financial & Material aid
    From: http://terminology.hl7.org/CodeSystem/service-category in valuesets.xml
    """
    Financial_MaterialAid = ServiceCategoryCode("16")
    """
    General Practice/GP (doctor)
    From: http://terminology.hl7.org/CodeSystem/service-category in valuesets.xml
    """
    GeneralPractice = ServiceCategoryCode("17")
    """
    Hospital
    From: http://terminology.hl7.org/CodeSystem/service-category in valuesets.xml
    """
    Hospital = ServiceCategoryCode("35")
    """
    Housing/Homelessness
    From: http://terminology.hl7.org/CodeSystem/service-category in valuesets.xml
    """
    Housing_Homelessness = ServiceCategoryCode("18")
    """
    Interpreting
    From: http://terminology.hl7.org/CodeSystem/service-category in valuesets.xml
    """
    Interpreting = ServiceCategoryCode("19")
    """
    Justice
    From: http://terminology.hl7.org/CodeSystem/service-category in valuesets.xml
    """
    Justice = ServiceCategoryCode("20")
    """
    Legal
    From: http://terminology.hl7.org/CodeSystem/service-category in valuesets.xml
    """
    Legal = ServiceCategoryCode("21")
    """
    Mental Health
    From: http://terminology.hl7.org/CodeSystem/service-category in valuesets.xml
    """
    MentalHealth = ServiceCategoryCode("22")
    """
    NDIA
    From: http://terminology.hl7.org/CodeSystem/service-category in valuesets.xml
    """
    NDIA = ServiceCategoryCode("38")
    """
    Physical Activity & Recreation
    From: http://terminology.hl7.org/CodeSystem/service-category in valuesets.xml
    """
    PhysicalActivity_Recreation = ServiceCategoryCode("23")
    """
    Regulation
    From: http://terminology.hl7.org/CodeSystem/service-category in valuesets.xml
    """
    Regulation = ServiceCategoryCode("24")
    """
    Respite/Carer Support
    From: http://terminology.hl7.org/CodeSystem/service-category in valuesets.xml
    """
    Respite_CarerSupport = ServiceCategoryCode("25")
    """
    Specialist Clinical Pathology - requires referral
    From: http://terminology.hl7.org/CodeSystem/service-category in valuesets.xml
    """
    SpecialistClinicalPathology = ServiceCategoryCode("26")
    """
    Specialist Medical - requires referral
    From: http://terminology.hl7.org/CodeSystem/service-category in valuesets.xml
    """
    SpecialistMedical = ServiceCategoryCode("27")
    """
    Specialist Obstetrics & Gynecology - requires referral
    From: http://terminology.hl7.org/CodeSystem/service-category in valuesets.xml
    """
    SpecialistObstetrics_Gynecology = ServiceCategoryCode("28")
    """
    Specialist Paediatric - requires referral
    From: http://terminology.hl7.org/CodeSystem/service-category in valuesets.xml
    """
    SpecialistPaediatric = ServiceCategoryCode("29")
    """
    Specialist Radiology/Imaging - requires referral
    From: http://terminology.hl7.org/CodeSystem/service-category in valuesets.xml
    """
    SpecialistRadiology_Imaging = ServiceCategoryCode("30")
    """
    Specialist Surgical - requires referral
    From: http://terminology.hl7.org/CodeSystem/service-category in valuesets.xml
    """
    SpecialistSurgical = ServiceCategoryCode("31")
    """
    Support group/s
    From: http://terminology.hl7.org/CodeSystem/service-category in valuesets.xml
    """
    SupportGroup_s = ServiceCategoryCode("32")
    """
    Test Message (HSD admin use only)
    From: http://terminology.hl7.org/CodeSystem/service-category in valuesets.xml
    """
    TestMessage_HSDAdmin_ = ServiceCategoryCode("37")
    """
    Transport
    From: http://terminology.hl7.org/CodeSystem/service-category in valuesets.xml
    """
    Transport = ServiceCategoryCode("33")
