from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class ServiceTypeCode(GenericTypeCode):
    """
    ServiceType
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
        This value set defines an example set of codes of service-types.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/service-type
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/service-type"


class ServiceTypeCodeValues:
    """
    Adoption & permanent care information/support
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """

    Adoption_PermanentCareInfo_Support = ServiceTypeCode("1")
    """
    Aged care assessment
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    AgedCareAssessment = ServiceTypeCode("2")
    """
    Aged Care information/referral
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    AgedCareInformation_Referral = ServiceTypeCode("3")
    """
    Aged Residential Care
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    AgedResidentialCare = ServiceTypeCode("4")
    """
    Case management for older persons
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    CaseManagementForOlderPersons = ServiceTypeCode("5")
    """
    Delivered meals (meals on wheels)
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    DeliveredMeals_MealsOnWheels_ = ServiceTypeCode("6")
    """
    Friendly visiting
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    FriendlyVisiting = ServiceTypeCode("7")
    """
    Home care/housekeeping assistance
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    HomeCare_HousekeepingAssistance = ServiceTypeCode("8")
    """
    Home maintenance and repair
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    HomeMaintenanceAndRepair = ServiceTypeCode("9")
    """
    Personal alarms/alerts
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PersonalAlarms_Alerts = ServiceTypeCode("10")
    """
    Personal care for older persons
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PersonalCareForOlderPersons = ServiceTypeCode("11")
    """
    Planned activity groups
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PlannedActivityGroups = ServiceTypeCode("12")
    """
    Acupuncture
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Acupuncture = ServiceTypeCode("13")
    """
    Alexander technique therapy
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    AlexanderTechniqueTherapy = ServiceTypeCode("14")
    """
    Aromatherapy
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Aromatherapy = ServiceTypeCode("15")
    """
    Biorhythm services
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    BiorhythmServices = ServiceTypeCode("16")
    """
    Bowen therapy
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    BowenTherapy = ServiceTypeCode("17")
    """
    Chinese herbal medicine
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    ChineseHerbalMedicine = ServiceTypeCode("18")
    """
    Feldenkrais
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Feldenkrais = ServiceTypeCode("19")
    """
    Homoeopathy
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Homoeopathy = ServiceTypeCode("20")
    """
    Hydrotherapy
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Hydrotherapy = ServiceTypeCode("21")
    """
    Hypnotherapy
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Hypnotherapy = ServiceTypeCode("22")
    """
    Kinesiology
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Kinesiology = ServiceTypeCode("23")
    """
    Magnetic therapy
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    MagneticTherapy = ServiceTypeCode("24")
    """
    Massage therapy
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    MassageTherapy = ServiceTypeCode("25")
    """
    Meditation
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Meditation = ServiceTypeCode("26")
    """
    Myotherapy
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Myotherapy = ServiceTypeCode("27")
    """
    Naturopathy
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Naturopathy = ServiceTypeCode("28")
    """
    Reflexology
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Reflexology = ServiceTypeCode("29")
    """
    Reiki
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Reiki = ServiceTypeCode("30")
    """
    Relaxation therapy
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    RelaxationTherapy = ServiceTypeCode("31")
    """
    Shiatsu
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Shiatsu = ServiceTypeCode("32")
    """
    Western herbal medicine
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    WesternHerbalMedicine = ServiceTypeCode("33")
    """
    Family day care
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    FamilyDayCare = ServiceTypeCode("34")
    """
    Holiday programs
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    HolidayPrograms = ServiceTypeCode("35")
    """
    Kindergarten inclusion support for children with a disability
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    KindergartenInclusionSupport = ServiceTypeCode("36")
    """
    Kindergarten/preschool
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Kindergarten_Preschool = ServiceTypeCode("37")
    """
    Long day child care
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    LongDayChildCare = ServiceTypeCode("38")
    """
    Occasional child care
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    OccasionalChildCare = ServiceTypeCode("39")
    """
    Outside school hours care
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    OutsideSchoolHoursCare = ServiceTypeCode("40")
    """
    Children's play programs
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Children_sPlayPrograms = ServiceTypeCode("41")
    """
    Parenting & family management support/education
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Parenting_FamilySupport_Education = ServiceTypeCode("42")
    """
    Playgroup
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Playgroup = ServiceTypeCode("43")
    """
    School nursing
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    SchoolNursing = ServiceTypeCode("44")
    """
    Toy library
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    ToyLibrary = ServiceTypeCode("45")
    """
    Child protection/child abuse report
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    ChildProtection_ChildAbuseReport = ServiceTypeCode("46")
    """
    Foster care
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    FosterCare = ServiceTypeCode("47")
    """
    Residential/ out of home care
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Residential_Out_of_HomeCare = ServiceTypeCode("48")
    """
    Support for young people leaving care
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Support_YoungPeopleLeavingCare = ServiceTypeCode("49")
    """
    Audiology
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Audiology = ServiceTypeCode("50")
    """
    Blood donation
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    BloodDonation = ServiceTypeCode("51")
    """
    Chiropractic
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Chiropractic = ServiceTypeCode("52")
    """
    Dietetics
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Dietetics = ServiceTypeCode("53")
    """
    Family planning
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    FamilyPlanning = ServiceTypeCode("54")
    """
    Health advocacy/Liaison service
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    HealthAdvocacy_LiaisonService = ServiceTypeCode("55")
    """
    Health information/referral
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    HealthInformation_Referral = ServiceTypeCode("56")
    """
    Immunization
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Immunization = ServiceTypeCode("57")
    """
    Maternal & child health
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Maternal_ChildHealth = ServiceTypeCode("58")
    """
    Nursing
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Nursing = ServiceTypeCode("59")
    """
    Nutrition
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Nutrition = ServiceTypeCode("60")
    """
    Occupational therapy
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    OccupationalTherapy = ServiceTypeCode("61")
    """
    Optometry
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Optometry = ServiceTypeCode("62")
    """
    Osteopathy
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Osteopathy = ServiceTypeCode("63")
    """
    Pharmacy
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Pharmacy = ServiceTypeCode("64")
    """
    Physiotherapy
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Physiotherapy = ServiceTypeCode("65")
    """
    Podiatry
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Podiatry = ServiceTypeCode("66")
    """
    Sexual health
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    SexualHealth = ServiceTypeCode("67")
    """
    Speech pathology/therapy
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    SpeechPathology_Therapy = ServiceTypeCode("68")
    """
    Bereavement counselling
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    BereavementCounselling = ServiceTypeCode("69")
    """
    Crisis counselling
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    CrisisCounselling = ServiceTypeCode("70")
    """
    Family counselling and/or family therapy
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    FamilyCounselling_Therapy = ServiceTypeCode("71")
    """
    Family violence counselling
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    FamilyViolenceCounselling = ServiceTypeCode("72")
    """
    Financial counselling
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    FinancialCounselling = ServiceTypeCode("73")
    """
    Generalist counselling
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    GeneralistCounselling = ServiceTypeCode("74")
    """
    Genetic counselling
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    GeneticCounselling = ServiceTypeCode("75")
    """
    Health counselling
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    HealthCounselling = ServiceTypeCode("76")
    """
    Mediation
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Mediation = ServiceTypeCode("77")
    """
    Problem gambling counselling
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    ProblemGamblingCounselling = ServiceTypeCode("78")
    """
    Relationship counselling
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    RelationshipCounselling = ServiceTypeCode("79")
    """
    Sexual assault counselling
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    SexualAssaultCounselling = ServiceTypeCode("80")
    """
    Trauma counselling
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    TraumaCounselling = ServiceTypeCode("81")
    """
    Victims of crime counselling
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    VictimsOfCrimeCounselling = ServiceTypeCode("82")
    """
    Cemetery operation
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    CemeteryOperation = ServiceTypeCode("83")
    """
    Cremation
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Cremation = ServiceTypeCode("84")
    """
    Death service information
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    DeathServiceInformation = ServiceTypeCode("85")
    """
    Funeral services
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    FuneralServices = ServiceTypeCode("86")
    """
    Endodontic
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Endodontic = ServiceTypeCode("87")
    """
    General dental
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    GeneralDental = ServiceTypeCode("88")
    """
    Oral medicine
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    OralMedicine = ServiceTypeCode("89")
    """
    Oral surgery
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    OralSurgery = ServiceTypeCode("90")
    """
    Orthodontic
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Orthodontic = ServiceTypeCode("91")
    """
    Paediatric Dentistry
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PaediatricDentistry = ServiceTypeCode("92")
    """
    Periodontic
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Periodontic = ServiceTypeCode("93")
    """
    Prosthodontic
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Prosthodontic = ServiceTypeCode("94")
    """
    Acquired brain injury information/referral
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    AcquiredBrainInjuryInfo_Referral = ServiceTypeCode("95")
    """
    Disability advocacy
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    DisabilityAdvocacy = ServiceTypeCode("96")
    """
    Disability aids & equipment
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    DisabilityAids_Equipment = ServiceTypeCode("97")
    """
    Disability case management
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    DisabilityCaseManagement = ServiceTypeCode("98")
    """
    Disability day programs & activities
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    DisabilityDayPrograms_Activities = ServiceTypeCode("99")
    """
    Disability information/referral
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    DisabilityInformation_Referral = ServiceTypeCode("100")
    """
    Disability support packages
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    DisabilitySupportPackages = ServiceTypeCode("101")
    """
    Disability supported accommodation
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    DisabilitySupportedAccommodation = ServiceTypeCode("102")
    """
    Early childhood intervention
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    EarlyChildhoodIntervention = ServiceTypeCode("103")
    """
    Hearing aids & equipment
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    HearingAids_Equipment = ServiceTypeCode("104")
    """
    Drug and/or alcohol counselling
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    DrugAnd_orAlcoholCounselling = ServiceTypeCode("105")
    """
    Drug and/or alcohol information/referral
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Drug_AlcoholInformation_Referral = ServiceTypeCode("106")
    """
    Needle & Syringe exchange
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Needle_SyringeExchange = ServiceTypeCode("107")
    """
    Non-residential alcohol and/or drug dependence treatment
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Non_resid_Alcohol_DrugTreatment = ServiceTypeCode("108")
    """
    Pharmacotherapy (eg. methadone) program
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Pharmacotherapy = ServiceTypeCode("109")
    """
    Quit program
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    QuitProgram = ServiceTypeCode("110")
    """
    Residential alcohol and/or drug dependence treatment
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    ResidentialAlcohol_DrugTreatment = ServiceTypeCode("111")
    """
    Adult/community education
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Adult_CommunityEducation = ServiceTypeCode("112")
    """
    Higher education
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    HigherEducation = ServiceTypeCode("113")
    """
    Primary education
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PrimaryEducation = ServiceTypeCode("114")
    """
    Secondary education
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    SecondaryEducation = ServiceTypeCode("115")
    """
    Training & vocational education
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Training_VocationalEducation = ServiceTypeCode("116")
    """
    Emergency medical
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    EmergencyMedical = ServiceTypeCode("117")
    """
    Employment placement and/or support
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    EmploymentPlacementAnd_orSupport = ServiceTypeCode("118")
    """
    Vocational Rehabilitation
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    VocationalRehabilitation = ServiceTypeCode("119")
    """
    Workplace safety and/or accident prevention
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    WorkSafety_AccidentPrevention = ServiceTypeCode("120")
    """
    Financial assistance
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    FinancialAssistance = ServiceTypeCode("121")
    """
    Financial information/advice
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    FinancialInformation_Advice = ServiceTypeCode("122")
    """
    Material aid
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    MaterialAid = ServiceTypeCode("123")
    """
    General Practice/GP (doctor)
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    GeneralPractice = ServiceTypeCode("124")
    """
    Accommodation placement and/or support
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    AccommodationPlacement_Support = ServiceTypeCode("125")
    """
    Crisis/emergency accommodation
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Crisis_EmergencyAccommodation = ServiceTypeCode("126")
    """
    Homelessness support
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    HomelessnessSupport = ServiceTypeCode("127")
    """
    Housing information/referral
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    HousingInformation_Referral = ServiceTypeCode("128")
    """
    Public rental housing
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PublicRentalHousing = ServiceTypeCode("129")
    """
    Interpreting/Multilingual/Language service
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Interpreting_MultilingualService = ServiceTypeCode("130")
    """
    Juvenile Justice
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    JuvenileJustice = ServiceTypeCode("131")
    """
    Legal advocacy
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    LegalAdvocacy = ServiceTypeCode("132")
    """
    Legal information/advice/referral
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    LegalInformation_Advice_Referral = ServiceTypeCode("133")
    """
    Mental health advocacy
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    MentalHealthAdvocacy = ServiceTypeCode("134")
    """
    Mental health assessment/triage/crisis response
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    MentalHealthAssess_Triage_CrisisResponse = ServiceTypeCode("135")
    """
    Mental health case management/continuing care
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    MentalHealthCaseManagement = ServiceTypeCode("136")
    """
    Mental health information/referral
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    MentalHealthInformation_Referral = ServiceTypeCode("137")
    """
    Mental health inpatient services (hospital psychiatric unit) - requires
    referral
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    MentalHealthInpatientServices = ServiceTypeCode("138")
    """
    Mental health non-residential rehabilitation
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    MentalHealthNon_residentialRehab = ServiceTypeCode("139")
    """
    Mental health residential rehabilitation/community care unit
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    MentalHealthResidentialRehab_CCU = ServiceTypeCode("140")
    """
    Psychiatry (requires referral)
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Psychiatry_RequiresReferral_ = ServiceTypeCode("141")
    """
    Psychology
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Psychology = ServiceTypeCode("142")
    """
    Martial arts
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    MartialArts = ServiceTypeCode("143")
    """
    Personal fitness training
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PersonalFitnessTraining = ServiceTypeCode("144")
    """
    Physical activity group
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PhysicalActivityGroup = ServiceTypeCode("145")
    """
    Physical activity programs
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PhysicalActivityPrograms = ServiceTypeCode("146")
    """
    Physical fitness testing
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PhysicalFitnessTesting = ServiceTypeCode("147")
    """
    Pilates
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Pilates = ServiceTypeCode("148")
    """
    Self defence
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Self_Defence = ServiceTypeCode("149")
    """
    Sporting club
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    SportingClub = ServiceTypeCode("150")
    """
    Yoga
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Yoga = ServiceTypeCode("151")
    """
    Food safety
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    FoodSafety = ServiceTypeCode("152")
    """
    Health regulatory, inspection and/or certification
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    HealthRegulatory_Inspection_Cert_ = ServiceTypeCode("153")
    """
    Workplace health and/or safety inspection and/or certification
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    WorkHealth_SafetyInspection_Cert_ = ServiceTypeCode("154")
    """
    Carer support
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    CarerSupport = ServiceTypeCode("155")
    """
    Respite care
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    RespiteCare = ServiceTypeCode("156")
    """
    Anatomical Pathology (including Cytopathology & Forensic Pathology)
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    AnatomicalPathology = ServiceTypeCode("157")
    """
    Pathology - Clinical Chemistry
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Pathology_ClinicalChemistry = ServiceTypeCode("158")
    """
    Pathology - General
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Pathology_General = ServiceTypeCode("159")
    """
    Pathology - Genetics
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Pathology_Genetics = ServiceTypeCode("160")
    """
    Pathology - Haematology
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Pathology_Haematology = ServiceTypeCode("161")
    """
    Pathology - Immunology
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Pathology_Immunology = ServiceTypeCode("162")
    """
    Pathology - Microbiology
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Pathology_Microbiology = ServiceTypeCode("163")
    """
    Anaesthesiology - Pain Medicine
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Anaesthesiology_PainMedicine = ServiceTypeCode("164")
    """
    Cardiology
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Cardiology = ServiceTypeCode("165")
    """
    Clinical Genetics
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    ClinicalGenetics = ServiceTypeCode("166")
    """
    Clinical Pharmacology
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    ClinicalPharmacology = ServiceTypeCode("167")
    """
    Dermatology
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Dermatology = ServiceTypeCode("168")
    """
    Endocrinology
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Endocrinology = ServiceTypeCode("169")
    """
    Gastroenterology & Hepatology
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Gastroenterology_Hepatology = ServiceTypeCode("170")
    """
    Geriatric medicine
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    GeriatricMedicine = ServiceTypeCode("171")
    """
    Immunology & Allergy
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Immunology_Allergy = ServiceTypeCode("172")
    """
    Infectious diseases
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    InfectiousDiseases = ServiceTypeCode("173")
    """
    Intensive care medicine
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    IntensiveCareMedicine = ServiceTypeCode("174")
    """
    Medical Oncology
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    MedicalOncology = ServiceTypeCode("175")
    """
    Nephrology
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Nephrology = ServiceTypeCode("176")
    """
    Neurology
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Neurology = ServiceTypeCode("177")
    """
    Occupational Medicine
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    OccupationalMedicine = ServiceTypeCode("178")
    """
    Palliative Medicine
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PalliativeMedicine = ServiceTypeCode("179")
    """
    Public Health Medicine
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PublicHealthMedicine = ServiceTypeCode("180")
    """
    Rehabilitation Medicine
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    RehabilitationMedicine = ServiceTypeCode("181")
    """
    Rheumatology
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Rheumatology = ServiceTypeCode("182")
    """
    Sleep Medicine
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    SleepMedicine = ServiceTypeCode("183")
    """
    Thoracic medicine
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    ThoracicMedicine = ServiceTypeCode("184")
    """
    Gynaecological Oncology
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    GynaecologicalOncology = ServiceTypeCode("185")
    """
    Obstetrics & Gynaecology
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Obstetrics_Gynaecology = ServiceTypeCode("186")
    """
    Reproductive Endocrinology & Infertility
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    ReproductiveEndocrinology_Infertility = ServiceTypeCode("187")
    """
    Urogynaecology
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Urogynaecology = ServiceTypeCode("188")
    """
    Neonatology & Perinatology
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Neonatology_Perinatology = ServiceTypeCode("189")
    """
    Paediatric Cardiology
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PaediatricCardiology = ServiceTypeCode("190")
    """
    Paediatric Clinical Genetics
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PaediatricClinicalGenetics = ServiceTypeCode("191")
    """
    Paediatric Clinical Pharmacology
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PaediatricClinicalPharmacology = ServiceTypeCode("192")
    """
    Paediatric Endocrinology
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PaediatricEndocrinology = ServiceTypeCode("193")
    """
    Paediatric Gastroenterology & Hepatology
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Paed_Gastroenterology_Hepatology = ServiceTypeCode("194")
    """
    Paediatric Haematology
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PaediatricHaematology = ServiceTypeCode("195")
    """
    Paediatric Immunology & Allergy
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PaediatricImmunology_Allergy = ServiceTypeCode("196")
    """
    Paediatric Infectious diseases
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PaediatricInfectiousDiseases = ServiceTypeCode("197")
    """
    Paediatric intensive care medicine
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PaediatricIntensiveCareMedicine = ServiceTypeCode("198")
    """
    Paediatric Medical Oncology
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PaediatricMedicalOncology = ServiceTypeCode("199")
    """
    Paediatric Medicine
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PaediatricMedicine = ServiceTypeCode("200")
    """
    Paediatric Nephrology
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PaediatricNephrology = ServiceTypeCode("201")
    """
    Paediatric Neurology
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PaediatricNeurology = ServiceTypeCode("202")
    """
    Paediatric Nuclear Medicine
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PaediatricNuclearMedicine = ServiceTypeCode("203")
    """
    Paediatric Rehabilitation Medicine
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PaediatricRehabilitationMedicine = ServiceTypeCode("204")
    """
    Paediatric Rheumatology
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PaediatricRheumatology = ServiceTypeCode("205")
    """
    Paediatric Sleep Medicine
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PaediatricSleepMedicine = ServiceTypeCode("206")
    """
    Paediatric Surgery
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PaediatricSurgery = ServiceTypeCode("207")
    """
    Paediatric Thoracic Medicine
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PaediatricThoracicMedicine = ServiceTypeCode("208")
    """
    Diagnostic Radiology/Xray/CT/Fluoroscopy
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Diag_Radiology_Xray_CT_Fluoroscopy = ServiceTypeCode("209")
    """
    Diagnostic Ultrasound
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    DiagnosticUltrasound = ServiceTypeCode("210")
    """
    Magnetic Resonance Imaging (MRI)
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    MagneticResonanceImaging_MRI_ = ServiceTypeCode("211")
    """
    Nuclear Medicine
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    NuclearMedicine = ServiceTypeCode("212")
    """
    Obstetric & Gynaecological Ultrasound
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Obstetric_GynaecologicalUltrasound = ServiceTypeCode("213")
    """
    Radiation oncology
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    RadiationOncology = ServiceTypeCode("214")
    """
    Cardiothoracic surgery
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    CardiothoracicSurgery = ServiceTypeCode("215")
    """
    Neurosurgery
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Neurosurgery = ServiceTypeCode("216")
    """
    Ophthalmology
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Ophthalmology = ServiceTypeCode("217")
    """
    Orthopaedic surgery
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    OrthopaedicSurgery = ServiceTypeCode("218")
    """
    Otolaryngology - Head & Neck Surgery
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Otolaryngology_Head_NeckSurgery = ServiceTypeCode("219")
    """
    Plastic & Reconstructive Surgery
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Plastic_ReconstructiveSurgery = ServiceTypeCode("220")
    """
    Surgery - General
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Surgery_General = ServiceTypeCode("221")
    """
    Urology
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Urology = ServiceTypeCode("222")
    """
    Vascular surgery
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    VascularSurgery = ServiceTypeCode("223")
    """
    Support groups
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    SupportGroups = ServiceTypeCode("224")
    """
    Air ambulance
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    AirAmbulance = ServiceTypeCode("225")
    """
    Ambulance
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Ambulance = ServiceTypeCode("226")
    """
    Blood transport
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    BloodTransport = ServiceTypeCode("227")
    """
    Community bus
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    CommunityBus = ServiceTypeCode("228")
    """
    Flying doctor service
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    FlyingDoctorService = ServiceTypeCode("229")
    """
    Patient transport
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PatientTransport = ServiceTypeCode("230")
    """
    A&E
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    A_E = ServiceTypeCode("231")
    """
    A&EP
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    A_EP = ServiceTypeCode("232")
    """
    Abuse
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Abuse = ServiceTypeCode("233")
    """
    ACAS
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    ACAS = ServiceTypeCode("234")
    """
    Access
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Access = ServiceTypeCode("235")
    """
    Accident
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Accident = ServiceTypeCode("236")
    """
    Acute Inpatient Service's
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    AcuteInpatientServ = ServiceTypeCode("237")
    """
    Adult Day Programs
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    AdultDayPrograms = ServiceTypeCode("238")
    """
    Adult Mental Health Services
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    AdultMentalHealthServices = ServiceTypeCode("239")
    """
    Advice
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Advice = ServiceTypeCode("240")
    """
    Advocacy
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Advocacy = ServiceTypeCode("241")
    """
    Aged Persons Mental Health Residential Units
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    AgedPersonsMental = ServiceTypeCode("242")
    """
    Aged Persons Mental Health Services
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    AgedPersonsMental = ServiceTypeCode("243")
    """
    Aged Persons Mental Health Teams
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    AgedPersonsMental = ServiceTypeCode("244")
    """
    Aids
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Aids = ServiceTypeCode("245")
    """
    Al-Anon
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Al_Anon = ServiceTypeCode("246")
    """
    Alcohol
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Alcohol = ServiceTypeCode("247")
    """
    Al-Teen
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Al_Teen = ServiceTypeCode("248")
    """
    Antenatal
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Antenatal = ServiceTypeCode("249")
    """
    Anxiety
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Anxiety = ServiceTypeCode("250")
    """
    Arthritis
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Arthritis = ServiceTypeCode("251")
    """
    Assessment
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Assessment = ServiceTypeCode("252")
    """
    Assistance
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Assistance = ServiceTypeCode("253")
    """
    Asthma
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Asthma = ServiceTypeCode("254")
    """
    ATSS
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    ATSS = ServiceTypeCode("255")
    """
    Attendant Care
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    AttendantCare = ServiceTypeCode("256")
    """
    Babies
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Babies = ServiceTypeCode("257")
    """
    Bathroom Modification
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    BathroomModificatio = ServiceTypeCode("258")
    """
    Behavior
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Behavior = ServiceTypeCode("259")
    """
    Behavior Intervention
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    BehaviorInterventi = ServiceTypeCode("260")
    """
    Bereavement
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Bereavement = ServiceTypeCode("261")
    """
    Bipolar
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Bipolar = ServiceTypeCode("262")
    """
    Birth
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Birth = ServiceTypeCode("263")
    """
    Birth Control
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    BirthControl = ServiceTypeCode("264")
    """
    Birthing Options
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    BirthingOptions = ServiceTypeCode("265")
    """
    BIST
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    BIST = ServiceTypeCode("266")
    """
    Blood
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Blood = ServiceTypeCode("267")
    """
    Bone
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Bone = ServiceTypeCode("268")
    """
    Bowel
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Bowel = ServiceTypeCode("269")
    """
    Brain
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Brain = ServiceTypeCode("270")
    """
    Breast Feeding
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    BreastFeeding = ServiceTypeCode("271")
    """
    Breast Screen
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    BreastScreen = ServiceTypeCode("272")
    """
    Brokerage
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Brokerage = ServiceTypeCode("273")
    """
    Cancer
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Cancer = ServiceTypeCode("274")
    """
    Cancer Support
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    CancerSupport = ServiceTypeCode("275")
    """
    Cardiovascular Disease
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    CardiovascularDisea = ServiceTypeCode("276")
    """
    Care Packages
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    CarePackages = ServiceTypeCode("277")
    """
    Carer
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Carer = ServiceTypeCode("278")
    """
    Case Management
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    CaseManagement = ServiceTypeCode("279")
    """
    Casualty
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Casualty = ServiceTypeCode("280")
    """
    Centrelink
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Centrelink = ServiceTypeCode("281")
    """
    Chemists
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Chemists = ServiceTypeCode("282")
    """
    Child And Adolescent Mental Health Services
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    ChildAndAdolescent = ServiceTypeCode("283")
    """
    Child Care
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    ChildCare = ServiceTypeCode("284")
    """
    Child Services
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    ChildServices = ServiceTypeCode("285")
    """
    Children
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Children = ServiceTypeCode("286")
    """
    Children's Services
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Children_sServices = ServiceTypeCode("287")
    """
    Cholesterol
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Cholesterol = ServiceTypeCode("288")
    """
    Clothing
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Clothing = ServiceTypeCode("289")
    """
    Community Based Accommodation
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    CommunityBasedAcco = ServiceTypeCode("290")
    """
    Community Care Unit
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    CommunityCareUnit = ServiceTypeCode("291")
    """
    Community Child And Adolescent Mental Health Services
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    CommunityChildAnd = ServiceTypeCode("292")
    """
    Community Health
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    CommunityHealth = ServiceTypeCode("293")
    """
    Community Residential Unit
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    CommunityResidentia = ServiceTypeCode("294")
    """
    Community Transport
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    CommunityTransport = ServiceTypeCode("295")
    """
    Companion Visiting
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    CompanionVisiting = ServiceTypeCode("296")
    """
    Companionship
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Companionship = ServiceTypeCode("297")
    """
    Consumer Advice
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    ConsumerAdvice = ServiceTypeCode("298")
    """
    Consumer Issues
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    ConsumerIssues = ServiceTypeCode("299")
    """
    Continuing Care Services
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    ContinuingCareServ = ServiceTypeCode("300")
    """
    Contraception Information
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    ContraceptionInform = ServiceTypeCode("301")
    """
    Coordinating Bodies
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    CoordinatingBodies = ServiceTypeCode("302")
    """
    Correctional Services
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    CorrectionalService = ServiceTypeCode("303")
    """
    Council Environmental Health
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    CouncilEnvironmenta = ServiceTypeCode("304")
    """
    Counselling
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Counselling = ServiceTypeCode("305")
    """
    Criminal
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Criminal = ServiceTypeCode("306")
    """
    Crises
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Crises = ServiceTypeCode("307")
    """
    Crisis Assessment And Treatment Services (Cats)
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    CrisisAssessmentAn = ServiceTypeCode("308")
    """
    Crisis Assistance
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    CrisisAssistance = ServiceTypeCode("309")
    """
    Crisis Refuge
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    CrisisRefuge = ServiceTypeCode("310")
    """
    Day Program
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    DayProgram = ServiceTypeCode("311")
    """
    Deaf
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Deaf = ServiceTypeCode("312")
    """
    Dental Hygiene
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    DentalHygiene = ServiceTypeCode("313")
    """
    Dentistry
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Dentistry = ServiceTypeCode("314")
    """
    Dentures
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Dentures = ServiceTypeCode("315")
    """
    Depression
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Depression = ServiceTypeCode("316")
    """
    Detoxification
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Detoxification = ServiceTypeCode("317")
    """
    Diabetes
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Diabetes = ServiceTypeCode("318")
    """
    Diaphragm Fitting
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    DiaphragmFitting = ServiceTypeCode("319")
    """
    Dieticians
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Dieticians = ServiceTypeCode("320")
    """
    Disabled Parking
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    DisabledParking = ServiceTypeCode("321")
    """
    District Nursing
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    DistrictNursing = ServiceTypeCode("322")
    """
    Divorce
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Divorce = ServiceTypeCode("323")
    """
    Doctors
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Doctors = ServiceTypeCode("324")
    """
    Drink-Drive
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Drink_Drive = ServiceTypeCode("325")
    """
    Dual Diagnosis Services
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    DualDiagnosisServi = ServiceTypeCode("326")
    """
    Early Choice
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    EarlyChoice = ServiceTypeCode("327")
    """
    Eating Disorder
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    EatingDisorder = ServiceTypeCode("328")
    """
    Emergency Relief
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    EmergencyRelief = ServiceTypeCode("330")
    """
    Employment And Training
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    EmploymentAndTrain = ServiceTypeCode("331")
    """
    Environment
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Environment = ServiceTypeCode("332")
    """
    Equipment
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Equipment = ServiceTypeCode("333")
    """
    Exercise
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Exercise = ServiceTypeCode("334")
    """
    Facility
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Facility = ServiceTypeCode("335")
    """
    Family Choice
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    FamilyChoice = ServiceTypeCode("336")
    """
    Family Law
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    FamilyLaw = ServiceTypeCode("337")
    """
    Family Options
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    FamilyOptions = ServiceTypeCode("338")
    """
    Family Services
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    FamilyServices = ServiceTypeCode("339")
    """
    FFYA
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    FFYA = ServiceTypeCode("340")
    """
    Financial Aid
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    FinancialAid = ServiceTypeCode("341")
    """
    Fitness
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Fitness = ServiceTypeCode("342")
    """
    Flexible Care Packages
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    FlexibleCarePackag = ServiceTypeCode("343")
    """
    Food
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Food = ServiceTypeCode("344")
    """
    Food Vouchers
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    FoodVouchers = ServiceTypeCode("345")
    """
    Forensic Mental Health Services
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    ForensicMentalHeal = ServiceTypeCode("346")
    """
    Futures
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Futures = ServiceTypeCode("347")
    """
    Futures For Young Adults
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    FuturesForYoungAd = ServiceTypeCode("348")
    """
    General Practitioners
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    GeneralPractitioner = ServiceTypeCode("349")
    """
    Grants
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Grants = ServiceTypeCode("350")
    """
    Grief
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Grief = ServiceTypeCode("351")
    """
    Grief Counselling
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    GriefCounselling = ServiceTypeCode("352")
    """
    HACC
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    HACC = ServiceTypeCode("353")
    """
    Heart Disease
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    HeartDisease = ServiceTypeCode("354")
    """
    Help
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Help = ServiceTypeCode("355")
    """
    High Blood Pressure
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    HighBloodPressure = ServiceTypeCode("356")
    """
    Home Help
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    HomeHelp = ServiceTypeCode("357")
    """
    Home Nursing
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    HomeNursing = ServiceTypeCode("358")
    """
    Homefirst
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Homefirst = ServiceTypeCode("359")
    """
    Hospice Care
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    HospiceCare = ServiceTypeCode("360")
    """
    Hospital Services
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    HospitalServices = ServiceTypeCode("361")
    """
    Hospital To Home
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    HospitalToHome = ServiceTypeCode("362")
    """
    Hostel
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Hostel = ServiceTypeCode("364")
    """
    Hostel Accommodation
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    HostelAccommodation = ServiceTypeCode("365")
    """
    Household Items
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    HouseholdItems = ServiceTypeCode("366")
    """
    Hypertension
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Hypertension = ServiceTypeCode("367")
    """
    Illness
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Illness = ServiceTypeCode("368")
    """
    Independent Living
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    IndependentLiving = ServiceTypeCode("369")
    """
    Information
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Information = ServiceTypeCode("370")
    """
    Injury
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Injury = ServiceTypeCode("371")
    """
    Intake
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Intake = ServiceTypeCode("372")
    """
    Intensive Mobile Youth Outreach Services (Imyos)
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    IntensiveMobileYou = ServiceTypeCode("373")
    """
    Intervention
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Intervention = ServiceTypeCode("374")
    """
    Job Searching
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    JobSearching = ServiceTypeCode("375")
    """
    Justice
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Justice = ServiceTypeCode("376")
    """
    Leisure
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Leisure = ServiceTypeCode("377")
    """
    Loans
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Loans = ServiceTypeCode("378")
    """
    Low Income Earners
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    LowIncomeEarners = ServiceTypeCode("379")
    """
    Lung
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Lung = ServiceTypeCode("380")
    """
    Making A Difference
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    MakingADifference = ServiceTypeCode("381")
    """
    Medical Services
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    MedicalServices = ServiceTypeCode("382")
    """
    Medical Specialists
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    MedicalSpecialists = ServiceTypeCode("383")
    """
    Medication Administration
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    MedicationAdministr = ServiceTypeCode("384")
    """
    Menstrual Information
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    MenstrualInformatio = ServiceTypeCode("385")
    """
    Methadone
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Methadone = ServiceTypeCode("386")
    """
    Mobile Support And Treatment Services (MSTS)
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    MobileSupportAndT = ServiceTypeCode("387")
    """
    Motor Neurone
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    MotorNeurone = ServiceTypeCode("388")
    """
    Multiple Sclerosis
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    MultipleSclerosis = ServiceTypeCode("389")
    """
    Neighbourhood House
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    NeighbourhoodHouse = ServiceTypeCode("390")
    """
    Nursing Home
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    NursingHome = ServiceTypeCode("391")
    """
    Nursing Mothers
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    NursingMothers = ServiceTypeCode("392")
    """
    Obesity
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Obesity = ServiceTypeCode("393")
    """
    Occupational Health & Safety
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    OccupationalHealth = ServiceTypeCode("394")
    """
    Optometrist
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Optometrist = ServiceTypeCode("395")
    """
    Oral Hygiene
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    OralHygiene = ServiceTypeCode("396")
    """
    Outpatients
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Outpatients = ServiceTypeCode("397")
    """
    Outreach Service
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    OutreachService = ServiceTypeCode("398")
    """
    PADP
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PADP = ServiceTypeCode("399")
    """
    Pain
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Pain = ServiceTypeCode("400")
    """
    Pap Smear
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PapSmear = ServiceTypeCode("401")
    """
    Parenting
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Parenting = ServiceTypeCode("402")
    """
    Peak Organizations
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PeakOrganizations = ServiceTypeCode("403")
    """
    Personal Care
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PersonalCare = ServiceTypeCode("404")
    """
    Pharmacies
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Pharmacies = ServiceTypeCode("405")
    """
    Phobias
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Phobias = ServiceTypeCode("406")
    """
    Physical
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Physical = ServiceTypeCode("407")
    """
    Physical Activity
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PhysicalActivity = ServiceTypeCode("408")
    """
    Postnatal
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Postnatal = ServiceTypeCode("409")
    """
    Pregnancy
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Pregnancy = ServiceTypeCode("410")
    """
    Pregnancy Tests
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PregnancyTests = ServiceTypeCode("411")
    """
    Preschool
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Preschool = ServiceTypeCode("412")
    """
    Prescriptions
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Prescriptions = ServiceTypeCode("413")
    """
    Primary Mental Health And Early Intervention Teams
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PrimaryMentalHealt = ServiceTypeCode("414")
    """
    Property Maintenance
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PropertyMaintenance = ServiceTypeCode("415")
    """
    Prostate
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Prostate = ServiceTypeCode("416")
    """
    Psychiatric
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Psychiatric = ServiceTypeCode("417")
    """
    Psychiatric Disability Support Services - Home-Based Outreach
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PsychiatricDisabili = ServiceTypeCode("418")
    """
    Psychiatric Disability Support Services - Planned Respite
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PsychiatricDisabili = ServiceTypeCode("419")
    """
    Psychiatric Disability Support Services - Residential Rehabilitation
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PsychiatricDisabili = ServiceTypeCode("420")
    """
    Psychiatric Disability Support Services Home-Based Outreach
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PsychiatricDisabili = ServiceTypeCode("421")
    """
    Psychiatric Disability Support Services Mutual Support And Self Help
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PsychiatricDisabili = ServiceTypeCode("422")
    """
    Psychiatric Support
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PsychiatricSupport = ServiceTypeCode("423")
    """
    Recreation
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Recreation = ServiceTypeCode("424")
    """
    Referral
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Referral = ServiceTypeCode("425")
    """
    Refuge
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Refuge = ServiceTypeCode("426")
    """
    Rent Assistance
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    RentAssistance = ServiceTypeCode("427")
    """
    Residential Facilities
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    ResidentialFaciliti = ServiceTypeCode("428")
    """
    Residential Respite
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    ResidentialRespite = ServiceTypeCode("429")
    """
    Respiratory
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Respiratory = ServiceTypeCode("430")
    """
    Response
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Response = ServiceTypeCode("431")
    """
    Rooming Houses
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    RoomingHouses = ServiceTypeCode("432")
    """
    Safe Sex
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    SafeSex = ServiceTypeCode("433")
    """
    Secure Extended Care Inpatient Services
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    SecureExtendedCare = ServiceTypeCode("434")
    """
    Self Help
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    SelfHelp = ServiceTypeCode("435")
    """
    Separation
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Separation = ServiceTypeCode("436")
    """
    Services
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Services = ServiceTypeCode("437")
    """
    Sex Education
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    SexEducation = ServiceTypeCode("438")
    """
    Sexual Abuse
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    SexualAbuse = ServiceTypeCode("439")
    """
    Sexual Issues
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    SexualIssues = ServiceTypeCode("440")
    """
    Sexually Transmitted Diseases
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    SexuallyTransmitted = ServiceTypeCode("441")
    """
    SIDS
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    SIDS = ServiceTypeCode("442")
    """
    Social Support
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    SocialSupport = ServiceTypeCode("443")
    """
    Socialisation
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Socialisation = ServiceTypeCode("444")
    """
    Special Needs
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    SpecialNeeds = ServiceTypeCode("445")
    """
    Speech Therapist
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    SpeechTherapist = ServiceTypeCode("446")
    """
    Splinting
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Splinting = ServiceTypeCode("447")
    """
    Sport
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Sport = ServiceTypeCode("448")
    """
    Statewide And Specialist Services
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    StatewideAndSpecia = ServiceTypeCode("449")
    """
    STD
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    STD = ServiceTypeCode("450")
    """
    STI
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    STI = ServiceTypeCode("451")
    """
    Stillbirth
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Stillbirth = ServiceTypeCode("452")
    """
    Stomal Care
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    StomalCare = ServiceTypeCode("453")
    """
    Stroke
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Stroke = ServiceTypeCode("454")
    """
    Substance Abuse
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    SubstanceAbuse = ServiceTypeCode("455")
    """
    Support
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Support = ServiceTypeCode("456")
    """
    Syringes
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Syringes = ServiceTypeCode("457")
    """
    Teeth
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Teeth = ServiceTypeCode("458")
    """
    Tenancy Advice
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    TenancyAdvice = ServiceTypeCode("459")
    """
    Terminal Illness
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    TerminalIllness = ServiceTypeCode("460")
    """
    Therapy
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Therapy = ServiceTypeCode("461")
    """
    Transcription
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Transcription = ServiceTypeCode("462")
    """
    Translating Services
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    TranslatingServices = ServiceTypeCode("463")
    """
    Translator
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Translator = ServiceTypeCode("464")
    """
    Transport
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Transport = ServiceTypeCode("465")
    """
    Vertebrae
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Vertebrae = ServiceTypeCode("466")
    """
    Violence
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Violence = ServiceTypeCode("467")
    """
    Vocational Guidance
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    VocationalGuidance = ServiceTypeCode("468")
    """
    Weight
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Weight = ServiceTypeCode("469")
    """
    Welfare Assistance
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    WelfareAssistance = ServiceTypeCode("470")
    """
    Welfare Counselling
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    WelfareCounselling = ServiceTypeCode("471")
    """
    Wheelchairs
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Wheelchairs = ServiceTypeCode("472")
    """
    Wound Management
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    WoundManagement = ServiceTypeCode("473")
    """
    Young People At Risk
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    YoungPeopleAtRisk = ServiceTypeCode("474")
    """
    Further Description - Community Health Care
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    FurtherDesc_CommunityHealthCare = ServiceTypeCode("475")
    """
    Library
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Library = ServiceTypeCode("476")
    """
    Community Hours
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    CommunityHours = ServiceTypeCode("477")
    """
    Further Description - Specialist Medical
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    FurtherDesc_SpecialistMedical = ServiceTypeCode("478")
    """
    Hepatology
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Hepatology = ServiceTypeCode("479")
    """
    Gastroenterology
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Gastroenterology = ServiceTypeCode("480")
    """
    Gynaecology
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Gynaecology = ServiceTypeCode("481")
    """
    Obstetrics
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Obstetrics = ServiceTypeCode("482")
    """
    Further Description - Specialist Surgical
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    FurtherDesc_SpecialistSurgical = ServiceTypeCode("483")
    """
    Placement Protection
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PlacementProtection = ServiceTypeCode("484")
    """
    Family Violence
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    FamilyViolence = ServiceTypeCode("485")
    """
    Integrated Family Services
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    IntegratedFamilyServices = ServiceTypeCode("486")
    """
    Diabetes Educator
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    DiabetesEducator = ServiceTypeCode("488")
    """
    Kinship Care
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    KinshipCare = ServiceTypeCode("489")
    """
    General Mental Health Services
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    GeneralMentalHealthServices = ServiceTypeCode("490")
    """
    Exercise Physiology
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    ExercisePhysiology = ServiceTypeCode("491")
    """
    Medical Research
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    MedicalResearch = ServiceTypeCode("492")
    """
    Youth
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Youth = ServiceTypeCode("493")
    """
    Youth Services
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    YouthServices = ServiceTypeCode("494")
    """
    Youth Health
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    YouthHealth = ServiceTypeCode("495")
    """
    Child and Family Services
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    ChildAndFamilySer = ServiceTypeCode("496")
    """
    Home Visits
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    HomeVisits = ServiceTypeCode("497")
    """
    Mobile Services
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    MobileServices = ServiceTypeCode("498")
    """
    Before and/or After School Care
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    BeforeAnd_orAfter = ServiceTypeCode("500")
    """
    Cancer Services
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    CancerServices = ServiceTypeCode("501")
    """
    Integrated Cancer Services
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    IntegratedCancerSe = ServiceTypeCode("502")
    """
    Multidisciplinary Services
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    MultidisciplinarySe = ServiceTypeCode("503")
    """
    Multidisciplinary Cancer Services
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    MultidisciplinaryCa = ServiceTypeCode("504")
    """
    Meetings
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Meetings = ServiceTypeCode("505")
    """
    Blood pressure monitoring
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    BloodPressureMonit = ServiceTypeCode("506")
    """
    Dose administration aid
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    DoseAdministration = ServiceTypeCode("507")
    """
    Medical Equipment Hire
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    MedicalEquipmentHi = ServiceTypeCode("508")
    """
    Parenting & family support/education
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Parenting_FamilySupport_Education = ServiceTypeCode("509")
    """
    Deputising Service
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    DeputisingService = ServiceTypeCode("510")
    """
    Cancer Support Groups
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    CancerSupportGroups = ServiceTypeCode("513")
    """
    Community Cancer Services
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    CommunityCancerServices = ServiceTypeCode("514")
    """
    Disability Care Transport
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    DisabilityCareTransport = ServiceTypeCode("530")
    """
    Aged Care Transport
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    AgedCareTransport = ServiceTypeCode("531")
    """
    Diabetes Education service
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    DiabetesEducationS = ServiceTypeCode("532")
    """
    Cardiac Rehabilitation Service
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    CardiacRehabilitati = ServiceTypeCode("533")
    """
    Young Adult Diabetes services (YADS)
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    YoungAdultDiabetes = ServiceTypeCode("534")
    """
    Pulmonary Rehabilitation Service
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PulmonaryRehabilita = ServiceTypeCode("535")
    """
    Art therapy
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    ArtTherapy = ServiceTypeCode("536")
    """
    Medication Reviews
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    MedicationReviews = ServiceTypeCode("537")
    """
    Telephone Counselling
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    TelephoneCounselling = ServiceTypeCode("538")
    """
    Telephone Help Line
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    TelephoneHelpLine = ServiceTypeCode("539")
    """
    Online Service
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    OnlineService = ServiceTypeCode("540")
    """
    Crisis - Mental Health
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Crisis_MentalHealth = ServiceTypeCode("541")
    """
    Youth Crisis
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    YouthCrisis = ServiceTypeCode("542")
    """
    Sexual Assault
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    SexualAssault = ServiceTypeCode("543")
    """
    GPAH Other
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    GPAHOther = ServiceTypeCode("544")
    """
    Paediatric Dermatology
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PaediatricDermatology = ServiceTypeCode("545")
    """
    Veterans Services
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    VeteransServices = ServiceTypeCode("546")
    """
    Veterans
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Veterans = ServiceTypeCode("547")
    """
    Food Relief/food/meals
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    FoodRelief_Food_Meals = ServiceTypeCode("548")
    """
    Dementia Care
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    DementiaCare = ServiceTypeCode("550")
    """
    Alzheimer
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Alzheimer = ServiceTypeCode("551")
    """
    Drug and/or alcohol support groups
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    DrugAnd_orAlcoholSupportGroups = ServiceTypeCode("552")
    """
    One on One Support/Mentoring/Coaching
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    _1_on_1Support_Mentoring_Coaching = ServiceTypeCode("553")
    """
    Chronic Disease Management
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    ChronicDiseaseManagement = ServiceTypeCode("554")
    """
    Liaison Services
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    LiaisonServices = ServiceTypeCode("555")
    """
    Walk in Centre / non emergency
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Walk_inCentre_Non_Emergency = ServiceTypeCode("556")
    """
    Inpatients
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Inpatients = ServiceTypeCode("557")
    """
    Spiritual Counselling
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    SpiritualCounselling = ServiceTypeCode("558")
    """
    Women's Health
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Women_sHealth = ServiceTypeCode("559")
    """
    Men's Health
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Men_sHealth = ServiceTypeCode("560")
    """
    Health education/Health awareness program
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    HealthEducation_AwarenessProgram = ServiceTypeCode("561")
    """
    Test Message
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    TestMessage = ServiceTypeCode("562")
    """
    Remedial Massage
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    RemedialMassage = ServiceTypeCode("563")
    """
    Adolescent Mental Health Services
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    AdolescentMentalHealthServices = ServiceTypeCode("564")
    """
    Youth drop in/assistance/support
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    YouthDropIn_Assistance_Support = ServiceTypeCode("565")
    """
    Aboriginal Health Worker
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    AboriginalHealthWorker = ServiceTypeCode("566")
    """
    Women's Health Clinic
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Women_sHealthClinic = ServiceTypeCode("567")
    """
    Men's Health Clinic
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Men_sHealthClinic = ServiceTypeCode("568")
    """
    Migrant Health Clinic
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    MigrantHealthClinic = ServiceTypeCode("569")
    """
    Refugee Health Clinic
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    RefugeeHealthClinic = ServiceTypeCode("570")
    """
    Aboriginal Health Clinic
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    AboriginalHealthClinic = ServiceTypeCode("571")
    """
    Nurse Practitioner lead Clinic/s
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    NursePractitionerLeadClinic_s = ServiceTypeCode("572")
    """
    Nurse lead Clinic/s
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    NurseLeadClinic_s = ServiceTypeCode("573")
    """
    Culturally tailored support groups
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    CulturallyTailoredSupportGroups = ServiceTypeCode("574")
    """
    Culturally tailored health promotion
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    CulturallyTailoredHealthPromotion = ServiceTypeCode("575")
    """
    Rehabilitation
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Rehabilitation = ServiceTypeCode("576")
    """
    Education information/referral
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    EducationInformation_Referral = ServiceTypeCode("577")
    """
    Social Work
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    SocialWork = ServiceTypeCode("580")
    """
    Haematology
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Haematology = ServiceTypeCode("581")
    """
    Maternity Shared Care
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    MaternitySharedCar = ServiceTypeCode("582")
    """
    Rehabilitation Service
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    RehabilitationServi = ServiceTypeCode("583")
    """
    Cranio-Sacral Therapy
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Cranio_sacralTherapy = ServiceTypeCode("584")
    """
    Prosthetics & Orthotics
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Prosthetics_Orthotics = ServiceTypeCode("585")
    """
    Home Medicine Review
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    HomeMedicineReview = ServiceTypeCode("589")
    """
    GPAH - Medical
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    GPAH_Medical = ServiceTypeCode("590")
    """
    Music Therapy
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    MusicTherapy = ServiceTypeCode("591")
    """
    Falls Prevention
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    FallsPrevention = ServiceTypeCode("593")
    """
    Accommodation/Tenancy
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Accommodation_Tenancy = ServiceTypeCode("599")
    """
    Assess-Skill, Ability, Needs
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Assess_Skill_Ability_Needs = ServiceTypeCode("600")
    """
    Assist Access/Maintain Employ
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    AssistAccess_MaintainEmploy = ServiceTypeCode("601")
    """
    Assist Prod-Pers Care/Safety
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    AssistProd_PersCare_Safety = ServiceTypeCode("602")
    """
    Assist-Integrate School/Ed
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Assist_IntegrateSchool_Ed = ServiceTypeCode("603")
    """
    Assist-Life Stage, Transition
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Assist_LifeStage_Transition = ServiceTypeCode("604")
    """
    Assist-Personal Activities
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Assist_PersonalActivities = ServiceTypeCode("605")
    """
    Assist-Travel/Transport
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Assist_Travel_Transport = ServiceTypeCode("606")
    """
    Assistive Equip-General Tasks
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    AssistiveEquip_GeneralTasks = ServiceTypeCode("607")
    """
    Assistive Equip-Recreation
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    AssistiveEquip_Recreation = ServiceTypeCode("608")
    """
    Assistive Prod-Household Task
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    AssistiveProd_HouseholdTask = ServiceTypeCode("609")
    """
    Behavior Support
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    BehaviorSupport = ServiceTypeCode("610")
    """
    Comms & Info Equipment
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Comms_InfoEquipment = ServiceTypeCode("611")
    """
    Community Nursing Care
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    CommunityNursingCare = ServiceTypeCode("612")
    """
    Daily Tasks/Shared Living
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    DailyTasks_SharedLiving = ServiceTypeCode("613")
    """
    Development-Life Skills
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Development_LifeSkills = ServiceTypeCode("614")
    """
    Early Childhood Supports
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    EarlyChildhoodSupports = ServiceTypeCode("615")
    """
    Equipment Special Assess Setup
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    EquipmentSpecialAssessSetup = ServiceTypeCode("616")
    """
    Hearing Equipment
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    HearingEquipment = ServiceTypeCode("617")
    """
    Home Modification
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    HomeModification = ServiceTypeCode("618")
    """
    Household Tasks
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    HouseholdTasks = ServiceTypeCode("619")
    """
    Interpret/Translate
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Interpret_Translate = ServiceTypeCode("620")
    """
    Other Innovative Supports
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    OtherInnovativeSupports = ServiceTypeCode("621")
    """
    Participate Community
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    ParticipateCommunity = ServiceTypeCode("622")
    """
    Personal Mobility Equipment
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PersonalMobilityEquipment = ServiceTypeCode("623")
    """
    Physical Wellbeing
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PhysicalWellbeing = ServiceTypeCode("624")
    """
    Plan Management
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    PlanManagement = ServiceTypeCode("625")
    """
    Therapeutic Supports
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    TherapeuticSupports = ServiceTypeCode("626")
    """
    Training-Travel Independence
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    Training_TravelIndependence = ServiceTypeCode("627")
    """
    Vehicle modifications
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    VehicleModifications = ServiceTypeCode("628")
    """
    Vision Equipment
    From: http://terminology.hl7.org/CodeSystem/service-type in valuesets.xml
    """
    VisionEquipment = ServiceTypeCode("629")
