from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class SignatureTypeCodesCode(GenericTypeCode):
    """
    SignatureTypeCodes
    From: urn:iso-astm:E1762-95:2013 in valuesets.xml
        The Digital Signature Purposes, an indication of the reason an entity signs a
    document. This is included in the signed information and can be used when
    determining accountability for various actions concerning the document.
    Examples include: author, transcriptionist/recorder, and witness.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    urn:iso-astm:E1762-95:2013
    """
    codeset: FhirUri = "urn:iso-astm:E1762-95:2013"


class SignatureTypeCodesCodeValues:
    """
    the signature of the primary or sole author of a health information document.
    There can be only one primary author of a health information document.
    From: urn:iso-astm:E1762-95:2013 in valuesets.xml
    """

    Author_sSignature = SignatureTypeCodesCode("1.2.840.10065.1.12.1.1")
    """
    the signature of a health information document coauthor. There can be multiple
    coauthors of a health information document.
    From: urn:iso-astm:E1762-95:2013 in valuesets.xml
    """
    Coauthor_sSignature = SignatureTypeCodesCode("1.2.840.10065.1.12.1.2")
    """
    the signature of an individual who is a participant in the health information
    document but is not an author or coauthor. (Example a surgeon who is required
    by institutional, regulatory, or legal rules to sign an operative report, but
    who was not involved in the authorship of that report.)
    From: urn:iso-astm:E1762-95:2013 in valuesets.xml
    """
    Co_participant_sSignature = SignatureTypeCodesCode("1.2.840.10065.1.12.1.3")
    """
    the signature of an individual who has transcribed a dictated document or
    recorded written text into a digital machine readable format.
    From: urn:iso-astm:E1762-95:2013 in valuesets.xml
    """
    Transcriptionist_RecorderSignature = SignatureTypeCodesCode(
        "1.2.840.10065.1.12.1.4"
    )
    """
    a signature verifying the information contained in a document. (Example a
    physician is required to countersign a verbal order that has previously been
    recorded in the medical record by a registered nurse who has carried out the
    verbal order.)
    From: urn:iso-astm:E1762-95:2013 in valuesets.xml
    """
    VerificationSignature = SignatureTypeCodesCode("1.2.840.10065.1.12.1.5")
    """
    a signature validating a health information document for inclusion in the
    patient record. (Example a medical student or resident is credentialed to
    perform history or physical examinations and to write progress notes. The
    attending physician signs the history and physical examination to validate the
    entry for inclusion in the patient's medical record.)
    From: urn:iso-astm:E1762-95:2013 in valuesets.xml
    """
    ValidationSignature = SignatureTypeCodesCode("1.2.840.10065.1.12.1.6")
    """
    the signature of an individual consenting to what is described in a health
    information document.
    From: urn:iso-astm:E1762-95:2013 in valuesets.xml
    """
    ConsentSignature = SignatureTypeCodesCode("1.2.840.10065.1.12.1.7")
    """
    the signature of a witness to any other signature.
    From: urn:iso-astm:E1762-95:2013 in valuesets.xml
    """
    SignatureWitnessSignature = SignatureTypeCodesCode("1.2.840.10065.1.12.1.8")
    """
    the signature of a witness to an event. (Example the witness has observed a
    procedure and is attesting to this fact.)
    From: urn:iso-astm:E1762-95:2013 in valuesets.xml
    """
    EventWitnessSignature = SignatureTypeCodesCode("1.2.840.10065.1.12.1.9")
    """
    the signature of an individual who has witnessed another individual who is
    known to them signing a document. (Example the identity witness is a notary
    public.)
    From: urn:iso-astm:E1762-95:2013 in valuesets.xml
    """
    IdentityWitnessSignature = SignatureTypeCodesCode("1.2.840.10065.1.12.1.10")
    """
    the signature of an individual who has witnessed the health care provider
    counselling a patient.
    From: urn:iso-astm:E1762-95:2013 in valuesets.xml
    """
    ConsentWitnessSignature = SignatureTypeCodesCode("1.2.840.10065.1.12.1.11")
    """
    the signature of an individual who has translated health care information
    during an event or the obtaining of consent to a treatment.
    From: urn:iso-astm:E1762-95:2013 in valuesets.xml
    """
    InterpreterSignature = SignatureTypeCodesCode("1.2.840.10065.1.12.1.12")
    """
    the signature of a person, device, or algorithm that has reviewed or filtered
    data for inclusion into the patient record. ( Examples: (1) a medical records
    clerk who scans a document for inclusion in the medical record, enters header
    information, or catalogues and classifies the data, or a combination thereof;
    (2) a gateway that receives data from another computer system and interprets
    that data or changes its format, or both, before entering it into the patient
    record.)
    From: urn:iso-astm:E1762-95:2013 in valuesets.xml
    """
    ReviewSignature = SignatureTypeCodesCode("1.2.840.10065.1.12.1.13")
    """
    the signature of an automated data source. (Examples: (1) the signature for an
    image that is generated by a device for inclusion in the patient record; (2)
    the signature for an ECG derived by an ECG system for inclusion in the patient
    record; (3) the data from a biomedical monitoring device or system that is for
    inclusion in the patient record.)
    From: urn:iso-astm:E1762-95:2013 in valuesets.xml
    """
    SourceSignature = SignatureTypeCodesCode("1.2.840.10065.1.12.1.14")
    """
    the signature on a new amended document of an individual who has corrected,
    edited, or amended an original health information document. An addendum
    signature can either be a signature type or a signature sub-type (see 8.1).
    Any document with an addendum signature shall have a companion document that
    is the original document with its original, unaltered content, and original
    signatures. The original document shall be referenced via an attribute in the
    new document, which contains, for example, the digest of the old document.
    Whether the original, unaltered, document is always displayed with the
    addended document is a local matter, but the original, unaltered, document
    must remain as part of the patient record and be retrievable on demand.
    From: urn:iso-astm:E1762-95:2013 in valuesets.xml
    """
    AddendumSignature = SignatureTypeCodesCode("1.2.840.10065.1.12.1.15")
    """
    the signature on an original document of an individual who has generated a new
    amended document. This (original) document shall reference the new document
    via an additional signature purpose. This is the inverse of an addendum
    signature and provides a pointer from the original to the amended document.
    From: urn:iso-astm:E1762-95:2013 in valuesets.xml
    """
    ModificationSignature = SignatureTypeCodesCode("1.2.840.10065.1.12.1.16")
    """
    the signature of an individual who is certifying that the document is
    invalidated by an error(s), or is placed in the wrong chart. An administrative
    (error/edit) signature must include an addendum to the document and therefore
    shall have an addendum signature sub-type (see 8.1). This signature is
    reserved for the highest health information system administrative
    classification, since it is a statement that the entire document is
    invalidated by the error and that the document should no longer be used for
    patient care, although for legal reasons the document must remain part of the
    permanent patient record.
    From: urn:iso-astm:E1762-95:2013 in valuesets.xml
    """
    Administrative_Error_Edit_Signature = SignatureTypeCodesCode(
        "1.2.840.10065.1.12.1.17"
    )
    """
    the signature by an entity or device trusted to provide accurate timestamps.
    This timestamp might be provided, for example, in the signature time
    attribute.
    From: urn:iso-astm:E1762-95:2013 in valuesets.xml
    """
    TimestampSignature = SignatureTypeCodesCode("1.2.840.10065.1.12.1.18")
