from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class SPDXLicenseCode(GenericTypeCode):
    """
    SPDXLicense
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
        The license that applies to an Implementation Guide (using an SPDX license
    Identifiers, or 'not-open-source'). The binding is required but new SPDX
    license Identifiers are allowed to be used (https://spdx.org/licenses/).
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/spdx-license
    """
    codeset: FhirUri = "http://hl7.org/fhir/spdx-license"


class SPDXLicenseCodeValues:
    """
    Not an open source license.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """

    NotOpenSource = SPDXLicenseCode("not-open-source")
    """
    BSD Zero Clause License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    BSDZeroClauseLicense = SPDXLicenseCode("0BSD")
    """
    Attribution Assurance License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    AttributionAssuranceLicense = SPDXLicenseCode("AAL")
    """
    Abstyles License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    AbstylesLicense = SPDXLicenseCode("Abstyles")
    """
    Adobe Systems Incorporated Source Code License Agreement.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    AdobeSystemsIncorporatedSourceCodeLicenseAgreement = SPDXLicenseCode("Adobe-2006")
    """
    Adobe Glyph List License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    AdobeGlyphListLicense = SPDXLicenseCode("Adobe-Glyph")
    """
    Amazon Digital Services License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    AmazonDigitalServicesLicense = SPDXLicenseCode("ADSL")
    """
    Academic Free License v1.1.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    AcademicFreeLicenseV1_1 = SPDXLicenseCode("AFL-1.1")
    """
    Academic Free License v1.2.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    AcademicFreeLicenseV1_2 = SPDXLicenseCode("AFL-1.2")
    """
    Academic Free License v2.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    AcademicFreeLicenseV2_0 = SPDXLicenseCode("AFL-2.0")
    """
    Academic Free License v2.1.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    AcademicFreeLicenseV2_1 = SPDXLicenseCode("AFL-2.1")
    """
    Academic Free License v3.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    AcademicFreeLicenseV3_0 = SPDXLicenseCode("AFL-3.0")
    """
    Afmparse License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    AfmparseLicense = SPDXLicenseCode("Afmparse")
    """
    Affero General Public License v1.0 only.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    AfferoGeneralPublicLicenseV1_0Only = SPDXLicenseCode("AGPL-1.0-only")
    """
    Affero General Public License v1.0 or later.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    AfferoGeneralPublicLicenseV1_0OrLater = SPDXLicenseCode("AGPL-1.0-or-later")
    """
    GNU Affero General Public License v3.0 only.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    GNUAfferoGeneralPublicLicenseV3_0Only = SPDXLicenseCode("AGPL-3.0-only")
    """
    GNU Affero General Public License v3.0 or later.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    GNUAfferoGeneralPublicLicenseV3_0OrLater = SPDXLicenseCode("AGPL-3.0-or-later")
    """
    Aladdin Free Public License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    AladdinFreePublicLicense = SPDXLicenseCode("Aladdin")
    """
    AMD's plpa_map.c License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    AMD_sPlpa_map_cLicense = SPDXLicenseCode("AMDPLPA")
    """
    Apple MIT License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    AppleMITLicense = SPDXLicenseCode("AML")
    """
    Academy of Motion Picture Arts and Sciences BSD.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    AcademyOfMotionPictureArtsAndSciencesBSD = SPDXLicenseCode("AMPAS")
    """
    ANTLR Software Rights Notice.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    ANTLRSoftwareRightsNotice = SPDXLicenseCode("ANTLR-PD")
    """
    Apache License 1.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    ApacheLicense1_0 = SPDXLicenseCode("Apache-1.0")
    """
    Apache License 1.1.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    ApacheLicense1_1 = SPDXLicenseCode("Apache-1.1")
    """
    Apache License 2.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    ApacheLicense2_0 = SPDXLicenseCode("Apache-2.0")
    """
    Adobe Postscript AFM License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    AdobePostscriptAFMLicense = SPDXLicenseCode("APAFML")
    """
    Adaptive Public License 1.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    AdaptivePublicLicense1_0 = SPDXLicenseCode("APL-1.0")
    """
    Apple Public Source License 1.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    ApplePublicSourceLicense1_0 = SPDXLicenseCode("APSL-1.0")
    """
    Apple Public Source License 1.1.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    ApplePublicSourceLicense1_1 = SPDXLicenseCode("APSL-1.1")
    """
    Apple Public Source License 1.2.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    ApplePublicSourceLicense1_2 = SPDXLicenseCode("APSL-1.2")
    """
    Apple Public Source License 2.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    ApplePublicSourceLicense2_0 = SPDXLicenseCode("APSL-2.0")
    """
    Artistic License 1.0 w/clause 8.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    ArtisticLicense1_0W_clause8 = SPDXLicenseCode("Artistic-1.0-cl8")
    """
    Artistic License 1.0 (Perl).
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    ArtisticLicense1_0_Perl_ = SPDXLicenseCode("Artistic-1.0-Perl")
    """
    Artistic License 1.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    ArtisticLicense1_0 = SPDXLicenseCode("Artistic-1.0")
    """
    Artistic License 2.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    ArtisticLicense2_0 = SPDXLicenseCode("Artistic-2.0")
    """
    Bahyph License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    BahyphLicense = SPDXLicenseCode("Bahyph")
    """
    Barr License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    BarrLicense = SPDXLicenseCode("Barr")
    """
    Beerware License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    BeerwareLicense = SPDXLicenseCode("Beerware")
    """
    BitTorrent Open Source License v1.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    BitTorrentOpenSourceLicenseV1_0 = SPDXLicenseCode("BitTorrent-1.0")
    """
    BitTorrent Open Source License v1.1.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    BitTorrentOpenSourceLicenseV1_1 = SPDXLicenseCode("BitTorrent-1.1")
    """
    Borceux license.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    BorceuxLicense = SPDXLicenseCode("Borceux")
    """
    BSD 1-Clause License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    BSD1_ClauseLicense = SPDXLicenseCode("BSD-1-Clause")
    """
    BSD 2-Clause FreeBSD License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    BSD2_ClauseFreeBSDLicense = SPDXLicenseCode("BSD-2-Clause-FreeBSD")
    """
    BSD 2-Clause NetBSD License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    BSD2_ClauseNetBSDLicense = SPDXLicenseCode("BSD-2-Clause-NetBSD")
    """
    BSD-2-Clause Plus Patent License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    BSD_2_ClausePlusPatentLicense = SPDXLicenseCode("BSD-2-Clause-Patent")
    """
    BSD 2-Clause "Simplified" License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    BSD2_Clause_Simplified_License = SPDXLicenseCode("BSD-2-Clause")
    """
    BSD with attribution.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    BSDWithAttribution = SPDXLicenseCode("BSD-3-Clause-Attribution")
    """
    BSD 3-Clause Clear License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    BSD3_ClauseClearLicense = SPDXLicenseCode("BSD-3-Clause-Clear")
    """
    Lawrence Berkeley National Labs BSD variant license.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    LawrenceBerkeleyNationalLabsBSDVariantLicense = SPDXLicenseCode("BSD-3-Clause-LBNL")
    """
    BSD 3-Clause No Nuclear License 2014.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    BSD3_ClauseNoNuclearLicense2014 = SPDXLicenseCode(
        "BSD-3-Clause-No-Nuclear-License-2014"
    )
    """
    BSD 3-Clause No Nuclear License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    BSD3_ClauseNoNuclearLicense = SPDXLicenseCode("BSD-3-Clause-No-Nuclear-License")
    """
    BSD 3-Clause No Nuclear Warranty.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    BSD3_ClauseNoNuclearWarranty = SPDXLicenseCode("BSD-3-Clause-No-Nuclear-Warranty")
    """
    BSD 3-Clause "New" or "Revised" License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    BSD3_Clause_New_Or_Revised_License = SPDXLicenseCode("BSD-3-Clause")
    """
    BSD-4-Clause (University of California-Specific).
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    BSD_4_Clause_UniversityOfCalifornia_Specific_ = SPDXLicenseCode("BSD-4-Clause-UC")
    """
    BSD 4-Clause "Original" or "Old" License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    BSD4_Clause_Original_Or_Old_License = SPDXLicenseCode("BSD-4-Clause")
    """
    BSD Protection License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    BSDProtectionLicense = SPDXLicenseCode("BSD-Protection")
    """
    BSD Source Code Attribution.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    BSDSourceCodeAttribution = SPDXLicenseCode("BSD-Source-Code")
    """
    Boost Software License 1.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    BoostSoftwareLicense1_0 = SPDXLicenseCode("BSL-1.0")
    """
    bzip2 and libbzip2 License v1.0.5.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    Bzip2AndLibbzip2LicenseV1_0_5 = SPDXLicenseCode("bzip2-1.0.5")
    """
    bzip2 and libbzip2 License v1.0.6.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    Bzip2AndLibbzip2LicenseV1_0_6 = SPDXLicenseCode("bzip2-1.0.6")
    """
    Caldera License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CalderaLicense = SPDXLicenseCode("Caldera")
    """
    Computer Associates Trusted Open Source License 1.1.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    ComputerAssociatesTrustedOpenSourceLicense1_1 = SPDXLicenseCode("CATOSL-1.1")
    """
    Creative Commons Attribution 1.0 Generic.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CreativeCommonsAttribution1_0Generic = SPDXLicenseCode("CC-BY-1.0")
    """
    Creative Commons Attribution 2.0 Generic.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CreativeCommonsAttribution2_0Generic = SPDXLicenseCode("CC-BY-2.0")
    """
    Creative Commons Attribution 2.5 Generic.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CreativeCommonsAttribution2_5Generic = SPDXLicenseCode("CC-BY-2.5")
    """
    Creative Commons Attribution 3.0 Unported.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CreativeCommonsAttribution3_0Unported = SPDXLicenseCode("CC-BY-3.0")
    """
    Creative Commons Attribution 4.0 International.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CreativeCommonsAttribution4_0International = SPDXLicenseCode("CC-BY-4.0")
    """
    Creative Commons Attribution Non Commercial 1.0 Generic.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CreativeCommonsAttributionNonCommercial1_0Generic = SPDXLicenseCode("CC-BY-NC-1.0")
    """
    Creative Commons Attribution Non Commercial 2.0 Generic.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CreativeCommonsAttributionNonCommercial2_0Generic = SPDXLicenseCode("CC-BY-NC-2.0")
    """
    Creative Commons Attribution Non Commercial 2.5 Generic.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CreativeCommonsAttributionNonCommercial2_5Generic = SPDXLicenseCode("CC-BY-NC-2.5")
    """
    Creative Commons Attribution Non Commercial 3.0 Unported.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CreativeCommonsAttributionNonCommercial3_0Unported = SPDXLicenseCode("CC-BY-NC-3.0")
    """
    Creative Commons Attribution Non Commercial 4.0 International.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CreativeCommonsAttributionNonCommercial4_0International = SPDXLicenseCode(
        "CC-BY-NC-4.0"
    )
    """
    Creative Commons Attribution Non Commercial No Derivatives 1.0 Generic.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CreativeCommonsAttributionNonCommercialNoDerivatives1_0Generic = SPDXLicenseCode(
        "CC-BY-NC-ND-1.0"
    )
    """
    Creative Commons Attribution Non Commercial No Derivatives 2.0 Generic.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CreativeCommonsAttributionNonCommercialNoDerivatives2_0Generic = SPDXLicenseCode(
        "CC-BY-NC-ND-2.0"
    )
    """
    Creative Commons Attribution Non Commercial No Derivatives 2.5 Generic.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CreativeCommonsAttributionNonCommercialNoDerivatives2_5Generic = SPDXLicenseCode(
        "CC-BY-NC-ND-2.5"
    )
    """
    Creative Commons Attribution Non Commercial No Derivatives 3.0 Unported.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CreativeCommonsAttributionNonCommercialNoDerivatives3_0Unported = SPDXLicenseCode(
        "CC-BY-NC-ND-3.0"
    )
    """
    Creative Commons Attribution Non Commercial No Derivatives 4.0 International.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CreativeCommonsAttributionNonCommercialNoDerivatives4_0International = (
        SPDXLicenseCode("CC-BY-NC-ND-4.0")
    )
    """
    Creative Commons Attribution Non Commercial Share Alike 1.0 Generic.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CreativeCommonsAttributionNonCommercialShareAlike1_0Generic = SPDXLicenseCode(
        "CC-BY-NC-SA-1.0"
    )
    """
    Creative Commons Attribution Non Commercial Share Alike 2.0 Generic.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CreativeCommonsAttributionNonCommercialShareAlike2_0Generic = SPDXLicenseCode(
        "CC-BY-NC-SA-2.0"
    )
    """
    Creative Commons Attribution Non Commercial Share Alike 2.5 Generic.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CreativeCommonsAttributionNonCommercialShareAlike2_5Generic = SPDXLicenseCode(
        "CC-BY-NC-SA-2.5"
    )
    """
    Creative Commons Attribution Non Commercial Share Alike 3.0 Unported.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CreativeCommonsAttributionNonCommercialShareAlike3_0Unported = SPDXLicenseCode(
        "CC-BY-NC-SA-3.0"
    )
    """
    Creative Commons Attribution Non Commercial Share Alike 4.0 International.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CreativeCommonsAttributionNonCommercialShareAlike4_0International = SPDXLicenseCode(
        "CC-BY-NC-SA-4.0"
    )
    """
    Creative Commons Attribution No Derivatives 1.0 Generic.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CreativeCommonsAttributionNoDerivatives1_0Generic = SPDXLicenseCode("CC-BY-ND-1.0")
    """
    Creative Commons Attribution No Derivatives 2.0 Generic.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CreativeCommonsAttributionNoDerivatives2_0Generic = SPDXLicenseCode("CC-BY-ND-2.0")
    """
    Creative Commons Attribution No Derivatives 2.5 Generic.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CreativeCommonsAttributionNoDerivatives2_5Generic = SPDXLicenseCode("CC-BY-ND-2.5")
    """
    Creative Commons Attribution No Derivatives 3.0 Unported.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CreativeCommonsAttributionNoDerivatives3_0Unported = SPDXLicenseCode("CC-BY-ND-3.0")
    """
    Creative Commons Attribution No Derivatives 4.0 International.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CreativeCommonsAttributionNoDerivatives4_0International = SPDXLicenseCode(
        "CC-BY-ND-4.0"
    )
    """
    Creative Commons Attribution Share Alike 1.0 Generic.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CreativeCommonsAttributionShareAlike1_0Generic = SPDXLicenseCode("CC-BY-SA-1.0")
    """
    Creative Commons Attribution Share Alike 2.0 Generic.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CreativeCommonsAttributionShareAlike2_0Generic = SPDXLicenseCode("CC-BY-SA-2.0")
    """
    Creative Commons Attribution Share Alike 2.5 Generic.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CreativeCommonsAttributionShareAlike2_5Generic = SPDXLicenseCode("CC-BY-SA-2.5")
    """
    Creative Commons Attribution Share Alike 3.0 Unported.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CreativeCommonsAttributionShareAlike3_0Unported = SPDXLicenseCode("CC-BY-SA-3.0")
    """
    Creative Commons Attribution Share Alike 4.0 International.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CreativeCommonsAttributionShareAlike4_0International = SPDXLicenseCode(
        "CC-BY-SA-4.0"
    )
    """
    Creative Commons Zero v1.0 Universal.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CreativeCommonsZeroV1_0Universal = SPDXLicenseCode("CC0-1.0")
    """
    Common Development and Distribution License 1.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CommonDevelopmentAndDistributionLicense1_0 = SPDXLicenseCode("CDDL-1.0")
    """
    Common Development and Distribution License 1.1.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CommonDevelopmentAndDistributionLicense1_1 = SPDXLicenseCode("CDDL-1.1")
    """
    Community Data License Agreement Permissive 1.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CommunityDataLicenseAgreementPermissive1_0 = SPDXLicenseCode("CDLA-Permissive-1.0")
    """
    Community Data License Agreement Sharing 1.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CommunityDataLicenseAgreementSharing1_0 = SPDXLicenseCode("CDLA-Sharing-1.0")
    """
    CeCILL Free Software License Agreement v1.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CeCILLFreeSoftwareLicenseAgreementV1_0 = SPDXLicenseCode("CECILL-1.0")
    """
    CeCILL Free Software License Agreement v1.1.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CeCILLFreeSoftwareLicenseAgreementV1_1 = SPDXLicenseCode("CECILL-1.1")
    """
    CeCILL Free Software License Agreement v2.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CeCILLFreeSoftwareLicenseAgreementV2_0 = SPDXLicenseCode("CECILL-2.0")
    """
    CeCILL Free Software License Agreement v2.1.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CeCILLFreeSoftwareLicenseAgreementV2_1 = SPDXLicenseCode("CECILL-2.1")
    """
    CeCILL-B Free Software License Agreement.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CeCILL_BFreeSoftwareLicenseAgreement = SPDXLicenseCode("CECILL-B")
    """
    CeCILL-C Free Software License Agreement.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CeCILL_CFreeSoftwareLicenseAgreement = SPDXLicenseCode("CECILL-C")
    """
    Clarified Artistic License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    ClarifiedArtisticLicense = SPDXLicenseCode("ClArtistic")
    """
    CNRI Jython License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CNRIJythonLicense = SPDXLicenseCode("CNRI-Jython")
    """
    CNRI Python Open Source GPL Compatible License Agreement.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CNRIPythonOpenSourceGPLCompatibleLicenseAgreement = SPDXLicenseCode(
        "CNRI-Python-GPL-Compatible"
    )
    """
    CNRI Python License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CNRIPythonLicense = SPDXLicenseCode("CNRI-Python")
    """
    Condor Public License v1.1.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CondorPublicLicenseV1_1 = SPDXLicenseCode("Condor-1.1")
    """
    Common Public Attribution License 1.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CommonPublicAttributionLicense1_0 = SPDXLicenseCode("CPAL-1.0")
    """
    Common Public License 1.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CommonPublicLicense1_0 = SPDXLicenseCode("CPL-1.0")
    """
    Code Project Open License 1.02.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CodeProjectOpenLicense1_02 = SPDXLicenseCode("CPOL-1.02")
    """
    Crossword License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CrosswordLicense = SPDXLicenseCode("Crossword")
    """
    CrystalStacker License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CrystalStackerLicense = SPDXLicenseCode("CrystalStacker")
    """
    CUA Office Public License v1.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CUAOfficePublicLicenseV1_0 = SPDXLicenseCode("CUA-OPL-1.0")
    """
    Cube License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CubeLicense = SPDXLicenseCode("Cube")
    """
    curl License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CurlLicense = SPDXLicenseCode("curl")
    """
    Deutsche Freie Software Lizenz.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    DeutscheFreieSoftwareLizenz = SPDXLicenseCode("D-FSL-1.0")
    """
    diffmark license.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    DiffmarkLicense = SPDXLicenseCode("diffmark")
    """
    DOC License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    DOCLicense = SPDXLicenseCode("DOC")
    """
    Dotseqn License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    DotseqnLicense = SPDXLicenseCode("Dotseqn")
    """
    DSDP License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    DSDPLicense = SPDXLicenseCode("DSDP")
    """
    dvipdfm License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    DvipdfmLicense = SPDXLicenseCode("dvipdfm")
    """
    Educational Community License v1.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    EducationalCommunityLicenseV1_0 = SPDXLicenseCode("ECL-1.0")
    """
    Educational Community License v2.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    EducationalCommunityLicenseV2_0 = SPDXLicenseCode("ECL-2.0")
    """
    Eiffel Forum License v1.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    EiffelForumLicenseV1_0 = SPDXLicenseCode("EFL-1.0")
    """
    Eiffel Forum License v2.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    EiffelForumLicenseV2_0 = SPDXLicenseCode("EFL-2.0")
    """
    eGenix.com Public License 1.1.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    EGenix_comPublicLicense1_1_0 = SPDXLicenseCode("eGenix")
    """
    Entessa Public License v1.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    EntessaPublicLicenseV1_0 = SPDXLicenseCode("Entessa")
    """
    Eclipse Public License 1.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    EclipsePublicLicense1_0 = SPDXLicenseCode("EPL-1.0")
    """
    Eclipse Public License 2.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    EclipsePublicLicense2_0 = SPDXLicenseCode("EPL-2.0")
    """
    Erlang Public License v1.1.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    ErlangPublicLicenseV1_1 = SPDXLicenseCode("ErlPL-1.1")
    """
    EU DataGrid Software License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    EUDataGridSoftwareLicense = SPDXLicenseCode("EUDatagrid")
    """
    European Union Public License 1.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    EuropeanUnionPublicLicense1_0 = SPDXLicenseCode("EUPL-1.0")
    """
    European Union Public License 1.1.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    EuropeanUnionPublicLicense1_1 = SPDXLicenseCode("EUPL-1.1")
    """
    European Union Public License 1.2.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    EuropeanUnionPublicLicense1_2 = SPDXLicenseCode("EUPL-1.2")
    """
    Eurosym License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    EurosymLicense = SPDXLicenseCode("Eurosym")
    """
    Fair License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    FairLicense = SPDXLicenseCode("Fair")
    """
    Frameworx Open License 1.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    FrameworxOpenLicense1_0 = SPDXLicenseCode("Frameworx-1.0")
    """
    FreeImage Public License v1.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    FreeImagePublicLicenseV1_0 = SPDXLicenseCode("FreeImage")
    """
    FSF All Permissive License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    FSFAllPermissiveLicense = SPDXLicenseCode("FSFAP")
    """
    FSF Unlimited License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    FSFUnlimitedLicense = SPDXLicenseCode("FSFUL")
    """
    FSF Unlimited License (with License Retention).
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    FSFUnlimitedLicense_withLicenseRetention_ = SPDXLicenseCode("FSFULLR")
    """
    Freetype Project License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    FreetypeProjectLicense = SPDXLicenseCode("FTL")
    """
    GNU Free Documentation License v1.1 only.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    GNUFreeDocumentationLicenseV1_1Only = SPDXLicenseCode("GFDL-1.1-only")
    """
    GNU Free Documentation License v1.1 or later.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    GNUFreeDocumentationLicenseV1_1OrLater = SPDXLicenseCode("GFDL-1.1-or-later")
    """
    GNU Free Documentation License v1.2 only.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    GNUFreeDocumentationLicenseV1_2Only = SPDXLicenseCode("GFDL-1.2-only")
    """
    GNU Free Documentation License v1.2 or later.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    GNUFreeDocumentationLicenseV1_2OrLater = SPDXLicenseCode("GFDL-1.2-or-later")
    """
    GNU Free Documentation License v1.3 only.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    GNUFreeDocumentationLicenseV1_3Only = SPDXLicenseCode("GFDL-1.3-only")
    """
    GNU Free Documentation License v1.3 or later.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    GNUFreeDocumentationLicenseV1_3OrLater = SPDXLicenseCode("GFDL-1.3-or-later")
    """
    Giftware License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    GiftwareLicense = SPDXLicenseCode("Giftware")
    """
    GL2PS License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    GL2PSLicense = SPDXLicenseCode("GL2PS")
    """
    3dfx Glide License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    _3dfxGlideLicense = SPDXLicenseCode("Glide")
    """
    Glulxe License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    GlulxeLicense = SPDXLicenseCode("Glulxe")
    """
    gnuplot License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    GnuplotLicense = SPDXLicenseCode("gnuplot")
    """
    GNU General Public License v1.0 only.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    GNUGeneralPublicLicenseV1_0Only = SPDXLicenseCode("GPL-1.0-only")
    """
    GNU General Public License v1.0 or later.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    GNUGeneralPublicLicenseV1_0OrLater = SPDXLicenseCode("GPL-1.0-or-later")
    """
    GNU General Public License v2.0 only.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    GNUGeneralPublicLicenseV2_0Only = SPDXLicenseCode("GPL-2.0-only")
    """
    GNU General Public License v2.0 or later.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    GNUGeneralPublicLicenseV2_0OrLater = SPDXLicenseCode("GPL-2.0-or-later")
    """
    GNU General Public License v3.0 only.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    GNUGeneralPublicLicenseV3_0Only = SPDXLicenseCode("GPL-3.0-only")
    """
    GNU General Public License v3.0 or later.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    GNUGeneralPublicLicenseV3_0OrLater = SPDXLicenseCode("GPL-3.0-or-later")
    """
    gSOAP Public License v1.3b.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    GSOAPPublicLicenseV1_3b = SPDXLicenseCode("gSOAP-1.3b")
    """
    Haskell Language Report License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    HaskellLanguageReportLicense = SPDXLicenseCode("HaskellReport")
    """
    Historical Permission Notice and Disclaimer.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    HistoricalPermissionNoticeAndDisclaimer = SPDXLicenseCode("HPND")
    """
    IBM PowerPC Initialization and Boot Software.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    IBMPowerPCInitializationAndBootSoftware = SPDXLicenseCode("IBM-pibs")
    """
    ICU License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    ICULicense = SPDXLicenseCode("ICU")
    """
    Independent JPEG Group License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    IndependentJPEGGroupLicense = SPDXLicenseCode("IJG")
    """
    ImageMagick License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    ImageMagickLicense = SPDXLicenseCode("ImageMagick")
    """
    iMatix Standard Function Library Agreement.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    IMatixStandardFunctionLibraryAgreement = SPDXLicenseCode("iMatix")
    """
    Imlib2 License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    Imlib2License = SPDXLicenseCode("Imlib2")
    """
    Info-ZIP License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    Info_ZIPLicense = SPDXLicenseCode("Info-ZIP")
    """
    Intel ACPI Software License Agreement.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    IntelACPISoftwareLicenseAgreement = SPDXLicenseCode("Intel-ACPI")
    """
    Intel Open Source License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    IntelOpenSourceLicense = SPDXLicenseCode("Intel")
    """
    Interbase Public License v1.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    InterbasePublicLicenseV1_0 = SPDXLicenseCode("Interbase-1.0")
    """
    IPA Font License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    IPAFontLicense = SPDXLicenseCode("IPA")
    """
    IBM Public License v1.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    IBMPublicLicenseV1_0 = SPDXLicenseCode("IPL-1.0")
    """
    ISC License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    ISCLicense = SPDXLicenseCode("ISC")
    """
    JasPer License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    JasPerLicense = SPDXLicenseCode("JasPer-2.0")
    """
    JSON License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    JSONLicense = SPDXLicenseCode("JSON")
    """
    Licence Art Libre 1.2.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    LicenceArtLibre1_2 = SPDXLicenseCode("LAL-1.2")
    """
    Licence Art Libre 1.3.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    LicenceArtLibre1_3 = SPDXLicenseCode("LAL-1.3")
    """
    Latex2e License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    Latex2eLicense = SPDXLicenseCode("Latex2e")
    """
    Leptonica License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    LeptonicaLicense = SPDXLicenseCode("Leptonica")
    """
    GNU Library General Public License v2 only.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    GNULibraryGeneralPublicLicenseV2Only = SPDXLicenseCode("LGPL-2.0-only")
    """
    GNU Library General Public License v2 or later.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    GNULibraryGeneralPublicLicenseV2OrLater = SPDXLicenseCode("LGPL-2.0-or-later")
    """
    GNU Lesser General Public License v2.1 only.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    GNULesserGeneralPublicLicenseV2_1Only = SPDXLicenseCode("LGPL-2.1-only")
    """
    GNU Lesser General Public License v2.1 or later.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    GNULesserGeneralPublicLicenseV2_1OrLater = SPDXLicenseCode("LGPL-2.1-or-later")
    """
    GNU Lesser General Public License v3.0 only.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    GNULesserGeneralPublicLicenseV3_0Only = SPDXLicenseCode("LGPL-3.0-only")
    """
    GNU Lesser General Public License v3.0 or later.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    GNULesserGeneralPublicLicenseV3_0OrLater = SPDXLicenseCode("LGPL-3.0-or-later")
    """
    Lesser General Public License For Linguistic Resources.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    LesserGeneralPublicLicenseForLinguisticResources = SPDXLicenseCode("LGPLLR")
    """
    libpng License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    LibpngLicense = SPDXLicenseCode("Libpng")
    """
    libtiff License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    LibtiffLicense = SPDXLicenseCode("libtiff")
    """
    Licence Libre du Québec – Permissive version 1.1.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    LicenceLibreDuQu_bec_PermissiveVersion1_1 = SPDXLicenseCode("LiLiQ-P-1.1")
    """
    Licence Libre du Québec – Réciprocité version 1.1.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    LicenceLibreDuQu_bec_R_ciprocit_Version1_1 = SPDXLicenseCode("LiLiQ-R-1.1")
    """
    Licence Libre du Québec – Réciprocité forte version 1.1.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    LicenceLibreDuQu_bec_R_ciprocit_ForteVersion1_1 = SPDXLicenseCode("LiLiQ-Rplus-1.1")
    """
    Linux Kernel Variant of OpenIB.org license.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    LinuxKernelVariantOfOpenIB_orgLicense = SPDXLicenseCode("Linux-OpenIB")
    """
    Lucent Public License Version 1.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    LucentPublicLicenseVersion1_0 = SPDXLicenseCode("LPL-1.0")
    """
    Lucent Public License v1.02.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    LucentPublicLicenseV1_02 = SPDXLicenseCode("LPL-1.02")
    """
    LaTeX Project Public License v1.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    LaTeXProjectPublicLicenseV1_0 = SPDXLicenseCode("LPPL-1.0")
    """
    LaTeX Project Public License v1.1.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    LaTeXProjectPublicLicenseV1_1 = SPDXLicenseCode("LPPL-1.1")
    """
    LaTeX Project Public License v1.2.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    LaTeXProjectPublicLicenseV1_2 = SPDXLicenseCode("LPPL-1.2")
    """
    LaTeX Project Public License v1.3a.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    LaTeXProjectPublicLicenseV1_3a = SPDXLicenseCode("LPPL-1.3a")
    """
    LaTeX Project Public License v1.3c.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    LaTeXProjectPublicLicenseV1_3c = SPDXLicenseCode("LPPL-1.3c")
    """
    MakeIndex License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    MakeIndexLicense = SPDXLicenseCode("MakeIndex")
    """
    MirOS License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    MirOSLicense = SPDXLicenseCode("MirOS")
    """
    MIT No Attribution.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    MITNoAttribution = SPDXLicenseCode("MIT-0")
    """
    Enlightenment License (e16).
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    EnlightenmentLicense_e16_ = SPDXLicenseCode("MIT-advertising")
    """
    CMU License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    CMULicense = SPDXLicenseCode("MIT-CMU")
    """
    enna License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    EnnaLicense = SPDXLicenseCode("MIT-enna")
    """
    feh License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    FehLicense = SPDXLicenseCode("MIT-feh")
    """
    MIT License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    MITLicense = SPDXLicenseCode("MIT")
    """
    MIT +no-false-attribs license.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    MIT_no_false_attribsLicense = SPDXLicenseCode("MITNFA")
    """
    Motosoto License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    MotosotoLicense = SPDXLicenseCode("Motosoto")
    """
    mpich2 License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    Mpich2License = SPDXLicenseCode("mpich2")
    """
    Mozilla Public License 1.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    MozillaPublicLicense1_0 = SPDXLicenseCode("MPL-1.0")
    """
    Mozilla Public License 1.1.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    MozillaPublicLicense1_1 = SPDXLicenseCode("MPL-1.1")
    """
    Mozilla Public License 2.0 (no copyleft exception).
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    MozillaPublicLicense2_0_noCopyleftException_ = SPDXLicenseCode(
        "MPL-2.0-no-copyleft-exception"
    )
    """
    Mozilla Public License 2.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    MozillaPublicLicense2_0 = SPDXLicenseCode("MPL-2.0")
    """
    Microsoft Public License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    MicrosoftPublicLicense = SPDXLicenseCode("MS-PL")
    """
    Microsoft Reciprocal License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    MicrosoftReciprocalLicense = SPDXLicenseCode("MS-RL")
    """
    Matrix Template Library License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    MatrixTemplateLibraryLicense = SPDXLicenseCode("MTLL")
    """
    Multics License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    MulticsLicense = SPDXLicenseCode("Multics")
    """
    Mup License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    MupLicense = SPDXLicenseCode("Mup")
    """
    NASA Open Source Agreement 1.3.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    NASAOpenSourceAgreement1_3 = SPDXLicenseCode("NASA-1.3")
    """
    Naumen Public License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    NaumenPublicLicense = SPDXLicenseCode("Naumen")
    """
    Net Boolean Public License v1.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    NetBooleanPublicLicenseV1 = SPDXLicenseCode("NBPL-1.0")
    """
    University of Illinois/NCSA Open Source License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    UniversityOfIllinois_NCSAOpenSourceLicense = SPDXLicenseCode("NCSA")
    """
    Net-SNMP License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    Net_SNMPLicense = SPDXLicenseCode("Net-SNMP")
    """
    NetCDF license.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    NetCDFLicense = SPDXLicenseCode("NetCDF")
    """
    Newsletr License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    NewsletrLicense = SPDXLicenseCode("Newsletr")
    """
    Nethack General Public License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    NethackGeneralPublicLicense = SPDXLicenseCode("NGPL")
    """
    Norwegian Licence for Open Government Data.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    NorwegianLicenceForOpenGovernmentData = SPDXLicenseCode("NLOD-1.0")
    """
    No Limit Public License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    NoLimitPublicLicense = SPDXLicenseCode("NLPL")
    """
    Nokia Open Source License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    NokiaOpenSourceLicense = SPDXLicenseCode("Nokia")
    """
    Netizen Open Source License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    NetizenOpenSourceLicense = SPDXLicenseCode("NOSL")
    """
    Noweb License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    NowebLicense = SPDXLicenseCode("Noweb")
    """
    Netscape Public License v1.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    NetscapePublicLicenseV1_0 = SPDXLicenseCode("NPL-1.0")
    """
    Netscape Public License v1.1.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    NetscapePublicLicenseV1_1 = SPDXLicenseCode("NPL-1.1")
    """
    Non-Profit Open Software License 3.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    Non_ProfitOpenSoftwareLicense3_0 = SPDXLicenseCode("NPOSL-3.0")
    """
    NRL License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    NRLLicense = SPDXLicenseCode("NRL")
    """
    NTP License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    NTPLicense = SPDXLicenseCode("NTP")
    """
    Open CASCADE Technology Public License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    OpenCASCADETechnologyPublicLicense = SPDXLicenseCode("OCCT-PL")
    """
    OCLC Research Public License 2.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    OCLCResearchPublicLicense2_0 = SPDXLicenseCode("OCLC-2.0")
    """
    ODC Open Database License v1.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    ODCOpenDatabaseLicenseV1_0 = SPDXLicenseCode("ODbL-1.0")
    """
    SIL Open Font License 1.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    SILOpenFontLicense1_0 = SPDXLicenseCode("OFL-1.0")
    """
    SIL Open Font License 1.1.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    SILOpenFontLicense1_1 = SPDXLicenseCode("OFL-1.1")
    """
    Open Group Test Suite License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    OpenGroupTestSuiteLicense = SPDXLicenseCode("OGTSL")
    """
    Open LDAP Public License v1.1.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    OpenLDAPPublicLicenseV1_1 = SPDXLicenseCode("OLDAP-1.1")
    """
    Open LDAP Public License v1.2.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    OpenLDAPPublicLicenseV1_2 = SPDXLicenseCode("OLDAP-1.2")
    """
    Open LDAP Public License v1.3.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    OpenLDAPPublicLicenseV1_3 = SPDXLicenseCode("OLDAP-1.3")
    """
    Open LDAP Public License v1.4.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    OpenLDAPPublicLicenseV1_4 = SPDXLicenseCode("OLDAP-1.4")
    """
    Open LDAP Public License v2.0.1.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    OpenLDAPPublicLicenseV2_0_1 = SPDXLicenseCode("OLDAP-2.0.1")
    """
    Open LDAP Public License v2.0 (or possibly 2.0A and 2.0B).
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    OpenLDAPPublicLicenseV2_0_orPossibly2_0AAnd2_0B_ = SPDXLicenseCode("OLDAP-2.0")
    """
    Open LDAP Public License v2.1.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    OpenLDAPPublicLicenseV2_1 = SPDXLicenseCode("OLDAP-2.1")
    """
    Open LDAP Public License v2.2.1.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    OpenLDAPPublicLicenseV2_2_1 = SPDXLicenseCode("OLDAP-2.2.1")
    """
    Open LDAP Public License 2.2.2.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    OpenLDAPPublicLicense2_2_2 = SPDXLicenseCode("OLDAP-2.2.2")
    """
    Open LDAP Public License v2.2.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    OpenLDAPPublicLicenseV2_2 = SPDXLicenseCode("OLDAP-2.2")
    """
    Open LDAP Public License v2.3.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    OpenLDAPPublicLicenseV2_3 = SPDXLicenseCode("OLDAP-2.3")
    """
    Open LDAP Public License v2.4.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    OpenLDAPPublicLicenseV2_4 = SPDXLicenseCode("OLDAP-2.4")
    """
    Open LDAP Public License v2.5.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    OpenLDAPPublicLicenseV2_5 = SPDXLicenseCode("OLDAP-2.5")
    """
    Open LDAP Public License v2.6.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    OpenLDAPPublicLicenseV2_6 = SPDXLicenseCode("OLDAP-2.6")
    """
    Open LDAP Public License v2.7.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    OpenLDAPPublicLicenseV2_7 = SPDXLicenseCode("OLDAP-2.7")
    """
    Open LDAP Public License v2.8.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    OpenLDAPPublicLicenseV2_8 = SPDXLicenseCode("OLDAP-2.8")
    """
    Open Market License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    OpenMarketLicense = SPDXLicenseCode("OML")
    """
    OpenSSL License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    OpenSSLLicense = SPDXLicenseCode("OpenSSL")
    """
    Open Public License v1.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    OpenPublicLicenseV1_0 = SPDXLicenseCode("OPL-1.0")
    """
    OSET Public License version 2.1.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    OSETPublicLicenseVersion2_1 = SPDXLicenseCode("OSET-PL-2.1")
    """
    Open Software License 1.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    OpenSoftwareLicense1_0 = SPDXLicenseCode("OSL-1.0")
    """
    Open Software License 1.1.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    OpenSoftwareLicense1_1 = SPDXLicenseCode("OSL-1.1")
    """
    Open Software License 2.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    OpenSoftwareLicense2_0 = SPDXLicenseCode("OSL-2.0")
    """
    Open Software License 2.1.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    OpenSoftwareLicense2_1 = SPDXLicenseCode("OSL-2.1")
    """
    Open Software License 3.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    OpenSoftwareLicense3_0 = SPDXLicenseCode("OSL-3.0")
    """
    ODC Public Domain Dedication & License 1.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    ODCPublicDomainDedication_License1_0 = SPDXLicenseCode("PDDL-1.0")
    """
    PHP License v3.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    PHPLicenseV3_0 = SPDXLicenseCode("PHP-3.0")
    """
    PHP License v3.01.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    PHPLicenseV3_01 = SPDXLicenseCode("PHP-3.01")
    """
    Plexus Classworlds License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    PlexusClassworldsLicense = SPDXLicenseCode("Plexus")
    """
    PostgreSQL License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    PostgreSQLLicense = SPDXLicenseCode("PostgreSQL")
    """
    psfrag License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    PsfragLicense = SPDXLicenseCode("psfrag")
    """
    psutils License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    PsutilsLicense = SPDXLicenseCode("psutils")
    """
    Python License 2.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    PythonLicense2_0 = SPDXLicenseCode("Python-2.0")
    """
    Qhull License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    QhullLicense = SPDXLicenseCode("Qhull")
    """
    Q Public License 1.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    QPublicLicense1_0 = SPDXLicenseCode("QPL-1.0")
    """
    Rdisc License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    RdiscLicense = SPDXLicenseCode("Rdisc")
    """
    Red Hat eCos Public License v1.1.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    RedHatECosPublicLicenseV1_1 = SPDXLicenseCode("RHeCos-1.1")
    """
    Reciprocal Public License 1.1.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    ReciprocalPublicLicense1_1 = SPDXLicenseCode("RPL-1.1")
    """
    Reciprocal Public License 1.5.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    ReciprocalPublicLicense1_5 = SPDXLicenseCode("RPL-1.5")
    """
    RealNetworks Public Source License v1.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    RealNetworksPublicSourceLicenseV1_0 = SPDXLicenseCode("RPSL-1.0")
    """
    RSA Message-Digest License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    RSAMessage_DigestLicense = SPDXLicenseCode("RSA-MD")
    """
    Ricoh Source Code Public License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    RicohSourceCodePublicLicense = SPDXLicenseCode("RSCPL")
    """
    Ruby License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    RubyLicense = SPDXLicenseCode("Ruby")
    """
    Sax Public Domain Notice.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    SaxPublicDomainNotice = SPDXLicenseCode("SAX-PD")
    """
    Saxpath License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    SaxpathLicense = SPDXLicenseCode("Saxpath")
    """
    SCEA Shared Source License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    SCEASharedSourceLicense = SPDXLicenseCode("SCEA")
    """
    Sendmail License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    SendmailLicense = SPDXLicenseCode("Sendmail")
    """
    SGI Free Software License B v1.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    SGIFreeSoftwareLicenseBV1_0 = SPDXLicenseCode("SGI-B-1.0")
    """
    SGI Free Software License B v1.1.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    SGIFreeSoftwareLicenseBV1_1 = SPDXLicenseCode("SGI-B-1.1")
    """
    SGI Free Software License B v2.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    SGIFreeSoftwareLicenseBV2_0 = SPDXLicenseCode("SGI-B-2.0")
    """
    Simple Public License 2.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    SimplePublicLicense2_0 = SPDXLicenseCode("SimPL-2.0")
    """
    Sun Industry Standards Source License v1.2.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    SunIndustryStandardsSourceLicenseV1_2 = SPDXLicenseCode("SISSL-1.2")
    """
    Sun Industry Standards Source License v1.1.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    SunIndustryStandardsSourceLicenseV1_1 = SPDXLicenseCode("SISSL")
    """
    Sleepycat License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    SleepycatLicense = SPDXLicenseCode("Sleepycat")
    """
    Standard ML of New Jersey License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    StandardMLOfNewJerseyLicense = SPDXLicenseCode("SMLNJ")
    """
    Secure Messaging Protocol Public License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    SecureMessagingProtocolPublicLicense = SPDXLicenseCode("SMPPL")
    """
    SNIA Public License 1.1.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    SNIAPublicLicense1_1 = SPDXLicenseCode("SNIA")
    """
    Spencer License 86.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    SpencerLicense86 = SPDXLicenseCode("Spencer-86")
    """
    Spencer License 94.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    SpencerLicense94 = SPDXLicenseCode("Spencer-94")
    """
    Spencer License 99.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    SpencerLicense99 = SPDXLicenseCode("Spencer-99")
    """
    Sun Public License v1.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    SunPublicLicenseV1_0 = SPDXLicenseCode("SPL-1.0")
    """
    SugarCRM Public License v1.1.3.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    SugarCRMPublicLicenseV1_1_3 = SPDXLicenseCode("SugarCRM-1.1.3")
    """
    Scheme Widget Library (SWL) Software License Agreement.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    SchemeWidgetLibrary_SWL_SoftwareLicenseAgreement = SPDXLicenseCode("SWL")
    """
    TCL/TK License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    TCL_TKLicense = SPDXLicenseCode("TCL")
    """
    TCP Wrappers License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    TCPWrappersLicense = SPDXLicenseCode("TCP-wrappers")
    """
    TMate Open Source License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    TMateOpenSourceLicense = SPDXLicenseCode("TMate")
    """
    TORQUE v2.5+ Software License v1.1.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    TORQUEV2_5_SoftwareLicenseV1_1 = SPDXLicenseCode("TORQUE-1.1")
    """
    Trusster Open Source License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    TrussterOpenSourceLicense = SPDXLicenseCode("TOSL")
    """
    Unicode License Agreement - Data Files and Software (2015).
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    UnicodeLicenseAgreement_DataFilesAndSoftware_2015_ = SPDXLicenseCode(
        "Unicode-DFS-2015"
    )
    """
    Unicode License Agreement - Data Files and Software (2016).
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    UnicodeLicenseAgreement_DataFilesAndSoftware_2016_ = SPDXLicenseCode(
        "Unicode-DFS-2016"
    )
    """
    Unicode Terms of Use.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    UnicodeTermsOfUse = SPDXLicenseCode("Unicode-TOU")
    """
    The Unlicense.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    TheUnlicense = SPDXLicenseCode("Unlicense")
    """
    Universal Permissive License v1.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    UniversalPermissiveLicenseV1_0 = SPDXLicenseCode("UPL-1.0")
    """
    Vim License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    VimLicense = SPDXLicenseCode("Vim")
    """
    VOSTROM Public License for Open Source.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    VOSTROMPublicLicenseForOpenSource = SPDXLicenseCode("VOSTROM")
    """
    Vovida Software License v1.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    VovidaSoftwareLicenseV1_0 = SPDXLicenseCode("VSL-1.0")
    """
    W3C Software Notice and License (1998-07-20).
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    W3CSoftwareNoticeAndLicense_1998_07_20_ = SPDXLicenseCode("W3C-19980720")
    """
    W3C Software Notice and Document License (2015-05-13).
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    W3CSoftwareNoticeAndDocumentLicense_2015_05_13_ = SPDXLicenseCode("W3C-20150513")
    """
    W3C Software Notice and License (2002-12-31).
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    W3CSoftwareNoticeAndLicense_2002_12_31_ = SPDXLicenseCode("W3C")
    """
    Sybase Open Watcom Public License 1.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    SybaseOpenWatcomPublicLicense1_0 = SPDXLicenseCode("Watcom-1.0")
    """
    Wsuipa License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    WsuipaLicense = SPDXLicenseCode("Wsuipa")
    """
    Do What The F*ck You Want To Public License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    DoWhatTheF_ckYouWantToPublicLicense = SPDXLicenseCode("WTFPL")
    """
    X11 License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    X11License = SPDXLicenseCode("X11")
    """
    Xerox License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    XeroxLicense = SPDXLicenseCode("Xerox")
    """
    XFree86 License 1.1.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    XFree86License1_1 = SPDXLicenseCode("XFree86-1.1")
    """
    xinetd License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    XinetdLicense = SPDXLicenseCode("xinetd")
    """
    X.Net License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    X_NetLicense = SPDXLicenseCode("Xnet")
    """
    XPP License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    XPPLicense = SPDXLicenseCode("xpp")
    """
    XSkat License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    XSkatLicense = SPDXLicenseCode("XSkat")
    """
    Yahoo! Public License v1.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    Yahoo_PublicLicenseV1_0 = SPDXLicenseCode("YPL-1.0")
    """
    Yahoo! Public License v1.1.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    Yahoo_PublicLicenseV1_1 = SPDXLicenseCode("YPL-1.1")
    """
    Zed License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    ZedLicense = SPDXLicenseCode("Zed")
    """
    Zend License v2.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    ZendLicenseV2_0 = SPDXLicenseCode("Zend-2.0")
    """
    Zimbra Public License v1.3.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    ZimbraPublicLicenseV1_3 = SPDXLicenseCode("Zimbra-1.3")
    """
    Zimbra Public License v1.4.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    ZimbraPublicLicenseV1_4 = SPDXLicenseCode("Zimbra-1.4")
    """
    zlib/libpng License with Acknowledgement.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    Zlib_libpngLicenseWithAcknowledgement = SPDXLicenseCode("zlib-acknowledgement")
    """
    zlib License.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    ZlibLicense = SPDXLicenseCode("Zlib")
    """
    Zope Public License 1.1.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    ZopePublicLicense1_1 = SPDXLicenseCode("ZPL-1.1")
    """
    Zope Public License 2.0.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    ZopePublicLicense2_0 = SPDXLicenseCode("ZPL-2.0")
    """
    Zope Public License 2.1.
    From: http://hl7.org/fhir/spdx-license in valuesets.xml
    """
    ZopePublicLicense2_1 = SPDXLicenseCode("ZPL-2.1")
