from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class SpecimenStatusCode(GenericTypeCode):
    """
    SpecimenStatus
    From: http://hl7.org/fhir/specimen-status in valuesets.xml
        Codes providing the status/availability of a specimen.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/specimen-status
    """
    codeset: FhirUri = "http://hl7.org/fhir/specimen-status"


class SpecimenStatusCodeValues:
    """
    The physical specimen is present and in good condition.
    From: http://hl7.org/fhir/specimen-status in valuesets.xml
    """

    Available = SpecimenStatusCode("available")
    """
    There is no physical specimen because it is either lost, destroyed or
    consumed.
    From: http://hl7.org/fhir/specimen-status in valuesets.xml
    """
    Unavailable = SpecimenStatusCode("unavailable")
    """
    The specimen cannot be used because of a quality issue such as a broken
    container, contamination, or too old.
    From: http://hl7.org/fhir/specimen-status in valuesets.xml
    """
    Unsatisfactory = SpecimenStatusCode("unsatisfactory")
    """
    The specimen was entered in error and therefore nullified.
    From: http://hl7.org/fhir/specimen-status in valuesets.xml
    """
    EnteredInError = SpecimenStatusCode("entered-in-error")
