from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class StandardsStatusCode(GenericTypeCode):
    """
    StandardsStatus
    From: http://terminology.hl7.org/CodeSystem/standards-status in valuesets.xml
        HL7 Ballot/Standards status of artifact.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/standards-status
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/standards-status"


class StandardsStatusCodeValues:
    """
    This portion of the specification is not considered to be complete enough or
    sufficiently reviewed to be safe for implementation. It may have known issues
    or still be in the "in development" stage. It is included in the publication
    as a place-holder, to solicit feedback from the implementation community
    and/or to give implementers some insight as to functionality likely to be
    included in future versions of the specification. Content at this level should
    only be implemented by the brave or desperate and is very much "use at your
    own risk". The content that is Draft that will usually be elevated to Trial
    Use once review and correction is complete after it has been subjected to
    ballot.
    From: http://terminology.hl7.org/CodeSystem/standards-status in valuesets.xml
    """

    Draft = StandardsStatusCode("draft")
    """
    This content has been subject to review and production implementation in a
    wide variety of environments. The content is considered to be stable and has
    been 'locked', subjecting it to FHIR Inter-version Compatibility Rules. While
    changes are possible, they are expected to be infrequent and are tightly
    constrained. Compatibility Rules.
    From: http://terminology.hl7.org/CodeSystem/standards-status in valuesets.xml
    """
    Normative = StandardsStatusCode("normative")
    """
    This content has been well reviewed and is considered by the authors to be
    ready for use in production systems. It has been subjected to ballot and
    approved as an official standard. However, it has not yet seen widespread use
    in production across the full spectrum of environments it is intended to be
    used in. In some cases, there may be documented known issues that require
    implementation experience to determine appropriate resolutions for.
    
    Future versions of FHIR may make significant changes to Trial Use content that
    are not compatible with previously published content.
    From: http://terminology.hl7.org/CodeSystem/standards-status in valuesets.xml
    """
    Trial_Use = StandardsStatusCode("trial-use")
    """
    This portion of the specification is provided for implementer assistance, and
    does not make rules that implementers are required to follow. Typical examples
    of this content in the FHIR specification are tables of contents, registries,
    examples, and implementer advice.
    From: http://terminology.hl7.org/CodeSystem/standards-status in valuesets.xml
    """
    Informative = StandardsStatusCode("informative")
    """
    This portion of the specification is provided for implementer assistance, and
    does not make rules that implementers are required to follow. Typical examples
    of this content in the FHIR specification are tables of contents, registries,
    examples, and implementer advice.
    From: http://terminology.hl7.org/CodeSystem/standards-status in valuesets.xml
    """
    Deprecated = StandardsStatusCode("deprecated")
    """
    This is content that is managed outside the FHIR Specification, but included
    for implementer convenience.
    From: http://terminology.hl7.org/CodeSystem/standards-status in valuesets.xml
    """
    External = StandardsStatusCode("external")
