from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class StudyTypeCode(GenericTypeCode):
    """
    StudyType
    From: http://terminology.hl7.org/CodeSystem/study-type in valuesets.xml
        Types of research studies (types of research methods).
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/study-type
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/study-type"


class StudyTypeCodeValues:
    """
    randomized controlled trial.
    From: http://terminology.hl7.org/CodeSystem/study-type in valuesets.xml
    """

    RandomizedTrial = StudyTypeCode("RCT")
    """
    controlled (but not randomized) trial.
    From: http://terminology.hl7.org/CodeSystem/study-type in valuesets.xml
    """
    ControlledTrial_non_randomized_ = StudyTypeCode("CCT")
    """
    observational study comparing cohorts.
    From: http://terminology.hl7.org/CodeSystem/study-type in valuesets.xml
    """
    ComparativeCohortStudy = StudyTypeCode("cohort")
    """
    case-control study.
    From: http://terminology.hl7.org/CodeSystem/study-type in valuesets.xml
    """
    Case_controlStudy = StudyTypeCode("case-control")
    """
    uncontrolled cohort or case series.
    From: http://terminology.hl7.org/CodeSystem/study-type in valuesets.xml
    """
    UncontrolledCohortOrCaseSeries = StudyTypeCode("series")
    """
    a single case report.
    From: http://terminology.hl7.org/CodeSystem/study-type in valuesets.xml
    """
    CaseReport = StudyTypeCode("case-report")
    """
    a combination of 1 or more types of studies.
    From: http://terminology.hl7.org/CodeSystem/study-type in valuesets.xml
    """
    MixedMethods = StudyTypeCode("mixed")
