from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class SubscriptionChannelTypeCode(GenericTypeCode):
    """
    SubscriptionChannelType
    From: http://hl7.org/fhir/subscription-channel-type in valuesets.xml
        The type of method used to execute a subscription.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/subscription-channel-type
    """
    codeset: FhirUri = "http://hl7.org/fhir/subscription-channel-type"


class SubscriptionChannelTypeCodeValues:
    """
    The channel is executed by making a post to the URI. If a payload is included,
    the URL is interpreted as the service base, and an update (PUT) is made.
    From: http://hl7.org/fhir/subscription-channel-type in valuesets.xml
    """

    RestHook = SubscriptionChannelTypeCode("rest-hook")
    """
    The channel is executed by sending a packet across a web socket connection
    maintained by the client. The URL identifies the websocket, and the client
    binds to this URL.
    From: http://hl7.org/fhir/subscription-channel-type in valuesets.xml
    """
    Websocket = SubscriptionChannelTypeCode("websocket")
    """
    The channel is executed by sending an email to the email addressed in the URI
    (which must be a mailto:).
    From: http://hl7.org/fhir/subscription-channel-type in valuesets.xml
    """
    Email = SubscriptionChannelTypeCode("email")
    """
    The channel is executed by sending an SMS message to the phone number
    identified in the URL (tel:).
    From: http://hl7.org/fhir/subscription-channel-type in valuesets.xml
    """
    SMS = SubscriptionChannelTypeCode("sms")
    """
    The channel is executed by sending a message (e.g. a Bundle with a
    MessageHeader resource etc.) to the application identified in the URI.
    From: http://hl7.org/fhir/subscription-channel-type in valuesets.xml
    """
    Message = SubscriptionChannelTypeCode("message")
