from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class SubstanceCategoryCodesCode(GenericTypeCode):
    """
    SubstanceCategoryCodes
    From: http://terminology.hl7.org/CodeSystem/substance-category in valuesets.xml
        Substance category codes
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/substance-category
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/substance-category"


class SubstanceCategoryCodesCodeValues:
    """
    A substance that causes an allergic reaction.
    From: http://terminology.hl7.org/CodeSystem/substance-category in valuesets.xml
    """

    Allergen = SubstanceCategoryCodesCode("allergen")
    """
    A substance that is produced by or extracted from a biological source.
    From: http://terminology.hl7.org/CodeSystem/substance-category in valuesets.xml
    """
    BiologicalSubstance = SubstanceCategoryCodesCode("biological")
    """
    A substance that comes directly from a human or an animal (e.g. blood, urine,
    feces, tears, etc.).
    From: http://terminology.hl7.org/CodeSystem/substance-category in valuesets.xml
    """
    BodySubstance = SubstanceCategoryCodesCode("body")
    """
    Any organic or inorganic substance of a particular molecular identity,
    including -- (i) any combination of such substances occurring in whole or in
    part as a result of a chemical reaction or occurring in nature and (ii) any
    element or uncombined radical (http://www.epa.gov/opptintr/import-
    export/pubs/importguide.pdf).
    From: http://terminology.hl7.org/CodeSystem/substance-category in valuesets.xml
    """
    Chemical = SubstanceCategoryCodesCode("chemical")
    """
    A food, dietary ingredient, or dietary supplement for human or animal.
    From: http://terminology.hl7.org/CodeSystem/substance-category in valuesets.xml
    """
    DietarySubstance = SubstanceCategoryCodesCode("food")
    """
    A substance intended for use in the diagnosis, cure, mitigation, treatment, or
    prevention of disease in man or other animals (Federal Food Drug and Cosmetic
    Act).
    From: http://terminology.hl7.org/CodeSystem/substance-category in valuesets.xml
    """
    DrugOrMedicament = SubstanceCategoryCodesCode("drug")
    """
    A finished product which is not normally ingested, absorbed or injected (e.g.
    steel, iron, wood, plastic and paper).
    From: http://terminology.hl7.org/CodeSystem/substance-category in valuesets.xml
    """
    Material = SubstanceCategoryCodesCode("material")
