from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class SupplementTypeCodesCode(GenericTypeCode):
    """
    SupplementTypeCodes
    From: http://hl7.org/fhir/ValueSet/supplement-type in valuesets.xml
        SupplementType :  Codes for nutritional supplements to be provided to the
    patient. This value set is composed of SNOMED CT (US Extension) Concepts from
    SCTID 470581016 (Enteral+supplement feeds hierarchy (product)) and is provided
    as a suggestive example.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://snomed.info/sct
    """
    codeset: FhirUri = "http://snomed.info/sct"


class SupplementTypeCodesCodeValues:
    """
    From: http://hl7.org/fhir/ValueSet/supplement-type in valuesets.xml
    """

    AdultClearLiquidSupplement = SupplementTypeCodesCode("442901000124106")
    """
    From: http://hl7.org/fhir/ValueSet/supplement-type in valuesets.xml
    """
    AdultCriticalCareFormula = SupplementTypeCodesCode("443031000124106")
    """
    From: http://hl7.org/fhir/ValueSet/supplement-type in valuesets.xml
    """
    AdultDiabetesSpecialtyFormula = SupplementTypeCodesCode("443051000124104")
    """
    From: http://hl7.org/fhir/ValueSet/supplement-type in valuesets.xml
    """
    AdultElementalFormula = SupplementTypeCodesCode("442911000124109")
    """
    From: http://hl7.org/fhir/ValueSet/supplement-type in valuesets.xml
    """
    AdultHepaticSpecialtyFormula = SupplementTypeCodesCode("443021000124108")
    """
    From: http://hl7.org/fhir/ValueSet/supplement-type in valuesets.xml
    """
    AdultHighEnergyFormula = SupplementTypeCodesCode("442971000124100")
    """
    From: http://hl7.org/fhir/ValueSet/supplement-type in valuesets.xml
    """
    AdultHydrolyzedProteinFormula = SupplementTypeCodesCode("442981000124102")
    """
    From: http://hl7.org/fhir/ValueSet/supplement-type in valuesets.xml
    """
    AdultHighProteinFormula = SupplementTypeCodesCode("442991000124104")
    """
    From: http://hl7.org/fhir/ValueSet/supplement-type in valuesets.xml
    """
    AdultHighProteinHighFiberFormula = SupplementTypeCodesCode("443011000124100")
    """
    From: http://hl7.org/fhir/ValueSet/supplement-type in valuesets.xml
    """
    AdultLowCarbohydrateFormula = SupplementTypeCodesCode("442961000124107")
    """
    From: http://hl7.org/fhir/ValueSet/supplement-type in valuesets.xml
    """
    AdultPulmonarySpecialtyFormula = SupplementTypeCodesCode("442951000124105")
    """
    From: http://hl7.org/fhir/ValueSet/supplement-type in valuesets.xml
    """
    AdultRenalSpecialtyFormula = SupplementTypeCodesCode("442941000124108")
    """
    From: http://hl7.org/fhir/ValueSet/supplement-type in valuesets.xml
    """
    AdultStandardFormula = SupplementTypeCodesCode("442921000124101")
    """
    From: http://hl7.org/fhir/ValueSet/supplement-type in valuesets.xml
    """
    AdultSoyProteinIsolateFormula = SupplementTypeCodesCode("442931000124103")
    """
    From: http://hl7.org/fhir/ValueSet/supplement-type in valuesets.xml
    """
    DiabeticMealReplacementBar = SupplementTypeCodesCode("444331000124106")
    """
    From: http://hl7.org/fhir/ValueSet/supplement-type in valuesets.xml
    """
    PediatricFormula = SupplementTypeCodesCode("443361000124100")
    """
    From: http://hl7.org/fhir/ValueSet/supplement-type in valuesets.xml
    """
    PediatricClearLiquidSupplement = SupplementTypeCodesCode("443391000124108")
    """
    From: http://hl7.org/fhir/ValueSet/supplement-type in valuesets.xml
    """
    PediatricElementalFormula = SupplementTypeCodesCode("443401000124105")
    """
    From: http://hl7.org/fhir/ValueSet/supplement-type in valuesets.xml
    """
    PediatricHighEnergyFormula = SupplementTypeCodesCode("443491000124103")
    """
    From: http://hl7.org/fhir/ValueSet/supplement-type in valuesets.xml
    """
    PediatricHighEnergyFormulaWithIncreasedFiber = SupplementTypeCodesCode(
        "443501000124106"
    )
    """
    From: http://hl7.org/fhir/ValueSet/supplement-type in valuesets.xml
    """
    PediatricHydrolyzedProteinFormula = SupplementTypeCodesCode("443421000124100")
    """
    From: http://hl7.org/fhir/ValueSet/supplement-type in valuesets.xml
    """
    PediatricIncreasedFiberFormula = SupplementTypeCodesCode("443471000124104")
    """
    From: http://hl7.org/fhir/ValueSet/supplement-type in valuesets.xml
    """
    PediatricReducedEnergyFormula = SupplementTypeCodesCode("444431000124104")
    """
    From: http://hl7.org/fhir/ValueSet/supplement-type in valuesets.xml
    """
    PediatricStandardFormula = SupplementTypeCodesCode("443451000124109")
    """
    From: http://hl7.org/fhir/ValueSet/supplement-type in valuesets.xml
    """
    StandardPuddingOralSupplement = SupplementTypeCodesCode("444321000124108")
    """
    From: http://hl7.org/fhir/ValueSet/supplement-type in valuesets.xml
    """
    StandardEnteralFormulaWithFiber = SupplementTypeCodesCode("441561000124106")
    """
    From: http://hl7.org/fhir/ValueSet/supplement-type in valuesets.xml
    """
    StandardFormula = SupplementTypeCodesCode("443461000124106")
    """
    From: http://hl7.org/fhir/ValueSet/supplement-type in valuesets.xml
    """
    StandardEnteralFormula = SupplementTypeCodesCode("441531000124102")
    """
    From: http://hl7.org/fhir/ValueSet/supplement-type in valuesets.xml
    """
    SoyBasedFormula = SupplementTypeCodesCode("443561000124107")
    """
    From: http://hl7.org/fhir/ValueSet/supplement-type in valuesets.xml
    """
    RenalFormula = SupplementTypeCodesCode("443481000124101")
    """
    From: http://hl7.org/fhir/ValueSet/supplement-type in valuesets.xml
    """
    HighEnergyEnteralFormulaWithFiber = SupplementTypeCodesCode("441571000124104")
    """
    From: http://hl7.org/fhir/ValueSet/supplement-type in valuesets.xml
    """
    DiabeticEnteralFormulaWithFiber = SupplementTypeCodesCode("441591000124103")
    """
    From: http://hl7.org/fhir/ValueSet/supplement-type in valuesets.xml
    """
    DiabeticHighCalorieHighProteinEnteralFormulaWithFiber = SupplementTypeCodesCode(
        "441601000124106"
    )
    """
    From: http://hl7.org/fhir/ValueSet/supplement-type in valuesets.xml
    """
    IncreasedFiberFormula = SupplementTypeCodesCode("443351000124102")
    """
    From: http://hl7.org/fhir/ValueSet/supplement-type in valuesets.xml
    """
    HydrolyzedProteinFormula = SupplementTypeCodesCode("443771000124106")
    """
    From: http://hl7.org/fhir/ValueSet/supplement-type in valuesets.xml
    """
    HydrolyzedPeptide_basedHighProteinEnteralFormula = SupplementTypeCodesCode(
        "441671000124100"
    )
    """
    From: http://hl7.org/fhir/ValueSet/supplement-type in valuesets.xml
    """
    HighProteinFormula = SupplementTypeCodesCode("443111000124101")
    """
    From: http://hl7.org/fhir/ValueSet/supplement-type in valuesets.xml
    """
    HighEnergyFormula = SupplementTypeCodesCode("443431000124102")
    """
    From: http://hl7.org/fhir/ValueSet/supplement-type in valuesets.xml
    """
    ElementalFormula = SupplementTypeCodesCode("443411000124108")
    """
    From: http://hl7.org/fhir/ValueSet/supplement-type in valuesets.xml
    """
    ElectrolyteReplacementSupplement = SupplementTypeCodesCode("444361000124102")
    """
    From: http://hl7.org/fhir/ValueSet/supplement-type in valuesets.xml
    """
    FrozenElectrolyteReplacementSupplement = SupplementTypeCodesCode("444401000124107")
    """
    From: http://hl7.org/fhir/ValueSet/supplement-type in valuesets.xml
    """
    LiquidElectrolyteReplacementSupplement = SupplementTypeCodesCode("444381000124107")
    """
    From: http://hl7.org/fhir/ValueSet/supplement-type in valuesets.xml
    """
    PowderedElectrolyteReplacementSupplement = SupplementTypeCodesCode(
        "444371000124109"
    )
    """
    From: http://hl7.org/fhir/ValueSet/supplement-type in valuesets.xml
    """
    ClearLiquidSupplement = SupplementTypeCodesCode("443441000124107")
    """
    From: http://hl7.org/fhir/ValueSet/supplement-type in valuesets.xml
    """
    AdultFormula = SupplementTypeCodesCode("442651000124102")
