from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class SurfaceCodesCode(GenericTypeCode):
    """
    SurfaceCodes
    From: http://terminology.hl7.org/CodeSystem/FDI-surface in valuesets.xml
        This value set includes a smattering of FDI tooth surface codes.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/FDI-surface
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/FDI-surface"


class SurfaceCodesCodeValues:
    """
    The surface of a tooth that is closest to the midline (middle) of the face.
    From: http://terminology.hl7.org/CodeSystem/FDI-surface in valuesets.xml
    """

    Mesial = SurfaceCodesCode("M")
    """
    The chewing surface of posterior teeth.
    From: http://terminology.hl7.org/CodeSystem/FDI-surface in valuesets.xml
    """
    Occlusal = SurfaceCodesCode("O")
    """
    The biting edge of anterior teeth.
    From: http://terminology.hl7.org/CodeSystem/FDI-surface in valuesets.xml
    """
    Incisal = SurfaceCodesCode("I")
    """
    The surface of a tooth that faces away from the midline of the face.
    From: http://terminology.hl7.org/CodeSystem/FDI-surface in valuesets.xml
    """
    Distal = SurfaceCodesCode("D")
    """
    The surface of a posterior tooth facing the cheeks.
    From: http://terminology.hl7.org/CodeSystem/FDI-surface in valuesets.xml
    """
    Buccal = SurfaceCodesCode("B")
    """
    The surface of a tooth facing the lips.
    From: http://terminology.hl7.org/CodeSystem/FDI-surface in valuesets.xml
    """
    Ventral = SurfaceCodesCode("V")
    """
    The surface of a tooth facing the tongue.
    From: http://terminology.hl7.org/CodeSystem/FDI-surface in valuesets.xml
    """
    Lingual = SurfaceCodesCode("L")
    """
    The Mesioclusal surfaces of a tooth.
    From: http://terminology.hl7.org/CodeSystem/FDI-surface in valuesets.xml
    """
    Mesioclusal = SurfaceCodesCode("MO")
    """
    The Distoclusal surfaces of a tooth.
    From: http://terminology.hl7.org/CodeSystem/FDI-surface in valuesets.xml
    """
    Distoclusal = SurfaceCodesCode("DO")
    """
    The Distoincisal surfaces of a tooth.
    From: http://terminology.hl7.org/CodeSystem/FDI-surface in valuesets.xml
    """
    Distoincisal = SurfaceCodesCode("DI")
    """
    The Mesioclusodistal surfaces of a tooth.
    From: http://terminology.hl7.org/CodeSystem/FDI-surface in valuesets.xml
    """
    Mesioclusodistal = SurfaceCodesCode("MOD")
