from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class TaskCodeCode(GenericTypeCode):
    """
    TaskCode
    From: http://hl7.org/fhir/CodeSystem/task-code in valuesets.xml
        Codes indicating the type of action that is expected to be performed
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/CodeSystem/task-code
    """
    codeset: FhirUri = "http://hl7.org/fhir/CodeSystem/task-code"


class TaskCodeCodeValues:
    """
    Take what actions are needed to transition the focus resource from 'draft' to
    'active' or 'in-progress', as appropriate for the resource type.  This may
    involve additing additional content, approval, validation, etc.
    From: http://hl7.org/fhir/CodeSystem/task-code in valuesets.xml
    """

    Activate_approveTheFocalResource = TaskCodeCode("approve")
    """
    Act to perform the actions defined in the focus request.  This might result in
    a 'more assertive' request (order for a plan or proposal, filler order for a
    placer order), but is intend to eventually result in events.  The degree of
    fulfillment requested might be limited by Task.restriction.
    From: http://hl7.org/fhir/CodeSystem/task-code in valuesets.xml
    """
    FulfillTheFocalRequest = TaskCodeCode("fulfill")
    """
    Abort, cancel or withdraw the focal resource, as appropriate for the type of
    resource.
    From: http://hl7.org/fhir/CodeSystem/task-code in valuesets.xml
    """
    MarkTheFocalResourceAsNoLongerActive = TaskCodeCode("abort")
    """
    Replace the focal resource with the specified input resource
    From: http://hl7.org/fhir/CodeSystem/task-code in valuesets.xml
    """
    ReplaceTheFocalResourceWithTheInputResource = TaskCodeCode("replace")
    """
    Update the focal resource of the owning system to reflect the content
    specified as the Task.focus
    From: http://hl7.org/fhir/CodeSystem/task-code in valuesets.xml
    """
    ChangeTheFocalResource = TaskCodeCode("change")
    """
    Transition the focal resource from 'active' or 'in-progress' to 'suspended'
    From: http://hl7.org/fhir/CodeSystem/task-code in valuesets.xml
    """
    SuspendTheFocalResource = TaskCodeCode("suspend")
    """
    Transition the focal resource from 'suspended' to 'active' or 'in-progress' as
    appropriate for the resource type.
    From: http://hl7.org/fhir/CodeSystem/task-code in valuesets.xml
    """
    Re_activateTheFocalResource = TaskCodeCode("resume")
