from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class TaskStatusCode(GenericTypeCode):
    """
    TaskStatus
    From: http://hl7.org/fhir/task-status in valuesets.xml
        The current status of the task.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/task-status
    """
    codeset: FhirUri = "http://hl7.org/fhir/task-status"


class TaskStatusCodeValues:
    """
    The task is not yet ready to be acted upon.
    From: http://hl7.org/fhir/task-status in valuesets.xml
    """

    Draft = TaskStatusCode("draft")
    """
    The task is ready to be acted upon and action is sought.
    From: http://hl7.org/fhir/task-status in valuesets.xml
    """
    Requested = TaskStatusCode("requested")
    """
    A potential performer has claimed ownership of the task and is evaluating
    whether to perform it.
    From: http://hl7.org/fhir/task-status in valuesets.xml
    """
    Received = TaskStatusCode("received")
    """
    The potential performer has agreed to execute the task but has not yet started
    work.
    From: http://hl7.org/fhir/task-status in valuesets.xml
    """
    Accepted = TaskStatusCode("accepted")
    """
    The potential performer who claimed ownership of the task has decided not to
    execute it prior to performing any action.
    From: http://hl7.org/fhir/task-status in valuesets.xml
    """
    Rejected = TaskStatusCode("rejected")
    """
    The task is ready to be performed, but no action has yet been taken.  Used in
    place of requested/received/accepted/rejected when request assignment and
    acceptance is a given.
    From: http://hl7.org/fhir/task-status in valuesets.xml
    """
    Ready = TaskStatusCode("ready")
    """
    The task was not completed.
    From: http://hl7.org/fhir/task-status in valuesets.xml
    """
    Cancelled = TaskStatusCode("cancelled")
    """
    The task has been started but is not yet complete.
    From: http://hl7.org/fhir/task-status in valuesets.xml
    """
    InProgress = TaskStatusCode("in-progress")
    """
    The task has been started but work has been paused.
    From: http://hl7.org/fhir/task-status in valuesets.xml
    """
    OnHold = TaskStatusCode("on-hold")
    """
    The task was attempted but could not be completed due to some error.
    From: http://hl7.org/fhir/task-status in valuesets.xml
    """
    Failed = TaskStatusCode("failed")
    """
    The task has been completed.
    From: http://hl7.org/fhir/task-status in valuesets.xml
    """
    Completed = TaskStatusCode("completed")
    """
    The task should never have existed and is retained only because of the
    possibility it may have used.
    From: http://hl7.org/fhir/task-status in valuesets.xml
    """
    EnteredInError = TaskStatusCode("entered-in-error")
