from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class TelecommunicationCapabilities(GenericTypeCode):
    """
    v3.TelecommunicationCapabilities
    From: http://terminology.hl7.org/ValueSet/v3-TelecommunicationCapabilities in v3-codesystems.xml
          Description:
    Concepts that define the telecommunication capabilities of a particular
    device. Used to identify the expected capabilities to be found at a particular
    telecommunication address.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/v3-TelecommunicationCapabilities
    """
    codeset: FhirUri = (
        "http://terminology.hl7.org/CodeSystem/v3-TelecommunicationCapabilities"
    )


class TelecommunicationCapabilitiesValues:
    """
    Description: This device can receive data calls (i.e. modem).
    From: http://terminology.hl7.org/CodeSystem/v3-TelecommunicationCapabilities in v3-codesystems.xml
    """

    Data = TelecommunicationCapabilities("data")
    """
    Description: This device can receive faxes.
    From: http://terminology.hl7.org/CodeSystem/v3-TelecommunicationCapabilities in v3-codesystems.xml
    """
    Fax = TelecommunicationCapabilities("fax")
    """
    Description: This device can receive SMS messages.
    From: http://terminology.hl7.org/CodeSystem/v3-TelecommunicationCapabilities in v3-codesystems.xml
    """
    Sms = TelecommunicationCapabilities("sms")
    """
    Description: This device is a text telephone.
    From: http://terminology.hl7.org/CodeSystem/v3-TelecommunicationCapabilities in v3-codesystems.xml
    """
    Text = TelecommunicationCapabilities("tty")
    """
    Description: This device can receive voice calls (i.e. talking to another
    person, or a recording device, or a voice activated computer).
    From: http://terminology.hl7.org/CodeSystem/v3-TelecommunicationCapabilities in v3-codesystems.xml
    """
    Voice = TelecommunicationCapabilities("voice")
