from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class TestScriptOperationCodeCode(GenericTypeCode):
    """
    TestScriptOperationCode
    From: http://terminology.hl7.org/CodeSystem/testscript-operation-codes in valuesets.xml
        This value set defines a set of codes that are used to indicate the supported
    operations of a testing engine or tool.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/testscript-operation-codes
    """
    codeset: FhirUri = (
        "http://terminology.hl7.org/CodeSystem/testscript-operation-codes"
    )


class TestScriptOperationCodeCodeValues:
    """
    Read the current state of the resource.
    From: http://terminology.hl7.org/CodeSystem/testscript-operation-codes in valuesets.xml
    """

    Read = TestScriptOperationCodeCode("read")
    """
    Read the state of a specific version of the resource.
    From: http://terminology.hl7.org/CodeSystem/testscript-operation-codes in valuesets.xml
    """
    VersionRead = TestScriptOperationCodeCode("vread")
    """
    Update an existing resource by its id.
    From: http://terminology.hl7.org/CodeSystem/testscript-operation-codes in valuesets.xml
    """
    Update = TestScriptOperationCodeCode("update")
    """
    Update an existing resource by its id (or create it if it is new).
    From: http://terminology.hl7.org/CodeSystem/testscript-operation-codes in valuesets.xml
    """
    CreateUsingUpdate = TestScriptOperationCodeCode("updateCreate")
    """
    Patch an existing resource by its id.
    From: http://terminology.hl7.org/CodeSystem/testscript-operation-codes in valuesets.xml
    """
    Patch = TestScriptOperationCodeCode("patch")
    """
    Delete a resource.
    From: http://terminology.hl7.org/CodeSystem/testscript-operation-codes in valuesets.xml
    """
    Delete = TestScriptOperationCodeCode("delete")
    """
    Conditionally delete a single resource based on search parameters.
    From: http://terminology.hl7.org/CodeSystem/testscript-operation-codes in valuesets.xml
    """
    ConditionalDeleteSingle = TestScriptOperationCodeCode("deleteCondSingle")
    """
    Conditionally delete one or more resources based on search parameters.
    From: http://terminology.hl7.org/CodeSystem/testscript-operation-codes in valuesets.xml
    """
    ConditionalDeleteMultiple = TestScriptOperationCodeCode("deleteCondMultiple")
    """
    Retrieve the change history for a particular resource or resource type.
    From: http://terminology.hl7.org/CodeSystem/testscript-operation-codes in valuesets.xml
    """
    History = TestScriptOperationCodeCode("history")
    """
    Create a new resource with a server assigned id.
    From: http://terminology.hl7.org/CodeSystem/testscript-operation-codes in valuesets.xml
    """
    Create = TestScriptOperationCodeCode("create")
    """
    Search based on some filter criteria.
    From: http://terminology.hl7.org/CodeSystem/testscript-operation-codes in valuesets.xml
    """
    Search = TestScriptOperationCodeCode("search")
    """
    Update, create or delete a set of resources as independent actions.
    From: http://terminology.hl7.org/CodeSystem/testscript-operation-codes in valuesets.xml
    """
    Batch = TestScriptOperationCodeCode("batch")
    """
    Update, create or delete a set of resources as a single transaction.
    From: http://terminology.hl7.org/CodeSystem/testscript-operation-codes in valuesets.xml
    """
    Transaction = TestScriptOperationCodeCode("transaction")
    """
    Get a capability statement for the system.
    From: http://terminology.hl7.org/CodeSystem/testscript-operation-codes in valuesets.xml
    """
    Capabilities = TestScriptOperationCodeCode("capabilities")
    """
    Realizes an ActivityDefinition in a specific context
    From: http://terminology.hl7.org/CodeSystem/testscript-operation-codes in valuesets.xml
    """
    _apply = TestScriptOperationCodeCode("apply")
    """
    Closure Table Maintenance
    From: http://terminology.hl7.org/CodeSystem/testscript-operation-codes in valuesets.xml
    """
    _closure = TestScriptOperationCodeCode("closure")
    """
    Finding Codes based on supplied properties
    From: http://terminology.hl7.org/CodeSystem/testscript-operation-codes in valuesets.xml
    """
    _find_matches = TestScriptOperationCodeCode("find-matches")
    """
    Compare two systems CapabilityStatements
    From: http://terminology.hl7.org/CodeSystem/testscript-operation-codes in valuesets.xml
    """
    _conforms = TestScriptOperationCodeCode("conforms")
    """
    Aggregates and returns the parameters and data requirements for a resource and
    all its dependencies as a single module definition
    From: http://terminology.hl7.org/CodeSystem/testscript-operation-codes in valuesets.xml
    """
    _data_requirements = TestScriptOperationCodeCode("data-requirements")
    """
    Generate a Document
    From: http://terminology.hl7.org/CodeSystem/testscript-operation-codes in valuesets.xml
    """
    _document = TestScriptOperationCodeCode("document")
    """
    Request clinical decision support guidance based on a specific decision
    support module
    From: http://terminology.hl7.org/CodeSystem/testscript-operation-codes in valuesets.xml
    """
    _evaluate = TestScriptOperationCodeCode("evaluate")
    """
    Invoke an eMeasure and obtain the results
    From: http://terminology.hl7.org/CodeSystem/testscript-operation-codes in valuesets.xml
    """
    _evaluate_measure = TestScriptOperationCodeCode("evaluate-measure")
    """
    Return all the related information as described in the Encounter or Patient
    From: http://terminology.hl7.org/CodeSystem/testscript-operation-codes in valuesets.xml
    """
    _everything = TestScriptOperationCodeCode("everything")
    """
    Value Set Expansion
    From: http://terminology.hl7.org/CodeSystem/testscript-operation-codes in valuesets.xml
    """
    _expand = TestScriptOperationCodeCode("expand")
    """
    Find a functional list
    From: http://terminology.hl7.org/CodeSystem/testscript-operation-codes in valuesets.xml
    """
    _find = TestScriptOperationCodeCode("find")
    """
    Invoke a GraphQL query
    From: http://terminology.hl7.org/CodeSystem/testscript-operation-codes in valuesets.xml
    """
    _graphql = TestScriptOperationCodeCode("graphql")
    """
    Test if a server implements a client's required operations
    From: http://terminology.hl7.org/CodeSystem/testscript-operation-codes in valuesets.xml
    """
    _implements = TestScriptOperationCodeCode("implements")
    """
    Last N Observations Query
    From: http://terminology.hl7.org/CodeSystem/testscript-operation-codes in valuesets.xml
    """
    _lastn = TestScriptOperationCodeCode("lastn")
    """
    Concept Look Up and Decomposition
    From: http://terminology.hl7.org/CodeSystem/testscript-operation-codes in valuesets.xml
    """
    _lookup = TestScriptOperationCodeCode("lookup")
    """
    Find patient matches using MPI based logic
    From: http://terminology.hl7.org/CodeSystem/testscript-operation-codes in valuesets.xml
    """
    _match = TestScriptOperationCodeCode("match")
    """
    Access a list of profiles, tags, and security labels
    From: http://terminology.hl7.org/CodeSystem/testscript-operation-codes in valuesets.xml
    """
    _meta = TestScriptOperationCodeCode("meta")
    """
    Add profiles, tags, and security labels to a resource
    From: http://terminology.hl7.org/CodeSystem/testscript-operation-codes in valuesets.xml
    """
    _meta_add = TestScriptOperationCodeCode("meta-add")
    """
    Delete profiles, tags, and security labels for a resource
    From: http://terminology.hl7.org/CodeSystem/testscript-operation-codes in valuesets.xml
    """
    _meta_delete = TestScriptOperationCodeCode("meta-delete")
    """
    Populate Questionnaire
    From: http://terminology.hl7.org/CodeSystem/testscript-operation-codes in valuesets.xml
    """
    _populate = TestScriptOperationCodeCode("populate")
    """
    Generate HTML for Questionnaire
    From: http://terminology.hl7.org/CodeSystem/testscript-operation-codes in valuesets.xml
    """
    _populatehtml = TestScriptOperationCodeCode("populatehtml")
    """
    Generate a link to a Questionnaire completion webpage
    From: http://terminology.hl7.org/CodeSystem/testscript-operation-codes in valuesets.xml
    """
    _populatelink = TestScriptOperationCodeCode("populatelink")
    """
    Process a message according to the defined event
    From: http://terminology.hl7.org/CodeSystem/testscript-operation-codes in valuesets.xml
    """
    _process_message = TestScriptOperationCodeCode("process-message")
    """
    Build Questionnaire
    From: http://terminology.hl7.org/CodeSystem/testscript-operation-codes in valuesets.xml
    """
    _questionnaire = TestScriptOperationCodeCode("questionnaire")
    """
    Observation Statistics
    From: http://terminology.hl7.org/CodeSystem/testscript-operation-codes in valuesets.xml
    """
    _stats = TestScriptOperationCodeCode("stats")
    """
    Fetch a subset of the CapabilityStatement resource
    From: http://terminology.hl7.org/CodeSystem/testscript-operation-codes in valuesets.xml
    """
    _subset = TestScriptOperationCodeCode("subset")
    """
    CodeSystem Subsumption Testing
    From: http://terminology.hl7.org/CodeSystem/testscript-operation-codes in valuesets.xml
    """
    _subsumes = TestScriptOperationCodeCode("subsumes")
    """
    Model Instance Transformation
    From: http://terminology.hl7.org/CodeSystem/testscript-operation-codes in valuesets.xml
    """
    _transform = TestScriptOperationCodeCode("transform")
    """
    Concept Translation
    From: http://terminology.hl7.org/CodeSystem/testscript-operation-codes in valuesets.xml
    """
    _translate = TestScriptOperationCodeCode("translate")
    """
    Validate a resource
    From: http://terminology.hl7.org/CodeSystem/testscript-operation-codes in valuesets.xml
    """
    _validate = TestScriptOperationCodeCode("validate")
    """
    ValueSet based Validation
    From: http://terminology.hl7.org/CodeSystem/testscript-operation-codes in valuesets.xml
    """
    _validate_code = TestScriptOperationCodeCode("validate-code")
