from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class TimingAbbreviationCode(GenericTypeCode):
    """
    TimingAbbreviation
    From: http://hl7.org/fhir/ValueSet/timing-abbreviation in valuesets.xml
        Code for a known / defined timing pattern.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/v3-GTSAbbreviation
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/v3-GTSAbbreviation"


class TimingAbbreviationCodeValues:
    """
    Every morning at institution specified times.
    From: http://terminology.hl7.org/CodeSystem/v3-GTSAbbreviation in v3-codesystems.xml
    """

    AM = TimingAbbreviationCode("AM")
    """
    At bedtime (institution specified time).
    From: http://terminology.hl7.org/CodeSystem/v3-GTSAbbreviation in v3-codesystems.xml
    """
    AtBedtime = TimingAbbreviationCode("BED")
    """
    Two times a day at institution specified time
    From: http://terminology.hl7.org/CodeSystem/v3-GTSAbbreviation in v3-codesystems.xml
    """
    BID = TimingAbbreviationCode("BID")
    """
    Regular business days (Monday to Friday excluding holidays)
    From: http://terminology.hl7.org/CodeSystem/v3-GTSAbbreviation in v3-codesystems.xml
    """
    JB = TimingAbbreviationCode("JB")
    """
    Regular weekends (Saturday and Sunday excluding holidays)
    From: http://terminology.hl7.org/CodeSystem/v3-GTSAbbreviation in v3-codesystems.xml
    """
    JE = TimingAbbreviationCode("JE")
    """
    Holidays
    From: http://terminology.hl7.org/CodeSystem/v3-GTSAbbreviation in v3-codesystems.xml
    """
    GTSAbbreviationHolidays = TimingAbbreviationCode("JH")
    """
    Monthly at institution specified time.
    From: http://terminology.hl7.org/CodeSystem/v3-GTSAbbreviation in v3-codesystems.xml
    """
    Monthly = TimingAbbreviationCode("MO")
    """
    Every afternoon at institution specified times.
    From: http://terminology.hl7.org/CodeSystem/v3-GTSAbbreviation in v3-codesystems.xml
    """
    PM = TimingAbbreviationCode("PM")
    """
    Every hour at institution specified times.
    From: http://terminology.hl7.org/CodeSystem/v3-GTSAbbreviation in v3-codesystems.xml
    """
    EveryHour = TimingAbbreviationCode("Q1H")
    """
    Every 2 hours at institution specified times.
    From: http://terminology.hl7.org/CodeSystem/v3-GTSAbbreviation in v3-codesystems.xml
    """
    Every2Hours = TimingAbbreviationCode("Q2H")
    """
    Every 3 hours at institution specified times.
    From: http://terminology.hl7.org/CodeSystem/v3-GTSAbbreviation in v3-codesystems.xml
    """
    Every3Hours = TimingAbbreviationCode("Q3H")
    """
    Every 4 hours at institution specified time
    From: http://terminology.hl7.org/CodeSystem/v3-GTSAbbreviation in v3-codesystems.xml
    """
    Q4H = TimingAbbreviationCode("Q4H")
    """
    Every 6 hours at institution specified time
    From: http://terminology.hl7.org/CodeSystem/v3-GTSAbbreviation in v3-codesystems.xml
    """
    Q6H = TimingAbbreviationCode("Q6H")
    """
    Every 8 hours at institution specified times.
    From: http://terminology.hl7.org/CodeSystem/v3-GTSAbbreviation in v3-codesystems.xml
    """
    Every8Hours = TimingAbbreviationCode("Q8H")
    """
    Every day at institution specified times.
    From: http://terminology.hl7.org/CodeSystem/v3-GTSAbbreviation in v3-codesystems.xml
    """
    QD = TimingAbbreviationCode("QD")
    """
    Four times a day at institution specified time
    From: http://terminology.hl7.org/CodeSystem/v3-GTSAbbreviation in v3-codesystems.xml
    """
    QID = TimingAbbreviationCode("QID")
    """
    Every other day at institution specified times.
    From: http://terminology.hl7.org/CodeSystem/v3-GTSAbbreviation in v3-codesystems.xml
    """
    QOD = TimingAbbreviationCode("QOD")
    """
    Three times a day at institution specified time
    From: http://terminology.hl7.org/CodeSystem/v3-GTSAbbreviation in v3-codesystems.xml
    """
    TID = TimingAbbreviationCode("TID")
    """
    Weekly at institution specified time.
    From: http://terminology.hl7.org/CodeSystem/v3-GTSAbbreviation in v3-codesystems.xml
    """
    Weekly = TimingAbbreviationCode("WK")
    """
    From: http://hl7.org/fhir/ValueSet/timing-abbreviation in valuesets.xml
    """
    BID = TimingAbbreviationCode("BID")
    """
    From: http://hl7.org/fhir/ValueSet/timing-abbreviation in valuesets.xml
    """
    TID = TimingAbbreviationCode("TID")
    """
    From: http://hl7.org/fhir/ValueSet/timing-abbreviation in valuesets.xml
    """
    QID = TimingAbbreviationCode("QID")
    """
    From: http://hl7.org/fhir/ValueSet/timing-abbreviation in valuesets.xml
    """
    AM = TimingAbbreviationCode("AM")
    """
    From: http://hl7.org/fhir/ValueSet/timing-abbreviation in valuesets.xml
    """
    PM = TimingAbbreviationCode("PM")
    """
    From: http://hl7.org/fhir/ValueSet/timing-abbreviation in valuesets.xml
    """
    QD = TimingAbbreviationCode("QD")
    """
    From: http://hl7.org/fhir/ValueSet/timing-abbreviation in valuesets.xml
    """
    QOD = TimingAbbreviationCode("QOD")
    """
    From: http://hl7.org/fhir/ValueSet/timing-abbreviation in valuesets.xml
    """
    EveryHour = TimingAbbreviationCode("Q1H")
    """
    From: http://hl7.org/fhir/ValueSet/timing-abbreviation in valuesets.xml
    """
    Every2Hours = TimingAbbreviationCode("Q2H")
    """
    From: http://hl7.org/fhir/ValueSet/timing-abbreviation in valuesets.xml
    """
    Every3Hours = TimingAbbreviationCode("Q3H")
    """
    From: http://hl7.org/fhir/ValueSet/timing-abbreviation in valuesets.xml
    """
    Q4H = TimingAbbreviationCode("Q4H")
    """
    From: http://hl7.org/fhir/ValueSet/timing-abbreviation in valuesets.xml
    """
    Q6H = TimingAbbreviationCode("Q6H")
    """
    From: http://hl7.org/fhir/ValueSet/timing-abbreviation in valuesets.xml
    """
    Every8Hours = TimingAbbreviationCode("Q8H")
    """
    From: http://hl7.org/fhir/ValueSet/timing-abbreviation in valuesets.xml
    """
    AtBedtime = TimingAbbreviationCode("BED")
    """
    From: http://hl7.org/fhir/ValueSet/timing-abbreviation in valuesets.xml
    """
    Weekly = TimingAbbreviationCode("WK")
    """
    From: http://hl7.org/fhir/ValueSet/timing-abbreviation in valuesets.xml
    """
    Monthly = TimingAbbreviationCode("MO")
