from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class UDIEntryTypeCode(GenericTypeCode):
    """
    UDIEntryType
    From: http://hl7.org/fhir/udi-entry-type in valuesets.xml
        Codes to identify how UDI data was entered.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/udi-entry-type
    """
    codeset: FhirUri = "http://hl7.org/fhir/udi-entry-type"


class UDIEntryTypeCodeValues:
    """
    a barcodescanner captured the data from the device label.
    From: http://hl7.org/fhir/udi-entry-type in valuesets.xml
    """

    Barcode = UDIEntryTypeCode("barcode")
    """
    An RFID chip reader captured the data from the device label.
    From: http://hl7.org/fhir/udi-entry-type in valuesets.xml
    """
    RFID = UDIEntryTypeCode("rfid")
    """
    The data was read from the label by a person and manually entered. (e.g.  via
    a keyboard).
    From: http://hl7.org/fhir/udi-entry-type in valuesets.xml
    """
    Manual = UDIEntryTypeCode("manual")
    """
    The data originated from a patient's implant card and was read by an operator.
    From: http://hl7.org/fhir/udi-entry-type in valuesets.xml
    """
    Card = UDIEntryTypeCode("card")
    """
    The data originated from a patient source and was not directly scanned or read
    from a label or card.
    From: http://hl7.org/fhir/udi-entry-type in valuesets.xml
    """
    SelfReported = UDIEntryTypeCode("self-reported")
    """
    The method of data capture has not been determined.
    From: http://hl7.org/fhir/udi-entry-type in valuesets.xml
    """
    Unknown = UDIEntryTypeCode("unknown")
