from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class VaccineManufacturer(GenericTypeCode):
    """
    v3.VaccineManufacturer
    From: http://terminology.hl7.org/ValueSet/v3-VaccineManufacturer in v3-codesystems.xml
         The manufacturer of a vaccine.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/v3-VaccineManufacturer
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/v3-VaccineManufacturer"


class VaccineManufacturerValues:
    """
    Abbott Laboratories (includes Ross Products Division)
    From: http://terminology.hl7.org/CodeSystem/v3-VaccineManufacturer in v3-codesystems.xml
    """

    AbbottLaboratories_includesRossProductsDivision_ = VaccineManufacturer("AB")
    """
    Adams Laboratories
    From: http://terminology.hl7.org/CodeSystem/v3-VaccineManufacturer in v3-codesystems.xml
    """
    AdamsLaboratories = VaccineManufacturer("AD")
    """
    Alpha Therapeutic Corporation
    From: http://terminology.hl7.org/CodeSystem/v3-VaccineManufacturer in v3-codesystems.xml
    """
    AlphaTherapeuticCorporation = VaccineManufacturer("ALP")
    """
    Armour [Inactive-use CEN]
    From: http://terminology.hl7.org/CodeSystem/v3-VaccineManufacturer in v3-codesystems.xml
    """
    Armour_Inactive_UseCEN_ = VaccineManufacturer("AR")
    """
    Aviron
    From: http://terminology.hl7.org/CodeSystem/v3-VaccineManufacturer in v3-codesystems.xml
    """
    Aviron = VaccineManufacturer("AVI")
    """
    Baxter Healthcare Corporation
    From: http://terminology.hl7.org/CodeSystem/v3-VaccineManufacturer in v3-codesystems.xml
    """
    BaxterHealthcareCorporation = VaccineManufacturer("BA")
    """
    Bayer Corporation (includes Miles, Inc. and Cutter Laboratories)
    From: http://terminology.hl7.org/CodeSystem/v3-VaccineManufacturer in v3-codesystems.xml
    """
    BayerCorporation_includesMiles_Inc_AndCutterLaboratories_ = VaccineManufacturer(
        "BAY"
    )
    """
    Berna Products [Inactive-use BPC]
    From: http://terminology.hl7.org/CodeSystem/v3-VaccineManufacturer in v3-codesystems.xml
    """
    BernaProducts_Inactive_UseBPC_ = VaccineManufacturer("BP")
    """
    Berna Products Corporation (includes Swiss Serum and Vaccine Institute Berne)
    From: http://terminology.hl7.org/CodeSystem/v3-VaccineManufacturer in v3-codesystems.xml
    """
    BernaProductsCorporation_includesSwissSerumAndVaccineInstituteBerne_ = (
        VaccineManufacturer("BPC")
    )
    """
    Centeon L.L.C. (includes Armour Pharmaceutical Company)
    From: http://terminology.hl7.org/CodeSystem/v3-VaccineManufacturer in v3-codesystems.xml
    """
    CenteonL_L_C_includesArmourPharmaceuticalCompany_ = VaccineManufacturer("CEN")
    """
    Chiron Corporation
    From: http://terminology.hl7.org/CodeSystem/v3-VaccineManufacturer in v3-codesystems.xml
    """
    ChironCorporation = VaccineManufacturer("CHI")
    """
    Connaught [Inactive-use PMC]
    From: http://terminology.hl7.org/CodeSystem/v3-VaccineManufacturer in v3-codesystems.xml
    """
    Connaught_Inactive_UsePMC_ = VaccineManufacturer("CON")
    """
    Evans Medical Limited (an affiliate of Medeva Pharmaceuticals, Inc.)
    From: http://terminology.hl7.org/CodeSystem/v3-VaccineManufacturer in v3-codesystems.xml
    """
    EvansMedicalLimited_anAffiliateOfMedevaPharmaceuticals_Inc_ = VaccineManufacturer(
        "EVN"
    )
    """
    Greer Laboratories, Inc.
    From: http://terminology.hl7.org/CodeSystem/v3-VaccineManufacturer in v3-codesystems.xml
    """
    GreerLaboratories_Inc_ = VaccineManufacturer("GRE")
    """
    Immuno International AG
    From: http://terminology.hl7.org/CodeSystem/v3-VaccineManufacturer in v3-codesystems.xml
    """
    ImmunoInternationalAG = VaccineManufacturer("IAG")
    """
    Merieux [Inactive-use PMC]
    From: http://terminology.hl7.org/CodeSystem/v3-VaccineManufacturer in v3-codesystems.xml
    """
    Merieux_Inactive_UsePMC_ = VaccineManufacturer("IM")
    """
    Immuno-U.S., Inc.
    From: http://terminology.hl7.org/CodeSystem/v3-VaccineManufacturer in v3-codesystems.xml
    """
    Immuno_U_S_Inc_ = VaccineManufacturer("IUS")
    """
    The Research Foundation for Microbial Diseases of Osaka University (BIKEN)
    From: http://terminology.hl7.org/CodeSystem/v3-VaccineManufacturer in v3-codesystems.xml
    """
    TheResearchFoundationForMicrobialDiseasesOfOsakaUniversity_BIKEN_ = (
        VaccineManufacturer("JPN")
    )
    """
    Korea Green Cross Corporation
    From: http://terminology.hl7.org/CodeSystem/v3-VaccineManufacturer in v3-codesystems.xml
    """
    KoreaGreenCrossCorporation = VaccineManufacturer("KGC")
    """
    Lederle [Inactive-use WAL]
    From: http://terminology.hl7.org/CodeSystem/v3-VaccineManufacturer in v3-codesystems.xml
    """
    Lederle_Inactive_UseWAL_ = VaccineManufacturer("LED")
    """
    Massachusetts Public Health Biologic Laboratories
    From: http://terminology.hl7.org/CodeSystem/v3-VaccineManufacturer in v3-codesystems.xml
    """
    MassachusettsPublicHealthBiologicLaboratories = VaccineManufacturer("MA")
    """
    MedImmune, Inc.
    From: http://terminology.hl7.org/CodeSystem/v3-VaccineManufacturer in v3-codesystems.xml
    """
    MedImmune_Inc_ = VaccineManufacturer("MED")
    """
    Miles [Inactive-use BAY]
    From: http://terminology.hl7.org/CodeSystem/v3-VaccineManufacturer in v3-codesystems.xml
    """
    Miles_Inactive_UseBAY_ = VaccineManufacturer("MIL")
    """
    Bioport Corporation (formerly Michigan Biologic Products Institute)
    From: http://terminology.hl7.org/CodeSystem/v3-VaccineManufacturer in v3-codesystems.xml
    """
    BioportCorporation_formerlyMichiganBiologicProductsInstitute_ = VaccineManufacturer(
        "MIP"
    )
    """
    Merck & Co., Inc.
    From: http://terminology.hl7.org/CodeSystem/v3-VaccineManufacturer in v3-codesystems.xml
    """
    MerckAndCo_Inc_ = VaccineManufacturer("MSD")
    """
    NABI (formerly North American Biologicals, Inc.)
    From: http://terminology.hl7.org/CodeSystem/v3-VaccineManufacturer in v3-codesystems.xml
    """
    NABI_formerlyNorthAmericanBiologicals_Inc_ = VaccineManufacturer("NAB")
    """
    North American Vaccine, Inc.
    From: http://terminology.hl7.org/CodeSystem/v3-VaccineManufacturer in v3-codesystems.xml
    """
    NorthAmericanVaccine_Inc_ = VaccineManufacturer("NAV")
    """
    Novartis Pharmaceutical Corporation (includes Ciba-Geigy Limited and Sandoz
    Limited)
    From: http://terminology.hl7.org/CodeSystem/v3-VaccineManufacturer in v3-codesystems.xml
    """
    NovartisPharmaceuticalCorporation_includesCiba_GeigyLimitedAndSandozLimited_ = (
        VaccineManufacturer("NOV")
    )
    """
    New York Blood Center
    From: http://terminology.hl7.org/CodeSystem/v3-VaccineManufacturer in v3-codesystems.xml
    """
    NewYorkBloodCenter = VaccineManufacturer("NYB")
    """
    Ortho Diagnostic Systems, Inc.
    From: http://terminology.hl7.org/CodeSystem/v3-VaccineManufacturer in v3-codesystems.xml
    """
    OrthoDiagnosticSystems_Inc_ = VaccineManufacturer("ORT")
    """
    Organon Teknika Corporation
    From: http://terminology.hl7.org/CodeSystem/v3-VaccineManufacturer in v3-codesystems.xml
    """
    OrganonTeknikaCorporation = VaccineManufacturer("OTC")
    """
    Parkedale Pharmaceuticals (formerly Parke-Davis)
    From: http://terminology.hl7.org/CodeSystem/v3-VaccineManufacturer in v3-codesystems.xml
    """
    ParkedalePharmaceuticals_formerlyParke_Davis_ = VaccineManufacturer("PD")
    """
    Aventis Pasteur Inc. (formerly Pasteur Merieux Connaught; includes Connaught
    Laboratories and Pasteur Merieux)
    From: http://terminology.hl7.org/CodeSystem/v3-VaccineManufacturer in v3-codesystems.xml
    """
    AventisPasteurInc_formerlyPasteurMerieuxConnaught_IncludesConnaughtLaboratoriesAndPasteurMerieux_ = VaccineManufacturer(
        "PMC"
    )
    """
    Praxis Biologics [Inactive-use WAL]
    From: http://terminology.hl7.org/CodeSystem/v3-VaccineManufacturer in v3-codesystems.xml
    """
    PraxisBiologics_Inactive_UseWAL_ = VaccineManufacturer("PRX")
    """
    Sclavo, Inc.
    From: http://terminology.hl7.org/CodeSystem/v3-VaccineManufacturer in v3-codesystems.xml
    """
    Sclavo_Inc_ = VaccineManufacturer("SCL")
    """
    Swiss Serum and Vaccine Inst. [Inactive-use BPC]
    From: http://terminology.hl7.org/CodeSystem/v3-VaccineManufacturer in v3-codesystems.xml
    """
    SwissSerumAndVaccineInst_Inactive_UseBPC_ = VaccineManufacturer("SI")
    """
    SmithKline Beecham
    From: http://terminology.hl7.org/CodeSystem/v3-VaccineManufacturer in v3-codesystems.xml
    """
    SmithKlineBeecham = VaccineManufacturer("SKB")
    """
    United States Army Medical Research and Materiel Command
    From: http://terminology.hl7.org/CodeSystem/v3-VaccineManufacturer in v3-codesystems.xml
    """
    UnitedStatesArmyMedicalResearchAndMaterielCommand = VaccineManufacturer("USA")
    """
    Wyeth-Ayerst [Inactive-use WAL]
    From: http://terminology.hl7.org/CodeSystem/v3-VaccineManufacturer in v3-codesystems.xml
    """
    Wyeth_Ayerst_Inactive_UseWAL_ = VaccineManufacturer("WA")
    """
    Wyeth-Ayerst (includes Wyeth-Lederle Vaccines and Pediatrics, Wyeth
    Laboratories, Lederle Laboratories, and Praxis Biologics)
    From: http://terminology.hl7.org/CodeSystem/v3-VaccineManufacturer in v3-codesystems.xml
    """
    Wyeth_Ayerst_includesWyeth_LederleVaccinesAndPediatrics_WyethLaboratories_LederleLaboratories_AndPraxisBiologics_ = VaccineManufacturer(
        "WAL"
    )
