from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class VerificationMethod(GenericTypeCode):
    """
    v3.VerificationMethod
    From: http://terminology.hl7.org/ValueSet/v3-VerificationMethod in v3-codesystems.xml
        No Description Provided
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/v3-ObservationMethod
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/v3-ObservationMethod"


class VerificationMethodValues:
    """
    Provides codes for decision methods, initially for assessing the causality of
    events.
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """

    DecisionObservationMethod = VerificationMethod("_DecisionObservationMethod")
    """
    A code that provides additional detail about the means or technique used to
    ascertain the genetic analysis. Example, PCR, Micro Array
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    GeneticObservationMethod = VerificationMethod("_GeneticObservationMethod")
    """
    Provides additional detail about the aggregation methods used to compute the
    aggregated values for an observation. This is an abstract code.
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ObservationMethodAggregate = VerificationMethod("_ObservationMethodAggregate")
    """
    VerificationMethod
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    VerificationMethod_ = VerificationMethod("_VerificationMethod")
    """
    Complement fixation
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ComplementFixation = VerificationMethod("0001")
    """
    Computed axial tomography
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ComputedAxialTomography = VerificationMethod("0002")
    """
    Susceptibility, High Level Aminoglycoside Resistance agar test
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    HLARAgarTest = VerificationMethod("0003")
    """
    Visual, Macroscopic observation
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    MacroscopicObservation = VerificationMethod("0004")
    """
    Computed, Magnetic resonance
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    MagneticResonance = VerificationMethod("0005")
    """
    Computed, Morphometry
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Morphometry = VerificationMethod("0006")
    """
    Computed, Positron emission tomography
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    PositronEmissionTomography = VerificationMethod("0007")
    """
    SAMHSA drug assay confirmation
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    SAMHSAConfirmation = VerificationMethod("0008")
    """
    SAMHSA drug assay screening
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    SAMHSAScreening = VerificationMethod("0009")
    """
    Serum Neutralization
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    SerumNeutralization = VerificationMethod("0010")
    """
    Titration
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Titration = VerificationMethod("0011")
    """
    Ultrasound
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Ultrasound = VerificationMethod("0012")
    """
    X-ray crystallography
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    X_rayCrystallography = VerificationMethod("0013")
    """
    Agglutination
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Agglutination = VerificationMethod("0014")
    """
    Agglutination, Buffered acidified plate
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    BufferedAcidifiedPlateAgglutination = VerificationMethod("0015")
    """
    Agglutination, Card
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    CardAgglutination = VerificationMethod("0016")
    """
    Agglutination, Hemagglutination
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Hemagglutination = VerificationMethod("0017")
    """
    Agglutination, Hemagglutination inhibition
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    HemagglutinationInhibition = VerificationMethod("0018")
    """
    Agglutination, Latex
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    LatexAgglutination = VerificationMethod("0019")
    """
    Agglutination, Plate
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    PlateAgglutination = VerificationMethod("0020")
    """
    Agglutination, Rapid Plate
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    RapidAgglutination = VerificationMethod("0021")
    """
    Agglutination, RBC
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    RBCAgglutination = VerificationMethod("0022")
    """
    Agglutination, Rivanol
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    RivanolAgglutination = VerificationMethod("0023")
    """
    Agglutination, Tube
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    TubeAgglutination = VerificationMethod("0024")
    """
    Bioassay
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Bioassay = VerificationMethod("0025")
    """
    Bioassay, Animal Inoculation
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    AnimalInoculation = VerificationMethod("0026")
    """
    Bioassay, Cytotoxicity
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Cytotoxicity = VerificationMethod("0027")
    """
    Bioassay, Embryo Infective Dose 50
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    EmbryoInfectiveDose50 = VerificationMethod("0028")
    """
    Bioassay, Embryo Lethal Dose 50
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    EmbryoLethalDose50 = VerificationMethod("0029")
    """
    Bioassay, Mouse intercerebral inoculation
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    MouseIntercerebralInoculation = VerificationMethod("0030")
    """
    Bioassay, qualitative
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Bioassay_Qualitative = VerificationMethod("0031")
    """
    Bioassay, quantitative
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Bioassay_Quantitative = VerificationMethod("0032")
    """
    Chemical
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ChemicalMethod = VerificationMethod("0033")
    """
    Chemical, Differential light absorption
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    DifferentialLightAbsorptionChemicalTest = VerificationMethod("0034")
    """
    Chemical, Dipstick
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Dipstick = VerificationMethod("0035")
    """
    Chemical, Dipstick colorimetric laboratory test
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    DipstickColorimetricLaboratoryTest = VerificationMethod("0036")
    """
    Chemical, Test strip
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    TestStrip = VerificationMethod("0037")
    """
    Chromatography
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Chromatography = VerificationMethod("0038")
    """
    Chromatography, Affinity
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    AffinityChromatography = VerificationMethod("0039")
    """
    Chromatography, Gas liquid
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    GasLiquidChromatography = VerificationMethod("0040")
    """
    Chromatography, High performance liquid
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    HighPerformanceLiquidChromatography = VerificationMethod("0041")
    """
    Chromatography, Liquid
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    LiquidChromatography = VerificationMethod("0042")
    """
    Chromatography, Protein A affinity
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ProteinAAffinityChromatography = VerificationMethod("0043")
    """
    Coagulation
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Coagulation = VerificationMethod("0044")
    """
    Coagulation, Tilt tube
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    TiltTubeCoagulationTime = VerificationMethod("0045")
    """
    Coagulation, Tilt tube reptilase induced
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    TiltTubeReptilaseInducedCoagulation = VerificationMethod("0046")
    """
    Count, Automated
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    AutomatedCount = VerificationMethod("0047")
    """
    Count, Manual
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ManualCellCount = VerificationMethod("0048")
    """
    Count, Platelet, Rees-Ecker
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    PlateletCount_Rees_Ecker = VerificationMethod("0049")
    """
    Culture, Aerobic
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    AerobicCulture = VerificationMethod("0050")
    """
    Culture, Anaerobic
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    AnaerobicCulture = VerificationMethod("0051")
    """
    Culture, Chicken Embryo
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ChickenEmbryoCulture = VerificationMethod("0052")
    """
    Culture, Delayed secondary enrichment
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    DelayedSecondaryEnrichment = VerificationMethod("0053")
    """
    Culture, Microaerophilic
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    MicroaerophilicCulture = VerificationMethod("0054")
    """
    Culture, Quantitative microbial, cup
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    QuantitativeMicrobialCulture_Cup = VerificationMethod("0055")
    """
    Culture, Quantitative microbial, droplet
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    QuantitativeMicrobialCulture_Droplet = VerificationMethod("0056")
    """
    Culture, Quantitative microbial, filter paper
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    QuantitativeMicrobialCulture_FilterPaper = VerificationMethod("0057")
    """
    Culture, Quantitative microbial, pad
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    QuantitativeMicrobialCulture_PadCulture = VerificationMethod("0058")
    """
    Culture, Quantitative microbial, pour plate
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    QuantitativeMicrobialCulture_PourPlate = VerificationMethod("0059")
    """
    Culture, Quantitative microbial, surface streak
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    QuantitativeMicrobialCulture_SurfaceStreak = VerificationMethod("0060")
    """
    Culture, Somatic Cell
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    SomaticCellCulture = VerificationMethod("0061")
    """
    Diffusion, Agar
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    AgarDiffusion = VerificationMethod("0062")
    """
    Diffusion, Agar Gel Immunodiffusion
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    AgarGelImmunodiffusion = VerificationMethod("0063")
    """
    Electrophoresis
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Electrophoresis = VerificationMethod("0064")
    """
    Electrophoresis, Agaorse gel
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    AgaorseGelElectrophoresis = VerificationMethod("0065")
    """
    Electrophoresis, citrate agar
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Electrophoresis_CitrateAgar = VerificationMethod("0066")
    """
    Electrophoresis, Immuno
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Immunoelectrophoresis = VerificationMethod("0067")
    """
    Electrophoresis, Polyacrylamide gel
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    PolyacrylamideGelElectrophoresis = VerificationMethod("0068")
    """
    Electrophoresis, Starch gel
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    StarchGelElectrophoresis = VerificationMethod("0069")
    """
    ELISA
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ELISA = VerificationMethod("0070")
    """
    ELISA, antigen capture
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ELISA_AntigenCapture = VerificationMethod("0071")
    """
    ELISA, avidin biotin peroxidase complex
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ELISA_AvidinBiotinPeroxidaseComplex = VerificationMethod("0072")
    """
    ELISA, Kinetic
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    KineticELISA = VerificationMethod("0073")
    """
    ELISA, peroxidase-antiperoxidase
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ELISA_Peroxidase_antiperoxidase = VerificationMethod("0074")
    """
    Identification, API 20 Strep
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    API20Strep = VerificationMethod("0075")
    """
    Identification, API 20A
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    API20A = VerificationMethod("0076")
    """
    Identification, API 20C AUX
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    API20CAUX = VerificationMethod("0077")
    """
    Identification, API 20E
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    API20E = VerificationMethod("0078")
    """
    Identification, API 20NE
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    API20NE = VerificationMethod("0079")
    """
    Identification, API 50 CH
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    API50CH = VerificationMethod("0080")
    """
    Identification, API An-IDENT
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    APIAn_IDENT = VerificationMethod("0081")
    """
    Identification, API Coryne
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    APICoryne = VerificationMethod("0082")
    """
    Identification, API Rapid 20E
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    APIRapid20E = VerificationMethod("0083")
    """
    Identification, API Staph
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    APIStaph = VerificationMethod("0084")
    """
    Identification, API ZYM
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    APIZYM = VerificationMethod("0085")
    """
    Identification, Bacterial
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    BacterialIdentification = VerificationMethod("0086")
    """
    Identification, mini VIDAS
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    MiniVIDAS = VerificationMethod("0087")
    """
    Identification, Phage susceptibility typing
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    PhageSusceptibilityTyping = VerificationMethod("0088")
    """
    Identification, Quad-FERM+
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Quad_FERM_ = VerificationMethod("0089")
    """
    Identification, RAPIDEC Staph
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    RAPIDECStaph = VerificationMethod("0090")
    """
    Identification, Staphaurex
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Staphaurex = VerificationMethod("0091")
    """
    Identification, VIDAS
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    VIDAS = VerificationMethod("0092")
    """
    Identification, Vitek
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Vitek = VerificationMethod("0093")
    """
    Identification, VITEK 2
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    VITEK2 = VerificationMethod("0094")
    """
    Immune stain
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ImmuneStain = VerificationMethod("0095")
    """
    Immune stain, Immunofluorescent antibody, direct
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ImmunofluorescentAntibody_Direct = VerificationMethod("0096")
    """
    Immune stain, Immunofluorescent antibody, indirect
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ImmunofluorescentAntibody_Indirect = VerificationMethod("0097")
    """
    Immune stain, Immunoperoxidase, Avidin-Biotin Complex
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Immunoperoxidase_Avidin_BiotinComplex = VerificationMethod("0098")
    """
    Immune stain, Immunoperoxidase, Peroxidase anti-peroxidase complex
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Immunoperoxidase_PeroxidaseAnti_peroxidaseComplex = VerificationMethod("0099")
    """
    Immune stain, Immunoperoxidase, Protein A-peroxidase complex
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Immunoperoxidase_ProteinA_peroxidaseComplex = VerificationMethod("0100")
    """
    Immunoassay
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Immunoassay = VerificationMethod("0101")
    """
    Immunoassay, qualitative, multiple step
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Immunoassay_Qualitative_MultipleStep = VerificationMethod("0102")
    """
    Immunoassay, qualitative, single step
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Immunoassay_Qualitative_SingleStep = VerificationMethod("0103")
    """
    Immunoassay, Radioimmunoassay
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Radioimmunoassay = VerificationMethod("0104")
    """
    Immunoassay, semi-quantitative, multiple step
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Immunoassay_Semi_quantitative_MultipleStep = VerificationMethod("0105")
    """
    Immunoassay, semi-quantitative, single step
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Immunoassay_Semi_quantitative_SingleStep = VerificationMethod("0106")
    """
    Microscopy
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Microscopy = VerificationMethod("0107")
    """
    Microscopy, Darkfield
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    DarkfieldMicroscopy = VerificationMethod("0108")
    """
    Microscopy, Electron
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ElectronMicroscopy = VerificationMethod("0109")
    """
    Microscopy, Electron microscopy tomography
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ElectronMicroscopyTomography = VerificationMethod("0110")
    """
    Microscopy, Electron, negative stain
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ElectronMicroscopy_NegativeStain = VerificationMethod("0111")
    """
    Microscopy, Electron, thick section transmission
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ElectronMicroscopy_ThickSection = VerificationMethod("0112")
    """
    Microscopy, Electron, thin section transmission
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ElectronMicroscopy_ThinSection = VerificationMethod("0113")
    """
    Microscopy, Light
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Microscopy_Light = VerificationMethod("0114")
    """
    Microscopy, Polarized light
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    PolarizingLightMicroscopy = VerificationMethod("0115")
    """
    Microscopy, Scanning electron
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ScanningElectronMicroscopy = VerificationMethod("0116")
    """
    Microscopy, Transmission electron
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    TransmissionElectronMicroscopy = VerificationMethod("0117")
    """
    Microscopy, Transparent tape direct examination
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    TransparentTapeDirectExamination = VerificationMethod("0118")
    """
    Molecular, 3 Self-Sustaining Sequence Replication
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    _3Self_SustainingSequenceReplication = VerificationMethod("0119")
    """
    Molecular, Branched Chain DNA
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    BranchedChainDNA = VerificationMethod("0120")
    """
    Molecular, Hybridization Protection Assay
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    HybridizationProtectionAssay = VerificationMethod("0121")
    """
    Molecular, Immune blot
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ImmuneBlot = VerificationMethod("0122")
    """
    Molecular, In-situ hybridization
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    In_situHybridization = VerificationMethod("0123")
    """
    Molecular, Ligase Chain Reaction
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    LigaseChainReaction = VerificationMethod("0124")
    """
    Molecular, Ligation Activated Transcription
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    LigationActivatedTranscription = VerificationMethod("0125")
    """
    Molecular, Nucleic Acid Probe
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    NucleicAcidProbe = VerificationMethod("0126")
    """
    Molecular, Nucleic acid probe with amplification
    
    
    
                            Rationale: Duplicate of code 0126. Use code 0126
    instead.
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    NucleicAcidProbeWithAmplification = VerificationMethod("0128")
    """
    Molecular, Nucleic acid probe with target amplification
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    NucleicAcidProbeWithTargetAmplification = VerificationMethod("0129")
    """
    Molecular, Nucleic acid reverse transcription
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    NucleicAcidReverseTranscription = VerificationMethod("0130")
    """
    Molecular, Nucleic Acid Sequence Based Analysis
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    NucleicAcidSequenceBasedAnalysis = VerificationMethod("0131")
    """
    Molecular, Polymerase chain reaction
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    PolymeraseChainReaction = VerificationMethod("0132")
    """
    Molecular, Q-Beta Replicase or probe amplification category method
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Q_BetaReplicaseOrProbeAmplificationCategoryMethod = VerificationMethod("0133")
    """
    Molecular, Restriction Fragment Length Polymorphism
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    RestrictionFragmentLengthPolymorphism = VerificationMethod("0134")
    """
    Molecular, Southern Blot
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    SouthernBlot = VerificationMethod("0135")
    """
    Molecular, Strand Displacement Amplification
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    StrandDisplacementAmplification = VerificationMethod("0136")
    """
    Molecular, Transcription Mediated Amplification
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    TranscriptionMediatedAmplification = VerificationMethod("0137")
    """
    Molecular, Western Blot
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    WesternBlot = VerificationMethod("0138")
    """
    Precipitation, Flocculation
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Flocculation = VerificationMethod("0139")
    """
    Precipitation, Immune precipitation
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ImmunePrecipitation = VerificationMethod("0140")
    """
    Precipitation, Milk ring test
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    MilkRingTest = VerificationMethod("0141")
    """
    Precipitation, Precipitin
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Precipitin = VerificationMethod("0142")
    """
    Stain, Acid fast
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    AcidFastStain = VerificationMethod("0143")
    """
    Stain, Acid fast, fluorochrome
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    AcidFastStain_Fluorochrome = VerificationMethod("0144")
    """
    Stain, Acid fast, Kinyoun's cold carbolfuchsin
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    AcidFastStain_Kinyoun_sColdCarbolfuchsin = VerificationMethod("0145")
    """
    Stain, Acid fast, Ziehl-Neelsen
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    AcidFastStain_Ziehl_Neelsen = VerificationMethod("0146")
    """
    Stain, Acid phosphatase
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    AcidPhosphataseStain = VerificationMethod("0147")
    """
    Stain, Acridine orange
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    AcridineOrangeStain = VerificationMethod("0148")
    """
    Stain, Active brilliant orange KH
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ActiveBrilliantOrangeKHStain = VerificationMethod("0149")
    """
    Stain, Alazarin red S
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    AlazarinRedSStain = VerificationMethod("0150")
    """
    Stain, Alcian blue
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    AlcianBlueStain = VerificationMethod("0151")
    """
    Stain, Alcian blue with Periodic acid Schiff
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    AlcianBlueWithPeriodicAcidSchiffStain = VerificationMethod("0152")
    """
    Stain, Argentaffin
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ArgentaffinStain = VerificationMethod("0153")
    """
    Stain, Argentaffin silver
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ArgentaffinSilverStain = VerificationMethod("0154")
    """
    Stain, Azure-eosin
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Azure_eosinStain = VerificationMethod("0155")
    """
    Stain, Basic Fuschin
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    BasicFuschinStain = VerificationMethod("0156")
    """
    Stain, Bennhold
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    BennholdStain = VerificationMethod("0157")
    """
    Stain, Bennhold's Congo red
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Bennhold_sCongoRedStain = VerificationMethod("0158")
    """
    Stain, Bielschowsky
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    BielschowskyStain = VerificationMethod("0159")
    """
    Stain, Bielschowsky's silver
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Bielschowsky_sSilverStain = VerificationMethod("0160")
    """
    Stain, Bleach
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    BleachStain = VerificationMethod("0161")
    """
    Stain, Bodian
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    BodianStain = VerificationMethod("0162")
    """
    Stain, Brown-Brenn
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Brown_BrennStain = VerificationMethod("0163")
    """
    Stain, Butyrate-esterase
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Butyrate_esteraseStain = VerificationMethod("0164")
    """
    Stain, Calcofluor white fluorescent
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    CalcofluorWhiteFluorescentStain = VerificationMethod("0165")
    """
    Stain, Carbol-fuchsin
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Carbol_fuchsinStain = VerificationMethod("0166")
    """
    Stain, Carmine
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    CarmineStain = VerificationMethod("0167")
    """
    Stain, Churukian-Schenk
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Churukian_SchenkStain = VerificationMethod("0168")
    """
    Stain, Congo red
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    CongoRedStain = VerificationMethod("0169")
    """
    Stain, Cresyl echt violet
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    CresylEchtVioletStain = VerificationMethod("0170")
    """
    Stain, Crystal violet
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    CrystalVioletStain = VerificationMethod("0171")
    """
    Stain, De Galantha
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    DeGalanthaStain = VerificationMethod("0172")
    """
    Stain, Dieterle silver impregnation
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    DieterleSilverImpregnationStain = VerificationMethod("0173")
    """
    Stain, Fite-Farco
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Fite_FarcoStain = VerificationMethod("0174")
    """
    Stain, Fontana-Masson silver
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Fontana_MassonSilverStain = VerificationMethod("0175")
    """
    Stain, Fouchet
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    FouchetStain = VerificationMethod("0176")
    """
    Stain, Gomori
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    GomoriStain = VerificationMethod("0177")
    """
    Stain, Gomori methenamine silver
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    GomoriMethenamineSilverStain = VerificationMethod("0178")
    """
    Stain, Gomori-Wheatly trichrome
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Gomori_WheatlyTrichromeStain = VerificationMethod("0179")
    """
    Stain, Gridley
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    GridleyStain = VerificationMethod("0180")
    """
    Stain, Grimelius silver
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    GrimeliusSilverStain = VerificationMethod("0181")
    """
    Stain, Grocott
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    GrocottStain = VerificationMethod("0182")
    """
    Stain, Grocott methenamine silver
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    GrocottMethenamineSilverStain = VerificationMethod("0183")
    """
    Stain, Hale's colloidal ferric oxide
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Hale_sColloidalFerricOxideStain = VerificationMethod("0184")
    """
    Stain, Hale's colloidal iron
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Hale_sColloidalIronStain = VerificationMethod("0185")
    """
    Stain, Hansel
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    HanselStain = VerificationMethod("0186")
    """
    Stain, Harris regressive hematoxylin and eosin
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    HarrisRegressiveHematoxylinAndEosinStain = VerificationMethod("0187")
    """
    Stain, Hematoxylin and eosin
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    HematoxylinAndEosinStain = VerificationMethod("0188")
    """
    Stain, Highman
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    HighmanStain = VerificationMethod("0189")
    """
    Stain, Holzer
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    HolzerStain = VerificationMethod("0190")
    """
    Stain, Iron hematoxylin
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    IronHematoxylinStain = VerificationMethod("0191")
    """
    Stain, Jones
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    JonesStain = VerificationMethod("0192")
    """
    Stain, Jones methenamine silver
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    JonesMethenamineSilverStain = VerificationMethod("0193")
    """
    Stain, Kossa
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    KossaStain = VerificationMethod("0194")
    """
    Stain, Lawson-Van Gieson
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Lawson_VanGiesonStain = VerificationMethod("0195")
    """
    Stain, Loeffler methylene blue
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    LoefflerMethyleneBlueStain = VerificationMethod("0196")
    """
    Stain, Luxol fast blue with cresyl violet
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    LuxolFastBlueWithCresylVioletStain = VerificationMethod("0197")
    """
    Stain, Luxol fast blue with Periodic acid-Schiff
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    LuxolFastBlueWithPeriodicAcid_SchiffStain = VerificationMethod("0198")
    """
    Stain, MacNeal's tetrachrome blood
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    MacNeal_sTetrachromeBloodStain = VerificationMethod("0199")
    """
    Stain, Mallory-Heidenhain
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Mallory_HeidenhainStain = VerificationMethod("0200")
    """
    Stain, Masson trichrome
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    MassonTrichromeStain = VerificationMethod("0201")
    """
    Stain, Mayer mucicarmine
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    MayerMucicarmineStain = VerificationMethod("0202")
    """
    Stain, Mayers progressive hematoxylin and eosin
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    MayersProgressiveHematoxylinAndEosinStain = VerificationMethod("0203")
    """
    Stain, May-Grunwald Giemsa
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    May_GrunwaldGiemsaStain = VerificationMethod("0204")
    """
    Stain, Methyl green
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    MethylGreenStain = VerificationMethod("0205")
    """
    Stain, Methyl green pyronin
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    MethylGreenPyroninStain = VerificationMethod("0206")
    """
    Stain, Modified Gomori-Wheatly trichrome
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ModifiedGomori_WheatlyTrichromeStain = VerificationMethod("0207")
    """
    Stain, Modified Masson trichrome
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ModifiedMassonTrichromeStain = VerificationMethod("0208")
    """
    Stain, Modified trichrome
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ModifiedTrichromeStain = VerificationMethod("0209")
    """
    Stain, Movat pentachrome
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    MovatPentachromeStain = VerificationMethod("0210")
    """
    Stain, Mucicarmine
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    MucicarmineStain = VerificationMethod("0211")
    """
    Stain, Neutral red
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    NeutralRedStain = VerificationMethod("0212")
    """
    Stain, Night blue
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    NightBlueStain = VerificationMethod("0213")
    """
    Stain, Non-specific esterase
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Non_specificEsteraseStain = VerificationMethod("0214")
    """
    Stain, Oil red-O
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    OilRed_OStain = VerificationMethod("0215")
    """
    Stain, Orcein
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    OrceinStain = VerificationMethod("0216")
    """
    Stain, Perls'
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Perls_Stain = VerificationMethod("0217")
    """
    Stain, Phosphotungstic acid-hematoxylin
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    PhosphotungsticAcid_hematoxylinStain = VerificationMethod("0218")
    """
    Stain, Potassium ferrocyanide
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    PotassiumFerrocyanideStain = VerificationMethod("0219")
    """
    Stain, Prussian blue
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    PrussianBlueStain = VerificationMethod("0220")
    """
    Stain, Putchler modified Bennhold
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    PutchlerModifiedBennholdStain = VerificationMethod("0221")
    """
    Stain, Quinacrine fluorescent
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    QuinacrineFluorescentStain = VerificationMethod("0222")
    """
    Stain, Reticulin
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ReticulinStain = VerificationMethod("0223")
    """
    Stain, Rhodamine
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    RhodamineStain = VerificationMethod("0224")
    """
    Stain, Safranin
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    SafraninStain = VerificationMethod("0225")
    """
    Stain, Schmorl
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    SchmorlStain = VerificationMethod("0226")
    """
    Stain, Seiver-Munger
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Seiver_MungerStain = VerificationMethod("0227")
    """
    Stain, Silver
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    SilverStain = VerificationMethod("0228")
    """
    Stain, Specific esterase
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    SpecificEsteraseStain = VerificationMethod("0229")
    """
    Stain, Steiner silver
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    SteinerSilverStain = VerificationMethod("0230")
    """
    Stain, Sudan III
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    SudanIIIStain = VerificationMethod("0231")
    """
    Stain, Sudan IVI
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    SudanIVIStain = VerificationMethod("0232")
    """
    Stain, Sulfated alcian blue
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    SulfatedAlcianBlueStain = VerificationMethod("0233")
    """
    Stain, Supravital
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    SupravitalStain = VerificationMethod("0234")
    """
    Stain, Thioflavine-S
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Thioflavine_SStain = VerificationMethod("0235")
    """
    Stain, Three micron Giemsa
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ThreeMicronGiemsaStain = VerificationMethod("0236")
    """
    Stain, Vassar-Culling
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Vassar_CullingStain = VerificationMethod("0237")
    """
    Stain, Vital
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    VitalStain = VerificationMethod("0238")
    """
    Stain, von Kossa
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    VonKossaStain = VerificationMethod("0239")
    """
    Susceptibility, Minimum bactericidal concentration, macrodilution
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    MinimumBactericidalConcentrationTest_Macrodilution = VerificationMethod("0243")
    """
    Susceptibility, Minimum bactericidal concentration, microdilution
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    MinimumBactericidalConcentrationTest_Microdilution = VerificationMethod("0244")
    """
    Turbidometric
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Turbidometric = VerificationMethod("0247")
    """
    Turbidometric, Refractometric
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Refractometric = VerificationMethod("0248")
    """
    Chromatography, Thin Layer
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ThinLayerChromatography_TLC_ = VerificationMethod("0249")
    """
    Immunoassay, enzyme-multiplied technique (EMIT)
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    EMIT = VerificationMethod("0250")
    """
    Flow Cytometry
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    FlowCytometry_FC_ = VerificationMethod("0251")
    """
    Radial Immunodiffusion
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    RadialImmunodiffusion_RID_ = VerificationMethod("0252")
    """
    Immunoassay, Fluorescence Polarization
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    FluorescencePolarizationImmunoassay_FPIA_ = VerificationMethod("0253")
    """
    Electrophoresis, Immunofixation
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ImmunofixationElectrophoresis_IFE_ = VerificationMethod("0254")
    """
    Dialysis, Direct Equilibrium
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    EquilibriumDialysis = VerificationMethod("0255")
    """
    Acid Elution, Kleihauer-Betke Method
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Kleihauer_BetkeAcidElution = VerificationMethod("0256")
    """
    Immunofluorescence, Anti-Complement
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Anti_complementImmunofluorescence_ACIF_ = VerificationMethod("0257")
    """
    Gas Chromatography/Mass Spectroscopy
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    GC_MS = VerificationMethod("0258")
    """
    Light Scatter, Nephelometry
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Nephelometry = VerificationMethod("0259")
    """
    Immunoassay, IgE Antibody Test
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    IgEImmunoassayAntibody = VerificationMethod("0260")
    """
    Lymphocyte Microcytotoxicity Assay
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    LymphocyteMicrocytotoxicityAssay = VerificationMethod("0261")
    """
    Spectrophotometry
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Spectrophotometry = VerificationMethod("0262")
    """
    Spectrophotometry, Atomic Absorption
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    AtomicAbsorptionSpectrophotometry_AAS_ = VerificationMethod("0263")
    """
    Electrochemical, Ion Selective Electrode
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    IonSelectiveElectrode_ISE_ = VerificationMethod("0264")
    """
    Chromatography, Gas
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    GasChromatography_GC_ = VerificationMethod("0265")
    """
    Isoelectric Focusing
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    IsoelectricFocusing_IEF_ = VerificationMethod("0266")
    """
    Immunoassay, Chemiluminescent
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    Immunochemiluminescence = VerificationMethod("0267")
    """
    Immunoassay, Microparticle Enzyme
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    MicroparticleEnzymeImmunoassay_MEIA_ = VerificationMethod("0268")
    """
    Inductively-Coupled Plasma/Mass Spectrometry
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ICP_MS = VerificationMethod("0269")
    """
    Immunoassay, Immunoradiometric Assay
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    ImmunoradiometricAssay_IRMA_ = VerificationMethod("0270")
    """
    Coagulation, Photo Optical Clot Detection
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    PhotoOpticalClotDetection = VerificationMethod("0271")
    """
    Test methods designed to determine a microorganismaTMs susceptibility to being
    killed by an antibiotic.
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    SusceptibilityTesting = VerificationMethod("0280")
    """
    Molecular, Nucleic acid probe
    From: http://terminology.hl7.org/CodeSystem/v3-ObservationMethod in v3-codesystems.xml
    """
    NucleicAcidProbe = VerificationMethod("0127")
