from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class W3cProvenanceActivityTypeCode(GenericTypeCode):
    """
    W3cProvenanceActivityType
    From: http://hl7.org/fhir/w3c-provenance-activity-type in valuesets.xml
        This value set includes W3C PROV Data Model Activity concepts, which are
    treated as codes in this valueset.  Some adaptations were made to make these
    concepts suitable values for the Provenance.activity element. Coded concepts
    are from PROV-DM and the display names are their counterparts in PROV-N (human
    readable notation syntax specification).[code system OID:
    http://www.w3.org/TR/2013/REC-prov-dm-20130430/ and
    http://www.w3.org/TR/2013/REC-prov-n-20130430/]
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/w3c-provenance-activity-type
    """
    codeset: FhirUri = "http://hl7.org/fhir/w3c-provenance-activity-type"


class W3cProvenanceActivityTypeCodeValues:
    """
    The completion of production of a new entity by an activity. This entity did
    not exist before generation and becomes available for usage after this
    generation. Given that a generation is the completion of production of an
    entity, it is instantaneous.
    From: http://hl7.org/fhir/w3c-provenance-activity-type in valuesets.xml
    """

    WasGeneratedBy = W3cProvenanceActivityTypeCode("Generation")
    """
    the beginning of utilizing an entity by an activity. Before usage, the
    activity had not begun to utilize this entity and could not have been affected
    by the entity.  (Note: This definition is formulated for a given usage; it is
    permitted for an activity to have used a same entity multiple times.) Given
    that a usage is the beginning of utilizing an entity, it is instantaneous.
    From: http://hl7.org/fhir/w3c-provenance-activity-type in valuesets.xml
    """
    Used = W3cProvenanceActivityTypeCode("Usage")
    """
    The exchange of some unspecified entity by two activities, one activity using
    some entity generated by the other. A communication implies that activity a2
    is dependent on another activity, a1, by way of some unspecified entity that
    is generated by a1 and used by a2.
    From: http://hl7.org/fhir/w3c-provenance-activity-type in valuesets.xml
    """
    WasInformedBy = W3cProvenanceActivityTypeCode("Communication")
    """
    When an activity is deemed to have been started by an entity, known as
    trigger. The activity did not exist before its start. Any usage, generation,
    or invalidation involving an activity follows the activity's start. A start
    may refer to a trigger entity that set off the activity, or to an activity,
    known as starter, that generated the trigger. Given that a start is when an
    activity is deemed to have started, it is instantaneous.
    From: http://hl7.org/fhir/w3c-provenance-activity-type in valuesets.xml
    """
    WasStartedBy = W3cProvenanceActivityTypeCode("Start")
    """
    When an activity is deemed to have been ended by an entity, known as trigger.
    The activity no longer exists after its end. Any usage, generation, or
    invalidation involving an activity precedes the activity's end. An end may
    refer to a trigger entity that terminated the activity, or to an activity,
    known as ender that generated the trigger.
    From: http://hl7.org/fhir/w3c-provenance-activity-type in valuesets.xml
    """
    WasEndedBy = W3cProvenanceActivityTypeCode("End")
    """
    The start of the destruction, cessation, or expiry of an existing entity by an
    activity. The entity is no longer available for use (or further invalidation)
    after invalidation. Any generation or usage of an entity precedes its
    invalidation. Given that an invalidation is the start of destruction,
    cessation, or expiry, it is instantaneous.
    From: http://hl7.org/fhir/w3c-provenance-activity-type in valuesets.xml
    """
    WasInvalidatedBy = W3cProvenanceActivityTypeCode("Invalidation")
    """
    A transformation of an entity into another, an update of an entity resulting
    in a new one, or the construction of a new entity based on a pre-existing
    entity. For an entity to be transformed from, created from, or resulting from
    an update to another, there must be some underpinning activity or activities
    performing the necessary action(s) resulting in such a derivation. A
    derivation can be described at various levels of precision. In its simplest
    form, derivation relates two entities. Optionally, attributes can be added to
    represent further information about the derivation. If the derivation is the
    result of a single known activity, then this activity can also be optionally
    expressed. To provide a completely accurate description of the derivation, the
    generation and usage of the generated and used entities, respectively, can be
    provided, so as to make the derivation path, through usage, activity, and
    generation, explicit. Optional information such as activity, generation, and
    usage can be linked to derivations to aid analysis of provenance and to
    facilitate provenance-based reproducibility.
    From: http://hl7.org/fhir/w3c-provenance-activity-type in valuesets.xml
    """
    WasDerivedFrom = W3cProvenanceActivityTypeCode("Derivation")
    """
    A derivation for which the resulting entity is a revised version of some
    original. The implication here is that the resulting entity contains
    substantial content from the original. A revision relation is a kind of
    derivation relation from a revised entity to a preceding entity.
    From: http://hl7.org/fhir/w3c-provenance-activity-type in valuesets.xml
    """
    WasRevisionOf = W3cProvenanceActivityTypeCode("Revision")
    """
    The repeat of (some or all of) an entity, such as text or image, by someone
    who might or might not be its original author. A quotation relation is a kind
    of derivation relation, for which an entity was derived from a preceding
    entity by copying, or 'quoting', some or all of it.
    From: http://hl7.org/fhir/w3c-provenance-activity-type in valuesets.xml
    """
    WasQuotedFrom = W3cProvenanceActivityTypeCode("Quotation")
    """
    Refers to something produced by some agent with direct experience and
    knowledge about the topic, at the time of the topic's study, without benefit
    from hindsight. Because of the directness of primary sources, they 'speak for
    themselves' in ways that cannot be captured through the filter of secondary
    sources. As such, it is important for secondary sources to reference those
    primary sources from which they were derived, so that their reliability can be
    investigated. It is also important to note that a given entity might be a
    primary source for one entity but not another. It is the reason why Primary
    Source is defined as a relation as opposed to a subtype of Entity.
    From: http://hl7.org/fhir/w3c-provenance-activity-type in valuesets.xml
    """
    WasPrimarySourceOf = W3cProvenanceActivityTypeCode("Primary-Source")
    """
    Ascribing of an entity (object/document) to an agent.
    From: http://hl7.org/fhir/w3c-provenance-activity-type in valuesets.xml
    """
    WasAttributedTo = W3cProvenanceActivityTypeCode("Attribution")
    """
     An aggregating activity that results in composition of an entity, which
    provides a structure to some constituents that must themselves be entities.
    These constituents are said to be member of the collections.
    From: http://hl7.org/fhir/w3c-provenance-activity-type in valuesets.xml
    """
    IsCollectionOf = W3cProvenanceActivityTypeCode("Collection")
