from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class XPathUsageTypeCode(GenericTypeCode):
    """
    XPathUsageType
    From: http://hl7.org/fhir/search-xpath-usage in valuesets.xml
        How a search parameter relates to the set of elements returned by evaluating
    its xpath query.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/search-xpath-usage
    """
    codeset: FhirUri = "http://hl7.org/fhir/search-xpath-usage"


class XPathUsageTypeCodeValues:
    """
    The search parameter is derived directly from the selected nodes based on the
    type definitions.
    From: http://hl7.org/fhir/search-xpath-usage in valuesets.xml
    """

    Normal = XPathUsageTypeCode("normal")
    """
    The search parameter is derived by a phonetic transform from the selected
    nodes.
    From: http://hl7.org/fhir/search-xpath-usage in valuesets.xml
    """
    Phonetic = XPathUsageTypeCode("phonetic")
    """
    The search parameter is based on a spatial transform of the selected nodes.
    From: http://hl7.org/fhir/search-xpath-usage in valuesets.xml
    """
    Nearby = XPathUsageTypeCode("nearby")
    """
    The search parameter is based on a spatial transform of the selected nodes,
    using physical distance from the middle.
    From: http://hl7.org/fhir/search-xpath-usage in valuesets.xml
    """
    Distance = XPathUsageTypeCode("distance")
    """
    The interpretation of the xpath statement is unknown (and can't be automated).
    From: http://hl7.org/fhir/search-xpath-usage in valuesets.xml
    """
    Other = XPathUsageTypeCode("other")
