from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class DICOMControlledTerminologyDefinitionsCode(GenericTypeCode):
    """
    DICOM Controlled Terminology Definitions
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
        DICOM Code Definitions (Coding Scheme Designator "DCM" Coding Scheme Version
    "01")
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://dicom.nema.org/resources/ontology/DCM
    """
    codeset: FhirUri = "http://dicom.nema.org/resources/ontology/DCM"


class DICOMControlledTerminologyDefinitionsCodeValues:
    """
    Archive device
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """

    Archive = DICOMControlledTerminologyDefinitionsCode("ARCHIVE")
    """
    Autorefraction device
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Autorefraction = DICOMControlledTerminologyDefinitionsCode("AR")
    """
    Angioscopy device
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Angioscopy = DICOMControlledTerminologyDefinitionsCode("AS")
    """
    Audio object
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Audio = DICOMControlledTerminologyDefinitionsCode("AU")
    """
    Ultrasound Bone Densitometry (modality)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    UltrasoundBoneDensitometry = DICOMControlledTerminologyDefinitionsCode("BDUS")
    """
    Biomagnetic imaging device
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BiomagneticImaging = DICOMControlledTerminologyDefinitionsCode("BI")
    """
    Bone Mineral Densitometry by X-Ray (modality), including dual-energy X-Ray
    absorptiometry (DXA) and morphometric X-Ray absorptiometry (MXA)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BoneMineralDensitometry = DICOMControlledTerminologyDefinitionsCode("BMD")
    """
    Computer Assisted Detection/Diagnosis device
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ComputerAssistedDetection_Diagnosis = DICOMControlledTerminologyDefinitionsCode(
        "CAD"
    )
    """
    Image Capture Device, includes video capture
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ImageCapture = DICOMControlledTerminologyDefinitionsCode("CAPTURE")
    """
    Color flow Doppler
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ColorFlowDoppler = DICOMControlledTerminologyDefinitionsCode("CD")
    """
    Cinefluorography
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Cinefluorography = DICOMControlledTerminologyDefinitionsCode("CF")
    """
    Computation Server; includes radiotherapy planning
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ComputationServer = DICOMControlledTerminologyDefinitionsCode("COMP")
    """
    Culposcopy
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Culposcopy = DICOMControlledTerminologyDefinitionsCode("CP")
    """
    Computed Radiography device
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ComputedRadiography = DICOMControlledTerminologyDefinitionsCode("CR")
    """
    Cystoscopy
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Cystoscopy = DICOMControlledTerminologyDefinitionsCode("CS")
    """
    Computed Tomography device
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ComputedTomography = DICOMControlledTerminologyDefinitionsCode("CT")
    """
    Duplex Doppler
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DuplexDoppler = DICOMControlledTerminologyDefinitionsCode("DD")
    """
    Digital fluoroscopy
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DigitalFluoroscopy = DICOMControlledTerminologyDefinitionsCode("DF")
    """
    Diaphanography device
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Diaphanography = DICOMControlledTerminologyDefinitionsCode("DG")
    """
    Digital microscopy
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DigitalMicroscopy = DICOMControlledTerminologyDefinitionsCode("DM")
    """
    Equipment that digitized hardcopy documents and imported them
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DocumentDigitizerEquipment = DICOMControlledTerminologyDefinitionsCode("DOCD")
    """
    Digital Subtraction Angiography
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DigitalSubtractionAngiography = DICOMControlledTerminologyDefinitionsCode("DS")
    """
    Department System Scheduler, workflow manager; includes RIS
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DepartmentSystemScheduler = DICOMControlledTerminologyDefinitionsCode("DSS")
    """
    Digital Radiography device
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DigitalRadiography = DICOMControlledTerminologyDefinitionsCode("DX")
    """
    Echocardiography
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Echocardiography = DICOMControlledTerminologyDefinitionsCode("EC")
    """
    Electrocardiography device
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Electrocardiography = DICOMControlledTerminologyDefinitionsCode("ECG")
    """
    Cardiac Electrophysiology device
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CardiacElectrophysiology = DICOMControlledTerminologyDefinitionsCode("EPS")
    """
    Endoscopy device
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Endoscopy = DICOMControlledTerminologyDefinitionsCode("ES")
    """
    Female sex
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Female = DICOMControlledTerminologyDefinitionsCode("F")
    """
    Fluorescein angiography
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FluoresceinAngiography = DICOMControlledTerminologyDefinitionsCode("FA")
    """
    Female sex changed to Male sex
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FemaleChangedToMale = DICOMControlledTerminologyDefinitionsCode("FC")
    """
    Film Digitizer
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FilmDigitizer = DICOMControlledTerminologyDefinitionsCode("FILMD")
    """
    Female Pseudohermaphrodite
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FemalePseudohermaphrodite = DICOMControlledTerminologyDefinitionsCode("FP")
    """
    Fundoscopy
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Fundoscopy = DICOMControlledTerminologyDefinitionsCode("FS")
    """
    General Microscopy device
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    GeneralMicroscopy = DICOMControlledTerminologyDefinitionsCode("GM")
    """
    Hermaphrodite
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Hermaphrodite = DICOMControlledTerminologyDefinitionsCode("H")
    """
    Hard Copy
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    HardCopy = DICOMControlledTerminologyDefinitionsCode("HC")
    """
    Hemodynamic Waveform acquisition device
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    HemodynamicWaveform = DICOMControlledTerminologyDefinitionsCode("HD")
    """
    Intra-oral Radiography device
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Intra_oralRadiography = DICOMControlledTerminologyDefinitionsCode("IO")
    """
    An acquisition device, process or method that performs intravascular optical
    coherence tomography
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IntravascularOpticalCoherenceTomography = DICOMControlledTerminologyDefinitionsCode(
        "IVOCT"
    )
    """
    Intravascular Ultrasound device
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IntravascularUltrasound = DICOMControlledTerminologyDefinitionsCode("IVUS")
    """
    Keratometry device
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Keratometry = DICOMControlledTerminologyDefinitionsCode("KER")
    """
    Key Object Selection object
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    KeyObjectSelection = DICOMControlledTerminologyDefinitionsCode("KO")
    """
    Lensometry device
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Lensometry = DICOMControlledTerminologyDefinitionsCode("LEN")
    """
    Procedure Logging device; includes cath lab logging
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ProcedureLogging = DICOMControlledTerminologyDefinitionsCode("LOG")
    """
    Laparoscopy
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Laparoscopy = DICOMControlledTerminologyDefinitionsCode("LP")
    """
    Laser surface scan device
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LaserSurfaceScan = DICOMControlledTerminologyDefinitionsCode("LS")
    """
    Male sex
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Male = DICOMControlledTerminologyDefinitionsCode("M")
    """
    Magnetic resonance angiography
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MagneticResonanceAngiography = DICOMControlledTerminologyDefinitionsCode("MA")
    """
    Male sex changed to Female sex
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MaleChangedToFemale = DICOMControlledTerminologyDefinitionsCode("MC")
    """
    A device that creates DICOM PS3.10 interchange media; e.g. a CD creator that
    is managed by the Media Creation Management Service Class
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MediaCreationDevice = DICOMControlledTerminologyDefinitionsCode("MCD")
    """
    Equipment that retrieved and imported objects from interchange Media
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PortableMediaImporterEquipment = DICOMControlledTerminologyDefinitionsCode("MEDIM")
    """
    Mammography device
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Mammography = DICOMControlledTerminologyDefinitionsCode("MG")
    """
    Male Pseudohermaphrodite
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MalePseudohermaphrodite = DICOMControlledTerminologyDefinitionsCode("MP")
    """
    Magnetic Resonance device
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MagneticResonance = DICOMControlledTerminologyDefinitionsCode("MR")
    """
    Magnetic resonance spectroscopy
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MagneticResonanceSpectroscopy = DICOMControlledTerminologyDefinitionsCode("MS")
    """
    Instances need to be retrieved from relatively slow media such as optical disk
    or tape
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Nearline = DICOMControlledTerminologyDefinitionsCode("NEARLINE")
    """
    Nuclear Medicine device
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NuclearMedicine = DICOMControlledTerminologyDefinitionsCode("NM")
    """
    Measurements of the axial length of the eye, which are done by various devices
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OphthalmicAxialMeasurements = DICOMControlledTerminologyDefinitionsCode("OAM")
    """
    Modality device that uses an interferometric, non-invasive optical tomographic
    technique to image 2D slices and 3D volumes of tissue using visible and near
    visible frequencies
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OpticalCoherenceTomography = DICOMControlledTerminologyDefinitionsCode("OCT")
    """
    Instances need to be retrieved by manual intervention
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Offline = DICOMControlledTerminologyDefinitionsCode("OFFLINE")
    """
    Instances are immediately available
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Online = DICOMControlledTerminologyDefinitionsCode("ONLINE")
    """
    Ophthalmic photography modality
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OphthalmicPhotography = DICOMControlledTerminologyDefinitionsCode("OP")
    """
    Modality device that measures corneal topography, corneal or retinal
    thickness, and other similar parameters that are typically displayed as maps
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OphthalmicMapping = DICOMControlledTerminologyDefinitionsCode("OPM")
    """
    Modality device that measures the refractive characteristics of the eye
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OphthalmicRefraction = DICOMControlledTerminologyDefinitionsCode("OPR")
    """
    Tomography of the eye acquired by a modality that is based on light and
    optical principles. Tomography based on other principles, such as ultrasound,
    is excluded
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OphthalmicTomography = DICOMControlledTerminologyDefinitionsCode("OPT")
    """
    Modality device that measures visual fields and perform visual perimetry
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OphthalmicVisualField = DICOMControlledTerminologyDefinitionsCode("OPV")
    """
    An acquisition device, process or method that performs optical surface
    scanning
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OpticalSurvaceScanner = DICOMControlledTerminologyDefinitionsCode("OSS")
    """
    Other Modality device
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OtherModality = DICOMControlledTerminologyDefinitionsCode("OT")
    """
    Presentation State object
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PresentationState = DICOMControlledTerminologyDefinitionsCode("PR")
    """
    Hard Copy Print Server; includes printers with embedded DICOM print server
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    HardCopyPrintServer = DICOMControlledTerminologyDefinitionsCode("PRINT")
    """
    Positron emission tomography (PET) device
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PositronEmissionTomography = DICOMControlledTerminologyDefinitionsCode("PT")
    """
    Panoramic X-Ray device
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PanoramicX_Ray = DICOMControlledTerminologyDefinitionsCode("PX")
    """
    Registration
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Registration = DICOMControlledTerminologyDefinitionsCode("REG")
    """
    Radiofluoroscopy device
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Radiofluoroscopy = DICOMControlledTerminologyDefinitionsCode("RF")
    """
    Radiographic imaging (conventional film/screen)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RadiographicImaging = DICOMControlledTerminologyDefinitionsCode("RG")
    """
    Radiation Therapy Device; includes linear accelerator, proton therapy
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RadiationTherapyDevice = DICOMControlledTerminologyDefinitionsCode("RT")
    """
    Radiotherapy Dose
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RadiotherapyDose = DICOMControlledTerminologyDefinitionsCode("RTDOSE")
    """
    Radiotherapy Imaging device; includes portal imaging
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RadiotherapyImage = DICOMControlledTerminologyDefinitionsCode("RTIMAGE")
    """
    Radiotherapy Plan
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RadiotherapyPlan = DICOMControlledTerminologyDefinitionsCode("RTPLAN")
    """
    Radiotherapy Treatment Record
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RadiotherapyTreatmentRecord = DICOMControlledTerminologyDefinitionsCode("RTRECORD")
    """
    Radiotherapy Structure Set
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RadiotherapyStructureSet = DICOMControlledTerminologyDefinitionsCode("RTSTRUCT")
    """
    Segmentation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Segmentation = DICOMControlledTerminologyDefinitionsCode("SEG")
    """
    Slide Microscopy
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SlideMicroscopy = DICOMControlledTerminologyDefinitionsCode("SM")
    """
    Stereometric image pairing modality
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StereometricRelationship = DICOMControlledTerminologyDefinitionsCode("SMR")
    """
    Structured Report Document
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StructuredReportDocument = DICOMControlledTerminologyDefinitionsCode("SR")
    """
    Subjective Refraction device
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SubjectiveRefraction = DICOMControlledTerminologyDefinitionsCode("SRF")
    """
    Single-photon emission computed tomography (SPECT) device
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Single_photonEmissionComputedTomography = DICOMControlledTerminologyDefinitionsCode(
        "ST"
    )
    """
    Thermography device
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Thermography = DICOMControlledTerminologyDefinitionsCode("TG")
    """
    Unknown Sex
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    UnknownSex = DICOMControlledTerminologyDefinitionsCode("U")
    """
    Instances cannot be retrieved
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Unavailable = DICOMControlledTerminologyDefinitionsCode("UNAVAILABLE")
    """
    Ultrasound device
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Ultrasound = DICOMControlledTerminologyDefinitionsCode("US")
    """
    Visual Acuity device
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VisualAcuity = DICOMControlledTerminologyDefinitionsCode("VA")
    """
    Videofluorography
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Videofluorography = DICOMControlledTerminologyDefinitionsCode("VF")
    """
    Equipment that digitizes video tape and imports it
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VideoTapeDigitizerEquipment = DICOMControlledTerminologyDefinitionsCode("VIDD")
    """
    Workstation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Workstation = DICOMControlledTerminologyDefinitionsCode("WSD")
    """
    X-Ray Angiography device
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    X_RayAngiography = DICOMControlledTerminologyDefinitionsCode("XA")
    """
    External-camera Photography device
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    External_cameraPhotography = DICOMControlledTerminologyDefinitionsCode("XC")
    """
    A signal transmitted for the purpose of interchange of the current time, not
    specific to any source or methodology
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DigitalTimecode_NOS_ = DICOMControlledTerminologyDefinitionsCode("109001")
    """
    A signal that is generated for each detection of a heart beat
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ECG_basedGatingSignal_Processed = DICOMControlledTerminologyDefinitionsCode(
        "109002"
    )
    """
    A signal transmitted by the Inter-Range Instrumentation Group for the purpose
    of synchronizing time clocks
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IRIG_BTimecode = DICOMControlledTerminologyDefinitionsCode("109003")
    """
    A signal that indicated that X-Ray source has been activated for fluoroscopy
    use
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    X_RayFluoroscopyOnSignal = DICOMControlledTerminologyDefinitionsCode("109004")
    """
    A signal that indicated that the X-Ray source has been activated for image
    recording
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    X_RayOnTrigger = DICOMControlledTerminologyDefinitionsCode("109005")
    """
    An electrical signal derived from two electrodes
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DifferentialSignal = DICOMControlledTerminologyDefinitionsCode("109006")
    """
    An electrophysiological recording from the HIS nerve bundle
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    HisBundleElectrogram = DICOMControlledTerminologyDefinitionsCode("109007")
    """
    An electrical signal from one electrode relative to an indifferent potential
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MonopoleSignal = DICOMControlledTerminologyDefinitionsCode("109008")
    """
    The voltage stimulus during cardiac pacing
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Pacing_electrical_Stimulus_Voltage = DICOMControlledTerminologyDefinitionsCode(
        "109009"
    )
    """
    The power injected during RF ablation procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RadioFrequencyAblation_Power = DICOMControlledTerminologyDefinitionsCode("109010")
    """
    Electrophysiological signals acquired using a multi-splined catheter each
    equipped with multiple electrodes
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VoltageMeasurementByBasketCatheter = DICOMControlledTerminologyDefinitionsCode(
        "109011"
    )
    """
    Electrophysiological signals acquired using a steerable catheter
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VoltageMeasurementByMappingCatheter = DICOMControlledTerminologyDefinitionsCode(
        "109012"
    )
    """
    A voltage measurement not otherwise specified
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VoltageMeasurement_NOS = DICOMControlledTerminologyDefinitionsCode("109013")
    """
    A signal point that is 35% of the peak thermal cardiac output signal
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    _35_OfThermalCO = DICOMControlledTerminologyDefinitionsCode("109014")
    """
    A signal point that is 70% of the peak thermal cardiac output signal
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    _70_OfThermalCO = DICOMControlledTerminologyDefinitionsCode("109015")
    """
    The peak pressure of each heart beat in the atrium caused by the atrial
    contraction
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AWavePeakPressure = DICOMControlledTerminologyDefinitionsCode("109016")
    """
    The average of several A wave pressure measurements
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AWavePressure_Average = DICOMControlledTerminologyDefinitionsCode("109017")
    """
    An identified cardiac beat used in the determination of a measurement
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BeatDetected_accepted_ = DICOMControlledTerminologyDefinitionsCode("109018")
    """
    An identified cardiac beat not used in the determination of a measurement
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BeatDetected_rejected_ = DICOMControlledTerminologyDefinitionsCode("109019")
    """
    The average of several diastolic pressure measurements
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DiastolicPressure_Average = DICOMControlledTerminologyDefinitionsCode("109020")
    """
    The lowest pressure value excluding any undershoot artifact
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DiastolicPressureNadir = DICOMControlledTerminologyDefinitionsCode("109021")
    """
    The moment at the end of the diastolic phase of the cardiac cycle
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EndDiastole = DICOMControlledTerminologyDefinitionsCode("109022")
    """
    The moment at the end of respiratory expiration
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EndOfExpiration = DICOMControlledTerminologyDefinitionsCode("109023")
    """
    The moment at the end of respiratory inspiration
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EndOfInspiration = DICOMControlledTerminologyDefinitionsCode("109024")
    """
    The maximum positive rate of change of pressure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MaxDp_dt = DICOMControlledTerminologyDefinitionsCode("109025")
    """
    The maximum negative rate of change of pressure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MaxNegDp_dt = DICOMControlledTerminologyDefinitionsCode("109026")
    """
    The average blood pressure value, generally over 2 or more seconds
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MeanBloodPressure = DICOMControlledTerminologyDefinitionsCode("109027")
    """
    The peak change in blood temperature during a thermal cardiac output
    measurement
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PeakOfThermalCardiacOutputBolus = DICOMControlledTerminologyDefinitionsCode(
        "109028"
    )
    """
    The moment respiratory expiration begins
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StartOfExpiration = DICOMControlledTerminologyDefinitionsCode("109029")
    """
    The moment of respiratory inspiration begins
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StartOfInspiration = DICOMControlledTerminologyDefinitionsCode("109030")
    """
    The first discernible blood temperature change following the injectate during
    a thermal cardiac output measurement
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StartOfThermalCardiacOutputBolus = DICOMControlledTerminologyDefinitionsCode(
        "109031"
    )
    """
    The average of several systolic blood pressure measurements
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SystolicPressure_Average = DICOMControlledTerminologyDefinitionsCode("109032")
    """
    The highest systolic blood pressure value excluding any overshoot artifact
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SystolicPeakPressure = DICOMControlledTerminologyDefinitionsCode("109033")
    """
    The peak pressure of each heart beat in the atrium caused by the filling of
    the atrium
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VWavePeakPressure = DICOMControlledTerminologyDefinitionsCode("109034")
    """
    The average of several V wave pressure measurements
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VWavePressure_Average = DICOMControlledTerminologyDefinitionsCode("109035")
    """
    The moment at which a heart valve closes
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ValveClose = DICOMControlledTerminologyDefinitionsCode("109036")
    """
    The moment at which a heart valve opens
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ValveOpen = DICOMControlledTerminologyDefinitionsCode("109037")
    """
    The moment when RF ablation current is turned off
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AblationOff = DICOMControlledTerminologyDefinitionsCode("109038")
    """
    The moment when RF ablation current is turned on
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AblationOn = DICOMControlledTerminologyDefinitionsCode("109039")
    """
    The moment in the cardiac cycle when the HIS bundle nerves depolarize
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    HISBundleWave = DICOMControlledTerminologyDefinitionsCode("109040")
    """
    The surface electrocardiogram of the atrial contraction
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PWave = DICOMControlledTerminologyDefinitionsCode("109041")
    """
    The first negative deflection of the electrocardiogram caused by ventricular
    depolarization
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    QWave = DICOMControlledTerminologyDefinitionsCode("109042")
    """
    The first positive deflection the electrocardiogram caused by ventricular
    depolarization
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RWave = DICOMControlledTerminologyDefinitionsCode("109043")
    """
    The first negative deflection after the R wave
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SWave = DICOMControlledTerminologyDefinitionsCode("109044")
    """
    The beginning of the atrial contraction
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StartOfAtrialContraction = DICOMControlledTerminologyDefinitionsCode("109045")
    """
    The beginning of the second atrial contraction of two consecutive beats
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StartOfAtrialContraction_subsequent_ = DICOMControlledTerminologyDefinitionsCode(
        "109046"
    )
    """
    The stimulation interval during cardiac stimulation first used in a pacing
    train
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StimulationAtRate1Interval = DICOMControlledTerminologyDefinitionsCode("109047")
    """
    The stimulation interval different from the first stimulation interval used in
    a pacing train
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StimulationAtRate2Interval = DICOMControlledTerminologyDefinitionsCode("109048")
    """
    A stimulation interval different from and subsequent to the second interval in
    a pacing train
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StimulationAtRate3Interval = DICOMControlledTerminologyDefinitionsCode("109049")
    """
    Describes a stimulation interval different from and subsequent to the third
    interval in a pacing train
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StimulationAtRate4Interval = DICOMControlledTerminologyDefinitionsCode("109050")
    """
    The electrocardiogram deflection caused by ventricular repolarization
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TWave = DICOMControlledTerminologyDefinitionsCode("109051")
    """
    The peak pressure of each heart beat monitored in the atrium caused by the
    filling of the atrium
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VWave = DICOMControlledTerminologyDefinitionsCode("109052")
    """
    The second V wave measurement of two consecutive beats
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VWaveOfNextBeat = DICOMControlledTerminologyDefinitionsCode("109053")
    """
    A description of the physiological condition of the patient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientState = DICOMControlledTerminologyDefinitionsCode("109054")
    """
    The exercise level during a progressive cardiac stress test
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ProtocolStage = DICOMControlledTerminologyDefinitionsCode("109055")
    """
    A series of physiological challenges designed to progressively increase the
    work of the heart
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StressProtocol = DICOMControlledTerminologyDefinitionsCode("109056")
    """
    A subpart of a cardiac catheterization procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CatheterizationProcedurePhase = DICOMControlledTerminologyDefinitionsCode("109057")
    """
    The subpart of a cardiac catheterization procedure in which a radio-opaque
    contrast medium is injected into the patient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ContrastPhase = DICOMControlledTerminologyDefinitionsCode("109058")
    """
    Physical changes administered to a patient in order to elicit an physiological
    response
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PhysiologicalChallenges = DICOMControlledTerminologyDefinitionsCode("109059")
    """
    Enumeration of a subpart of a catheterization procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ProcedureStepNumber = DICOMControlledTerminologyDefinitionsCode("109060")
    """
    A subpart of an electrophysiological procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EPProcedurePhase = DICOMControlledTerminologyDefinitionsCode("109061")
    """
    A means of defining a series of cardiac stimulation pulses
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PulseTrainDefinition = DICOMControlledTerminologyDefinitionsCode("109063")
    """
    End of the contraction phase of the cardiac cycle
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EndOfSystole = DICOMControlledTerminologyDefinitionsCode("109070")
    """
    Time for a median particle to travel from point of injection to point of
    detection
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IndicatorMeanTransitTime = DICOMControlledTerminologyDefinitionsCode("109071")
    """
    The time constant of isovolumic pressure fall
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Tau = DICOMControlledTerminologyDefinitionsCode("109072")
    """
    Maximum velocity of myocardial contractility
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VMaxMyocardial = DICOMControlledTerminologyDefinitionsCode("109073")
    """
    Total time for the acquisition is shorter than cardiac cycle, no gating is
    applied; see Cardiac Synchronization Technique (0018,9037)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RealTimeAcquisition = DICOMControlledTerminologyDefinitionsCode("109080")
    """
    Certain thresholds have been set for a gating window that defines the
    acceptance of measurement data during the acquisition; see Cardiac
    Synchronization Technique (0018,9037)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ProspectiveGating = DICOMControlledTerminologyDefinitionsCode("109081")
    """
    Certain thresholds have been set for a gating window that defines the
    acceptance of measurement data after the acquisition; see Cardiac
    Synchronization Technique (0018,9037)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RetrospectiveGating = DICOMControlledTerminologyDefinitionsCode("109082")
    """
    There is a constant RR interval, which makes thresholding not required; see
    Cardiac Synchronization Technique (0018,9037); e.g. Pacemaker
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Paced = DICOMControlledTerminologyDefinitionsCode("109083")
    """
    Imaging after injection of tracer during increased cardiac workload or
    increased myocardial blood flow, achieved by either exercise or pharmacologic
    means
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CardiacStressState = DICOMControlledTerminologyDefinitionsCode("109091")
    """
    Imaging after injection of additional tracer under resting conditions
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ReinjectionState = DICOMControlledTerminologyDefinitionsCode("109092")
    """
    Imaging after allowing a moderate amount of time for tracer to move from its
    initial sites of uptake. Example: For Thallium imaging this would correspond
    to imaging 2-6 hours after injection
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RedistributionState = DICOMControlledTerminologyDefinitionsCode("109093")
    """
    Imaging after allowing an extended amount of time for tracer to move from its
    initial sites of uptake. Example: For Thallium imaging this would correspond
    to imaging more than 6 hours after injection
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DelayedRedistributionState = DICOMControlledTerminologyDefinitionsCode("109094")
    """
    Peak cardiac stress state
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PeakStressState = DICOMControlledTerminologyDefinitionsCode("109095")
    """
    Recovery from cardiac stress
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RecoveryState = DICOMControlledTerminologyDefinitionsCode("109096")
    """
    Equipment that originally acquired the data stored within composite instances;
    e.g. a CT, MR or Ultrasound modality
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AcquisitionEquipment = DICOMControlledTerminologyDefinitionsCode("109101")
    """
    Equipment that has processed composite instances to create new composite
    instances; e.g. a 3D Workstation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ProcessingEquipment = DICOMControlledTerminologyDefinitionsCode("109102")
    """
    Equipment that has modified existing composite instances (without creating new
    composite instances); e.g. a QA Station or Archive
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ModifyingEquipment = DICOMControlledTerminologyDefinitionsCode("109103")
    """
    Equipment that has modified an existing composite instance to remove patient
    identifying information
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    De_identifyingEquipment = DICOMControlledTerminologyDefinitionsCode("109104")
    """
    Equipment that has processed composite instances to create new composite
    instances by extracting selected frames from the original instance
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FrameExtractingEquipment = DICOMControlledTerminologyDefinitionsCode("109105")
    """
    Equipment that has processed composite instances to create new composite
    instances by converting classic single frame images to enhanced multi-frame
    image, or vice versa and updating other instances to maintain referential
    integrity
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EnhancedMulti_frameConversionEquipment = DICOMControlledTerminologyDefinitionsCode(
        "109106"
    )
    """
    The sound of a human's speech, recorded during a procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Voice = DICOMControlledTerminologyDefinitionsCode("109110")
    """
    The voice of a device operator, recorded during a procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Operator_sNarrative = DICOMControlledTerminologyDefinitionsCode("109111")
    """
    The ambient sound recorded during a procedure, which may or may not include
    voice and other types of sound
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AmbientRoomEnvironment = DICOMControlledTerminologyDefinitionsCode("109112")
    """
    The Doppler waveform recorded as an audible signal
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DopplerAudio = DICOMControlledTerminologyDefinitionsCode("109113")
    """
    The sound of the human heart beating
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Phonocardiogram = DICOMControlledTerminologyDefinitionsCode("109114")
    """
    Any sound made by the human body
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PhysiologicalAudioSignal = DICOMControlledTerminologyDefinitionsCode("109115")
    """
    A digitized signal from the patient arterial system collected through pulse
    oximetry or other means
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ArterialPulseWaveform = DICOMControlledTerminologyDefinitionsCode("109116")
    """
    A digitized signal from the patient respiratory system representing
    respiration
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RespirationWaveform = DICOMControlledTerminologyDefinitionsCode("109117")
    """
    The occasion on which a procedure was performed on admission to a specialist
    unit; e.g. intensive care
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OnAdmissionToUnit = DICOMControlledTerminologyDefinitionsCode("109120")
    """
    The occasion on which a procedure was performed on discharge from hospital as
    an in-patient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OnDischarge = DICOMControlledTerminologyDefinitionsCode("109121")
    """
    The occasion on which a procedure was performed on discharge from a specialist
    unit; e.g. intensive care
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OnDischargeFromUnit = DICOMControlledTerminologyDefinitionsCode("109122")
    """
    The occasion on which a procedure was performed immediately prior to non-
    surgical intervention; e.g, percutaneous angioplasty, biopsy
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Pre_intervention = DICOMControlledTerminologyDefinitionsCode("109123")
    """
    The occasion on which a procedure was performed immediately after to non-
    surgical intervention; e.g, percutaneous angioplasty, biopsy
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Post_intervention = DICOMControlledTerminologyDefinitionsCode("109124")
    """
    The occasion on which a procedure was performed at the most recent outpatient
    visit
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AtLastAppointment = DICOMControlledTerminologyDefinitionsCode("109125")
    """
    The active or passive joint positioning during acquisition
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    JointPositionMethod = DICOMControlledTerminologyDefinitionsCode("109132")
    """
    A physical force applied during acquisition
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PhysicalForce = DICOMControlledTerminologyDefinitionsCode("109133")
    """
    Prior to voiding
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PriorToVoiding = DICOMControlledTerminologyDefinitionsCode("109134")
    """
    Post voiding
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PostVoiding = DICOMControlledTerminologyDefinitionsCode("109135")
    """
    Neutral musculoskeletal position
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NeutralMusculoskeletalPosition = DICOMControlledTerminologyDefinitionsCode("109136")
    """
    America Kennel Club
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AmericaKennelClub = DICOMControlledTerminologyDefinitionsCode("109200")
    """
    America's Pet Registry Inc
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    America_sPetRegistryInc_ = DICOMControlledTerminologyDefinitionsCode("109201")
    """
    American Canine Association
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AmericanCanineAssociation = DICOMControlledTerminologyDefinitionsCode("109202")
    """
    American Purebred Registry
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AmericanPurebredRegistry = DICOMControlledTerminologyDefinitionsCode("109203")
    """
    American Rare Breed Association
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AmericanRareBreedAssociation = DICOMControlledTerminologyDefinitionsCode("109204")
    """
    Animal Registry Unlimited
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AnimalRegistryUnlimited = DICOMControlledTerminologyDefinitionsCode("109205")
    """
    Animal Research Foundation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AnimalResearchFoundation = DICOMControlledTerminologyDefinitionsCode("109206")
    """
    Canadian Border Collie Association
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CanadianBorderCollieAssociation = DICOMControlledTerminologyDefinitionsCode(
        "109207"
    )
    """
    Canadian Kennel Club
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CanadianKennelClub = DICOMControlledTerminologyDefinitionsCode("109208")
    """
    Canadian Livestock Records Association
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CanadianLivestockRecordsAssociation = DICOMControlledTerminologyDefinitionsCode(
        "109209"
    )
    """
    Canine Federation of Canada
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CanineFederationOfCanada = DICOMControlledTerminologyDefinitionsCode("109210")
    """
    Continental Kennel Club
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ContinentalKennelClub = DICOMControlledTerminologyDefinitionsCode("109211")
    """
    Dog Registry of America
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DogRegistryOfAmerica = DICOMControlledTerminologyDefinitionsCode("109212")
    """
    Federation of International Canines
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FederationOfInternationalCanines = DICOMControlledTerminologyDefinitionsCode(
        "109213"
    )
    """
    International Progressive Dog Breeders' Alliance
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    InternationalProgressiveDogBreeders_Alliance = (
        DICOMControlledTerminologyDefinitionsCode("109214")
    )
    """
    National Kennel Club
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NationalKennelClub = DICOMControlledTerminologyDefinitionsCode("109215")
    """
    North American Purebred Dog Registry
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NorthAmericanPurebredDogRegistry = DICOMControlledTerminologyDefinitionsCode(
        "109216"
    )
    """
    United All Breed Registry
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    UnitedAllBreedRegistry = DICOMControlledTerminologyDefinitionsCode("109217")
    """
    United Kennel Club
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    UnitedKennelClub = DICOMControlledTerminologyDefinitionsCode("109218")
    """
    Universal Kennel Club International
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    UniversalKennelClubInternational = DICOMControlledTerminologyDefinitionsCode(
        "109219"
    )
    """
    Working Canine Association of Canada
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    WorkingCanineAssociationOfCanada = DICOMControlledTerminologyDefinitionsCode(
        "109220"
    )
    """
    World Kennel Club
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    WorldKennelClub = DICOMControlledTerminologyDefinitionsCode("109221")
    """
    World Wide Kennel Club
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    WorldWideKennelClub = DICOMControlledTerminologyDefinitionsCode("109222")
    """
    Evaluation of overall image quality as described in section 7.3.2 of [IEC
    62563-1]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OverallImageQualityEvaluation = DICOMControlledTerminologyDefinitionsCode("109701")
    """
    Visual verification of sufficient grayscale resolution based on 8 and 10-bit
    markers as described in section 7.3.3 of [IEC 62563-1]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    GrayscaleResolutionEvaluation = DICOMControlledTerminologyDefinitionsCode("109702")
    """
    Visual evaluation of luminance response using the TG18-CT test pattern as
    described in section 7.3.4 of [IEC 62563-1]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LuminanceResponseEvaluation = DICOMControlledTerminologyDefinitionsCode("109703")
    """
    Visual detection of luminance non-uniformities as described in section 7.3.5
    of [IEC 62563-1]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LuminanceUniformityEvaluation = DICOMControlledTerminologyDefinitionsCode("109704")
    """
    Visual verification of color uniformity as described in section 7.3.6 of [IEC
    62563-1]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ChromaticityEvaluation = DICOMControlledTerminologyDefinitionsCode("109705")
    """
    Visual detection of defective pixels on dark (TG18-UN80) and bright
    (TG18-UN10) images as described in section 7.3.7 of [IEC 62563-1]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PixelFaultsEvaluation = DICOMControlledTerminologyDefinitionsCode("109706")
    """
    Visual evaluation of veiling glare by looking at low contrast objects on 2
    test patterns as described in section 7.3.8 of [IEC 62563-1]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VeilingGlareEvaluation = DICOMControlledTerminologyDefinitionsCode("109707")
    """
    Visual evaluation of geometry, phase/clock correction and clipping as
    described in section 7.3.9 of [IEC 62563-1]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    GeometricalImageEvaluation = DICOMControlledTerminologyDefinitionsCode("109708")
    """
    Visual evaluation of viewing angle as described in section 7.3.10 of [IEC
    62563-1]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AngularViewingEvaluation = DICOMControlledTerminologyDefinitionsCode("109709")
    """
    Visual evaluation of the appearance of clinical images as described in section
    7.3.11 of [IEC 62563-1]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ClinicalEvaluation = DICOMControlledTerminologyDefinitionsCode("109710")
    """
    AAPM TG18-QC Pattern used for evaluation of resolution, luminance, distortion,
    artifacts. See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_QCPattern = DICOMControlledTerminologyDefinitionsCode("109801")
    """
    AAPM TG18-BR Pattern used for the evaluation of the display of low-contrast,
    fine-detail image structures See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_BRPattern = DICOMControlledTerminologyDefinitionsCode("109802")
    """
    AAPM TG18-PQC Pattern used for evaluation of resolution, luminance, contrast
    transfer for prints. See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_PQCPattern = DICOMControlledTerminologyDefinitionsCode("109803")
    """
    AAPM TG18-CT Pattern used for evaluation of luminance response. See [AAPM OR
    03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_CTPattern = DICOMControlledTerminologyDefinitionsCode("109804")
    """
    The 1st image in the AAPM TG18-LN8 set used for DICOM grayscale calibration.
    See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_LN8_01Pattern = DICOMControlledTerminologyDefinitionsCode("109805")
    """
    The 2nd image in the AAPM TG18-LN8 set used for DICOM grayscale calibration.
    See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_LN8_02Pattern = DICOMControlledTerminologyDefinitionsCode("109806")
    """
    The 3rd image in the AAPM TG18-LN8 set used for DICOM grayscale calibration.
    See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_LN8_03Pattern = DICOMControlledTerminologyDefinitionsCode("109807")
    """
    The 4th image in the AAPM TG18-LN8 set used for DICOM grayscale calibration.
    See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_LN8_04Pattern = DICOMControlledTerminologyDefinitionsCode("109808")
    """
    The 5th image in the AAPM TG18-LN8 set used for DICOM grayscale calibration.
    See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_LN8_05Pattern = DICOMControlledTerminologyDefinitionsCode("109809")
    """
    The 6th image in the AAPM TG18-LN8 set used for DICOM grayscale calibration.
    See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_LN8_06Pattern = DICOMControlledTerminologyDefinitionsCode("109810")
    """
    The 7th image in the AAPM TG18-LN8 set used for DICOM grayscale calibration.
    See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_LN8_07Pattern = DICOMControlledTerminologyDefinitionsCode("109811")
    """
    The 8th image in the AAPM TG18-LN8 set used for DICOM grayscale calibration.
    See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_LN8_08Pattern = DICOMControlledTerminologyDefinitionsCode("109812")
    """
    The 9th image in the AAPM TG18-LN8 set used for DICOM grayscale calibration.
    See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_LN8_09Pattern = DICOMControlledTerminologyDefinitionsCode("109813")
    """
    The 10th image in the AAPM TG18-LN8 set used for DICOM grayscale calibration
    series. See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_LN8_10Pattern = DICOMControlledTerminologyDefinitionsCode("109814")
    """
    The 11th image in the AAPM TG18-LN8 set used for DICOM grayscale calibration.
    See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_LN8_11Pattern = DICOMControlledTerminologyDefinitionsCode("109815")
    """
    The 12th image in the AAPM TG18-LN8 set used for DICOM grayscale calibration.
    See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_LN8_12Pattern = DICOMControlledTerminologyDefinitionsCode("109816")
    """
    The 13th image in the AAPM TG18-LN8 set used for DICOM grayscale calibration.
    See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_LN8_13Pattern = DICOMControlledTerminologyDefinitionsCode("109817")
    """
    The 14th image in the AAPM TG18-LN8 set used for DICOM grayscale calibration.
    See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_LN8_14Pattern = DICOMControlledTerminologyDefinitionsCode("109818")
    """
    The 15th image in the AAPM TG18-LN8 set used for DICOM grayscale calibration.
    See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_LN8_15Pattern = DICOMControlledTerminologyDefinitionsCode("109819")
    """
    The 16th image in the AAPM TG18-LN8 set used for DICOM grayscale calibration.
    See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_LN8_16Pattern = DICOMControlledTerminologyDefinitionsCode("109820")
    """
    The 17th image in the AAPM TG18-LN8 set used for DICOM grayscale calibration.
    See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_LN8_17Pattern = DICOMControlledTerminologyDefinitionsCode("109821")
    """
    The 18th image in the AAPM TG18-LN8- set used for DICOM grayscale calibration.
    See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_LN8_18Pattern = DICOMControlledTerminologyDefinitionsCode("109822")
    """
    The 1st image in the AAPM TG18-LN12 set used for DICOM grayscale calibration.
    See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_LN12_01Pattern = DICOMControlledTerminologyDefinitionsCode("109823")
    """
    The 2 nd image in the AAPM TG18-LN12 set used for DICOM grayscale calibration.
    See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_LN12_02Pattern = DICOMControlledTerminologyDefinitionsCode("109824")
    """
    The 3rd image in the AAPM TG18-LN12 set used for DICOM grayscale calibration.
    See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_LN12_03Pattern = DICOMControlledTerminologyDefinitionsCode("109825")
    """
    The 4th image in the AAPM TG18-LN12 set used for DICOM grayscale calibration.
    See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_LN12_04Pattern = DICOMControlledTerminologyDefinitionsCode("109826")
    """
    The 5th image in the AAPM TG18-LN12 set used for DICOM grayscale calibration.
    See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_LN12_05Pattern = DICOMControlledTerminologyDefinitionsCode("109827")
    """
    The 6th image in the AAPM TG18-LN12 set used for DICOM grayscale calibration.
    See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_LN12_06Pattern = DICOMControlledTerminologyDefinitionsCode("109828")
    """
    The 7th image in the AAPM TG18-LN12 set used for DICOM grayscale calibration.
    See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_LN12_07Pattern = DICOMControlledTerminologyDefinitionsCode("109829")
    """
    The 8th image in the AAPM TG18-LN12 set used for DICOM grayscale calibration.
    See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_LN12_08Pattern = DICOMControlledTerminologyDefinitionsCode("109830")
    """
    The 9th image in the AAPM TG18-LN12 set used for DICOM grayscale calibration.
    See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_LN12_09Pattern = DICOMControlledTerminologyDefinitionsCode("109831")
    """
    The 10th image in the AAPM TG18-LN12 set used for DICOM grayscale calibration.
    See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_LN12_10Pattern = DICOMControlledTerminologyDefinitionsCode("109832")
    """
    The 11th image in the AAPM TG18-LN12 set used for DICOM grayscale calibration.
    See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_LN12_11Pattern = DICOMControlledTerminologyDefinitionsCode("109833")
    """
    The 12th image in the AAPM TG18-LN12 set used for DICOM grayscale calibration.
    See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_LN12_12Pattern = DICOMControlledTerminologyDefinitionsCode("109834")
    """
    The 13th image in the AAPM TG18-LN12 set used for DICOM grayscale calibration.
    See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_LN12_13Pattern = DICOMControlledTerminologyDefinitionsCode("109835")
    """
    The 14th image in the AAPM TG18-LN12 set used for DICOM grayscale calibration.
    See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_LN12_14Pattern = DICOMControlledTerminologyDefinitionsCode("109836")
    """
    The 15th image in the AAPM TG18-LN12 set used for DICOM grayscale calibration.
    See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_LN12_15Pattern = DICOMControlledTerminologyDefinitionsCode("109837")
    """
    The 16th image in the AAPM TG18-LN12 set used for DICOM grayscale calibration.
    See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_LN12_16Pattern = DICOMControlledTerminologyDefinitionsCode("109838")
    """
    The 17th image in the AAPM TG18-LN12 set used for DICOM grayscale calibration.
    See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_LN12_17Pattern = DICOMControlledTerminologyDefinitionsCode("109839")
    """
    The 18th image in the AAPM TG18-LN12 set used for DICOM grayscale calibration.
    See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_LN12_18Pattern = DICOMControlledTerminologyDefinitionsCode("109840")
    """
    The AAPM TG18-UN10 Pattern used for evaluation of luminance and color
    uniformity, and angular response. See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_UN10Pattern = DICOMControlledTerminologyDefinitionsCode("109841")
    """
    The AAPM TG18-UN80 Pattern used for evaluation of luminance and color
    uniformity, and angular response. See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_UN80Pattern = DICOMControlledTerminologyDefinitionsCode("109842")
    """
    The AAPM TG18-UNL10 Pattern is the AAPM TG-18 UN10 Pattern with added defining
    lines. See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_UNL10Pattern = DICOMControlledTerminologyDefinitionsCode("109843")
    """
    The AAPM TG18-UNL80 Pattern is the AAPM TG-18 UN80 Pattern with added defining
    lines. See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_UNL80Pattern = DICOMControlledTerminologyDefinitionsCode("109844")
    """
    The AAPM TG18-AD Pattern used for visual evaluation of the reflection of
    ambient light from the display. See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_ADPattern = DICOMControlledTerminologyDefinitionsCode("109845")
    """
    The AAPM TG18-MP Pattern used for evaluation of Luminance response (bit-depth
    resolution). See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_MPPattern = DICOMControlledTerminologyDefinitionsCode("109846")
    """
    The AAPM TG18-RH10 Pattern used for LSF-line spectra function-(1k and 2k)
    evaluation by 5 horizontal lines at 10% luminance level. See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_RH10Pattern = DICOMControlledTerminologyDefinitionsCode("109847")
    """
    The AAPM TG18-RH50 Pattern used for LSF-line spectra function-(1k and 2k)
    evaluation by 5 horizontal lines at 50% luminance level. See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_RH50Pattern = DICOMControlledTerminologyDefinitionsCode("109848")
    """
    The AAPM TG18-RH89 Pattern used for LSF-line spectra function-(1k and 2k)
    evaluation by 5 horizontal lines at 89% luminance level. See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_RH89Pattern = DICOMControlledTerminologyDefinitionsCode("109849")
    """
    The AAPM TG18-RV10 Pattern used for LSF-line spectra function-(1k and 2k)
    evaluation by 5 vertical lines at 10% luminance level. See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_RV10Pattern = DICOMControlledTerminologyDefinitionsCode("109850")
    """
    The AAPM TG18-RV50 Pattern used for LSF-line spectra function-(1k and 2k)
    evaluation by 5 vertical lines at 50% luminance level. See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_RV50Pattern = DICOMControlledTerminologyDefinitionsCode("109851")
    """
    The AAPM TG18-RV89 Pattern used for LSF-line spectra function-(1k and 2k)
    evaluation by 5 vertical lines at 89% luminance level. See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_RV89Pattern = DICOMControlledTerminologyDefinitionsCode("109852")
    """
    The AAPM TG18-PX Pattern used for the assessment of display resolution. See
    [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_PXPattern = DICOMControlledTerminologyDefinitionsCode("109853")
    """
    The AAPM TG18-CX Pattern used to assess display resolution and resolution
    uniformity. See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_CXPattern = DICOMControlledTerminologyDefinitionsCode("109854")
    """
    The AAPM TG18-LPH10 Pattern used to assess display resolution. This pattern
    has horizontal bars consisting of alternating single-pixel-wide lines across
    the faceplate of display. The lines have a 12% positive contrast against 10%
    background level of the maximum pixel value. See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_LPH10Pattern = DICOMControlledTerminologyDefinitionsCode("109855")
    """
    The AAPM TG18-LPH50 Pattern used to assess display resolution. This pattern
    has horizontal bars consisting of alternating single-pixel-wide lines across
    the faceplate of display. The lines have a 50% positive contrast against 10%
    background level of the maximum pixel value. See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_LPH50Pattern = DICOMControlledTerminologyDefinitionsCode("109856")
    """
    The AAPM TG18-LPH89 Pattern used to assess display resolution. This pattern
    has horizontal bars consisting of alternating single-pixel-wide lines across
    the faceplate of display. The lines have a 12% positive contrast against 89%
    background level of the maximum pixel value. See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_LPH89Pattern = DICOMControlledTerminologyDefinitionsCode("109857")
    """
    The AAPM TG18-LPV10 Pattern used to assess display resolution. This pattern
    has vertical bars consisting of alternating single-pixel-wide lines across the
    faceplate of display. The lines have a 12% positive contrast against 10%
    background level of the maximum pixel value. See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_LPV10Pattern = DICOMControlledTerminologyDefinitionsCode("109858")
    """
    The AAPM TG18-LPV50 Pattern used to assess display resolution. This pattern
    has vertical bars consisting of alternating single-pixel-wide lines across the
    faceplate of display. The lines have a 12% positive contrast against 50%
    background level of the maximum pixel value. See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_LPV50Pattern = DICOMControlledTerminologyDefinitionsCode("109859")
    """
    The AAPM TG18-LPV89 Pattern used to assess display resolution. This pattern
    has vertical bars consisting of alternating single-pixel-wide lines across the
    faceplate of display. The lines have a 12% positive contrast against 89%
    background level of the maximum pixel value. See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_LPV89Pattern = DICOMControlledTerminologyDefinitionsCode("109860")
    """
    The AAPM TG18-AFC Pattern used to assess display noise. See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_AFCPattern = DICOMControlledTerminologyDefinitionsCode("109861")
    """
    The AAPM TG18-NS10 Pattern is AAPM TG18-RV10/RH10 with only difference being
    the absence of the single line at the center of the measurement area. See
    [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_NS10Pattern = DICOMControlledTerminologyDefinitionsCode("109862")
    """
    The AAPM TG18-NS50 Pattern is AAPM TG18-RV50/RH50 with only difference being
    the absence of the single line at the center of the measurement area. See
    [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_NS50Pattern = DICOMControlledTerminologyDefinitionsCode("109863")
    """
    The AAPM TG18-NS89 Pattern is AAPM TG18-RV89/RH89 with only difference being
    the absence of the single line at the center of the measurement area. See
    [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_NS89Pattern = DICOMControlledTerminologyDefinitionsCode("109864")
    """
    The TG18-GV Pattern used to assess display veiling. See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_GVPattern = DICOMControlledTerminologyDefinitionsCode("109865")
    """
    The TG18-GVN Pattern used to assess display veiling. This pattern is identical
    to AAPM TG18-GV Pattern except that the large-diameter white circle is
    replaced with a black circle, creating a completely black pattern except for
    the presence of low-contrast targets. See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_GVNPattern = DICOMControlledTerminologyDefinitionsCode("109866")
    """
    The TG18-GQ Pattern used for quantitative assessment of veiling glare. This
    pattern is identical to TG18-GV except that is lacks the central low-contrast
    objects. See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_GQPattern = DICOMControlledTerminologyDefinitionsCode("109867")
    """
    TG18-GQN Pattern used for the quantitative assessment of veiling glare. This
    pattern is identical to AAPM TG18-GQ Pattern except that the large-diameter
    white circle is replaced with a black circle, creating a completely black
    pattern except for the presence of low-contrast targets. See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_GQNPattern = DICOMControlledTerminologyDefinitionsCode("109868")
    """
    The TG18-GQB Pattern used for the quantitative assessment of veiling glare.
    This pattern is identical to AAPM TG18-GQ Pattern except eliminating the
    central black circle. See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_GQBPattern = DICOMControlledTerminologyDefinitionsCode("109869")
    """
    The TG18-GA03 Pattern used for quantitative assessment of veiling glare. This
    pattern is identical to TG18-GQ except that the radius of the central black
    circle is varied as r = 3. See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_GA03Pattern = DICOMControlledTerminologyDefinitionsCode("109870")
    """
    The TG18-GA05 Pattern This pattern is identical to TG18-GQ except that the
    radius of the central black circle is varied as r = 5. See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_GA05Pattern = DICOMControlledTerminologyDefinitionsCode("109871")
    """
    The TG18-GA08 Pattern used for quantitative assessment of veiling glare. This
    pattern is identical to TG18-GQ except that the radius of the central black
    circle is varied as r = 8. See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_GA08Pattern = DICOMControlledTerminologyDefinitionsCode("109872")
    """
    The TG18-GA10 Pattern used for quantitative assessment of veiling glare. This
    pattern is identical to TG18-GQ except that the radius of the central black
    circle is varied as r = 10. See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_GA10Pattern = DICOMControlledTerminologyDefinitionsCode("109873")
    """
    The TG18-GA15 Pattern used for quantitative assessment of veiling glare. This
    pattern is identical to TG18-GQ except that the radius of the central black
    circle is varied as r = 15
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_GA15Pattern = DICOMControlledTerminologyDefinitionsCode("109874")
    """
    The TG18-GA20 Pattern used for quantitative assessment of veiling glare. This
    pattern is identical to TG18-GQ except that the radius of the central black
    circle is varied as r = 20. See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_GA20Pattern = DICOMControlledTerminologyDefinitionsCode("109875")
    """
    The TG18-GA25 Pattern used for quantitative assessment of veiling glare. This
    pattern is identical to TG18-GQ except that the radius of the central black
    circle is varied as r = 25. See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_GA25Pattern = DICOMControlledTerminologyDefinitionsCode("109876")
    """
    The TG18-GA30 Pattern used for quantitative assessment of veiling glare. This
    pattern is identical to TG18-GQ except that the radius of the central black
    circle is varied as r = 30. See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_GA30Pattern = DICOMControlledTerminologyDefinitionsCode("109877")
    """
    The AAPM TG18-CH Image is a reference anatomical PA chest image. See [AAPM OR
    03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_CHImage = DICOMControlledTerminologyDefinitionsCode("109878")
    """
    The AAPM TG18-KN Image is a reference anatomical knee image. See [AAPM OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_KNImage = DICOMControlledTerminologyDefinitionsCode("109879")
    """
    The AAPM TG18-MM1 Image is a reference anatomical mammogram image. See [AAPM
    OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_MM1Image = DICOMControlledTerminologyDefinitionsCode("109880")
    """
    The AAPM TG18-MM2 Image is a reference anatomical mammogram image. See [AAPM
    OR 03]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TG18_MM2Image = DICOMControlledTerminologyDefinitionsCode("109881")
    """
    The IEC OIQ Pattern is used as an alternative to the TG18-QC Pattern. See [IEC
    62563-1]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OIQPattern = DICOMControlledTerminologyDefinitionsCode("109901")
    """
    The IEC ANG Pattern used for angular viewing evaluation. See [IEC 62563-1]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ANGPattern = DICOMControlledTerminologyDefinitionsCode("109902")
    """
    The IEC GD Pattern used for geometrical image evaluation. See [IEC 62563-1]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    GDPattern = DICOMControlledTerminologyDefinitionsCode("109903")
    """
    The IEC BN01 Pattern is used as analternative to the TG18-LN-01 Pattern, to
    avoid the use of a cone or baffle with LCDs. See [IEC 62563-1]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BN01Pattern = DICOMControlledTerminologyDefinitionsCode("109904")
    """
    The IEC BN02 Pattern is used as analternative to the TG18-LN-02 Pattern, to
    avoid the use of a cone or baffle with LCDs. See [IEC 62563-1]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BN02Pattern = DICOMControlledTerminologyDefinitionsCode("109905")
    """
    The IEC BN03 Pattern is used as analternative to the TG18-LN-03 Pattern, to
    avoid the use of a cone or baffle with LCDs. See [IEC 62563-1]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BN03Pattern = DICOMControlledTerminologyDefinitionsCode("109906")
    """
    The IEC BN04 Pattern is used as analternative to the TG18-LN-04 Pattern, to
    avoid the use of a cone or baffle with LCDs. See [IEC 62563-1]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BN04Pattern = DICOMControlledTerminologyDefinitionsCode("109907")
    """
    The IEC BN05 Pattern is used as analternative to the TG18-LN-05 Pattern, to
    avoid the use of a cone or baffle with LCDs. See [IEC 62563-1]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BN05Pattern = DICOMControlledTerminologyDefinitionsCode("109908")
    """
    The IEC BN06 Pattern is used as analternative to the TG18-LN-06 Pattern, to
    avoid the use of a cone or baffle with LCDs. See [IEC 62563-1]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BN06Pattern = DICOMControlledTerminologyDefinitionsCode("109909")
    """
    The IEC BN07 Pattern is used as analternative to the TG18-LN-07 Pattern, to
    avoid the use of a cone or baffle with LCDs. See [IEC 62563-1]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BN07Pattern = DICOMControlledTerminologyDefinitionsCode("109910")
    """
    The IEC BN08 Pattern is used as analternative to the TG18-LN-08 Pattern, to
    avoid the use of a cone or baffle with LCDs. See [IEC 62563-1]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BN08Pattern = DICOMControlledTerminologyDefinitionsCode("109911")
    """
    The IEC BN09 Pattern is used as analternative to the TG18-LN-09 Pattern, to
    avoid the use of a cone or baffle with LCDs. See [IEC 62563-1]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BN09Pattern = DICOMControlledTerminologyDefinitionsCode("109912")
    """
    The IEC BN10 Pattern is used as analternative to the TG18-LN-10 Pattern, to
    avoid the use of a cone or baffle with LCDs. See [IEC 62563-1]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BN10Pattern = DICOMControlledTerminologyDefinitionsCode("109913")
    """
    The IEC BN11 Pattern is used as analternative to the TG18-LN-11 Pattern, to
    avoid the use of a cone or baffle with LCDs. See [IEC 62563-1]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BN11Pattern = DICOMControlledTerminologyDefinitionsCode("109914")
    """
    The IEC BN12 Pattern is used as analternative to the TG18-LN-12 Pattern, to
    avoid the use of a cone or baffle with LCDs. See [IEC 62563-1]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BN12Pattern = DICOMControlledTerminologyDefinitionsCode("109915")
    """
    The IEC BN13 Pattern is used as analternative to the TG18-LN-13 Pattern, to
    avoid the use of a cone or baffle with LCDs. See [IEC 62563-1]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BN13Pattern = DICOMControlledTerminologyDefinitionsCode("109916")
    """
    The IEC BN14 Pattern is used as analternative to the TG18-LN-14 Pattern, to
    avoid the use of a cone or baffle with LCDs. See [IEC 62563-1]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BN14Pattern = DICOMControlledTerminologyDefinitionsCode("109917")
    """
    The IEC BN15 Pattern is used as analternative to the TG18-LN-15 Pattern, to
    avoid the use of a cone or baffle with LCDs. See [IEC 62563-1]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BN15Pattern = DICOMControlledTerminologyDefinitionsCode("109918")
    """
    The IEC BN16 Pattern is used as analternative to the TG18-LN-16 Pattern, to
    avoid the use of a cone or baffle with LCDs. See [IEC 62563-1]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BN16Pattern = DICOMControlledTerminologyDefinitionsCode("109919")
    """
    The IEC BN17 Pattern is used as analternative to the TG18-LN-17 Pattern, to
    avoid the use of a cone or baffle with LCDs. See [IEC 62563-1]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BN17Pattern = DICOMControlledTerminologyDefinitionsCode("109920")
    """
    The IEC BN18 Pattern is used as analternative to the TG18-LN-18 Pattern, to
    avoid the use of a cone or baffle with LCDs. See [IEC 62563-1]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BN18Pattern = DICOMControlledTerminologyDefinitionsCode("109921")
    """
    Test image "Bild 2" for the gray-scale reproduction of imaging devices. See
    [DIN 6868-57]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DINGrayscalePattern = DICOMControlledTerminologyDefinitionsCode("109931")
    """
    Test image "Bild 3" for the geometrical imaging properties of imaging devices.
    See [DIN 6868-57]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DINGeometryPattern = DICOMControlledTerminologyDefinitionsCode("109932")
    """
    Test image "Bild 5" for displaying the spatial and contrast resolution as well
    as the line structure of imaging devices. See [DIN 6868-57]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DINResolutionPattern = DICOMControlledTerminologyDefinitionsCode("109933")
    """
    An alternative to AAPM TG18-UN80, specified at 100% of maximum pixel value
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    WhitePattern = DICOMControlledTerminologyDefinitionsCode("109941")
    """
    A standard display test pattern. See [SMPTE RP133]. A pattern is available at
    http://www.dclunie.com/images/smpte.512.512.8.gif
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SMPTEPattern = DICOMControlledTerminologyDefinitionsCode("109943")
    """
    A Display Device that displays images on a Cathode Ray Tube
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CRTDisplay = DICOMControlledTerminologyDefinitionsCode("109991")
    """
    A Display Device that displays images on a Liquid Crystal Display
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LiquidCrystalDisplay = DICOMControlledTerminologyDefinitionsCode("109992")
    """
    A Display Device that displays images on a Plasma Display
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PlasmaDisplay = DICOMControlledTerminologyDefinitionsCode("109993")
    """
    A Display Device that displays images on an Organic Light Emitting Diode based
    display
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OLED = DICOMControlledTerminologyDefinitionsCode("109994")
    """
    A Display Device that projects images on a surface from behind using a Digital
    Light Processing Projector
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DLPRearProjectionSystem = DICOMControlledTerminologyDefinitionsCode("109995")
    """
    A Display Device that projects images on a surface from in front using a
    Digital Light Processing Projector
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DLPFrontProjectionSystem = DICOMControlledTerminologyDefinitionsCode("109996")
    """
    A Display Device that projects images on a surface from behind using a Cathode
    Ray Tube
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CRTRearProjectionSystem = DICOMControlledTerminologyDefinitionsCode("109997")
    """
    A Display Device that projects images on a surface from in front using a
    Cathode Ray Tube
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CRTFrontProjectionSystem = DICOMControlledTerminologyDefinitionsCode("109998")
    """
    A Display Device that projects images on a surface from an unspecified
    direction using an unspecified means
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OtherProjectionSystem = DICOMControlledTerminologyDefinitionsCode("109999")
    """
    Image processing work item
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ImageProcessing = DICOMControlledTerminologyDefinitionsCode("110001")
    """
    Quality control work item
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    QualityControl = DICOMControlledTerminologyDefinitionsCode("110002")
    """
    Computer aided diagnosis work item
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ComputerAidedDiagnosis = DICOMControlledTerminologyDefinitionsCode("110003")
    """
    Computer aided detection work item
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ComputerAidedDetection = DICOMControlledTerminologyDefinitionsCode("110004")
    """
    Interpretation work item
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Interpretation = DICOMControlledTerminologyDefinitionsCode("110005")
    """
    Transcription work item
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Transcription = DICOMControlledTerminologyDefinitionsCode("110006")
    """
    Report verification work item
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ReportVerification = DICOMControlledTerminologyDefinitionsCode("110007")
    """
    Print work item
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Print = DICOMControlledTerminologyDefinitionsCode("110008")
    """
    There will be no more work items scheduled
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NoSubsequentWorkitems = DICOMControlledTerminologyDefinitionsCode("110009")
    """
    Film type of output
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Film = DICOMControlledTerminologyDefinitionsCode("110010")
    """
    Dictation type of output
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Dictation = DICOMControlledTerminologyDefinitionsCode("110011")
    """
    Transcription type of output
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Transcription = DICOMControlledTerminologyDefinitionsCode("110012")
    """
    The procedure to read DICOM instances from DICOM interchange media, coerce
    identifying attributes into the local namespace if necessary, and make the
    instances available
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MediaImport = DICOMControlledTerminologyDefinitionsCode("110013")
    """
    Digitization of Sheet Film
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SheetFilmDigitized = DICOMControlledTerminologyDefinitionsCode("110020")
    """
    Digitization of Cine Film
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CineFilmDigitized = DICOMControlledTerminologyDefinitionsCode("110021")
    """
    Digitization of Video Tape
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VideoTapeDigitized = DICOMControlledTerminologyDefinitionsCode("110022")
    """
    Digitization of pages of a paper document (Units may be specified as Pages,
    Documents)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PaperDigitized = DICOMControlledTerminologyDefinitionsCode("110023")
    """
    Importation of CD
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CDImported = DICOMControlledTerminologyDefinitionsCode("110024")
    """
    Importation of DVD
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DVDImported = DICOMControlledTerminologyDefinitionsCode("110025")
    """
    Importation of MOD
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MODImported = DICOMControlledTerminologyDefinitionsCode("110026")
    """
    Importation of DICOM Studies
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StudiesImported = DICOMControlledTerminologyDefinitionsCode("110027")
    """
    Importation of DICOM Composite Instances
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    InstancesImported = DICOMControlledTerminologyDefinitionsCode("110028")
    """
    A device that connects using the USB hard drive interface. These may be USB-
    Sticks, portable hard drives, and other technologies
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    USBDiskEmulation = DICOMControlledTerminologyDefinitionsCode("110030")
    """
    Email and email attachments used as a media for data transport
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Email = DICOMControlledTerminologyDefinitionsCode("110031")
    """
    CD-R, CD-ROM, and CD-RW media used for data transport
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CD = DICOMControlledTerminologyDefinitionsCode("110032")
    """
    DVD, DVD-RAM, and other DVD formatted media used for data transport
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DVD = DICOMControlledTerminologyDefinitionsCode("110033")
    """
    Media that comply with the Compact Flash standard
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CompactFlash = DICOMControlledTerminologyDefinitionsCode("110034")
    """
    Media that comply with the Multi-media Card standard
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Multi_mediaCard = DICOMControlledTerminologyDefinitionsCode("110035")
    """
    Media that comply with the Secure Digital Card standard
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SecureDigitalCard = DICOMControlledTerminologyDefinitionsCode("110036")
    """
    URI Identifier for network or other resource, see RFC 3968
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    URI = DICOMControlledTerminologyDefinitionsCode("110037")
    """
    Any paper or similar document
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PaperDocument = DICOMControlledTerminologyDefinitionsCode("110038")
    """
    Audit event: Application Activity has taken place
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ApplicationActivity = DICOMControlledTerminologyDefinitionsCode("110100")
    """
    Audit event: Audit Log has been used
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AuditLogUsed = DICOMControlledTerminologyDefinitionsCode("110101")
    """
    Audit event: Storage of DICOM Instances has begun
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BeginTransferringDICOMInstances = DICOMControlledTerminologyDefinitionsCode(
        "110102"
    )
    """
    Audit event: DICOM Instances have been created, read, updated, or deleted
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DICOMInstancesAccessed = DICOMControlledTerminologyDefinitionsCode("110103")
    """
    Audit event: Storage of DICOM Instances has been completed
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DICOMInstancesTransferred = DICOMControlledTerminologyDefinitionsCode("110104")
    """
    Audit event: Entire Study has been deleted
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DICOMStudyDeleted = DICOMControlledTerminologyDefinitionsCode("110105")
    """
    Audit event: Data has been exported out of the system
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Export = DICOMControlledTerminologyDefinitionsCode("110106")
    """
    Audit event: Data has been imported into the system
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Import = DICOMControlledTerminologyDefinitionsCode("110107")
    """
    Audit event: System has joined or left network
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NetworkEntry = DICOMControlledTerminologyDefinitionsCode("110108")
    """
    Audit event: Order has been created, read, updated or deleted
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OrderRecord = DICOMControlledTerminologyDefinitionsCode("110109")
    """
    Audit event: Patient Record has been created, read, updated, or deleted
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientRecord = DICOMControlledTerminologyDefinitionsCode("110110")
    """
    Audit event: Procedure Record has been created, read, updated, or deleted
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ProcedureRecord = DICOMControlledTerminologyDefinitionsCode("110111")
    """
    Audit event: Query has been made
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Query = DICOMControlledTerminologyDefinitionsCode("110112")
    """
    Audit event: Security Alert has been raised
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SecurityAlert = DICOMControlledTerminologyDefinitionsCode("110113")
    """
    Audit event: User Authentication has been attempted
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    UserAuthentication = DICOMControlledTerminologyDefinitionsCode("110114")
    """
    Audit event: Application Entity has started
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ApplicationStart = DICOMControlledTerminologyDefinitionsCode("110120")
    """
    Audit event: Application Entity has stopped
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ApplicationStop = DICOMControlledTerminologyDefinitionsCode("110121")
    """
    Audit event: User login has been attempted
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Login = DICOMControlledTerminologyDefinitionsCode("110122")
    """
    Audit event: User logout has been attempted
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Logout = DICOMControlledTerminologyDefinitionsCode("110123")
    """
    Audit event: Node has been attached
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Attach = DICOMControlledTerminologyDefinitionsCode("110124")
    """
    Audit event: Node has been detached
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Detach = DICOMControlledTerminologyDefinitionsCode("110125")
    """
    Audit event: Node Authentication has been attempted
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NodeAuthentication = DICOMControlledTerminologyDefinitionsCode("110126")
    """
    Audit event: Emergency Override has started
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EmergencyOverrideStarted = DICOMControlledTerminologyDefinitionsCode("110127")
    """
    Audit event: Network configuration has been changed
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NetworkConfiguration = DICOMControlledTerminologyDefinitionsCode("110128")
    """
    Audit event: Security configuration has been changed
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SecurityConfiguration = DICOMControlledTerminologyDefinitionsCode("110129")
    """
    Audit event: Hardware configuration has been changed
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    HardwareConfiguration = DICOMControlledTerminologyDefinitionsCode("110130")
    """
    Audit event: Software configuration has been changed
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SoftwareConfiguration = DICOMControlledTerminologyDefinitionsCode("110131")
    """
    Audit event: A use of a restricted function has been attempted
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    UseOfRestrictedFunction = DICOMControlledTerminologyDefinitionsCode("110132")
    """
    Audit event: Audit recording has been stopped
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AuditRecordingStopped = DICOMControlledTerminologyDefinitionsCode("110133")
    """
    Audit event: Audit recording has been started
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AuditRecordingStarted = DICOMControlledTerminologyDefinitionsCode("110134")
    """
    Audit event: Security attributes of an object have been changed
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ObjectSecurityAttributesChanged = DICOMControlledTerminologyDefinitionsCode(
        "110135"
    )
    """
    Audit event: Security roles have been changed
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SecurityRolesChanged = DICOMControlledTerminologyDefinitionsCode("110136")
    """
    Audit event: Security attributes of a user have been changed
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    UserSecurityAttributesChanged = DICOMControlledTerminologyDefinitionsCode("110137")
    """
    Audit event: Emergency Override has Stopped
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EmergencyOverrideStopped = DICOMControlledTerminologyDefinitionsCode("110138")
    """
    Audit event: Remote Service Operation has Begun
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RemoteServiceOperationStarted = DICOMControlledTerminologyDefinitionsCode("110139")
    """
    Audit event: Remote Service Operation has Stopped
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RemoteServiceOperationStopped = DICOMControlledTerminologyDefinitionsCode("110140")
    """
    Audit event: Local Service Operation has Begun
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LocalServiceOperationStarted = DICOMControlledTerminologyDefinitionsCode("110141")
    """
    Audit event: Local Service Operation Stopped
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LocalServiceOperationStopped = DICOMControlledTerminologyDefinitionsCode("110142")
    """
    Audit participant role ID of software application
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Application = DICOMControlledTerminologyDefinitionsCode("110150")
    """
    Audit participant role ID of software application launcher, i.e., the entity
    that started or stopped an application
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ApplicationLauncher = DICOMControlledTerminologyDefinitionsCode("110151")
    """
    Audit participant role ID of the receiver of data
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DestinationRoleID = DICOMControlledTerminologyDefinitionsCode("110152")
    """
    Audit participant role ID of the sender of data
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SourceRoleID = DICOMControlledTerminologyDefinitionsCode("110153")
    """
    Audit participant role ID of media receiving data during an export
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DestinationMedia = DICOMControlledTerminologyDefinitionsCode("110154")
    """
    Audit participant role ID of media providing data during an import
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SourceMedia = DICOMControlledTerminologyDefinitionsCode("110155")
    """
    ParticipantObjectID type: Study Instance UID
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StudyInstanceUID = DICOMControlledTerminologyDefinitionsCode("110180")
    """
    ParticipantObjectID type: SOP Class UID
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SOPClassUID = DICOMControlledTerminologyDefinitionsCode("110181")
    """
    ID of a node that is a participant object of an audit message
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NodeID = DICOMControlledTerminologyDefinitionsCode("110182")
    """
    System, organization, agency, or department that has assigned an instance
    identifier (such as placer or filler number, patient or provider identifier,
    etc.)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IssuerOfIdentifier = DICOMControlledTerminologyDefinitionsCode("110190")
    """
    Procedure order canceled by requesting physician or other authorized physician
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DoctorCanceledProcedure = DICOMControlledTerminologyDefinitionsCode("110500")
    """
    Equipment failure prevented completion of procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EquipmentFailure = DICOMControlledTerminologyDefinitionsCode("110501")
    """
    Procedure discontinued due to incorrect procedure being ordered
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IncorrectProcedureOrdered = DICOMControlledTerminologyDefinitionsCode("110502")
    """
    Procedure discontinued due to patient allergy to media/contrast (reported or
    reaction)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientAllergicToMedia_contrast = DICOMControlledTerminologyDefinitionsCode(
        "110503"
    )
    """
    Procedure discontinued due to death of Patient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientDied = DICOMControlledTerminologyDefinitionsCode("110504")
    """
    Procedure discontinued due to patient refusal to continue procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientRefusedToContinueProcedure = DICOMControlledTerminologyDefinitionsCode(
        "110505"
    )
    """
    Procedure discontinued due to patient being taken for treatment or surgery
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientTakenForTreatmentOrSurgery = DICOMControlledTerminologyDefinitionsCode(
        "110506"
    )
    """
    Patient did not arrive for procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientDidNotArrive = DICOMControlledTerminologyDefinitionsCode("110507")
    """
    Procedure discontinued due to patient pregnancy (reported or determined)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientPregnant = DICOMControlledTerminologyDefinitionsCode("110508")
    """
    Procedure discontinued to restart with new procedure code for correct charging
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ChangeOfProcedureForCorrectCharging = DICOMControlledTerminologyDefinitionsCode(
        "110509"
    )
    """
    Procedure discontinued due to duplicate orders received for same procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DuplicateOrder = DICOMControlledTerminologyDefinitionsCode("110510")
    """
    Procedure order canceled by nursing unit
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NursingUnitCancel = DICOMControlledTerminologyDefinitionsCode("110511")
    """
    Procedure discontinued due to incorrect side (laterality) being ordered
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IncorrectSideOrdered = DICOMControlledTerminologyDefinitionsCode("110512")
    """
    Procedure discontinued for unspecified reason
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DiscontinuedForUnspecifiedReason = DICOMControlledTerminologyDefinitionsCode(
        "110513"
    )
    """
    Procedure discontinued due to incorrect patient or procedure step selected
    from modality worklist
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IncorrectWorklistEntrySelected = DICOMControlledTerminologyDefinitionsCode("110514")
    """
    Patient condition prevented continuation of procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientConditionPreventedContinuing = DICOMControlledTerminologyDefinitionsCode(
        "110515"
    )
    """
    Procedure step is discontinued to change to other equipment or modality
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EquipmentChange = DICOMControlledTerminologyDefinitionsCode("110516")
    """
    A movement of the patient affecting test quality
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientMovement = DICOMControlledTerminologyDefinitionsCode("110518")
    """
    An error of the operator affecting test quality
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OperatorError = DICOMControlledTerminologyDefinitionsCode("110519")
    """
    One or more of the objects is malformed
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ObjectsIncorrectlyFormatted = DICOMControlledTerminologyDefinitionsCode("110521")
    """
    Receiving System is unable to accept the object type
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ObjectTypesNotSupported = DICOMControlledTerminologyDefinitionsCode("110522")
    """
    One or more objects associated with the object set is missing
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ObjectSetIncomplete = DICOMControlledTerminologyDefinitionsCode("110523")
    """
    The contents of the Media could not be accessed properly
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MediaFailure = DICOMControlledTerminologyDefinitionsCode("110524")
    """
    Procedure discontinued due to necessary equipment, staff or other resource
    becoming (temporarily) unavailable to the procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ResourcePre_empted = DICOMControlledTerminologyDefinitionsCode("110526")
    """
    Procedure discontinued due to necessary equipment, staff or other resource
    being inadequate to complete the procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ResourceInadequate = DICOMControlledTerminologyDefinitionsCode("110527")
    """
    A new Procedure Step has been scheduled to replace the Discontinued Procedure
    Step
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DiscontinuedProcedureStepRescheduled = DICOMControlledTerminologyDefinitionsCode(
        "110528"
    )
    """
    It is recommended that a new Procedure Step be scheduled to replace the
    Discontinued Procedure Step
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DiscontinuedProcedureStepReschedulingRecommended = (
        DICOMControlledTerminologyDefinitionsCode("110529")
    )
    """
    Ventral structures of the diencephalon that cannot readily be distinguished on
    MR imaging, including the hypothalamus, mammillary body, subthalamic nuclei,
    substantia nigra, red nucleus, lateral geniculate nucleus, medial geniculate
    nucleus, zona incerta, cerebral peduncle, lenticular fasciculus, medial
    lemniscus, and optic tract. See http://neuromorphometrics.org:8080/Seg/html/se
    gmentation/ventral%20diencephalon.html
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VentralDiencephalon = DICOMControlledTerminologyDefinitionsCode("110700")
    """
    Area(s) of reduced intensity on T1 weighted images relative to the surrounding
    white matter. These may be indicative of age-related or neurodegenerative
    white matter lesions, and may be co-located with areas of white matter T2
    hyperintensity, but the concept is specifically confined to the MR appearance
    on T1 weighted images
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    WhiteMatterT1Hypointensity = DICOMControlledTerminologyDefinitionsCode("110701")
    """
    Area(s) of increased intensity on T2 weighted images relative to the
    surrounding white matter. These may be indicative of age-related or
    neurodegenerative white matter lesions, and may be co-located with areas of
    white matter T1 hypointensity, but the concept is specifically confined to the
    MR appearance on T2 weighted images
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    WhiteMatterT2Hyperintensity = DICOMControlledTerminologyDefinitionsCode("110702")
    """
    The dorsal component of the SLF originating from the medial and dorsal
    parietal cortex and ending in the dorsal and medial part of the frontal lobe.
    See Makris N, et al. "Segmentation of Subcomponents within the Superior
    Longitudinal Fascicle in Humans: A Quantitative, In Vivo, DT-MRI Study."
    Cerebral Cortex 15, no. 6 (June 1, 2005): 854-69. doi:10.1093/cercor/bhh186
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SuperiorLongitudinalFasciculusI = DICOMControlledTerminologyDefinitionsCode(
        "110703"
    )
    """
    The major component of the SLF, derived from the caudal-inferior parietal
    region corresponding to the angular gyrus in the human and terminating within
    the dorsolateral frontal region. See Makris N, et al. "Segmentation of
    Subcomponents within the Superior Longitudinal Fascicle in Humans: A
    Quantitative, In Vivo, DT-MRI Study." Cerebral Cortex 15, no. 6 (June 1,
    2005): 854-69. doi:10.1093/cercor/bhh186
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SuperiorLongitudinalFasciculusII = DICOMControlledTerminologyDefinitionsCode(
        "110704"
    )
    """
    The ventral component of the SLF, originating from the supramarginal gyrus and
    terminating predominantly in the ventral premotor and prefrontal areas. See
    Makris N, et al. "Segmentation of Subcomponents within the Superior
    Longitudinal Fascicle in Humans: A Quantitative, In Vivo, DT-MRI Study."
    Cerebral Cortex 15, no. 6 (June 1, 2005): 854-69. doi:10.1093/cercor/bhh186
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SuperiorLongitudinalFasciculusIII = DICOMControlledTerminologyDefinitionsCode(
        "110705"
    )
    """
    White matter that surrounds a lesion of interest; e.g. to identify the
    otherwise unclassified white matter that surrounds a tumor to be surgically
    resected
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PerilesionalWhiteMatter = DICOMControlledTerminologyDefinitionsCode("110706")
    """
    Signal intensity of a Spin tagging Perfusion MR image. Spin tagging is a
    technique for the measurement of blood perfusion, based on magnetically
    labeled arterial blood water as an endogenous tracer
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SpinTaggingPerfusionMRSignalIntensity = DICOMControlledTerminologyDefinitionsCode(
        "110800"
    )
    """
    Signal intensity of a Contrast Agent Angio MR image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ContrastAgentAngioMRSignalIntensity = DICOMControlledTerminologyDefinitionsCode(
        "110801"
    )
    """
    Signal intensity of a Time-of-flight (TOF) MR image. Time-of-flight (TOF) is
    based on the phenomenon of flow-related enhancement of spins entering into an
    imaging slice. As a result of being unsaturated, these spins give more signal
    that surrounding stationary spins
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TimeOfFlightAngioMRSignalIntensity = DICOMControlledTerminologyDefinitionsCode(
        "110802"
    )
    """
    Signal intensity of a Proton Density Weighted MR image. All MR images have
    intensity proportional to proton density. Images with very little T1 or T2
    weighting are called 'PD-weighted'
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ProtonDensityWeightedMRSignalIntensity = DICOMControlledTerminologyDefinitionsCode(
        "110803"
    )
    """
    Signal intensity of T1 Weighted MR image. A T1 Weighted MR image is created
    typically by using short TE and TR times
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    T1WeightedMRSignalIntensity = DICOMControlledTerminologyDefinitionsCode("110804")
    """
    Signal intensity of a T2 Weighted MR image. T2 Weighted image contrast state
    is approached by imaging with a TR long compared to tissue T1 (to reduce T1
    contribution to image contrast) and a TE between the longest and shortest
    tissue T2s of interest
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    T2WeightedMRSignalIntensity = DICOMControlledTerminologyDefinitionsCode("110805")
    """
    Signal intensity of a T2* Weighted MR image. The T2* phenomenon results from
    molecular interactions (spin spin relaxation) and local magnetic field non-
    uniformities, which cause the protons to precess at slightly different
    frequencies
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    T2_WeightedMRSignalIntensity = DICOMControlledTerminologyDefinitionsCode("110806")
    """
    Signal intensity of a Field Map MR image. A Field Map MR image provides a
    direct measure of the B 0 inhomogeneity at each point in the image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FieldMapMRSignalIntensity = DICOMControlledTerminologyDefinitionsCode("110807")
    """
    Coefficient reflecting the fractional anisotropy of the tissues, derived from
    a diffusion weighted MR image. Fractional anisotropy is proportional to the
    square root of the variance of the Eigen values divided by the square root of
    the sum of the squares of the Eigen values
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FractionalAnisotropy = DICOMControlledTerminologyDefinitionsCode("110808")
    """
    Coefficient reflecting the relative anisotropy of the tissues, derived from a
    diffusion weighted MR image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RelativeAnisotropy = DICOMControlledTerminologyDefinitionsCode("110809")
    """
    Dxx Component of the diffusion tensor, quantifying the molecular mobility
    along the X axis
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VolumetricDiffusionDxxComponent = DICOMControlledTerminologyDefinitionsCode(
        "110810"
    )
    """
    Dxy Component of the diffusion tensor, quantifying the correlation of
    molecular displacements in the X and Y directions
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VolumetricDiffusionDxyComponent = DICOMControlledTerminologyDefinitionsCode(
        "110811"
    )
    """
    Dxz Component of the diffusion tensor, quantifying the correlation of
    molecular displacements in the X and Z directions
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VolumetricDiffusionDxzComponent = DICOMControlledTerminologyDefinitionsCode(
        "110812"
    )
    """
    Dyy Component of the diffusion tensor, quantifying the molecular mobility
    along the Y axis
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VolumetricDiffusionDyyComponent = DICOMControlledTerminologyDefinitionsCode(
        "110813"
    )
    """
    Dyz Component of the diffusion tensor, quantifying the correlation of
    molecular displacements in the Y and Z directions
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VolumetricDiffusionDyzComponent = DICOMControlledTerminologyDefinitionsCode(
        "110814"
    )
    """
    Dzz Component of the diffusion tensor, quantifying the molecular mobility
    along the Z axis
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VolumetricDiffusionDzzComponent = DICOMControlledTerminologyDefinitionsCode(
        "110815"
    )
    """
    Signal intensity of a T1 Weighted Dynamic Contrast Enhanced MR image. A T1
    Weighted Dynamic Contrast Enhanced MR image reflects the dynamics of diffusion
    of the exogenous contrast media from the blood pool into the extra vascular
    extracellular space (EES) of the brain at a rate determined by the blood flow
    to the tissue, the permeability of the Brain Blood Barrier (BBB), and the
    surface area of the perfusing vessels
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    T1WeightedDynamicContrastEnhancedMRSignalIntensity = (
        DICOMControlledTerminologyDefinitionsCode("110816")
    )
    """
    Signal intensity of a T2 Weighted Dynamic Contrast Enhanced MR image. A T2
    Weighted Dynamic Contrast Enhanced MR image reflects the T2 of tissue decrease
    as the Gd contrast agent bolus passes through the brain
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    T2WeightedDynamicContrastEnhancedMRSignalIntensity = (
        DICOMControlledTerminologyDefinitionsCode("110817")
    )
    """
    Signal intensity of a T2* Weighted Dynamic Contrast Enhanced MR image. A T2*
    Weighted Dynamic Contrast Enhanced MR image reflects the T2* of tissue
    decrease as the Gd contrast agent bolus passes through the brain
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    T2_WeightedDynamicContrastEnhancedMRSignalIntensity = (
        DICOMControlledTerminologyDefinitionsCode("110818")
    )
    """
    Signal intensity of a Blood Oxygenation Level image. BOLD imaging is sensitive
    to blood oxygenation (but also to cerebral blood flow and volume). This
    modality is essentially used for detecting brain activation (functional MR)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BloodOxygenationLevel = DICOMControlledTerminologyDefinitionsCode("110819")
    """
    Accumulated decay event counts in a nuclear medicine projection image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NuclearMedicineProjectionActivity = DICOMControlledTerminologyDefinitionsCode(
        "110820"
    )
    """
    Accumulated decay event counts in a Nuclear Medicine Tomographic image
    (including PET)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NuclearMedicineTomographicActivity = DICOMControlledTerminologyDefinitionsCode(
        "110821"
    )
    """
    Spatial Displacement along axis X of a non-linear deformable spatial
    registration image. The X axis is defined in reference to the patient's
    orientation, and is increasing to the left hand side of the patient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SpatialDisplacementXComponent = DICOMControlledTerminologyDefinitionsCode("110822")
    """
    Spatial Displacement along axis Y of a non-linear deformable spatial
    registration image. The Y axis is defined in reference to the patient's
    orientation, and is increasing to the posterior side of the patient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SpatialDisplacementYComponent = DICOMControlledTerminologyDefinitionsCode("110823")
    """
    Spatial Displacement along axis Z of a non-linear deformable spatial
    registration image. The Z axis is defined in reference to the patient's
    orientation, and is increasing toward the head of the patient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SpatialDisplacementZComponent = DICOMControlledTerminologyDefinitionsCode("110824")
    """
    Measured resistance to the flow of blood; e.g. through the vasculature or
    through a heart value
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    HemodynamicResistance = DICOMControlledTerminologyDefinitionsCode("110825")
    """
    Measured resistance to the flow of blood; e.g. through the vasculature or
    through a heart value, normalized to a particular indexed scale
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IndexedHemodynamicResistance = DICOMControlledTerminologyDefinitionsCode("110826")
    """
    Velocity of tissue based on Doppler measurements
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TissueVelocity = DICOMControlledTerminologyDefinitionsCode("110827")
    """
    Velocity of blood flow based on Doppler measurements
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FlowVelocity = DICOMControlledTerminologyDefinitionsCode("110828")
    """
    Statistical variance of blood velocity relative to mean
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FlowVariance = DICOMControlledTerminologyDefinitionsCode("110829")
    """
    Scalar value related to the elastic properties of the tissue
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Elasticity = DICOMControlledTerminologyDefinitionsCode("110830")
    """
    Scalar value related to the volume of blood perfusing into tissue
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Perfusion = DICOMControlledTerminologyDefinitionsCode("110831")
    """
    Speed of sound in tissue
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SpeedOfSound = DICOMControlledTerminologyDefinitionsCode("110832")
    """
    Reduction in strength of ultrasound signal as the wave
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    UltrasoundAttenuation = DICOMControlledTerminologyDefinitionsCode("110833")
    """
    Red component of a true color image (RGB)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RGBRComponent = DICOMControlledTerminologyDefinitionsCode("110834")
    """
    Green component of a true color image (RGB)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RGBGComponent = DICOMControlledTerminologyDefinitionsCode("110835")
    """
    Blue component of a true color image (RGB)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RGBBComponent = DICOMControlledTerminologyDefinitionsCode("110836")
    """
    Y (Luminance) component of a YBR FULL image, as defined in JPEG 2000
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    YBRFULLYComponent = DICOMControlledTerminologyDefinitionsCode("110837")
    """
    CB (Blue chrominance) component of a YBR FULL image, as defined in JPEG 2000
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    YBRFULLCBComponent = DICOMControlledTerminologyDefinitionsCode("110838")
    """
    CR (Red chrominance) component of a YBR FULL image, as defined in JPEG 2000
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    YBRFULLCRComponent = DICOMControlledTerminologyDefinitionsCode("110839")
    """
    Y (Luminance) component of a YBR PARTIAL image, as defined in JPEG 2000
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    YBRPARTIALYComponent = DICOMControlledTerminologyDefinitionsCode("110840")
    """
    CB (Blue chrominance) component of a YBR PARTIAL image, as defined in JPEG
    2000
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    YBRPARTIALCBComponent = DICOMControlledTerminologyDefinitionsCode("110841")
    """
    CR (Red chrominance) component of a YBR PARTIAL image, as defined in JPEG 2000
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    YBRPARTIALCRComponent = DICOMControlledTerminologyDefinitionsCode("110842")
    """
    Y (Luminance) component of a YBR ICT image (Irreversible Color Transform), as
    defined in JPEG 2000
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    YBRICTYComponent = DICOMControlledTerminologyDefinitionsCode("110843")
    """
    CB (Blue chrominance) component of a YBR ICT image (Irreversible Color
    Transform), as defined in JPEG 2000
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    YBRICTCBComponent = DICOMControlledTerminologyDefinitionsCode("110844")
    """
    CR (Red chrominance) component of a YBR ICT image (Irreversible Color
    Transform), as defined in JPEG 2000
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    YBRICTCRComponent = DICOMControlledTerminologyDefinitionsCode("110845")
    """
    Y (Luminance) component of a YBR RCT image (Reversible Color Transform), as
    defined in JPEG 2000
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    YBRRCTYComponent = DICOMControlledTerminologyDefinitionsCode("110846")
    """
    CB (Blue chrominance) component of a YBR RCT image (Reversible Color
    Transform), as defined in JPEG 2000
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    YBRRCTCBComponent = DICOMControlledTerminologyDefinitionsCode("110847")
    """
    CR (Red chrominance) component of a YBR RCT image (Reversible Color
    Transform), as defined in JPEG 2000
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    YBRRCTCRComponent = DICOMControlledTerminologyDefinitionsCode("110848")
    """
    The ability of a material to create an ultrasound return echo
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Echogenicity = DICOMControlledTerminologyDefinitionsCode("110849")
    """
    Decrease in the number of photons in an X-Ray beam due to interactions with
    the atoms of a material substance. Attenuation is due primarily to two
    processes, absorption and scattering
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    X_RayAttenuation = DICOMControlledTerminologyDefinitionsCode("110850")
    """
    Coefficient that describes the fraction of a beam of X-Rays or gamma rays that
    is absorbed or scattered per unit thickness of the absorber. This value
    basically accounts for the number of atoms in a cubic cm volume of material
    and the probability of a photon being scattered or absorbed from the nucleus
    or an electron of one of these atoms
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    X_RayAttenuationCoefficient = DICOMControlledTerminologyDefinitionsCode("110851")
    """
    Signal intensity of an MR image, not otherwise specified
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MRSignalIntensity = DICOMControlledTerminologyDefinitionsCode("110852")
    """
    Binary value denoting that the segmented property is present
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BinarySegmentation = DICOMControlledTerminologyDefinitionsCode("110853")
    """
    Probability, defined as a percentage, that the segmented property occupies the
    spatial area defined by the voxel
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FractionalProbabilisticSegmentation = DICOMControlledTerminologyDefinitionsCode(
        "110854"
    )
    """
    Percentage of the voxel area occupied by the segmented property
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FractionalOccupancySegmentation = DICOMControlledTerminologyDefinitionsCode(
        "110855"
    )
    """
    Spatial dimension, denoting a linear displacement
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LinearDisplacement = DICOMControlledTerminologyDefinitionsCode("110856")
    """
    Dimension denoting the energy (frequency or wavelength) of photons
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PhotonEnergy = DICOMControlledTerminologyDefinitionsCode("110857")
    """
    Dimension used to sequence events, to compare the duration of events and the
    intervals between events
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Time = DICOMControlledTerminologyDefinitionsCode("110858")
    """
    Spatial dimension, denoting an angle
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Angle = DICOMControlledTerminologyDefinitionsCode("110859")
    """
    A spatial dimension axis running along a line between the patient's left and
    right side
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Left_RightAxis = DICOMControlledTerminologyDefinitionsCode("110860")
    """
    A spatial dimension axis running along a line between the patient's head and
    foot
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Head_FootAxis = DICOMControlledTerminologyDefinitionsCode("110861")
    """
    A spatial dimension axis running along a line between the patient's anterior
    and posterior sides
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Anterior_PosteriorAxis = DICOMControlledTerminologyDefinitionsCode("110862")
    """
    A spatial dimension axis running along a line between the apex and base of an
    organ, object, or chamber
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Apex_BaseAxis = DICOMControlledTerminologyDefinitionsCode("110863")
    """
    A spatial dimension axis running along a line between the anterior and
    inferior sides of an organ, object, or chamber
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Anterior_InferiorAxis = DICOMControlledTerminologyDefinitionsCode("110864")
    """
    A spatial dimension axis running along a line between the septum and wall of a
    chamber
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Septum_WallAxis = DICOMControlledTerminologyDefinitionsCode("110865")
    """
    Orientation of a spatial dimension where increasing values run from the right
    to the left side of the patient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RightToLeft = DICOMControlledTerminologyDefinitionsCode("110866")
    """
    Orientation of a spatial dimension where increasing values run from the left
    to the right side of the patient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LeftToRight = DICOMControlledTerminologyDefinitionsCode("110867")
    """
    Orientation of a spatial dimension where increasing values run from the head
    to the foot of the patient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    HeadToFoot = DICOMControlledTerminologyDefinitionsCode("110868")
    """
    Orientation of a spatial dimension where increasing values run from the foot
    to the head of the patient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FootToHead = DICOMControlledTerminologyDefinitionsCode("110869")
    """
    Orientation of a spatial dimension where increasing values run from the
    anterior to the posterior side of the patient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AnteriorToPosterior = DICOMControlledTerminologyDefinitionsCode("110870")
    """
    Orientation of a spatial dimension where increasing values run from the
    posterior to the anterior side of the patient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PosteriorToAnterior = DICOMControlledTerminologyDefinitionsCode("110871")
    """
    Orientation of a spatial dimension where increasing values run from the apex
    to the base
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ApexToBase = DICOMControlledTerminologyDefinitionsCode("110872")
    """
    Orientation of a spatial dimension where increasing values run from the base
    to the apex
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BaseToApex = DICOMControlledTerminologyDefinitionsCode("110873")
    """
    Orientation of a spatial dimension where increasing values run from the
    anterior to the inferior
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AnteriorToInferior = DICOMControlledTerminologyDefinitionsCode("110874")
    """
    Orientation of a spatial dimension where increasing values run from the
    inferior to the anterior
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    InferiorToAnterior = DICOMControlledTerminologyDefinitionsCode("110875")
    """
    Orientation of a spatial dimension where increasing values run from the septum
    of a chamber to the opposite wall
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SeptumToWall = DICOMControlledTerminologyDefinitionsCode("110876")
    """
    Orientation of a spatial dimension where increasing values run from the
    opposite wall to the septum of a chamber
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    WallToSeptum = DICOMControlledTerminologyDefinitionsCode("110877")
    """
    The x coordinate of the upper left hand corner (center of the first voxel
    transmitted) of the image, with respect to the patient-based coordinate system
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ImagePosition_Patient_X = DICOMControlledTerminologyDefinitionsCode("110901")
    """
    The y coordinate of the upper left hand corner (center of the first voxel
    transmitted) of the image, with respect to the patient-based coordinate system
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ImagePosition_Patient_Y = DICOMControlledTerminologyDefinitionsCode("110902")
    """
    The z coordinate of the upper left hand corner (center of the first voxel
    transmitted) of the image, with respect to the patient-based coordinate system
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ImagePosition_Patient_Z = DICOMControlledTerminologyDefinitionsCode("110903")
    """
    The x value of the first row direction cosine with respect to the patient,
    with respect to the patient-based coordinate system
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ImageOrientation_Patient_RowX = DICOMControlledTerminologyDefinitionsCode("110904")
    """
    The y value of the first row direction cosine with respect to the patient,
    with respect to the patient-based coordinate system
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ImageOrientation_Patient_RowY = DICOMControlledTerminologyDefinitionsCode("110905")
    """
    The z value of the first row direction cosine with respect to the patient,
    with respect to the patient-based coordinate system
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ImageOrientation_Patient_RowZ = DICOMControlledTerminologyDefinitionsCode("110906")
    """
    The x value of the first column direction cosine with respect to the patient,
    with respect to the patient-based coordinate system
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ImageOrientation_Patient_ColumnX = DICOMControlledTerminologyDefinitionsCode(
        "110907"
    )
    """
    The y value of the first column direction cosine with respect to the patient,
    with respect to the patient-based coordinate system
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ImageOrientation_Patient_ColumnY = DICOMControlledTerminologyDefinitionsCode(
        "110908"
    )
    """
    The z value of the first column direction cosine with respect to the patient,
    with respect to the patient-based coordinate system
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ImageOrientation_Patient_ColumnZ = DICOMControlledTerminologyDefinitionsCode(
        "110909"
    )
    """
    Number of rows in the pixel data of the image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PixelDataRows = DICOMControlledTerminologyDefinitionsCode("110910")
    """
    Number of columns in the pixel data of the image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PixelDataColumns = DICOMControlledTerminologyDefinitionsCode("110911")
    """
    The name assigned by a manufacturer to a specific software algorithm
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AlgorithmName = DICOMControlledTerminologyDefinitionsCode("111001")
    """
    The input parameters used by a manufacturer to configure the behavior of a
    specific software algorithm
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AlgorithmParameters = DICOMControlledTerminologyDefinitionsCode("111002")
    """
    The software version identifier assigned by a manufacturer to a specific
    software algorithm
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AlgorithmVersion = DICOMControlledTerminologyDefinitionsCode("111003")
    """
    The type of correlation applied to detection results; e.g. temporal, spatial
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AnalysisPerformed = DICOMControlledTerminologyDefinitionsCode("111004")
    """
    Assignment of intermediate or overall interpretation results to a general
    category
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AssessmentCategory = DICOMControlledTerminologyDefinitionsCode("111005")
    """
    Assessment of annotating tissues in breast; generally including fatty, mixed
    or dense
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BreastComposition = DICOMControlledTerminologyDefinitionsCode("111006")
    """
    Purpose of reference for an SCOORD content item that is an outline of the
    breast that includes the pectoral muscle tissue
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BreastOutlineIncludingPectoralMuscleTissue = (
        DICOMControlledTerminologyDefinitionsCode("111007")
    )
    """
    The type of distribution associated with detected calcifications
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CalcificationDistribution = DICOMControlledTerminologyDefinitionsCode("111008")
    """
    Identification of the morphology of detected calcifications
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CalcificationType = DICOMControlledTerminologyDefinitionsCode("111009")
    """
    Purpose of reference for an SCOORD content item that identifies the central
    point of a finding or feature
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Center = DICOMControlledTerminologyDefinitionsCode("111010")
    """
    The likelihood that the feature analyzed is in fact the type of feature
    identified
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CertaintyOfFeature = DICOMControlledTerminologyDefinitionsCode("111011")
    """
    The likelihood that the finding detected is in fact the type of finding
    identified
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CertaintyOfFinding = DICOMControlledTerminologyDefinitionsCode("111012")
    """
    The certainty that a device places on an impression, where 0 equals no
    certainty and 100 equals certainty
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CertaintyOfImpression = DICOMControlledTerminologyDefinitionsCode("111013")
    """
    A location identifier based on clock-face numbering or anatomic sub-region
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ClockfaceOrRegion = DICOMControlledTerminologyDefinitionsCode("111014")
    """
    An item that is an inferred correlation relating two or more individual
    findings or features
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CompositeFeature = DICOMControlledTerminologyDefinitionsCode("111015")
    """
    The inferred relationship between the findings or features making up a
    composite feature
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CompositeType = DICOMControlledTerminologyDefinitionsCode("111016")
    """
    General assessment of whether or not CAD processing was successful, and
    whether any findings resulted
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CADProcessingAndFindingsSummary = DICOMControlledTerminologyDefinitionsCode(
        "111017"
    )
    """
    The date the data creation started
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ContentDate = DICOMControlledTerminologyDefinitionsCode("111018")
    """
    The time the data creation started
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ContentTime = DICOMControlledTerminologyDefinitionsCode("111019")
    """
    A location identifier based on a feature's inferred distance from the surface
    of the associated anatomy
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Depth = DICOMControlledTerminologyDefinitionsCode("111020")
    """
    A textual description of the change that occurred over time in a qualitative
    characteristic of a feature
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DescriptionOfChange = DICOMControlledTerminologyDefinitionsCode("111021")
    """
    The type of finding sought after by a specific algorithm applied to one image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DetectionPerformed = DICOMControlledTerminologyDefinitionsCode("111022")
    """
    A general change that occurred within an imaged area between a prior imaging
    procedure and the current imaging procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DifferentialDiagnosis_Impression = DICOMControlledTerminologyDefinitionsCode(
        "111023"
    )
    """
    A group of analysis algorithms that were attempted, but failed
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FailedAnalyses = DICOMControlledTerminologyDefinitionsCode("111024")
    """
    A group of detection algorithms that were attempted, but failed
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FailedDetections = DICOMControlledTerminologyDefinitionsCode("111025")
    """
    For projection radiography, the horizontal physical distance measured at the
    front plane of an Image Receptor housing between the center of each pixel. For
    tomographic images, the horizontal physical distance in the patient between
    the center of each pixel
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    HorizontalPixelSpacing = DICOMControlledTerminologyDefinitionsCode("111026")
    """
    Laterality of (possibly paired) body part contained in an image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ImageLaterality = DICOMControlledTerminologyDefinitionsCode("111027")
    """
    A container that references all image data used as evidence to produce a
    report
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ImageLibrary = DICOMControlledTerminologyDefinitionsCode("111028")
    """
    A numeric value in the range 0 to 100, inclusive, where 0 is worst quality and
    100 is best quality
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ImageQualityRating = DICOMControlledTerminologyDefinitionsCode("111029")
    """
    Purpose of reference for an SCOORD content item that identifies a specific
    region of interest within an image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ImageRegion = DICOMControlledTerminologyDefinitionsCode("111030")
    """
    The projection of the anatomic region of interest on an image receptor
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ImageView = DICOMControlledTerminologyDefinitionsCode("111031")
    """
    Modifier for Image View
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ImageViewModifier = DICOMControlledTerminologyDefinitionsCode("111032")
    """
    Free-form text describing the overall or an individual impression
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ImpressionDescription = DICOMControlledTerminologyDefinitionsCode("111033")
    """
    A container for a group of related results from interpretation of one or more
    images and associated clinical information
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IndividualImpression_Recommendation = DICOMControlledTerminologyDefinitionsCode(
        "111034"
    )
    """
    The X-Ray attenuation of a lesion relative to the expected attenuation of an
    equal volume of fibroglandular breast tissue
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LesionDensity = DICOMControlledTerminologyDefinitionsCode("111035")
    """
    A structured report containing the results of computer-aided detection or
    diagnosis applied to breast imaging and associated clinical information
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MammographyCADReport = DICOMControlledTerminologyDefinitionsCode("111036")
    """
    The characteristic of the boundary, edges or border of a detected lesion
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Margins = DICOMControlledTerminologyDefinitionsCode("111037")
    """
    The quantity of calcifications detected within an identified group or cluster
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NumberOfCalcifications = DICOMControlledTerminologyDefinitionsCode("111038")
    """
    A non-lesion object identified within one or more images
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ObjectType = DICOMControlledTerminologyDefinitionsCode("111039")
    """
    Purpose of reference for a COMPOSITE content item that identifies it as the
    original source of evidence for another content item in the report
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OriginalSource = DICOMControlledTerminologyDefinitionsCode("111040")
    """
    Purpose of reference for an SCOORD content item that identifies the outline or
    bounding region of a finding or feature
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Outline = DICOMControlledTerminologyDefinitionsCode("111041")
    """
    The inferred type of disease associated with an identified feature
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Pathology = DICOMControlledTerminologyDefinitionsCode("111042")
    """
    The patient orientation relative to the image plane, specified by a value that
    designates the anatomical direction of the positive column axis (top to
    bottom)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientOrientationColumn = DICOMControlledTerminologyDefinitionsCode("111043")
    """
    The patient orientation relative to the image plane, specified by a value that
    designates the anatomical direction of the positive row axis (left to right)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientOrientationRow = DICOMControlledTerminologyDefinitionsCode("111044")
    """
    Purpose of reference for an SCOORD content item that is an outline of the
    pectoral muscle tissue only
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PectoralMuscleOutline = DICOMControlledTerminologyDefinitionsCode("111045")
    """
    Percent of breast area that is mammographically dense, excluding pectoralis
    muscle
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PercentFibroglandularTissue = DICOMControlledTerminologyDefinitionsCode("111046")
    """
    The likelihood that an identified finding or feature is cancerous
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ProbabilityOfCancer = DICOMControlledTerminologyDefinitionsCode("111047")
    """
    A location identifier based on the division of an area into four regions
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    QuadrantLocation = DICOMControlledTerminologyDefinitionsCode("111048")
    """
    A qualitative characteristic of a feature that has changed over time
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    QualitativeDifference = DICOMControlledTerminologyDefinitionsCode("111049")
    """
    The effect of the quality of an image on its usability
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    QualityAssessment = DICOMControlledTerminologyDefinitionsCode("111050")
    """
    The quality control standard used to make a quality assessment
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    QualityControlStandard = DICOMControlledTerminologyDefinitionsCode("111051")
    """
    A specific quality related deficiency detected within an image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    QualityFinding = DICOMControlledTerminologyDefinitionsCode("111052")
    """
    Recommended type of follow-up to an imaging procedure, based on interpreted
    results
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RecommendedFollow_up = DICOMControlledTerminologyDefinitionsCode("111053")
    """
    Recommended follow-up date to an imaging procedure, based on interpreted
    results
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RecommendedFollow_upDate = DICOMControlledTerminologyDefinitionsCode("111054")
    """
    Recommended follow-up interval to an imaging procedure, based on interpreted
    results
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RecommendedFollow_upInterval = DICOMControlledTerminologyDefinitionsCode("111055")
    """
    The recommendation of the producer of a content item regarding presentation of
    the content item by recipients of the report
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RenderingIntent = DICOMControlledTerminologyDefinitionsCode("111056")
    """
    An indication of how widespread the detection of a feature is within the
    analyzed image data set
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ScopeOfFeature = DICOMControlledTerminologyDefinitionsCode("111057")
    """
    A textual description of the contents of a selected region identified within
    an image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SelectedRegionDescription = DICOMControlledTerminologyDefinitionsCode("111058")
    """
    An item that was detected on one image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SingleImageFinding = DICOMControlledTerminologyDefinitionsCode("111059")
    """
    Date on which the acquisition of the study information was started
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StudyDate = DICOMControlledTerminologyDefinitionsCode("111060")
    """
    Time at which the acquisition of the study information was started
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StudyTime = DICOMControlledTerminologyDefinitionsCode("111061")
    """
    A group of analysis algorithms that were attempted and completed successfully
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SuccessfulAnalyses = DICOMControlledTerminologyDefinitionsCode("111062")
    """
    A group of detection algorithms that were attempted and completed successfully
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SuccessfulDetections = DICOMControlledTerminologyDefinitionsCode("111063")
    """
    An overall indication of whether the CAD detection algorithms applied were
    completed successfully
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SummaryOfDetections = DICOMControlledTerminologyDefinitionsCode("111064")
    """
    An overall indication of whether the CAD analysis algorithms applied were
    completed successfully
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SummaryOfAnalyses = DICOMControlledTerminologyDefinitionsCode("111065")
    """
    For projection radiography, the vertical physical distance measured at the
    front plane of an Image Receptor housing between the center of each pixel. For
    tomographic images, the vertical physical distance in the patient between the
    center of each pixel
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VerticalPixelSpacing = DICOMControlledTerminologyDefinitionsCode("111066")
    """
    A radiographic projection that has been with the patient lying on a table with
    the X-Ray source on one side of the table and the detector on the other; e.g.
    may describe a cross-table cervical spine, chest or pelvis X-Ray image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Crosstable = DICOMControlledTerminologyDefinitionsCode("111069")
    """
    One of a number of discrete points on the Receiver-Operator Characteristics
    (ROC) curve that reflects the expected sensitivity and specificity of a CAD
    algorithm, where zero indicates the highest specificity, lowest sensitivity
    operating point. The value should not exceed the Maximum CAD Operating Point
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CADOperatingPoint = DICOMControlledTerminologyDefinitionsCode("111071")
    """
    The maximum value of CAD Operating Point for the specific CAD algorithm used
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MaximumCADOperatingPoint = DICOMControlledTerminologyDefinitionsCode("111072")
    """
    The intended interpretation of a CAD Operating Point
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CADOperatingPointDescription = DICOMControlledTerminologyDefinitionsCode("111081")
    """
    The number of false CAD markers per image. Correlates to inverse of Image
    Specificity
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FalseMarkersPerImage = DICOMControlledTerminologyDefinitionsCode("111086")
    """
    The number of false markers per collection of images that are CAD processed as
    a group. Correlates to inverse of Case Specificity
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FalseMarkersPerCase = DICOMControlledTerminologyDefinitionsCode("111087")
    """
    The percentage of cancers that should be detected by a CAD algorithm where CAD
    marks the cancers in at least one view
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CaseSensitivity = DICOMControlledTerminologyDefinitionsCode("111088")
    """
    The percentage of cancers that should be detected by a CAD algorithm where CAD
    marks the cancers in each view
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LesionSensitivity = DICOMControlledTerminologyDefinitionsCode("111089")
    """
    The percentage of cases (collections of images CAD processed as a group)
    without cancer that have no CAD findings whatsoever. Correlates to inverse of
    False Markers per Case
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CaseSpecificity = DICOMControlledTerminologyDefinitionsCode("111090")
    """
    The percentage of images without cancer that have no CAD findings whatsoever.
    Correlates to inverse of False Markers per Image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ImageSpecificity = DICOMControlledTerminologyDefinitionsCode("111091")
    """
    The CAD operating point that is recommended for initial display by the creator
    of the structured report
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RecommendedCADOperatingPoint = DICOMControlledTerminologyDefinitionsCode("111092")
    """
    A list of CAD operating points including their corresponding characteristics
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CADOperatingPointTable = DICOMControlledTerminologyDefinitionsCode("111093")
    """
    A specific area of interest noted within an image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SelectedRegion = DICOMControlledTerminologyDefinitionsCode("111099")
    """
    The surface shape of all or a portion of breast related anatomy
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BreastGeometry = DICOMControlledTerminologyDefinitionsCode("111100")
    """
    Image quality incorporates the following clinical image evaluation parameters:
    assessment of positioning, compression, artifacts, exposure, contrast,
    sharpness, and labeling
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ImageQuality = DICOMControlledTerminologyDefinitionsCode("111101")
    """
    A finding or feature that is identified as a non-anatomic foreign object
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Non_lesion = DICOMControlledTerminologyDefinitionsCode("111102")
    """
    A space-occupying lesion identified in a single image or projection
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Density = DICOMControlledTerminologyDefinitionsCode("111103")
    """
    A single identified calcification
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IndividualCalcification = DICOMControlledTerminologyDefinitionsCode("111104")
    """
    Multiple calcifications identified as occupying a small area of tissue (less
    than 2 cc)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CalcificationCluster = DICOMControlledTerminologyDefinitionsCode("111105")
    """
    Straightening or thickening of Cooper's ligaments
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Cooper_sLigamentChanges = DICOMControlledTerminologyDefinitionsCode("111111")
    """
    An abnormality noted at imaging within the dermis of the breast
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MassInTheSkin = DICOMControlledTerminologyDefinitionsCode("111112")
    """
    An abnormality noted at imaging on the epidermis of the breast
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MassOnTheSkin = DICOMControlledTerminologyDefinitionsCode("111113")
    """
    An assessment category to indicate that images have been acquired to assess
    marker placement following a breast interventional procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PostProcedureMammogramsForMarkerPlacement = (
        DICOMControlledTerminologyDefinitionsCode("111120")
    )
    """
    An indication that the patient should seek post procedural follow-up
    directives from a clinical health care provider
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Follow_upPostBiopsyAsDirectedByClinician = (
        DICOMControlledTerminologyDefinitionsCode("111121")
    )
    """
    A recommendation on a patient with known cancer to take steps appropriate to
    the diagnosis
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    KnownBiopsyProvenMalignancy_TakeAppropriateAction = (
        DICOMControlledTerminologyDefinitionsCode("111122")
    )
    """
    Positioning of a radiopaque marker
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MarkerPlacement = DICOMControlledTerminologyDefinitionsCode("111123")
    """
    Patient has previous diagnosis of breast cancer resulting in mastectomy
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PersonalHistoryOfBreastCancerWithMastectomy = (
        DICOMControlledTerminologyDefinitionsCode("111124")
    )
    """
    Patient has had biopsy containing proven malignancy
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    KnownBiopsyProvenMalignancy = DICOMControlledTerminologyDefinitionsCode("111125")
    """
    Patient has a finding of mass reported on a prior imaging exam
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ImageDetectedMass = DICOMControlledTerminologyDefinitionsCode("111126")
    """
    A breast imaging procedure performed on a specific area of the breast
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Targeted = DICOMControlledTerminologyDefinitionsCode("111127")
    """
    A breast imaging procedure performed on the entire breast
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Survey = DICOMControlledTerminologyDefinitionsCode("111128")
    """
    A cluster of tiny anechoic foci each smaller than 2-3 mm in diameter with thin
    (less than 0.5 mm) intervening septations and no discrete solid components
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ClusteredMicrocysts = DICOMControlledTerminologyDefinitionsCode("111129")
    """
    A fluid filled mass most commonly characterized by homogeneous low-level
    internal echoes on ultrasound
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ComplicatedCyst = DICOMControlledTerminologyDefinitionsCode("111130")
    """
    Views not inclusive of MLO and CC (BI-RADS®)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AdditionalProjections = DICOMControlledTerminologyDefinitionsCode("111135")
    """
    A spot or coned down compression of the breast providing a reduction in the
    thickness and a magnification of the localized area of interest and improved
    separation of breast tissue
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SpotMagnificationView_s_ = DICOMControlledTerminologyDefinitionsCode("111136")
    """
    Use of sound waves to visualize muscles, tendons, and many internal organs, to
    capture their size, structure and any pathological lesions with real time
    tomographic images.
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Ultrasound = DICOMControlledTerminologyDefinitionsCode("111137")
    """
    Obtain previous mammography studies to compare to present study
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OldFilmsForComparison = DICOMControlledTerminologyDefinitionsCode("111138")
    """
    A medical procedure used for the sampling of mammary duct tissue
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Ductography = DICOMControlledTerminologyDefinitionsCode("111139")
    """
    Follow up study at 12 months for women 40 years of age having a prior negative
    study and no mitigating risk factors for breast cancer
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NormalIntervalFollow_up = DICOMControlledTerminologyDefinitionsCode("111140")
    """
    Any decision to perform tissue acquisition should be based on clinical
    assessment
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AnyDecisionToBiopsyShouldBeBasedOnClinicalAssessment = (
        DICOMControlledTerminologyDefinitionsCode("111141")
    )
    """
    Follow-up at short interval (1-11 months)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Follow_upAtShortInterval_1_11Months_ = DICOMControlledTerminologyDefinitionsCode(
        "111142"
    )
    """
    Tissue acquisition should be considered
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BiopsyShouldBeConsidered = DICOMControlledTerminologyDefinitionsCode("111143")
    """
    Breast tissue acquisition following the identification of an area of concern
    with the placement of a needle or needle-wire assembly
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NeedleLocalizationAndBiopsy = DICOMControlledTerminologyDefinitionsCode("111144")
    """
    Pathologic analysis of breast tissue and lesions using core tissue samples
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    HistologyUsingCoreBiopsy = DICOMControlledTerminologyDefinitionsCode("111145")
    """
    Lesions that do not have the characteristic morphologies of breast cancer but
    have a definite probability of being malignant. There is a sufficient concern
    to urge a biopsy
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SuggestiveOfMalignancy_TakeAppropriateAction = (
        DICOMControlledTerminologyDefinitionsCode("111146")
    )
    """
    Cellular analysis of specimen
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CytologicAnalysis = DICOMControlledTerminologyDefinitionsCode("111147")
    """
    Tissue acquisition should be strongly considered
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BiopsyShouldBeStronglyConsidered = DICOMControlledTerminologyDefinitionsCode(
        "111148"
    )
    """
    Lesions have a high probability of being cancer, which require additional
    action
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    HighlySuggestiveOfMalignancy_TakeAppropriateAction = (
        DICOMControlledTerminologyDefinitionsCode("111149")
    )
    """
    The producer of a report intends for a recipient of the report to present or
    display the associated content item
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PresentationRequired_RenderingDeviceIsExpectedToPresent = (
        DICOMControlledTerminologyDefinitionsCode("111150")
    )
    """
    The producer of a report considers the presentation or display of the
    associated content item by a recipient to be optional
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PresentationOptional_RenderingDeviceMayPresent = (
        DICOMControlledTerminologyDefinitionsCode("111151")
    )
    """
    The producer of a report intends for a recipient of the report NOT to present
    or display the associated content item
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NotForPresentation_RenderingDeviceExpectedNotToPresent = (
        DICOMControlledTerminologyDefinitionsCode("111152")
    )
    """
    The associated content items are identified as being the same finding or
    feature at different points in time
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TargetContentItemsAreRelatedTemporally = DICOMControlledTerminologyDefinitionsCode(
        "111153"
    )
    """
    The associated content items are identified as being the same finding or
    feature on different projections taken at the same point in time
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TargetContentItemsAreRelatedSpatially = DICOMControlledTerminologyDefinitionsCode(
        "111154"
    )
    """
    The associated content items are identified as being related side-to-side
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TargetContentItemsAreRelatedContra_laterally = (
        DICOMControlledTerminologyDefinitionsCode("111155")
    )
    """
    There is one image in the interpreted data set
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FeatureDetectedOnTheOnlyImage = DICOMControlledTerminologyDefinitionsCode("111156")
    """
    There is more than one image of the same modality in the interpreted data set
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FeatureDetectedOnOnlyOneOfTheImages = DICOMControlledTerminologyDefinitionsCode(
        "111157"
    )
    """
    There is more than one image of the same modality in the interpreted data set
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FeatureDetectedOnMultipleImages = DICOMControlledTerminologyDefinitionsCode(
        "111158"
    )
    """
    The interpreted data set contains images from multiple modalities
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FeatureDetectedOnImagesFromMultipleModalities = (
        DICOMControlledTerminologyDefinitionsCode("111159")
    )
    """
    The fibrous tissue replacing normal tissues destroyed by disease or injury
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ScarTissue = DICOMControlledTerminologyDefinitionsCode("111168")
    """
    A medical appliance used for localization of non palpable breast lesions to
    insure that the proper area is removed in a surgical biopsy
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    JWire = DICOMControlledTerminologyDefinitionsCode("111170")
    """
    A medical appliance used for regulating cardiac rhythms
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Pacemaker = DICOMControlledTerminologyDefinitionsCode("111171")
    """
    A compression device used for obtaining mammographic images
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Paddle = DICOMControlledTerminologyDefinitionsCode("111172")
    """
    A device used for restricting an X-Ray beam
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Collimator = DICOMControlledTerminologyDefinitionsCode("111173")
    """
    An area designated on a radiographic film for facility and patient ID
    information
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IDPlate = DICOMControlledTerminologyDefinitionsCode("111174")
    """
    Site specific markers
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OtherMarker = DICOMControlledTerminologyDefinitionsCode("111175")
    """
    The value of the concept is not specified
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Unspecified = DICOMControlledTerminologyDefinitionsCode("111176")
    """
    Image quality deficiency according to MQSA
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ViewAndLateralityMarkerIsMissing = DICOMControlledTerminologyDefinitionsCode(
        "111177"
    )
    """
    Image quality deficiency according to MQCM
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ViewAndLateralityMarkerDoesNotHaveBothViewAndLaterality = (
        DICOMControlledTerminologyDefinitionsCode("111178")
    )
    """
    Image quality deficiency according to MQCM
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ViewAndLateralityMarkerDoesNotHaveApprovedCodes = (
        DICOMControlledTerminologyDefinitionsCode("111179")
    )
    """
    Image quality deficiency according to MQCM
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ViewAndLateralityMarkerIsNotNearTheAxilla = (
        DICOMControlledTerminologyDefinitionsCode("111180")
    )
    """
    Image quality deficiency according to MQCM
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ViewAndLateralityMarkerOverlapsBreastTissue = (
        DICOMControlledTerminologyDefinitionsCode("111181")
    )
    """
    Image quality deficiency according to MQCM
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ViewAndLateralityMarkerIsPartiallyObscured = (
        DICOMControlledTerminologyDefinitionsCode("111182")
    )
    """
    Image quality deficiency
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ViewAndLateralityMarkerIsIncorrect = DICOMControlledTerminologyDefinitionsCode(
        "111183"
    )
    """
    Image quality deficiency
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ViewAndLateralityMarkerIsOffImage = DICOMControlledTerminologyDefinitionsCode(
        "111184"
    )
    """
    Image quality deficiency according to MQCM
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FlashIsNotNearEdgeOfFilm = DICOMControlledTerminologyDefinitionsCode("111185")
    """
    Image quality deficiency according to MQSA
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FlashIsIlligible_DoesNotFit_OrIsLopsided = (
        DICOMControlledTerminologyDefinitionsCode("111186")
    )
    """
    Image quality deficiency according to MQCM
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FlashDoesn_tIncludePatientNameAndAdditionalPatientId = (
        DICOMControlledTerminologyDefinitionsCode("111187")
    )
    """
    Image quality deficiency according to MQCM
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FlashDoesn_tIncludeDateOfExamination = DICOMControlledTerminologyDefinitionsCode(
        "111188"
    )
    """
    Image quality deficiency according to MQSA
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FlashDoesn_tIncludeFacilityNameAndLocation = (
        DICOMControlledTerminologyDefinitionsCode("111189")
    )
    """
    Image quality deficiency according to MQCM
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FlashDoesn_tIncludeTechnologistIdentification = (
        DICOMControlledTerminologyDefinitionsCode("111190")
    )
    """
    Image quality deficiency according to MQCM
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FlashDoesn_tIncludeCassette_screen_detectorIdentification = (
        DICOMControlledTerminologyDefinitionsCode("111191")
    )
    """
    Image quality deficiency according to MQCM
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FlashDoesn_tIncludeMammographyUnitIdentification = (
        DICOMControlledTerminologyDefinitionsCode("111192")
    )
    """
    Image quality deficiency according to MQCM
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DateStickerIsMissing = DICOMControlledTerminologyDefinitionsCode("111193")
    """
    Image quality deficiency according to MQCM
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TechnicalFactorsMissing = DICOMControlledTerminologyDefinitionsCode("111194")
    """
    Image quality deficiency according to MQCM
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CollimationTooCloseToBreast = DICOMControlledTerminologyDefinitionsCode("111195")
    """
    Image quality deficiency according to MQCM
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    InadequateCompression = DICOMControlledTerminologyDefinitionsCode("111196")
    """
    Image quality deficiency according to MQCM
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MLOInsufficientPectoralMuscle = DICOMControlledTerminologyDefinitionsCode("111197")
    """
    Image quality deficiency according to MQCM
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MLONoFatIsVisualizedPosteriorToFibroglandularTissues = (
        DICOMControlledTerminologyDefinitionsCode("111198")
    )
    """
    Image quality deficiency according to MQCM
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MLOPoorSeparationOfDeepAndSuperficialBreastTissues = (
        DICOMControlledTerminologyDefinitionsCode("111199")
    )
    """
    Image quality deficiency according to MQCM
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MLOEvidenceOfMotionBlur = DICOMControlledTerminologyDefinitionsCode("111200")
    """
    Image quality deficiency according to MQCM
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MLOInframammaryFoldIsNotOpen = DICOMControlledTerminologyDefinitionsCode("111201")
    """
    Image quality deficiency according to MQCM
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CCNotAllMedialTissueVisualized = DICOMControlledTerminologyDefinitionsCode("111202")
    """
    Image quality deficiency according to MQCM
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CCNippleNotCenteredOnImage = DICOMControlledTerminologyDefinitionsCode("111203")
    """
    Image quality deficiency according to MQCM
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CCPosteriorNippleLineDoesNotMeasureWithin1CmOfMLO = (
        DICOMControlledTerminologyDefinitionsCode("111204")
    )
    """
    Image quality deficiency
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NippleNotInProfile = DICOMControlledTerminologyDefinitionsCode("111205")
    """
    Image quality deficiency according to MQCM
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    InsufficientImplantDisplacementIncorrect = (
        DICOMControlledTerminologyDefinitionsCode("111206")
    )
    """
    Signals that do not faithfully reproduce actual anatomic structures because of
    distortion or of addition or deletion of information
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ImageArtifact_s_ = DICOMControlledTerminologyDefinitionsCode("111207")
    """
    Feature(s) arising from the acquisition unit's anti-scatter grid mechanism.
    For two-dimensional systems, such features include those of mechanically
    damaged or incorrectly positioned grids. For moving or Bucky grids, artifacts
    may result from intentional grid motion that is inadequate in duration or
    velocity uniformity
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    GridArtifact_s_ = DICOMControlledTerminologyDefinitionsCode("111208")
    """
    Inadequate arrangement of the anatomy of interest with respect to the X-Ray
    field and image detector sensitive area. Examples: 1) positioning is "cutoff"
    when the projection of anatomy of interest falls outside the sensitive area of
    the detector; 2) "cone cut", in which the X-Ray field does not adequately
    cover the anatomy of interest; 3) detector's sensitive surface is too small to
    cover the projection of the anatomy of interest; 4) improper angular
    orientation or "rotation" of anatomy of interest with respect to the X-Ray
    source, or detector; 5) projection of other anatomy or clothing over the
    anatomy of interest in the image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Positioning = DICOMControlledTerminologyDefinitionsCode("111209")
    """
    Unacceptable image blur resulting from motion of the anatomy of interest
    during exposure or the inadequately compensated motion of X-Ray source with
    respect to the image detector during exposure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MotionBlur = DICOMControlledTerminologyDefinitionsCode("111210")
    """
    Inadequate number of quanta reached the detector during exposure. Reasons for
    under exposed images include low kVp, low mAs product, excess Source Image
    Distance. Under exposed images have inadequate signal and higher noise in the
    areas of interest
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    UnderExposed = DICOMControlledTerminologyDefinitionsCode("111211")
    """
    An excess number of quanta reached the detector during exposure. Reasons for
    over exposed images include high kVp, high mAs product, short Source Image
    Distance. Over exposed images have high signal and lower noise in the areas of
    interest. Over exposed area may demonstrate lack of contrast from over
    saturation of the detector
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OverExposed = DICOMControlledTerminologyDefinitionsCode("111212")
    """
    No evidence of a patient exposure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NoImage = DICOMControlledTerminologyDefinitionsCode("111213")
    """
    Superposed features or flaws of the detector
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DetectorArtifact_s_ = DICOMControlledTerminologyDefinitionsCode("111214")
    """
    Features or discontinuities arising from causes other than the anti-scatter
    grid and image detector
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Artifact_s_OtherThanGridOrDetectorArtifact = (
        DICOMControlledTerminologyDefinitionsCode("111215")
    )
    """
    Failure of the device to operate according to mechanical design specifications
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MechanicalFailure = DICOMControlledTerminologyDefinitionsCode("111216")
    """
    Failure of a device to operate according to electrical design specifications
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ElectricalFailure = DICOMControlledTerminologyDefinitionsCode("111217")
    """
    Attributable to software used in generation or handling of image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SoftwareFailure = DICOMControlledTerminologyDefinitionsCode("111218")
    """
    Images processed inappropriately, not following appropriate protocol
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    InappropriateImageProcessing = DICOMControlledTerminologyDefinitionsCode("111219")
    """
    Failure that is not mechanical or electrical or otherwise described
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OtherFailure = DICOMControlledTerminologyDefinitionsCode("111220")
    """
    Unidentified or unknown cause of failure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    UnknownFailure = DICOMControlledTerminologyDefinitionsCode("111221")
    """
    The attempted process was completely successful
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Succeeded = DICOMControlledTerminologyDefinitionsCode("111222")
    """
    The attempted process succeeded in some ways, but failed in others
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PartiallySucceeded = DICOMControlledTerminologyDefinitionsCode("111223")
    """
    The attempted process completely failed
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Failed = DICOMControlledTerminologyDefinitionsCode("111224")
    """
    No process was performed
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NotAttempted = DICOMControlledTerminologyDefinitionsCode("111225")
    """
    Analysis of a related group of findings or features detected during image data
    inspection, to produce a summary impression and/or recommendation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IndividualImpression_RecommendationAnalysis = (
        DICOMControlledTerminologyDefinitionsCode("111233")
    )
    """
    Analysis of all groups of findings or features, to produce a single impression
    and/or recommendation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OverallImpression_RecommendationAnalysis = (
        DICOMControlledTerminologyDefinitionsCode("111234")
    )
    """
    The usability of an image for diagnostic interpretation or CAD, based on a
    quality control standard
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Unusable_QualityRendersImageUnusable = DICOMControlledTerminologyDefinitionsCode(
        "111235"
    )
    """
    The usability of an image for diagnostic interpretation or CAD, based on a
    quality control standard
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Usable_DoesNotMeetTheQualityControlStandard = (
        DICOMControlledTerminologyDefinitionsCode("111236")
    )
    """
    The usability of an image for diagnostic interpretation or CAD, based on a
    quality control standard
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Usable_MeetsTheQualityControlStandard = DICOMControlledTerminologyDefinitionsCode(
        "111237"
    )
    """
    An image quality control standard specified by the American College of
    Radiology
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MammographyQualityControlManual1999_ACR = DICOMControlledTerminologyDefinitionsCode(
        "111238"
    )
    """
    An image quality control standard in the US Code of Federal Regulations
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Title21CFRSection900_SubpartB = DICOMControlledTerminologyDefinitionsCode("111239")
    """
    An image quality control standard specified or adopted by the institution
    responsible for the document
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    InstitutionallyDefinedQualityControlStandard = (
        DICOMControlledTerminologyDefinitionsCode("111240")
    )
    """
    No findings resulted upon successful completion of all attempted computer-
    aided detection and/or analysis
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AllAlgorithmsSucceeded_WithoutFindings = DICOMControlledTerminologyDefinitionsCode(
        "111241"
    )
    """
    One or more findings resulted upon successful completion of all attempted
    computer-aided detection and/or analysis
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AllAlgorithmsSucceeded_WithFindings = DICOMControlledTerminologyDefinitionsCode(
        "111242"
    )
    """
    No findings resulted from the attempted computer-aided detection and/or
    analysis, but one or more failures occurred in the process
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NotAllAlgorithmsSucceeded_WithoutFindings = (
        DICOMControlledTerminologyDefinitionsCode("111243")
    )
    """
    One or more findings resulted from the attempted computer-aided detection
    and/or analysis, but one or more failures occurred in the process
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NotAllAlgorithmsSucceeded_WithFindings = DICOMControlledTerminologyDefinitionsCode(
        "111244"
    )
    """
    All of the attempted computer-aided detection and/or analysis failed, so there
    could be no findings
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NoAlgorithmsSucceeded_WithoutFindings = DICOMControlledTerminologyDefinitionsCode(
        "111245"
    )
    """
    A benign tumor having glandular characteristics but composed of fat, with the
    presence of normal mammary ducts
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Adenolipoma = DICOMControlledTerminologyDefinitionsCode("111248")
    """
    Hyperplasia is also known as epithelial hyperplasia or proliferative breast
    disease. It's an overgrowth of the cells that line the ducts or the lobules.
    Based on how the cells look under a microscope, the hyperplasia is called
    either ductal hyperplasia (also called duct epithelial hyperplasia) or lobular
    hyperplasia. Based on the pattern of the cells, hyperplasia may be called
    usual or atypical. In usual hyperplasia, the pattern of cells is very close to
    normal. Atypical hyperplasia (or hyperplasia with atypia) is a term used when
    the cells are more distorted. FROM:
    http://www.cancer.org/healthy/findcancerearly/womenshealth/non-
    cancerousbreastconditions/non-cancerous-breast-conditions-hyperplasia
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DuctalHyperplasia = DICOMControlledTerminologyDefinitionsCode("111249")
    """
    Neoplasms composed of myoepithelial cells
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Adenomyoepithelioma = DICOMControlledTerminologyDefinitionsCode("111250")
    """
    Axillary node that is normal in appearance with no associated pathology
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NormalAxillaryNode = DICOMControlledTerminologyDefinitionsCode("111251")
    """
    Axillary node containing calcifications
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AxillaryNodeWithCalcifications = DICOMControlledTerminologyDefinitionsCode("111252")
    """
    Excessive proliferation of normal tissue arrangement of the axillary node
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AxillaryNodeHyperplasia = DICOMControlledTerminologyDefinitionsCode("111253")
    """
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AsynchronousInvolution = DICOMControlledTerminologyDefinitionsCode("111254")
    """
    Cyst with benign morphology containing blood
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BenignCystWithBlood = DICOMControlledTerminologyDefinitionsCode("111255")
    """
    Calcifications having typically benign morphology. They are not of
    intermediate or high probability of concern for malignancy
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BenignCalcifications = DICOMControlledTerminologyDefinitionsCode("111256")
    """
    Growing within a cystic adenoma, filling the cavity with a mass of branching
    epithelial processes
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IntracysticPapilloma = DICOMControlledTerminologyDefinitionsCode("111257")
    """
    Adenoma located in mammary duct, present as discrete sclerotic nodules,
    solitary or multiple
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DuctalAdenoma = DICOMControlledTerminologyDefinitionsCode("111258")
    """
    The occurrence of fibrous tumor-forming stromal proliferation in patients with
    diabetes mellitus
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DiabeticFibrousMastopathy = DICOMControlledTerminologyDefinitionsCode("111259")
    """
    A deep seated firm tumor frequently occurring on the chest consisting of
    collagenous tissue that infiltrates surround muscle; frequently recurs but
    does not metastasize
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ExtraAbdominalDesmoid = DICOMControlledTerminologyDefinitionsCode("111260")
    """
    A cyst formed of a mass of epithelial cells, as a result of trauma has been
    pushed beneath the epidermis. The cyst is lined with squamous epithelium and
    contains concentric layers or keratin
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EpidermalInclusionCyst = DICOMControlledTerminologyDefinitionsCode("111262")
    """
    Excessive proliferation of fibroadenoma tissue
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FibroadenomatoidHyperplasia = DICOMControlledTerminologyDefinitionsCode("111263")
    """
    A lipoma with an abundant stroma of fibrous tissue
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Fibroadenolipoma = DICOMControlledTerminologyDefinitionsCode("111264")
    """
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ForeignBody_reaction_ = DICOMControlledTerminologyDefinitionsCode("111265")
    """
    Retention cyst caused by occlusion of a lactiferous duct
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Galactocele = DICOMControlledTerminologyDefinitionsCode("111269")
    """
    A congenital anomaly that leads to a proliferation of blood vessels leading to
    a mass that resembles a neoplasm, not located in parenchymal areas but
    subcutaneous
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Hemangioma_Nonparenchymal_Subcutaneous = DICOMControlledTerminologyDefinitionsCode(
        "111271"
    )
    """
    Hyperplasia is also known as epithelial hyperplasia or proliferative breast
    disease. It's an overgrowth of the cells that line the ducts or the lobules.
    Based on how the cells look under a microscope, the hyperplasia is called
    either ductal hyperplasia (also called duct epithelial hyperplasia) or lobular
    hyperplasia. FROM:
    http://www.cancer.org/healthy/findcancerearly/womenshealth/non-
    cancerousbreastconditions/non-cancerous-breast-conditions-hyperplasia
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Hyperplasia_Usual = DICOMControlledTerminologyDefinitionsCode("111273")
    """
    A form of fibrocystic disease in young woman with florid and sclerosing
    adenosis that microscopically may suggest carcinoma
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    JuvenilePapillomatosis = DICOMControlledTerminologyDefinitionsCode("111277")
    """
    Enlarging masses during lactation. A circumscribed benign tumor composed
    primarily of glandular structures with scanty stroma, with prominent secretory
    changes in the duct
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LactatingAdenoma = DICOMControlledTerminologyDefinitionsCode("111278")
    """
    Changes related to the process of lactation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LactationalChange = DICOMControlledTerminologyDefinitionsCode("111279")
    """
    A papilloma pertaining to large mammary duct
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LargeDuctPapilloma = DICOMControlledTerminologyDefinitionsCode("111281")
    """
    Solitary or multiple tumors of muscles and fibrous tissues, or tumors composed
    of myofibroblasts
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Myofibroblastoma = DICOMControlledTerminologyDefinitionsCode("111283")
    """
    Irregular clusters of small tubules are present in adipose or fibrous tissue,
    resembling tubular carcinoma but lacking stromal fibroblastic proliferation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MicroglandularAdenosis = DICOMControlledTerminologyDefinitionsCode("111284")
    """
    Papilloma typically involving an aggregate of adjacent ducts in the periphery
    of the breast, likely representing involvement of several foci of one or two
    duct systems
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MultipleIntraductalPapillomas = DICOMControlledTerminologyDefinitionsCode("111285")
    """
    No abnormality
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NoAbnormality = DICOMControlledTerminologyDefinitionsCode("111286")
    """
    Normal breast tissue
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NormalBreastTissue = DICOMControlledTerminologyDefinitionsCode("111287")
    """
    Condition in which there are tumors of various sizes on peripheral nerves.
    They may be neuromas or fibromas
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Neurofibromatosis = DICOMControlledTerminologyDefinitionsCode("111288")
    """
    A cyst resulting from the loss of the epithelial lining of a sebaceous dermoid
    or lacteal cyst
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OilCyst_fatNecrosisCyst_ = DICOMControlledTerminologyDefinitionsCode("111290")
    """
    Breast tissue with characteristics of a benign nature, following breast
    reduction surgery
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PostReductionMammoplasty = DICOMControlledTerminologyDefinitionsCode("111291")
    """
    A benign stromal lesion composed of intermixed stromal and epithelial
    elements. The lobular and duct structures of the breast parenchyma are
    separated by an increased amount of stroma, non specific proliferative
    epithelial changes include hyperplasia of duct and lobular epithelium often
    with accentuation of myoepithelial cells and aprocine metaplasia with or
    without cyst formation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PseudoangiomatousStromalHyperplasia = DICOMControlledTerminologyDefinitionsCode(
        "111292"
    )
    """
    An nonencapsulated stellate lesion consisting of a fibroelastic core and
    radiating bands of fibrous connective tissue containing lobules manifesting
    adenosis and ducts with papillary or diffuse intraductal hyperplasia
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RadialScar = DICOMControlledTerminologyDefinitionsCode("111293")
    """
    Prominent interductal fibrosis of the terminal ductules
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SclerosingAdenosis = DICOMControlledTerminologyDefinitionsCode("111294")
    """
    Nodular inflammatory lesions due to the presence of silicone in the breast
    tissue
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SiliconeGranuloma = DICOMControlledTerminologyDefinitionsCode("111296")
    """
    The morphologic status of the nipple
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NippleCharacteristic = DICOMControlledTerminologyDefinitionsCode("111297")
    """
    Spontaneous excessive proliferation of breast tissue, usually found in younger
    women
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VirginalHyperplasia = DICOMControlledTerminologyDefinitionsCode("111298")
    """
    Papilloma(s) pertaining the peripheral ducts
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PeripheralDuctPapillomas = DICOMControlledTerminologyDefinitionsCode("111299")
    """
    Axillary node with lymphoid tissue neoplasm
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AxillaryNodeWithLymphoma = DICOMControlledTerminologyDefinitionsCode("111300")
    """
    Metastatic disease to the axillary node
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AxillaryNodalMetastases = DICOMControlledTerminologyDefinitionsCode("111301")
    """
    A malignant neoplasm occurring most often in breast and skin, believed to
    originate from endothelial cells of blood vessels, microscopically composed of
    closely packed round or spindle shaped cells, some of which line small spaces
    resembling vascular clefts
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Angiosarcoma = DICOMControlledTerminologyDefinitionsCode("111302")
    """
    Histological changes to the vascular system related to an invasive process
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BloodVessel_vascular_Invasion = DICOMControlledTerminologyDefinitionsCode("111303")
    """
    Carcinoma of the breast found in patients less than 20 years of age
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CarcinomaInChildren = DICOMControlledTerminologyDefinitionsCode("111304")
    """
    A carcinoma found in supernumerary breasts and aberrant breast tissue
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CarcinomaInEctopicBreast = DICOMControlledTerminologyDefinitionsCode("111305")
    """
    A carcinoma that synthesizes substances, including hormones, not considered to
    be normal products of the breast
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CarcinomaWithEndocrineDifferentiation = DICOMControlledTerminologyDefinitionsCode(
        "111306"
    )
    """
    A basal cell carcinoma that arises in the nipple of the breast
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BasalCellCarcinomaOfNipple = DICOMControlledTerminologyDefinitionsCode("111307")
    """
    Metaplastic carcinoma is cancer that begins in cells that have changed into
    another cell type (for example, a squamous cell of the esophagus changing to
    resemble a cell of the stomach). In some cases, metaplastic changes alone may
    mean there is an increased chance of cancer developing at the site.
    Metaplastic carcinoma is a relatively uncommon type of cancer with treatment
    generally similar to that of invasive ductal carcinoma of no special type.[1]
    FROM: https://en.wikipedia.org/wiki/Metaplastic_carcinoma
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CarcinomaWithMetaplasia = DICOMControlledTerminologyDefinitionsCode("111308")
    """
    Tissue changes to bones and cartilage
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CartilaginousAndOsseousChange = DICOMControlledTerminologyDefinitionsCode("111309")
    """
    Carcinoma of the breast presenting during pregnancy or lactation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CarcinomaInPregnancyAndLactation = DICOMControlledTerminologyDefinitionsCode(
        "111310"
    )
    """
    A malignant neoplasm that contains elements of carcinoma and sarcoma, so
    extensively intermixed as to indicate neoplasia of epithelial and mesenchymal
    tissue
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Carcinosarcoma = DICOMControlledTerminologyDefinitionsCode("111311")
    """
    Comedocarcinoma of a duct with areas of necrotic tissue
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IntraductalComedocarcinomaWithNecrosis = DICOMControlledTerminologyDefinitionsCode(
        "111312"
    )
    """
    A non-invasive carcinoma restricted to the glandular lumen characterized by
    less aggressive malignant cytologic features and behavior
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IntraductalCarcinoma_LowGrade = DICOMControlledTerminologyDefinitionsCode("111313")
    """
    Papillary and micropapillary Ductal Carcinoma In Situ (DCIS): the cancer cells
    arrange themselves in a fern-like pattern within the affected breast ducts;
    micropapillary DCIS cells are smaller than papillary DCIS cells. FROM:
    http://www.imaginis.com/breast-cancer-diagnosis/ductal-carcinoma-in-situ-
    dcis-3
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IntraductalCarcinomaMicro_papillary = DICOMControlledTerminologyDefinitionsCode(
        "111314"
    )
    """
    A malignant neoplasm characterized by the formation of numerous, irregular,
    finger-like projections of fibrous stroma that is covered with a surface layer
    of neoplastic epithelial cells found in a cyst
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IntracysticPapillaryCarcinoma = DICOMControlledTerminologyDefinitionsCode("111315")
    """
    Carcinoma with both characteristics of localized and spreading disease
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    InvasiveAndIn_situCarcinoma = DICOMControlledTerminologyDefinitionsCode("111316")
    """
    Invasive lobular carcinoma is a type of breast cancer that begins in the milk-
    producing glands (lobules) of the breast. Invasive cancer means the cancer
    cells have broken out of the lobule where they began and have the potential to
    spread to the lymph nodes and other areas of the body. Invasive lobular
    carcinoma typically doesn't form a lump, which is common in breast cancer.
    Instead, there is a change in the breast that feels like a thickening or
    fullness in one part of the breast and is different from the surrounding
    breast tissue. FROM: http://www.mayoclinic.org/diseases-conditions/invasive-
    lobular-carcinoma/basics/definition/con-20033968
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    InvasiveLobularCarcinoma = DICOMControlledTerminologyDefinitionsCode("111317")
    """
    Mammary infiltrates as a secondary manifestation in patients with established
    leukemia
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LeukemicInfiltration = DICOMControlledTerminologyDefinitionsCode("111318")
    """
    Histological changes to the lymphatic system related to an invasive process
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LympathicVesselInvasion = DICOMControlledTerminologyDefinitionsCode("111320")
    """
    A heterogeneous group of neoplasms arising in the reticuloendoethelial and
    lymphatic systems
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Lymphoma = DICOMControlledTerminologyDefinitionsCode("111321")
    """
    A small carcinoma, either asymptomatic or giving rise to metastases without
    symptoms due to the primary carcinoma presenting with metastatic disease in
    the axillary lymph nodes
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OccultCarcinomaPresentingWithAxillaryLymphNodeMetastases = (
        DICOMControlledTerminologyDefinitionsCode("111322")
    )
    """
    A malignant lesion in the breast with morphologic patterns not typical of
    breast carcinoma arising from a non-mammary malignant neoplasm
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MetastaticCancerToTheBreast = DICOMControlledTerminologyDefinitionsCode("111323")
    """
    A malignant lesion in the breast with morphologic patterns not typical of
    breast carcinoma arising from a neoplasm in the colon
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MetastaticCancerToTheBreastFromTheColon = DICOMControlledTerminologyDefinitionsCode(
        "111324"
    )
    """
    A malignant lesion in the breast with morphologic patterns not typical of
    breast carcinoma arising from a neoplasm in the lung
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MetastaticCancerToTheBreastFromTheLung = DICOMControlledTerminologyDefinitionsCode(
        "111325"
    )
    """
    A malignant lesion in the breast with morphologic patterns not typical of
    breast carcinoma arising from a melanoma
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MetastaticMelanomaToTheBreast = DICOMControlledTerminologyDefinitionsCode("111326")
    """
    A malignant lesion in the breast with morphologic patterns not typical of
    breast carcinoma arising from a neoplasm in the ovary
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MetastaticCancerToTheBreastFromTheOvary = DICOMControlledTerminologyDefinitionsCode(
        "111327"
    )
    """
    A malignant lesion in the breast with morphologic patterns not typical of
    breast carcinoma arising from a sarcoma
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MetastaticSarcomaToTheBreast = DICOMControlledTerminologyDefinitionsCode("111328")
    """
    Multiple foci of non-invasive carcinoma restricted to the glandular lumen
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MultifocalIntraductalCarcinoma = DICOMControlledTerminologyDefinitionsCode("111329")
    """
    A malignant lesion in an axillary node arising from a non-axillary neoplasm
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MetastaticDiseaseToAxillaryNode = DICOMControlledTerminologyDefinitionsCode(
        "111330"
    )
    """
    Pleomorphic undifferentiated sarcoma (abbreviated PUS), also undifferentiated
    pleomorphic sarcoma and previously malignant fibrous histiocytoma (abbreviated
    MFH), is a type of soft tissue sarcoma. FROM:
    https://en.wikipedia.org/wiki/Pleomorphic_undifferentiated_sarcoma
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MalignantFibrousHistiocytoma = DICOMControlledTerminologyDefinitionsCode("111331")
    """
    Multiple sites of ductal carcinoma
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MultifocalInvasiveDuctalCarcinoma = DICOMControlledTerminologyDefinitionsCode(
        "111332"
    )
    """
    A malignant lesion in a intramammary lymph node arising from a non-
    intramammary lymph node neoplasm
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MetastasisToAnIntramammaryLymphNode = DICOMControlledTerminologyDefinitionsCode(
        "111333"
    )
    """
    A malignant melanoma of the skin that arises in the nipple of the breast
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MalignantMelanomaOfNipple = DICOMControlledTerminologyDefinitionsCode("111334")
    """
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NeoplasmOfTheMammarySkin = DICOMControlledTerminologyDefinitionsCode("111335")
    """
    Papillary and micropapillary Ductal Carcinoma In Situ (DCIS): the cancer cells
    arrange themselves in a fern-like pattern within the affected breast ducts;
    micropapillary DCIS cells are smaller than papillary DCIS cells. FROM:
    http://www.imaginis.com/breast-cancer-diagnosis/ductal-carcinoma-in-situ-
    dcis-3
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PapillaryCarcinomaIn_situ = DICOMControlledTerminologyDefinitionsCode("111336")
    """
    Recurrent malignancy
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RecurrentMalignancy = DICOMControlledTerminologyDefinitionsCode("111338")
    """
    Squamous cell carcinoma to the terminal portion of the alveolar
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SquamousCellCarcinomaOfTheNipple = DICOMControlledTerminologyDefinitionsCode(
        "111340"
    )
    """
    A non-invasive carcinoma restricted to the glandular lumen characterized by
    more aggressive malignant cytologic features and behavior
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IntraductalCarcinoma_HighGrade = DICOMControlledTerminologyDefinitionsCode("111341")
    """
    Invasive tumor with cribriform pattern similar to cribriform DCIS. Low grade,
    cribriform appearance (well defined spaces formed by arches of cells) similar
    to cribriform DCIS but with larger cells, more cytoplasm and more vesicular
    nuclei: Tumor cells are small, often have apical snouts, mild/moderate nuclear
    pleomorphism; Also stromal invasion by islands of cells, often angulated; May
    have predominantly solid appearance; Associated with cribriform DCIS; Often
    mixed with tubular carcinoma. FROM:
    http://www.pathologyoutlines.com/topic/breastmalignantcribriform.html
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    InvasiveCribriformCarcinoma = DICOMControlledTerminologyDefinitionsCode("111342")
    """
    An indication that some or all of the margin of a lesion has sharp corners,
    often forming acute angles
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AngularMargins = DICOMControlledTerminologyDefinitionsCode("111343")
    """
    Calcifications that vary in sizes and shapes and are usually smaller than0.5
    mm in diameter
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FinePleomorphicCalcification = DICOMControlledTerminologyDefinitionsCode("111344")
    """
    Coarse calcifications that are 0.5 mm or greater in size
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Macrocalcifications = DICOMControlledTerminologyDefinitionsCode("111345")
    """
    An indicator that calcifications are imbedded within a mass
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CalcificationsWithinAMass = DICOMControlledTerminologyDefinitionsCode("111346")
    """
    An indicator that calcifications are imaged outside of a mass finding
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CalcificationsOutsideOfAMass = DICOMControlledTerminologyDefinitionsCode("111347")
    """
    Tissue composition of the breast noted on sonography
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BreastBackgroundEchotexture = DICOMControlledTerminologyDefinitionsCode("111350")
    """
    Fat lobules and uniformly echogenic bands of supporting structures comprise
    the bulk of breast tissue
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    HomogeneousFatEchotexture = DICOMControlledTerminologyDefinitionsCode("111351")
    """
    A uniformly echogenic layer of fibroglandular tissue is seen beneath a thin
    layer of subcutaneous fat
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    HomogeneousFibroglandularEchotexture = DICOMControlledTerminologyDefinitionsCode(
        "111352"
    )
    """
    The breast texture is characterized by multiple small areas of increased and
    decreased echogenicity
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    HeterogeneousEchotexture = DICOMControlledTerminologyDefinitionsCode("111353")
    """
    Referential relationship of the finding to the imaging device as noted on
    sonography
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Orientation = DICOMControlledTerminologyDefinitionsCode("111354")
    """
    The long axis of a lesion parallels the skin line ("wider-than-tall" or in a
    horizontal orientation)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Parallel = DICOMControlledTerminologyDefinitionsCode("111355")
    """
    The anterior-posterior or vertical dimension is greater than the transverse or
    horizontal dimension
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NotParallel = DICOMControlledTerminologyDefinitionsCode("111356")
    """
    The lesion boundary describes the transition zone between themas and the
    surrounding tissue
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LesionBoundary = DICOMControlledTerminologyDefinitionsCode("111357")
    """
    The sharp demarcation between the lesion and surrounding tissue can be
    imperceptible or a distinct well-defined echogenic rim of any thickness
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AbruptInterface = DICOMControlledTerminologyDefinitionsCode("111358")
    """
    There is no sharp demarcation between the mass and the surrounding tissue,
    which is bridged by an echogenic transition zone
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EchogenicHalo = DICOMControlledTerminologyDefinitionsCode("111359")
    """
    An imaging characteristic of resonance noted during sonography
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EchoPattern = DICOMControlledTerminologyDefinitionsCode("111360")
    """
    Without internal echoes
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Anechoic = DICOMControlledTerminologyDefinitionsCode("111361")
    """
    Having increased echogenicity relative to fat or equal to fibroglandular
    tissue
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Hyperechoic = DICOMControlledTerminologyDefinitionsCode("111362")
    """
    Mass contains both anechoic and echogenic components
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Complex = DICOMControlledTerminologyDefinitionsCode("111363")
    """
    Defined relative to fat; masses are characterized by low-level echoes
    throughout; e.g. appearance of a complicated cyst or fibroadenoma
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Hypoechoic = DICOMControlledTerminologyDefinitionsCode("111364")
    """
    Having the same echogenicity as fat (a complicated cyst or fibroadenoma may be
    isoechoic or hypoechoic)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Isoechoic = DICOMControlledTerminologyDefinitionsCode("111365")
    """
    The attenuation characteristics of a mass with respect to its acoustic
    transmission
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PosteriorAcousticFeatures = DICOMControlledTerminologyDefinitionsCode("111366")
    """
    No posterior shadowing or enhancement
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NoPosteriorAcousticFeatures = DICOMControlledTerminologyDefinitionsCode("111367")
    """
    Increased posterior echoes
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PosteriorEnhancement = DICOMControlledTerminologyDefinitionsCode("111368")
    """
    Decreased posterior echoes; edge shadows are excluded
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PosteriorShadowing = DICOMControlledTerminologyDefinitionsCode("111369")
    """
    More than one pattern of posterior attenuation, both shadowing and enhancement
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CombinedPosteriorEnhancementAndShadowing = (
        DICOMControlledTerminologyDefinitionsCode("111370")
    )
    """
    Sonographic appearance of adjacent structures relative to a mass finding
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IdentifiableEffectOnSurroundingTissues = DICOMControlledTerminologyDefinitionsCode(
        "111371"
    )
    """
    Characterization of vascularization in region of interest
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Vascularity = DICOMControlledTerminologyDefinitionsCode("111372")
    """
    Vascularity not evident, such as on ultrasound
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VascularityNotPresent = DICOMControlledTerminologyDefinitionsCode("111373")
    """
    Vascularity not evaluated
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VascularityNotAssessed = DICOMControlledTerminologyDefinitionsCode("111374")
    """
    Vascularity on imaging is seen within a lesion
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VascularityPresentInLesion = DICOMControlledTerminologyDefinitionsCode("111375")
    """
    Vascularity on imaging is seen immediately adjacent to a lesion
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VascularityPresentImmediatelyAdjacentToLesion = (
        DICOMControlledTerminologyDefinitionsCode("111376")
    )
    """
    Vascularity on imaging is considered diffusely elevated within the surrounding
    breast tissue
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DiffuselyIncreasedVascularityInSurroundingTissue = (
        DICOMControlledTerminologyDefinitionsCode("111377")
    )
    """
    Relationship of the new anomaly to other clinical or imaging anomalies
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CorrelationToOtherFindings = DICOMControlledTerminologyDefinitionsCode("111380")
    """
    An indication that the current imaging finding relates to a finding from a
    clinical breast exam
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CorrelatesToPhysicalExamFindings = DICOMControlledTerminologyDefinitionsCode(
        "111381"
    )
    """
    An indication that the current imaging finding relates to a finding from a
    mammography exam
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CorrelatesToMammographyFindings = DICOMControlledTerminologyDefinitionsCode(
        "111382"
    )
    """
    An indication that the current imaging finding relates to a finding from a
    breast MRI exam
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CorrelatesToMRIFindings = DICOMControlledTerminologyDefinitionsCode("111383")
    """
    An indication that the current imaging finding relates to a finding from a
    breast ultrasound exam
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CorrelatesToUltrasoundFindings = DICOMControlledTerminologyDefinitionsCode("111384")
    """
    An indication that the current imaging finding relates to a finding from an
    imaging exam
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CorrelatesToOtherImagingFindings = DICOMControlledTerminologyDefinitionsCode(
        "111385"
    )
    """
    An indication that the current imaging finding has no relation to findings
    from any other imaging exam
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NoCorrelationToOtherImagingFindings = DICOMControlledTerminologyDefinitionsCode(
        "111386"
    )
    """
    An indication that the current imaging finding has no relation to any other
    clinical findings
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NoCorrelationToClinicalFindings = DICOMControlledTerminologyDefinitionsCode(
        "111387"
    )
    """
    Classification of the cancer as invasive, DCIS, or other
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MalignancyType = DICOMControlledTerminologyDefinitionsCode("111388")
    """
    A malignancy that has spread beyond an area of focus
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    InvasiveBreastCarcinoma = DICOMControlledTerminologyDefinitionsCode("111389")
    """
    A breast cancer with malignant pathology findings that are not classified as
    invasive or in situ
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OtherMalignancyType = DICOMControlledTerminologyDefinitionsCode("111390")
    """
    A specific timeframe during menses
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MenstrualCyclePhase = DICOMControlledTerminologyDefinitionsCode("111391")
    """
    In the first week of the menstrual cycle phase, that is, one week following
    menses
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    _1stWeek = DICOMControlledTerminologyDefinitionsCode("111392")
    """
    In the second week of the menstrual cycle phase, that is, two weeks following
    menses
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    _2ndWeek = DICOMControlledTerminologyDefinitionsCode("111393")
    """
    In the third week of the menstrual cycle phase, that is, three weeks following
    menses
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    _3rdWeek = DICOMControlledTerminologyDefinitionsCode("111394")
    """
    An estimated period of time
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EstimatedTimeframe = DICOMControlledTerminologyDefinitionsCode("111395")
    """
    An event occurred less than 3 months ago
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    _3MonthsAgo = DICOMControlledTerminologyDefinitionsCode("111396")
    """
    An event occurred between 4 months and 1 year ago
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    _4MonthsTo1YearAgo = DICOMControlledTerminologyDefinitionsCode("111397")
    """
    An event occurred longer than 1 year ago
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    _1YearAgo = DICOMControlledTerminologyDefinitionsCode("111398")
    """
    The timing of an event is not recalled
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TimeframeUncertain = DICOMControlledTerminologyDefinitionsCode("111399")
    """
    Report title for the diagnostic report for one or more breast imaging or
    intervention procedures
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BreastImagingReport = DICOMControlledTerminologyDefinitionsCode("111400")
    """
    Concept name for the description of why a procedure has been performed
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ReasonForProcedure = DICOMControlledTerminologyDefinitionsCode("111401")
    """
    A finding during clinical examination (i.e., history and physical examination)
    such as pain, palpable mass or discharge
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ClinicalFinding = DICOMControlledTerminologyDefinitionsCode("111402")
    """
    First screening mammogram taken for patient that is used as a comparison
    baseline for further examinations
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BaselineScreeningMammogram = DICOMControlledTerminologyDefinitionsCode("111403")
    """
    First mammogram taken for a patient without regard to whether it was for
    screening or a diagnostic procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FirstMammogramEver = DICOMControlledTerminologyDefinitionsCode("111404")
    """
    Concept name for the material of which a breast prosthetic device is
    constructed
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ImplantType = DICOMControlledTerminologyDefinitionsCode("111405")
    """
    A numeric count of findings classified as similar in nature
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NumberOfSimilarFindings = DICOMControlledTerminologyDefinitionsCode("111406")
    """
    Concept name for the status of a breast prosthetic device as noted by imaging
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ImplantFinding = DICOMControlledTerminologyDefinitionsCode("111407")
    """
    Mammogram using traditional X-Ray film
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FilmScreenMammography = DICOMControlledTerminologyDefinitionsCode("111408")
    """
    Mammogram using a digital image acquisition system
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DigitalMammography = DICOMControlledTerminologyDefinitionsCode("111409")
    """
    Referred for evaluation by a surgeon
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SurgicalConsult = DICOMControlledTerminologyDefinitionsCode("111410")
    """
    Computer aided detection and/or computer aided diagnosis for mammography
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MammographyCAD = DICOMControlledTerminologyDefinitionsCode("111411")
    """
    Concept name for a text-based section of a report
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NarrativeSummary = DICOMControlledTerminologyDefinitionsCode("111412")
    """
    A title for a report section that summarizes all interpretation results for a
    report with one overriding assessment; e.g. benign or negative
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OverallAssessment = DICOMControlledTerminologyDefinitionsCode("111413")
    """
    Concept name for a collection of supporting evidence for a report
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SupplementaryData = DICOMControlledTerminologyDefinitionsCode("111414")
    """
    Prior study indicates that additional imaging be performed to further evaluate
    a suspicious or questionable anatomic region
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AdditionalEvaluationRequestedFromPriorStudy = (
        DICOMControlledTerminologyDefinitionsCode("111415")
    )
    """
    The prior study recommended a follow-up breast imaging exam in 1 to 11 months
    (generally in 6 months)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Follow_upAtShortIntervalFromPriorStudy = DICOMControlledTerminologyDefinitionsCode(
        "111416"
    )
    """
    Prior breast augmentation (breast enlargement) and is not presenting with any
    symptoms
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    HistoryOfBreastAugmentation_Asymptomatic = (
        DICOMControlledTerminologyDefinitionsCode("111417")
    )
    """
    Review or second opinion made on an image performed outside of the facility
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ReviewOfAnOutsideStudy = DICOMControlledTerminologyDefinitionsCode("111418")
    """
    Additional breast imaging performed at the time of the patient's screening
    mammogram
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AdditionalEvaluationRequestedFromAbnormalScreeningExam = (
        DICOMControlledTerminologyDefinitionsCode("111419")
    )
    """
    Patient has had previous benign breast biopsies
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    HistoryOfBenignBreastBiopsy = DICOMControlledTerminologyDefinitionsCode("111420")
    """
    Patient has had a prior surgery such as a lumpectomy or quadrantectomy to
    remove malignant breast tissue, but breast tissue remains
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PersonalHistoryOfBreastCancerWithBreastConservationTherapy = (
        DICOMControlledTerminologyDefinitionsCode("111421")
    )
    """
    The results of a physical examination performed on the patient, possibly
    including the results of inspection, palpation, auscultation, or percussion
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PhysicalExaminationResults = DICOMControlledTerminologyDefinitionsCode("111423")
    """
    The result of assessing the current imaging exam in comparison to previous
    imaging exams
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ComparisonToPreviousFindings = DICOMControlledTerminologyDefinitionsCode("111424")
    """
    An abnormality observed during ductography where the ductal system within the
    breast fills in an abnormal pattern. Ductography is an imaging exam in which a
    radio opaque contrast media is introduced into the ductal system of the breast
    through the nipple and images of the ductal system are obtained
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IntraluminalFillingDefect = DICOMControlledTerminologyDefinitionsCode("111425")
    """
    During ductography an observation of more than one filling abnormality within
    the breast ductal system
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MultipleFillingDefect = DICOMControlledTerminologyDefinitionsCode("111426")
    """
    An abnormality observed during ductography where the ductal system within the
    breast terminates in an unusual fashion
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AbruptDuctTermination = DICOMControlledTerminologyDefinitionsCode("111427")
    """
    Abnormal flowage of contrast media within the breast noted on ductography
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Extravasation = DICOMControlledTerminologyDefinitionsCode("111428")
    """
    An abnormality observed during ductography where the ductal system within the
    breast appears narrow
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DuctNarrowing = DICOMControlledTerminologyDefinitionsCode("111429")
    """
    During ductography an observation of the contrast media filling a cyst within
    the breast
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CystFill = DICOMControlledTerminologyDefinitionsCode("111430")
    """
    The area and line within the anatomy through which a needle or instrument
    passes during an interventional procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    InstrumentApproach = DICOMControlledTerminologyDefinitionsCode("111431")
    """
    The line within the anatomy from the lower outer to the upper inner aspect;
    e.g. through which a needle or instrument passes in an interventional
    procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    InferolateralToSuperomedial = DICOMControlledTerminologyDefinitionsCode("111432")
    """
    The line within the anatomy from the lower inner to the upper outer aspect;
    e.g. through which a needle or instrument passes in an interventional
    procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    InferomedialToSuperolateral = DICOMControlledTerminologyDefinitionsCode("111433")
    """
    The line within the anatomy from the upper outer to the lower inner aspect;
    e.g. through which a needle or instrument passes in an interventional
    procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SuperolateralToInferomedial = DICOMControlledTerminologyDefinitionsCode("111434")
    """
    The line within the anatomy from the upper inner to the lower outer aspect;
    e.g. through which a needle or instrument passes in an interventional
    procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SuperomedialToInferolateral = DICOMControlledTerminologyDefinitionsCode("111435")
    """
    The number of times a biopsy instrument is passed through an area of interest
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NumberOfPasses = DICOMControlledTerminologyDefinitionsCode("111436")
    """
    The number of biopsy specimens obtained from an interventional procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NumberOfSpecimens = DICOMControlledTerminologyDefinitionsCode("111437")
    """
    An indicator of whether or not a biopsy or localizing needle in an
    interventional procedure is seen to be in the area of interest
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NeedleInTarget = DICOMControlledTerminologyDefinitionsCode("111438")
    """
    The number of localizing needles placed around the area of interest in an
    interventional procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NumberOfNeedlesAroundTarget = DICOMControlledTerminologyDefinitionsCode("111439")
    """
    An indicator of whether or not an incision was made in the anatomy during an
    interventional procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IncisionMade = DICOMControlledTerminologyDefinitionsCode("111440")
    """
    An indicator of whether or not a radio opaque microclip was placed in the
    anatomy during an interventional procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MicroclipPlaced = DICOMControlledTerminologyDefinitionsCode("111441")
    """
    An indicator of the degree of success of an interventional procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ConfirmationOfTarget = DICOMControlledTerminologyDefinitionsCode("111442")
    """
    An indicator that during an interventional procedure the area of interest was
    fully excised and is noted in the resultant biopsy specimen
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TargetCompletelyContainedInTheSpecimen = DICOMControlledTerminologyDefinitionsCode(
        "111443"
    )
    """
    An indicator that during an interventional procedure the area of interest was
    partially excised and is noted in the resultant biopsy specimen
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TargetPartiallyObtainedInTheSpecimen = DICOMControlledTerminologyDefinitionsCode(
        "111444"
    )
    """
    An indicator that following an interventional procedure the area of interest
    is not seen in the resultant biopsy specimen
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TargetNotInTheSpecimen = DICOMControlledTerminologyDefinitionsCode("111445")
    """
    An indicator that following an interventional procedure the targeted
    calcifications are noted in the resultant biopsy specimen
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CalcificationsSeenInTheCore = DICOMControlledTerminologyDefinitionsCode("111446")
    """
    An indicator that during an interventional procedure the area of interest was
    fully excised and is noted in the resultant biopsy specimen
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LesionCompletelyRemoved = DICOMControlledTerminologyDefinitionsCode("111447")
    """
    An indicator that during an interventional procedure the area of interest was
    partially excised and is noted in the resultant biopsy specimen
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LesionPartiallyRemoved = DICOMControlledTerminologyDefinitionsCode("111448")
    """
    An indicator that during an interventional procedure fluid was successfully
    aspirated
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FluidObtained = DICOMControlledTerminologyDefinitionsCode("111449")
    """
    Color that is a light shade of brown
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LightBrownColor = DICOMControlledTerminologyDefinitionsCode("111450")
    """
    Color that is a dark shade of red
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DarkRedColor = DICOMControlledTerminologyDefinitionsCode("111451")
    """
    Color that is a dark shade of brown
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DarkBrownColor = DICOMControlledTerminologyDefinitionsCode("111452")
    """
    Color that is a bright shade of red
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BrightRedColor = DICOMControlledTerminologyDefinitionsCode("111453")
    """
    Color that is tinged with the color of blood
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BloodTingedColor = DICOMControlledTerminologyDefinitionsCode("111454")
    """
    An indicator of whether or not the fluid obtained during an interventional
    procedure contains red blood cells
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OccultBloodTestResult = DICOMControlledTerminologyDefinitionsCode("111455")
    """
    An indicator of whether or not fluid during an interventional procedure was
    sent for cytological analysis or simply discarded
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ActionOnFluid = DICOMControlledTerminologyDefinitionsCode("111456")
    """
    An indicator that fluid obtained during an interventional procedure was sent
    to a laboratory for analysis
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SentForAnalysis = DICOMControlledTerminologyDefinitionsCode("111457")
    """
    An indicator that fluid obtained during an interventional procedure was
    discarded
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Discarded = DICOMControlledTerminologyDefinitionsCode("111458")
    """
    A radiopaque density noted during diagnostic imaging that has associated
    calcific densities
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MassWithCalcifications = DICOMControlledTerminologyDefinitionsCode("111459")
    """
    A fluid-filled sac with greater than normal characteristics
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ComplexCyst = DICOMControlledTerminologyDefinitionsCode("111460")
    """
    A tumor within a cyst
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IntracysticLesion = DICOMControlledTerminologyDefinitionsCode("111461")
    """
    A tumor or lesion
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SolidMass = DICOMControlledTerminologyDefinitionsCode("111462")
    """
    Supporting evidence for interpretation results of an interventional procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SupplementaryDataForIntervention = DICOMControlledTerminologyDefinitionsCode(
        "111463"
    )
    """
    A descriptor that further qualifies or characterizes a type of procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ProcedureModifier = DICOMControlledTerminologyDefinitionsCode("111464")
    """
    Needle size (diameter) characterization; e.g. of a biopsy needle
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NeedleGauge = DICOMControlledTerminologyDefinitionsCode("111465")
    """
    An indicator of the gravity of a problem experienced by a patient, related to
    a procedure that was performed
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SeverityOfComplication = DICOMControlledTerminologyDefinitionsCode("111466")
    """
    Distance from the hub or bushing to the tip of the needle
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NeedleLength = DICOMControlledTerminologyDefinitionsCode("111467")
    """
    The collection of observations and findings from pathologic analysis
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PathologyResults = DICOMControlledTerminologyDefinitionsCode("111468")
    """
    The date and time that the sample was collected from the patient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SamplingDateTime = DICOMControlledTerminologyDefinitionsCode("111469")
    """
    Indicates that the margin of the biopsy specimen was not involved with the
    tumor
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Uninvolved = DICOMControlledTerminologyDefinitionsCode("111470")
    """
    Indicates that the margin of the biopsy specimen was involved with the tumor
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Involved = DICOMControlledTerminologyDefinitionsCode("111471")
    """
    Indicates whether the nipple was involved in an interventional procedure or
    pathologic analysis
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NippleInvolved = DICOMControlledTerminologyDefinitionsCode("111472")
    """
    Indicates the number of lymph nodes removed
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NumberOfNodesRemoved = DICOMControlledTerminologyDefinitionsCode("111473")
    """
    Indicates the number of lymph nodes removed that contain cancer cells
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NumberOfNodesPositive = DICOMControlledTerminologyDefinitionsCode("111474")
    """
    The result of a test for the presence of a protein that binds with estrogen
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EstrogenReceptor = DICOMControlledTerminologyDefinitionsCode("111475")
    """
    The result of a test for the presence of a protein that binds with
    progesterone
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ProgesteroneReceptor = DICOMControlledTerminologyDefinitionsCode("111476")
    """
    Indicates the percentage of cells in S phase. Cell division is defined by
    phases; the S phase is the stage during which DNA replicates
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SPhase = DICOMControlledTerminologyDefinitionsCode("111477")
    """
    The visible emission of non-bloody fluid from the nipple
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Non_bloodyDischarge_fromNipple_ = DICOMControlledTerminologyDefinitionsCode(
        "111478"
    )
    """
    The inability to discern normal versus abnormal breast tissue during palpation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DifficultPhysical_clinicalExamination = DICOMControlledTerminologyDefinitionsCode(
        "111479"
    )
    """
    An indication that a patient has or had a malignant occurrence in an area of
    the body other than the breast
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CancerElsewhere = DICOMControlledTerminologyDefinitionsCode("111480")
    """
    A salt water filled prosthetic device implanted in the breast
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SalineImplant = DICOMControlledTerminologyDefinitionsCode("111481")
    """
    A polymer based (plastic) prosthetic device implanted in the breast
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PolyurethaneImplant = DICOMControlledTerminologyDefinitionsCode("111482")
    """
    The introduction of polymeric organic silicon based material through the skin,
    as for breast augmentation or reconstruction
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PercutaneousSiliconeInjection = DICOMControlledTerminologyDefinitionsCode("111483")
    """
    A prosthetic device that contains more than one material implanted in the
    breast
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CombinationImplant = DICOMControlledTerminologyDefinitionsCode("111484")
    """
    A breast implant placed in front of the pectoralis major muscle
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Pre_pectoralImplant = DICOMControlledTerminologyDefinitionsCode("111485")
    """
    A breast implant placed behind the pectoralis major muscle
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Retro_pectoralImplant = DICOMControlledTerminologyDefinitionsCode("111486")
    """
    Using X-Ray technique and a superimposed set of crossed lines for detection or
    placement
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Mammographic_crosshair_ = DICOMControlledTerminologyDefinitionsCode("111487")
    """
    Using X-Ray technique and a superimposed aperture for detection or placement
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Mammographic_grid_ = DICOMControlledTerminologyDefinitionsCode("111488")
    """
    Using physical touch for detection or placement
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PalpationGuided = DICOMControlledTerminologyDefinitionsCode("111489")
    """
    The performance of a biopsy procedure using a vacuum device attached to the
    biopsy needle
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VacuumAssisted = DICOMControlledTerminologyDefinitionsCode("111490")
    """
    Unusual or unexpected emission of fluid
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AbnormalDischarge = DICOMControlledTerminologyDefinitionsCode("111491")
    """
    Having experienced no adverse medical conditions related to or resulting from
    an interventional procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NoComplications = DICOMControlledTerminologyDefinitionsCode("111492")
    """
    TNM grouping of tumor stage, from AJCC, where primary tumor is Tis, regional
    lymph node is N0, and distant metastasis is M0
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Stage0 = DICOMControlledTerminologyDefinitionsCode("111494")
    """
    TNM grouping of tumor stage, from AJCC, where primary tumor is T1, regional
    lymph node is N0, and distant metastasis is M0
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StageI = DICOMControlledTerminologyDefinitionsCode("111495")
    """
    TNM grouping of tumor stage, from AJCC, where primary tumor is T0 or T1, with
    regional lymph node N1 and distant metastasis is M0, or T2 with N0 and M0
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StageIIA = DICOMControlledTerminologyDefinitionsCode("111496")
    """
    TNM grouping of tumor stage, from AJCC, where primary tumor is T2, with
    regional lymph node N1 and distant metastasis is M0, or T3 with N0 and M0
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StageIIB = DICOMControlledTerminologyDefinitionsCode("111497")
    """
    TNM grouping of tumor stage, from AJCC, where primary tumor is T0, T1 or T2,
    with regional lymph node N2 and distant metastasis is M0, or T3 with N1 or N2
    and M0
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StageIIIA = DICOMControlledTerminologyDefinitionsCode("111498")
    """
    TNM grouping of tumor stage, from AJCC, where primary tumor is T4, regional
    lymph node is N0, N1 or N2, and distant metastasis is M0
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StageIIIB = DICOMControlledTerminologyDefinitionsCode("111499")
    """
    TNM grouping of tumor stage, from AJCC, where primary tumor is any T value,
    regional lymph node is N3, and distant metastasis is M0
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StageIIIC = DICOMControlledTerminologyDefinitionsCode("111500")
    """
    TNM grouping of tumor stage, from AJCC, where primary tumor is any T value,
    regional lymph node is any N value, and distant metastasis is M1
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StageIV = DICOMControlledTerminologyDefinitionsCode("111501")
    """
    Histologic tumor grade (sometimes called Scarff-Bloom-Richardson grade) is
    based on the arrangement of the cells in relation to each other -- whether
    they form tubules, how closely they resemble normal breast cells (nuclear
    grade) and how many of the cancer cells are in the process of dividing
    (mitotic count)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Bloom_RichardsonGrade = DICOMControlledTerminologyDefinitionsCode("111502")
    """
    Breast prosthetic devices are intact, not leaking, and are in a normal shape
    and form
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NormalImplants = DICOMControlledTerminologyDefinitionsCode("111503")
    """
    Breast prosthetic devices are not symmetric, equal, corresponding in form, or
    are in one breast (unilateral)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AsymmetricImplants = DICOMControlledTerminologyDefinitionsCode("111504")
    """
    Fibrous or calcific contracture of the tissue capsule that forms around a
    breast prosthetic device
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CalcifiedImplant = DICOMControlledTerminologyDefinitionsCode("111505")
    """
    Breast prosthetic device is twisted out of normal shape or form
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DistortedImplant = DICOMControlledTerminologyDefinitionsCode("111506")
    """
    Silicone from breast prosthetic device found in lymphatic tissue
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Silicone_ladenLymphNodes = DICOMControlledTerminologyDefinitionsCode("111507")
    """
    Silicone found in breast tissue outside of the prosthetic capsule or implant
    membrane
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FreeSilicone = DICOMControlledTerminologyDefinitionsCode("111508")
    """
    Protrusion of part of the structure normally encapsulating the content of the
    breast prosthetic device
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    HerniatedImplant = DICOMControlledTerminologyDefinitionsCode("111509")
    """
    Evidence of removal of a breast prosthetic device
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Explantation = DICOMControlledTerminologyDefinitionsCode("111510")
    """
    Historical patient health information of interest to the breast health
    clinician
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RelevantPatientInformationForBreastImaging = (
        DICOMControlledTerminologyDefinitionsCode("111511")
    )
    """
    Information regarding usage by the patient of certain medications, such as
    hormones
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MedicationHistory = DICOMControlledTerminologyDefinitionsCode("111512")
    """
    Interventional or non-interventional procedures previously performed on the
    patient, such as breast biopsies
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RelevantPreviousProcedures = DICOMControlledTerminologyDefinitionsCode("111513")
    """
    Abnormal conditions experienced by the patient that serve as the reason for
    performing a procedure, such as a breast exam
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RelevantIndicatedProblems = DICOMControlledTerminologyDefinitionsCode("111514")
    """
    Personal, familial, and other health factors that may indicate an increase in
    the patient's chances of developing a health condition or disease, such as
    breast cancer
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RelevantRiskFactors = DICOMControlledTerminologyDefinitionsCode("111515")
    """
    A classification of a medicinal substance, such as hormonal contraceptive or
    antibiotic
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MedicationType = DICOMControlledTerminologyDefinitionsCode("111516")
    """
    Historical patient health information for general purpose use
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RelevantPatientInformation = DICOMControlledTerminologyDefinitionsCode("111517")
    """
    The age of the patient at the first occurrence of menses
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AgeWhenFirstMenstrualPeriodOccurred = DICOMControlledTerminologyDefinitionsCode(
        "111518"
    )
    """
    The age of the patient at the time of her first full term pregnancy
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AgeAtFirstFullTermPregnancy = DICOMControlledTerminologyDefinitionsCode("111519")
    """
    The age of the patient at the cessation of menses
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AgeAtMenopause = DICOMControlledTerminologyDefinitionsCode("111520")
    """
    The age of the patient at the time her uterus was removed
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AgeWhenHysterectomyPerformed = DICOMControlledTerminologyDefinitionsCode("111521")
    """
    The age of the patient at the time she had her left ovary removed
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AgeWhenLeftOvaryRemoved = DICOMControlledTerminologyDefinitionsCode("111522")
    """
    The age of the patient at the time she had her right ovary removed
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AgeWhenRightOvaryRemoved = DICOMControlledTerminologyDefinitionsCode("111523")
    """
    The age of a patient on the first occurrence of an event, such as the first
    use of a medication
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AgeStarted = DICOMControlledTerminologyDefinitionsCode("111524")
    """
    The age of a patient on the last occurrence of an event, such as the last use
    of a medication
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AgeEnded = DICOMControlledTerminologyDefinitionsCode("111525")
    """
    The date and time of the first occurrence of an event, such as the first use
    of a medication
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DateTimeStarted = DICOMControlledTerminologyDefinitionsCode("111526")
    """
    The date and time of the last occurrence of an event, such as the last use of
    a medication
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DateTimeEnded = DICOMControlledTerminologyDefinitionsCode("111527")
    """
    An indicator of whether an event is still in progress, such as the use of a
    medication or substance, or environmental exposure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Ongoing = DICOMControlledTerminologyDefinitionsCode("111528")
    """
    Product name of a device or substance, such as medication, to identify it as
    the product of a single firm or manufacturer
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BrandName = DICOMControlledTerminologyDefinitionsCode("111529")
    """
    A descriptor that further qualifies or characterizes a risk factor
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RiskFactorModifier = DICOMControlledTerminologyDefinitionsCode("111530")
    """
    A prior non-interventional exam or interventional procedure performed on a
    patient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PreviousProcedure = DICOMControlledTerminologyDefinitionsCode("111531")
    """
    Describes the pregnancy state of a referenced subject
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PregnancyStatus = DICOMControlledTerminologyDefinitionsCode("111532")
    """
    A symptom experienced by a patient that is used as the reason for performing
    an exam or procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IndicatedProblem = DICOMControlledTerminologyDefinitionsCode("111533")
    """
    The function of the individual who is reporting information on a patient,
    which could be a specific health care related profession, the patient
    him/herself, or a relative or friend
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RoleOfPersonReporting = DICOMControlledTerminologyDefinitionsCode("111534")
    """
    The date and time that a symptom was noted
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DateTimeProblemObserved = DICOMControlledTerminologyDefinitionsCode("111535")
    """
    The date and time of the most recent evaluation of an indicated problem
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DateTimeOfLastEvaluation = DICOMControlledTerminologyDefinitionsCode("111536")
    """
    A patient's biological relative who exhibits a health factor that may indicate
    an increase in the patient's chances of developing a particular disease or
    medical problem
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FamilyMemberWithRiskFactor = DICOMControlledTerminologyDefinitionsCode("111537")
    """
    The age at which an individual experienced a specific event, such as breast
    cancer
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AgeAtOccurrence = DICOMControlledTerminologyDefinitionsCode("111538")
    """
    The current stage of an individual in her gynecological development
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MenopausalPhase = DICOMControlledTerminologyDefinitionsCode("111539")
    """
    An indicator of paternal or maternal relationship
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SideOfFamily = DICOMControlledTerminologyDefinitionsCode("111540")
    """
    Relating to biological female parentage
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Maternal = DICOMControlledTerminologyDefinitionsCode("111541")
    """
    A gynecological hormone for which the specific type is not specified; e.g.
    contraceptive, estrogen, Tamoxifen
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    UnspecifiedGynecologicalHormone = DICOMControlledTerminologyDefinitionsCode(
        "111542"
    )
    """
    An indicator of whether or not a patient ever provided breast milk to her
    offspring
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BreastFeedingHistory = DICOMControlledTerminologyDefinitionsCode("111543")
    """
    The average length of time that a patient provided breast milk to her
    offspring
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AverageBreastFeedingPeriod = DICOMControlledTerminologyDefinitionsCode("111544")
    """
    Information regarding usage by the patient of certain legal or illicit
    substances
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SubstanceUseHistory = DICOMControlledTerminologyDefinitionsCode("111545")
    """
    A classification of a substance, such as alcohol or a legal or illicit drug
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    UsedSubstanceType = DICOMControlledTerminologyDefinitionsCode("111546")
    """
    Information regarding exposure of the patient to potentially harmful
    environmental factors
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EnvironmentalExposureHistory = DICOMControlledTerminologyDefinitionsCode("111547")
    """
    A classification of a potentially harmful substance or gas in a subject's
    environment, such as asbestos, lead, or carcinogens
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EnvironmentalFactor = DICOMControlledTerminologyDefinitionsCode("111548")
    """
    Previous Structured Reports that could have relevant information for a current
    imaging service request
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PreviousReports = DICOMControlledTerminologyDefinitionsCode("111549")
    """
    An indication that a patient has had a previous malignancy of the breast
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PersonalBreastCancerHistory = DICOMControlledTerminologyDefinitionsCode("111550")
    """
    Indicates a previous occurrence of cancer of the lining of the uterus
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    HistoryOfEndometrialCancer = DICOMControlledTerminologyDefinitionsCode("111551")
    """
    Indicates a previous occurrence of cancer of the lining of the ovary
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    HistoryOfOvarianCancer = DICOMControlledTerminologyDefinitionsCode("111552")
    """
    Indicates a prior diagnosis of pre-cancerous cells or tissue removed for
    pathologic evaluation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    HistoryOfHighRiskLesionOnPreviousBiopsy = DICOMControlledTerminologyDefinitionsCode(
        "111553"
    )
    """
    A female patient whose menstrual periods have ceased
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PostMenopausalPatient = DICOMControlledTerminologyDefinitionsCode("111554")
    """
    A female patient whose first child was born after the patient was 30 years old
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LateChildBearing_after30_ = DICOMControlledTerminologyDefinitionsCode("111555")
    """
    The first level genetic marker indicating risk for breast cancer
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BRCA1BreastCancerGene = DICOMControlledTerminologyDefinitionsCode("111556")
    """
    The second level genetic marker indicating risk for breast cancer
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BRCA2BreastCancerGene = DICOMControlledTerminologyDefinitionsCode("111557")
    """
    The third level genetic marker indicating risk for breast cancer
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BRCA3BreastCancerGene = DICOMControlledTerminologyDefinitionsCode("111558")
    """
    A patient's biological aunt, grandmother, or female cousin was diagnosed with
    breast cancer. Definition from BI-RADS®
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    WeakFamilyHistoryOfBreastCancer = DICOMControlledTerminologyDefinitionsCode(
        "111559"
    )
    """
    A patient's biological mother or sister was diagnosed with breast cancer after
    they had gone through menopause. Definition from BI-RADS®
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IntermediateFamilyHistoryOfBreastCancer = DICOMControlledTerminologyDefinitionsCode(
        "111560"
    )
    """
    A patient's biological mother or sister was diagnosed with breast cancer
    before they had gone through menopause, or more than one of the patient's
    first-degree relatives (biological mother or sister) were diagnosed with
    breast cancer after they had gone through menopause. Definition from BI-RADS®
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VeryStrongFamilyHistoryOfBreastCancer = DICOMControlledTerminologyDefinitionsCode(
        "111561"
    )
    """
    Previous diagnosis of a malignancy of the prostate gland in a biological
    relative
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FamilyHistoryOfProstateCancer = DICOMControlledTerminologyDefinitionsCode("111562")
    """
    The health record of a patient's biological relatives is not known
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FamilyHistoryUnknown = DICOMControlledTerminologyDefinitionsCode("111563")
    """
    The study of cells obtained from fluid emitted from the breast
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NippleDischargeCytology = DICOMControlledTerminologyDefinitionsCode("111564")
    """
    A developmental abnormality resulting in an abnormal shape of the uterus
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    UterineMalformations = DICOMControlledTerminologyDefinitionsCode("111565")
    """
    A naturally occurring premature expulsion from the uterus of the products of
    conception - the embryo or a nonviable fetus
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SpontaneousAbortion = DICOMControlledTerminologyDefinitionsCode("111566")
    """
    An ailment/abnormality or state of the female reproductive tract
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    GynecologicCondition = DICOMControlledTerminologyDefinitionsCode("111567")
    """
    A surgical operation performed on any portion of the female reproductive tract
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    GynecologicSurgery = DICOMControlledTerminologyDefinitionsCode("111568")
    """
    Prior pregnancy with a low birth weight baby or a fetus with Intrauterine
    Growth Restriction or Retardation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PreviousLBWOrIUGRBirth = DICOMControlledTerminologyDefinitionsCode("111569")
    """
    History of at least one prior pregnancy with fetal anatomic abnormality(s)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PreviousFetalMalformation_syndrome = DICOMControlledTerminologyDefinitionsCode(
        "111570"
    )
    """
    History of delivering a Rhesis Isoimmunization affected child(ren) or a
    child(ren) with another blood disorder
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PreviousRHNegativeOrBloodDyscrasiaAtBirth = (
        DICOMControlledTerminologyDefinitionsCode("111571")
    )
    """
    History of at least one pregnancy that contained more than one fetus; e.g.
    twins, triplets, etc.
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    HistoryOfMultipleFetuses = DICOMControlledTerminologyDefinitionsCode("111572")
    """
    At least one fetus of this pregnancy has an anatomic abnormality(s) that is
    known to exist, or a "marker" is present that suggests the abnormality(s) may
    be present
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CurrentPregnancy_KnownOrSuspectedMalformations_syndromes = (
        DICOMControlledTerminologyDefinitionsCode("111573")
    )
    """
    Biological relatives have previously conceived a fetus with an anatomic
    abnormality(s)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FamilyHistory_FetalMalformation_syndrome = (
        DICOMControlledTerminologyDefinitionsCode("111574")
    )
    """
    A subjective descriptor for an elevated amount of exposure, use, or dosage,
    incurring high risk of adverse effects
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    High = DICOMControlledTerminologyDefinitionsCode("111575")
    """
    A subjective descriptor for a moderate amount of exposure, use, or dosage,
    incurring medium risk of adverse effects
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Medium = DICOMControlledTerminologyDefinitionsCode("111576")
    """
    A subjective descriptor for a limited amount of exposure, use, or dosage,
    incurring low risk of adverse effects
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Low = DICOMControlledTerminologyDefinitionsCode("111577")
    """
    A measurement of the rate of occurrence of which a patient takes a certain
    medication
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DoseFrequency = DICOMControlledTerminologyDefinitionsCode("111578")
    """
    The quantity per unit of time that a patient was or is being exposed to an
    environmental irritant
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RateOfExposure = DICOMControlledTerminologyDefinitionsCode("111579")
    """
    The quantity per unit of time that a medication or substance was or is being
    used
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VolumeOfUse = DICOMControlledTerminologyDefinitionsCode("111580")
    """
    A qualitative descriptor for the amount of a medication that was or is being
    taken
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RelativeDoseAmount = DICOMControlledTerminologyDefinitionsCode("111581")
    """
    A qualitative descriptor for the amount of present or past exposure to an
    environmental irritant
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RelativeAmountOfExposure = DICOMControlledTerminologyDefinitionsCode("111582")
    """
    A qualitative descriptor for the amount of a medication or substance that was
    or is being used
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RelativeAmountOfUse = DICOMControlledTerminologyDefinitionsCode("111583")
    """
    A qualitative descriptor for the frequency with which a medication was or is
    being taken
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RelativeDoseFrequency = DICOMControlledTerminologyDefinitionsCode("111584")
    """
    A qualitative descriptor for the frequency of present or past exposure to an
    environmental irritant
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RelativeFrequencyOfExposure = DICOMControlledTerminologyDefinitionsCode("111585")
    """
    A qualitative descriptor for the frequency with which a medication or
    substance was or is being used
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RelativeFrequencyOfUse = DICOMControlledTerminologyDefinitionsCode("111586")
    """
    Patient is not known to have been exposed to or used the substance or
    medication
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NoKnownExposure = DICOMControlledTerminologyDefinitionsCode("111587")
    """
    Patient returns for additional images to improve the quality of the most
    recent exam
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RecallForTechnicalReasons = DICOMControlledTerminologyDefinitionsCode("111590")
    """
    Patient returns for additional images to clarify findings from the most recent
    exam
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RecallForImagingFindings = DICOMControlledTerminologyDefinitionsCode("111591")
    """
    Patient returns for additional images to clarify symptoms or signs reported by
    the patient or a healthcare professional at the time of the most recent exam
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RecallForPatientSymptoms_ClinicalFindings = (
        DICOMControlledTerminologyDefinitionsCode("111592")
    )
    """
    Number of births with low birth weight or intrauterine growth restriction
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LBWOrIUGR = DICOMControlledTerminologyDefinitionsCode("111593")
    """
    Filter that transmits green light while blocking the other colors, typically
    centered at 510-540 nm
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    GreenFilter = DICOMControlledTerminologyDefinitionsCode("111601")
    """
    Filter that transmits red light while blocking the other colors, typically
    centered at 630-680 nm
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RedFilter = DICOMControlledTerminologyDefinitionsCode("111602")
    """
    Filter that transmits blue while blocking the other colors, typically centered
    at 460-480 nm
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BlueFilter = DICOMControlledTerminologyDefinitionsCode("111603")
    """
    A filter of 560nm that is used for retinal imaging and can provide good
    contrast and good visibility of the retinal vasculature
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Yellow_greenFilter = DICOMControlledTerminologyDefinitionsCode("111604")
    """
    A filter of 490nm that is used for retinal imaging because of excessive
    scattering of some retinal structures at very short wavelengths
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Blue_greenFilter = DICOMControlledTerminologyDefinitionsCode("111605")
    """
    Filter that transmits the infrared spectrum, which is light that lies outside
    of the visible spectrum, with wavelengths longer than those of red light,
    while blocking visible light
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    InfraredFilter = DICOMControlledTerminologyDefinitionsCode("111606")
    """
    A filter that reduces reflections from non-metallic surfaces such as glass or
    water by blocking light waves that are vibrating at selected angles to the
    filter
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PolarizingFilter = DICOMControlledTerminologyDefinitionsCode("111607")
    """
    No filter used
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NoFilter = DICOMControlledTerminologyDefinitionsCode("111609")
    """
    Joslin NM-1 is a 45 degree field focused centrally between the temporal margin
    of optic disc and the center of the macula: Center the camera on the
    papillomacular bundle midway between the temporal margin of the optic disc and
    the center of the macula. The horizontal centerline of the image should pass
    directly through the center of the disc
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Field1ForJoslin3Field = DICOMControlledTerminologyDefinitionsCode("111621")
    """
    Joslin NM-2 is a 45 degree field focused superior temporal to the optic disc:
    Center the camera laterally approximately one-half disc diameter temporal to
    the center of the macula. The lower edge of the field is tangent to a
    horizontal line passing through the upper edge of the optic disc. The image is
    taken temporal to the macula but includes more retinal nasal and superior to
    the macula than standard field 2
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Field2ForJoslin3Field = DICOMControlledTerminologyDefinitionsCode("111622")
    """
    Joslin NM-3 is a 45 degree field focused nasal to the optic disc: This field
    is nasal to the optic disc and may include part of the optic disc. The
    horizontal centerline of the image should pass tangent to the lower edge of
    the optic disc
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Field3ForJoslin3Field = DICOMControlledTerminologyDefinitionsCode("111623")
    """
    A broad or "soft" light supplied from a single source
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DiffuseDirectIllumination = DICOMControlledTerminologyDefinitionsCode("111625")
    """
    A slit reflected light microscope, which has the ability to form an image of
    the back scattered light from the eye in a sagittal plane. Scheimpflug cameras
    are able to achieve a wide depth of focus by employing the "Sheimpflug
    principle" where the lens and image planes are not parallel with each other.
    Rotating Sheimplug cameras are able to generate three-dimensional images and
    calculate measurements of the anterior chamber of the eye
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ScheimpflugCamera = DICOMControlledTerminologyDefinitionsCode("111626")
    """
    Lighting condition approximately 0.04 lux
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ScotopicLight = DICOMControlledTerminologyDefinitionsCode("111627")
    """
    Lighting condition approximately 4 lux
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MesopicLight = DICOMControlledTerminologyDefinitionsCode("111628")
    """
    Lighting condition approximately 40 lux
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PhotopicLight = DICOMControlledTerminologyDefinitionsCode("111629")
    """
    Acquisition preceded by intense light
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DynamicLight = DICOMControlledTerminologyDefinitionsCode("111630")
    """
    Calculated from values of entrance exposure in air, the X-Ray beam quality
    (half-value layer), and compressed breast thickness, is the energy deposited
    per unit mass of glandular tissue averaged over all the glandular tissue in
    the breast
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AverageGlandularDose = DICOMControlledTerminologyDefinitionsCode("111631")
    """
    The primary material in the anode of an X-Ray source
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AnodeTargetMaterial = DICOMControlledTerminologyDefinitionsCode("111632")
    """
    The average thickness of the body part examined when compressed, if
    compression has been applied during X-Ray exposure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CompressionThickness = DICOMControlledTerminologyDefinitionsCode("111633")
    """
    Thickness of Aluminum required to reduce the X-Ray output at the patient
    entrance surface by a factor of two
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    HalfValueLayer = DICOMControlledTerminologyDefinitionsCode("111634")
    """
    An anti-scatter device based on radiation absorbing strips above the detector;
    e.g. in the patient support
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    X_RayGrid = DICOMControlledTerminologyDefinitionsCode("111635")
    """
    Exposure measurement in air at the reference point that does not include back
    scatter, according to MQCM 1999
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EntranceExposureAtRP = DICOMControlledTerminologyDefinitionsCode("111636")
    """
    Average Glandular Dose to a single breast accumulated over multiple images
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AccumulatedAverageGlandularDose = DICOMControlledTerminologyDefinitionsCode(
        "111637"
    )
    """
    Value of the control variable used to parametrize the Automatic Exposure
    Control (AEC) closed loop; e.g. "Water Value"
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientEquivalentThickness = DICOMControlledTerminologyDefinitionsCode("111638")
    """
    An X-Ray Grid that does not move during exposure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FixedGrid = DICOMControlledTerminologyDefinitionsCode("111641")
    """
    An X-Ray Grid with radiation absorbing strips that are focused toward the
    focal spot, to eliminate grid cutoff
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FocusedGrid = DICOMControlledTerminologyDefinitionsCode("111642")
    """
    An X-Ray Grid that is designed to move during exposure, to eliminate the
    appearance of grid lines on the image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ReciprocatingGrid = DICOMControlledTerminologyDefinitionsCode("111643")
    """
    An X-Ray Grid with radiation absorbing strips that are parallel to each other
    and that is used only with long source to image distances
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ParallelGrid = DICOMControlledTerminologyDefinitionsCode("111644")
    """
    An X-Ray Grid with crossed radiation absorbing strips used for more complete
    cleanup of scatter radiation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CrossedGrid = DICOMControlledTerminologyDefinitionsCode("111645")
    """
    No X-Ray Grid was used due to low scatter conditions
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NoGrid = DICOMControlledTerminologyDefinitionsCode("111646")
    """
    The spectacle prescription for a patient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SpectaclePrescriptionReport = DICOMControlledTerminologyDefinitionsCode("111671")
    """
    Refractive measurements of the eye to correct for inability to focus at near
    while wearing the distance prescription
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AddNear = DICOMControlledTerminologyDefinitionsCode("111672")
    """
    Refractive measurements of the eye to correct for inability to focus at
    intermediate distance while wearing the distance prescription
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AddIntermediate = DICOMControlledTerminologyDefinitionsCode("111673")
    """
    Refractive measurements of the eye to correct for inability to focus at the
    specified distance while wearing the distance prescription
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AddOther = DICOMControlledTerminologyDefinitionsCode("111674")
    """
    The power of a prism to bend light in the horizontal direction, in prism
    diopters
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    HorizontalPrismPower = DICOMControlledTerminologyDefinitionsCode("111675")
    """
    Direction of the base of a horizontal prism -- either in (toward the nose), or
    out (away from the nose)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    HorizontalPrismBase = DICOMControlledTerminologyDefinitionsCode("111676")
    """
    The power of a prism to bend light in the vertical direction, in prism
    diopters
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VerticalPrismPower = DICOMControlledTerminologyDefinitionsCode("111677")
    """
    Direction of the base of a vertical prism -- either up, or down
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VerticalPrismBase = DICOMControlledTerminologyDefinitionsCode("111678")
    """
    Distance in mm between the pupils when the patient's object of regard is in
    the distance
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DistancePupillaryDistance = DICOMControlledTerminologyDefinitionsCode("111679")
    """
    Distance in mm between the pupils when the patient's object of regard is at
    near
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NearPupillaryDistance = DICOMControlledTerminologyDefinitionsCode("111680")
    """
    A patient's vision with the correction measured by an autorefractor in place
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AutorefractionVisualAcuity = DICOMControlledTerminologyDefinitionsCode("111685")
    """
    A patient's vision with whichever vision correction the patient customarily
    wears
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    HabitualVisualAcuity = DICOMControlledTerminologyDefinitionsCode("111686")
    """
    A patient's vision with the final spectacle prescription in place
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PrescriptionVisualAcuity = DICOMControlledTerminologyDefinitionsCode("111687")
    """
    The spectacle prescription for the right eye
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RightEyeRx = DICOMControlledTerminologyDefinitionsCode("111688")
    """
    The spectacle prescription for the left eye
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LeftEyeRx = DICOMControlledTerminologyDefinitionsCode("111689")
    """
    A macular grid thickness and volume report for a patient. The macular grid is
    an analytic tool described in PS3.1
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MacularGridThicknessAndVolumeReport = DICOMControlledTerminologyDefinitionsCode(
        "111690"
    )
    """
    Number of images used for the macular grid measurement
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NumberOfImagesUsedForMacularMeasurements = (
        DICOMControlledTerminologyDefinitionsCode("111691")
    )
    """
    Number of samples used per Image for analysis
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NumberOfSamplesUsedPerImage = DICOMControlledTerminologyDefinitionsCode("111692")
    """
    A numeric rating of the quality of the entire analysis with respect to grading
    and diagnostic purposes. Higher numbers indicate greater quality
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AnalysisQualityRating = DICOMControlledTerminologyDefinitionsCode("111693")
    """
    A numeric rating of the quality of an entire image set with respect to grading
    and diagnostic purposes. Higher numbers indicate greater quality
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ImageSetQualityRating = DICOMControlledTerminologyDefinitionsCode("111694")
    """
    Tear film or drops affecting test quality
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    InterferingTearsOrDrops = DICOMControlledTerminologyDefinitionsCode("111695")
    """
    The assessment of the centricity and persistence of the visual fixation
    (direction of gaze) during the acquisition
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VisualFixationQualityDuringAcquisition = DICOMControlledTerminologyDefinitionsCode(
        "111696"
    )
    """
    The reason why the patient's visual fixation was not steady or was
    indeterminate
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VisualFixationQualityProblem = DICOMControlledTerminologyDefinitionsCode("111697")
    """
    The reason why the macular grid measurements may be questionable
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OphthalmicMacularGridProblem = DICOMControlledTerminologyDefinitionsCode("111698")
    """
    Identifier of container (box, block, microscope slide, etc.) for the specimen
    under observation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SpecimenContainerIdentifier = DICOMControlledTerminologyDefinitionsCode("111700")
    """
    Type of processing that tissue specimen underwent
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ProcessingType = DICOMControlledTerminologyDefinitionsCode("111701")
    """
    Date and time of processing step
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DateTimeOfProcessing = DICOMControlledTerminologyDefinitionsCode("111702")
    """
    Description of the individual step in the tissue processing sequence
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ProcessingStepDescription = DICOMControlledTerminologyDefinitionsCode("111703")
    """
    Method of sampling used to derive specimen from its parent
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SamplingMethod = DICOMControlledTerminologyDefinitionsCode("111704")
    """
    Identifier of the parent specimen that gave rise to the current specimen
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ParentSpecimenIdentifier = DICOMControlledTerminologyDefinitionsCode("111705")
    """
    Assigning authority for parent specimen's identifier
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IssuerOfParentSpecimenIdentifier = DICOMControlledTerminologyDefinitionsCode(
        "111706"
    )
    """
    Parent specimen type that gave rise to current specimen
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ParentSpecimenType = DICOMControlledTerminologyDefinitionsCode("111707")
    """
    Description of coordinate system and origin reference point on parent
    specimen, or parent specimen container, or image used for localizing the
    sampling site or location within container or image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PositionFrameOfReference = DICOMControlledTerminologyDefinitionsCode("111708")
    """
    Reference to image of parent specimen localizing the sampling site; may
    include referenced Presentation State object
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LocationOfSamplingSite = DICOMControlledTerminologyDefinitionsCode("111709")
    """
    Location of sampling site of specimen (nominal center) relative to the
    Position Frame of Reference in the X dimension
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LocationOfSamplingSiteXOffset = DICOMControlledTerminologyDefinitionsCode("111710")
    """
    Location of sampling site of specimen (nominal center) relative to the
    Position Frame of Reference in the Y dimension
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LocationOfSamplingSiteYOffset = DICOMControlledTerminologyDefinitionsCode("111711")
    """
    Location of sampling site of specimen (nominal center) relative to the
    Position Frame of Reference in the Z dimension
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LocationOfSamplingSiteZOffset = DICOMControlledTerminologyDefinitionsCode("111712")
    """
    Description of specimen location, either in absolute terms or relative to the
    Position Frame of Reference
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LocationOfSpecimen = DICOMControlledTerminologyDefinitionsCode("111718")
    """
    Location of specimen (nominal center) relative to the Position Frame of
    Reference in the X dimension
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LocationOfSpecimenXOffset = DICOMControlledTerminologyDefinitionsCode("111719")
    """
    Location of specimen (nominal center) relative to the Position Frame of
    Reference in the Y dimension
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LocationOfSpecimenYOffset = DICOMControlledTerminologyDefinitionsCode("111720")
    """
    Location of specimen (nominal center) relative to the Position Frame of
    Reference in the Z dimension
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LocationOfSpecimenZOffset = DICOMControlledTerminologyDefinitionsCode("111721")
    """
    Description of visual distinguishing identifiers; e.g. ink, or a particular
    shape of the specimen
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VisualMarkingOfSpecimen = DICOMControlledTerminologyDefinitionsCode("111723")
    """
    Assigning authority for specimen identifier
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IssuerOfSpecimenIdentifier = DICOMControlledTerminologyDefinitionsCode("111724")
    """
    Dissection of specimen with submission of all its sections for further
    processing or examination
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DissectionWithEntireSpecimenSubmission = DICOMControlledTerminologyDefinitionsCode(
        "111726"
    )
    """
    Dissection of specimen with submission of representative sections for further
    processing or examination
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DissectionWithRepresentativeSectionsSubmission = (
        DICOMControlledTerminologyDefinitionsCode("111727")
    )
    """
    A workflow step, during which tissue specimens are stored in a climate-
    controlled environment
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SpecimenStorage = DICOMControlledTerminologyDefinitionsCode("111729")
    """
    Transmission illumination method for specimen microscopy
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TransmissionIllumination = DICOMControlledTerminologyDefinitionsCode("111741")
    """
    Reflection illumination method for specimen microscopy
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ReflectionIllumination = DICOMControlledTerminologyDefinitionsCode("111742")
    """
    Epifluorescence illumination method for specimen microscopy
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EpifluorescenceIllumination = DICOMControlledTerminologyDefinitionsCode("111743")
    """
    Brightfield illumination method for specimen microscopy
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BrightfieldIllumination = DICOMControlledTerminologyDefinitionsCode("111744")
    """
    Darkfield illumination method for specimen microscopy
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DarkfieldIllumination = DICOMControlledTerminologyDefinitionsCode("111745")
    """
    Oblique illumination method for specimen microscopy
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ObliqueIllumination = DICOMControlledTerminologyDefinitionsCode("111746")
    """
    Phase contrast illumination method for specimen microscopy
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PhaseContrastIllumination = DICOMControlledTerminologyDefinitionsCode("111747")
    """
    Differential interference contrast method for specimen microscopy
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DifferentialInterferenceContrast = DICOMControlledTerminologyDefinitionsCode(
        "111748"
    )
    """
    Total internal reflection fluorescence method for specimen microscopy
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TotalInternalReflectionFluorescence = DICOMControlledTerminologyDefinitionsCode(
        "111749"
    )
    """
    A method of obtaining ophthalmic axial measurements that uses ultrasound, and
    that requires applanation of the cornea
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    UltrasoundContact = DICOMControlledTerminologyDefinitionsCode("111750")
    """
    A method of obtaining ophthalmic axial measurements that uses ultrasound, and
    that requires immersion of the patient's eye in fluid as he lies in a supine
    position
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    UltrasoundImmersion = DICOMControlledTerminologyDefinitionsCode("111751")
    """
    A method of obtaining ophthalmic axial measurements that uses light
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Optical = DICOMControlledTerminologyDefinitionsCode("111752")
    """
    Measurements taken of the corneal curvature using a manual keratometer
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ManualKeratometry = DICOMControlledTerminologyDefinitionsCode("111753")
    """
    Measurements taken of the corneal curvature using an automated keratometer
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AutoKeratometry = DICOMControlledTerminologyDefinitionsCode("111754")
    """
    Simulated Keratometry measurements derived from corneal topography
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SimulatedKeratometry = DICOMControlledTerminologyDefinitionsCode("111755")
    """
    Corneal power measurements using Scheimpflug camera
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EquivalentK_reading = DICOMControlledTerminologyDefinitionsCode("111756")
    """
    The Haigis IOL calculation formula. Haigis W, Lege B, Miller N, Schneider B.
    Comparison of immersion ultrasound biometry and partial coherence
    interferometry for intraocular lens calculation according to Haigis. Graefes
    Arch Clin Exp Ophthalmol 2000;238:765-73
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Haigis = DICOMControlledTerminologyDefinitionsCode("111760")
    """
    The Haigis-L IOL calculation formula. Haigis W. Intraocular lens calculation
    after refractive surgery for myopia: Haigis-L formula. J Cataract Refract
    Surg. 2008 Oct;34(10):1658-63
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Haigis_L = DICOMControlledTerminologyDefinitionsCode("111761")
    """
    The Holladay 1 IOL calculation formula. Holladay JT, Prager TC, Chandler TY,
    Musgrove KH, Lewis JW, Ruiz RS. A three-part system for refining intraocular
    lens power calculations. J Cataract Refract Surg. 1988; 14:17-24
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Holladay1 = DICOMControlledTerminologyDefinitionsCode("111762")
    """
    The Holladay 2 IOL calculation formula
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Holladay2 = DICOMControlledTerminologyDefinitionsCode("111763")
    """
    The Hoffer Q IOL calculation formula. Hoffer KJ. The Hoffer Q formula: a
    comparison of theoretic and regression formulas. J Cataract Refract Surg
    1993;19:700-12. Errata. J Cataract Refract Surg 1994;20:677 and 2007;33:2-3
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    HofferQ = DICOMControlledTerminologyDefinitionsCode("111764")
    """
    The Olsen IOL calculation formula. Olsen T. Calculation of intraocular lens
    power: a review. Acta Ophthalmol. Scand. 2007: 85: 472-485
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Olsen = DICOMControlledTerminologyDefinitionsCode("111765")
    """
    The SRKII IOL calculation formula. Sanders DR, Retzlaff J, Kraff MC.
    Comparison of the SRK II formula and other second generation formulas. J
    Cataract Refract Surg. 1988 Mar;14(2):136-41
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SRKII = DICOMControlledTerminologyDefinitionsCode("111766")
    """
    The SRK-T IOL calculation formula. Retzlaff JA, Sanders DR, Kraff MC.
    Development of the SRK/T intraocular lens implant power calculation formula. J
    Cataract Refract Surg 1990;16:333-40. Erratum 1990;16:528
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SRK_T = DICOMControlledTerminologyDefinitionsCode("111767")
    """
    The "ACD Constant" used in IOL calculation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ACDConstant = DICOMControlledTerminologyDefinitionsCode("111768")
    """
    The "Haigis a0" constant used in IOL calculation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    HaigisA0 = DICOMControlledTerminologyDefinitionsCode("111769")
    """
    The "Haigis a1" constant used in IOL calculation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    HaigisA1 = DICOMControlledTerminologyDefinitionsCode("111770")
    """
    The "Haigis a2" constant used in IOL calculation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    HaigisA2 = DICOMControlledTerminologyDefinitionsCode("111771")
    """
    The "Hoffer pACD Constant" used in IOL calculation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    HofferPACDConstant = DICOMControlledTerminologyDefinitionsCode("111772")
    """
    The "Surgeon Factor" constant used in IOL calculation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SurgeonFactor = DICOMControlledTerminologyDefinitionsCode("111773")
    """
    Anterior chamber depth defined as the front of the cornea to the front of the
    lens
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FrontOfCorneaToFrontOfLens = DICOMControlledTerminologyDefinitionsCode("111776")
    """
    Anterior chamber depth defined as the back of the cornea to the front of the
    lens
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BackOfCorneaToFrontOfLens = DICOMControlledTerminologyDefinitionsCode("111777")
    """
    Refers to the anterior lens when there are two lenses in the eye. The
    distance, in mm, from the anterior surface of the lens to the posterior
    surface of the lens
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SingleOrAnteriorLens = DICOMControlledTerminologyDefinitionsCode("111778")
    """
    Refers to the posterior lens when there are two lenses in the eye. The
    distance, in mm, from the anterior surface of the lens to the posterior
    surface of the lens
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PosteriorLens = DICOMControlledTerminologyDefinitionsCode("111779")
    """
    Value obtained from measurements taken by the device creating this SOP
    Instance
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MeasurementFromThisDevice = DICOMControlledTerminologyDefinitionsCode("111780")
    """
    Value obtained by data transfer from an external source - not from
    measurements taken by the device providing the value
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ExternalDataSource = DICOMControlledTerminologyDefinitionsCode("111781")
    """
    Axial Measurements DICOM SOP Instance
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AxialMeasurementsSOPInstance = DICOMControlledTerminologyDefinitionsCode("111782")
    """
    Refractive Measurements DICOM SOP Instance
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RefractiveMeasurementsSOPInstance = DICOMControlledTerminologyDefinitionsCode(
        "111783"
    )
    """
    Standard Deviation is a simple measure of the variability of a data set
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StandardDeviationOfMeasurementsUsed = DICOMControlledTerminologyDefinitionsCode(
        "111786"
    )
    """
    Signal to Noise Ratio of the data samples taken to create a measurement
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SignalToNoiseRatio = DICOMControlledTerminologyDefinitionsCode("111787")
    """
    Projection from 2D image pixels to 3D Cartesian coordinates based on a
    spherical mathematical model
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SphericalProjection = DICOMControlledTerminologyDefinitionsCode("111791")
    """
    Mapping from 2D image pixels to 3D Cartesian coordinates based on measurements
    of the retinal surface; e.g. of the retina, derived via a measurement
    technology such as Optical Coherence Tomography, Ultrasound etc.
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SurfaceContourMapping = DICOMControlledTerminologyDefinitionsCode("111792")
    """
    Test pattern, nominally covering an area within 24° of fixation. Consists of
    54 test points a minimum of 3° from each meridian and placed 6° apart. The
    "-2" distinguishes this from another 24° pattern (no longer supported)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VisualField24_2TestPattern = DICOMControlledTerminologyDefinitionsCode("111800")
    """
    Test pattern, nominally covering an area within 10° of fixation. Consists of
    68 test points a minimum of 1° from each meridian and placed 2° apart. The
    "-2" in this case indicates its point layout to be similar to the 30-2 and
    24-2
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VisualField10_2TestPattern = DICOMControlledTerminologyDefinitionsCode("111801")
    """
    Test pattern consisting of test point locations within 30° of fixation.
    Consists of 76 test points a minimum of 3° from each meridian and placed 6°
    apart. The "-2" distinguishes this from another 30° pattern (no longer
    supported)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VisualField30_2TestPattern = DICOMControlledTerminologyDefinitionsCode("111802")
    """
    Test pattern consisting of 60 test point locations between 30° and 60° of
    fixation a minimum of 6° from each meridian and placed 12° apart. The "-4"
    distinguishes this from a similar 60° pattern having 4 additional points
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VisualField60_4TestPattern = DICOMControlledTerminologyDefinitionsCode("111803")
    """
    Test pattern consisting of 16 test point locations within 10° of fixation a
    minimum of 1° from each meridian and placed 2° apart
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VisualFieldMaculaTestPattern = DICOMControlledTerminologyDefinitionsCode("111804")
    """
    Test pattern consisting of 40 test point locations within 30° of fixation that
    spread out radially from fixation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VisualFieldCentral40PointTestPattern = DICOMControlledTerminologyDefinitionsCode(
        "111805"
    )
    """
    Test pattern consisting of 76 test point locations within 30° of fixation a
    minimum of 3° from each meridian and placed 6° apart
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VisualFieldCentral76PointTestPattern = DICOMControlledTerminologyDefinitionsCode(
        "111806"
    )
    """
    Test pattern consisting of 60 test point locations between 30° and 60° of
    fixation a minimum of 6° from each meridian and placed 12° apart
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VisualFieldPeripheral60PointTestPattern = DICOMControlledTerminologyDefinitionsCode(
        "111807"
    )
    """
    Test pattern consisting of 81 test point locations within 60° of fixation that
    spread out radially from fixation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VisualFieldFullField81PointTestPattern = DICOMControlledTerminologyDefinitionsCode(
        "111808"
    )
    """
    Test pattern consisting of 120 test point locations within 60° of fixation
    that spread out radially from fixation, concentrated in the nasal hemisphere
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VisualFieldFullField120PointTestPattern = DICOMControlledTerminologyDefinitionsCode(
        "111809"
    )
    """
    Test pattern for Glaucoma and general visual field assessment with 59 test
    locations of which 16 test locations are in the macular area (up to 10°
    eccentricity) and where the density of test location is reduced with
    eccentricity. The test can be extended with the inclusion of 14 test locations
    between 30° and 60° eccentricity, 6 of which are located at the nasal step
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VisualFieldGTestPattern = DICOMControlledTerminologyDefinitionsCode("111810")
    """
    Test pattern for the macular area. Orthogonal test pattern with 0.7° spacing
    within the central 4° of eccentricity and reduced density of test locations
    between 4 and 10, 5° of eccentricity. 81 test locations over all. The test can
    be extended to include the test locations of the Visual Field G Test Pattern
    between 10, 5° and 60°
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VisualFieldMTestPattern = DICOMControlledTerminologyDefinitionsCode("111811")
    """
    Full field test pattern with 48 test locations from 0-30° and 82 test
    locations from 30-70°. Reduced test point density with increased eccentricity.
    Can be combined with screening and threshold strategies
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VisualField07TestPattern = DICOMControlledTerminologyDefinitionsCode("111812")
    """
    Low Vision Central. Orthogonal off-center test pattern with 6° spacing. 75
    test locations within the central 30°. Corresponds with the 32/30-2 excluding
    the 2 locations at the blind spot, including a macular test location. The LVC
    is linked with a staircase threshold strategy starting at 0 dB intensity and
    applies stimulus area V
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VisualFieldLVCTestPattern = DICOMControlledTerminologyDefinitionsCode("111813")
    """
    General test corresponding to the 30-2 but excluding the 2 test locations in
    the blind spot area, hence with 74 instead of 76 test locations
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VisualFieldCentralTestPattern = DICOMControlledTerminologyDefinitionsCode("111814")
    """
    Swedish Interactive Thresholding Algorithm (SITA). Strategy gains testing
    efficiency through use of visual field and information theory models. In:
    Bengtsson B, Olsson J, Heijl A, Rootzen H. A new generation of algorithms for
    computerized threshold perimetry, SITA. Acta Ophthalmologica Scandinavica,
    1997, 75: 368-375
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VisualFieldSITA_StandardTestStrategy = DICOMControlledTerminologyDefinitionsCode(
        "111815"
    )
    """
    Adaptation of SITA testing methods to Blue-Yellow testing
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VisualFieldSITA_SWAPTestStrategy = DICOMControlledTerminologyDefinitionsCode(
        "111816"
    )
    """
    Similar to SITA-Standard but with less strict criteria for closing test
    points. Intended for patients who must be tested in the shortest possible
    time. In: Bengtsson B, Hejl A. SITA Fast, a new rapid perimetric threshold
    test. Description of methods and evaluation in patients with manifest and
    suspect glaucoma. Acta Ophthalmologica Scandinavica, 1998, 76: 431-437
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VisualFieldSITA_FastTestStrategy = DICOMControlledTerminologyDefinitionsCode(
        "111817"
    )
    """
    Threshold test algorithm that determines a patient's sensitivity at each test
    point in the threshold test pattern by adjusting intensity by 4 dB steps until
    the patient changes their response, and then adjusts the intensity in the
    opposite direction by 2 dB steps until the patient changes their response
    again. The last stimulus seen by the patient is recognized as the threshold
    for that point. The starting values are determined by first thresholding a
    "primary" point in each quadrant then using the results of each primary point
    to determine the starting values for neighboring points
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VisualFieldFullThresholdTestStrategy = DICOMControlledTerminologyDefinitionsCode(
        "111818"
    )
    """
    Similar to the Full Threshold algorithm except that it steps by 3 dB and only
    crosses the threshold only once. In: Flanagan JG, Wild JM, Trope GE.
    Evaluation of FASTPAC, a new strategy for threshold estimation with the
    Humphrey Field Analyzer, in a glaucomatous population. Ophthalmology, 1993,
    100: 949-954
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VisualFieldFastPacTestStrategy = DICOMControlledTerminologyDefinitionsCode("111819")
    """
    Identical to Full Threshold except that starting values are determined by the
    results of a previous test performed using the same test pattern and the Full
    Threshold test strategy
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VisualFieldFullFromPriorTestStrategy = DICOMControlledTerminologyDefinitionsCode(
        "111820"
    )
    """
    Similar to FastPac except that the steps are pseudo-dynamic (differ based on
    the intensity of the last presentation)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VisualFieldOptimaTestStrategy = DICOMControlledTerminologyDefinitionsCode("111821")
    """
    Suprathreshold testing strategy, in which each point is initially tested using
    stimulus that is 6 dB brighter than the expected hill of vision. If the
    patient does not respond, the stimulus is presented a second time at the same
    brightness. If the patient sees either presentation, the point is marked as
    "seen"; otherwise it is marked as "not seen"
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VisualFieldTwo_ZoneTestStrategy = DICOMControlledTerminologyDefinitionsCode(
        "111822"
    )
    """
    An extension of the two-zone strategy in which test points where the second
    stimulus is not seen are presented with a third stimulus at maximum brightness
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VisualFieldThree_ZoneTestStrategy = DICOMControlledTerminologyDefinitionsCode(
        "111823"
    )
    """
    An extension of the two-zone strategy, in which test points where the second
    stimulus is not seen receive threshold testing to quantify the depth of any
    detected scotomas
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VisualFieldQuantify_DefectsTestStrategy = DICOMControlledTerminologyDefinitionsCode(
        "111824"
    )
    """
    Tendency Oriented Perimetry. Fast thresholding algorithm. Test strategy makes
    use of the interaction between neighboring test locations to reduce the test
    time compared to normal full threshold strategy by 60-80%. In: Morales J,
    Weitzman ML, Gonzalez de la Rosa M. Comparison between Tendency-Oriented
    Perimetry (TOP) and octopus threshold perimetry. Ophthalmology, 2000, 107:
    134-142
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VisualFieldTOPTestStrategy = DICOMControlledTerminologyDefinitionsCode("111825")
    """
    Dynamic strategy is a fast thresholding strategy reducing test duration by
    adapting the dB step sizes according to the frequency-of-seeing curve of the
    threshold. Reduction of test time compared to normal full threshold strategy
    30-50%
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VisualFieldDynamicTestStrategy = DICOMControlledTerminologyDefinitionsCode("111826")
    """
    Traditional full threshold staircase strategy. Initial intensities are
    presented, based on anchor point sensitivities in each quadrant and based on
    already known neighboring sensitivities. In a first run, thresholds are
    changed in 4dB steps until the first response reversal. Then the threshold is
    changed in 2 dB steps until the second response reversal. The threshold is
    calculated as the average between the last seen and last not-seen stimulus,
    supposed to correspond with the 50% point in the frequency-of-seeing curve
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VisualFieldNormalTestStrategy = DICOMControlledTerminologyDefinitionsCode("111827")
    """
    One level screening test: Each test location is tested with a single
    intensity. The result is shown as seen or not-seen. The intensity can either
    be a 0 dB stimulus or a predefined intensity
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VisualField1_LTTestStrategy = DICOMControlledTerminologyDefinitionsCode("111828")
    """
    Two level screening test: Each test location is initially tested 6 dB brighter
    than the age corrected normal value
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VisualField2_LTTestStrategy = DICOMControlledTerminologyDefinitionsCode("111829")
    """
    Low Vision Strategy is a full threshold normal strategy with the exception
    that it starts at 0 dB intensity and applies stimulus area V
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VisualFieldLVSTestStrategy = DICOMControlledTerminologyDefinitionsCode("111830")
    """
    German Adaptive Threshold Estimation is a fast strategy based on a modified
    4-2 staircase algorithm, using prior visual fields to calculate the starting
    intensity. In: Chiefer U, Pascual JP, Edmunds B, Feudner E, Hoffmann EM,
    Johnson CA, Lagreze WA, Pfeiffer N, Sample PA, Staubach F, Weleber RG,
    Vonthein R, Krapp E, Paetzold J. Comparison of the new perimetric GATE
    strategy with conventional full-threshold and SITA standard strategies.
    Investigative Ophthalmology and Visual Science, 2009, 51: 488-494
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VisualFieldGATETestStrategy = DICOMControlledTerminologyDefinitionsCode("111831")
    """
    Similar to GATE. The i stands for initial. If there was no prior visual field
    test to calculate the starting values, an anchor point method is used to
    define the local start values
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VisualFieldGATEiTestStrategy = DICOMControlledTerminologyDefinitionsCode("111832")
    """
    A test started as two level screening test. In the course of the test, the
    threshold of relative defects and/or normal test locations has been quantified
    using the dynamic threshold strategy
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VisualField2LT_DynamicTestStrategy = DICOMControlledTerminologyDefinitionsCode(
        "111833"
    )
    """
    A test started as two level screening test. In the course of the test, the
    threshold of relative defects and/or normal test locations has been quantified
    using the normal full threshold strategy
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VisualField2LT_NormalTestStrategy = DICOMControlledTerminologyDefinitionsCode(
        "111834"
    )
    """
    Takes neighborhood test point results into account and offers stimuli with an
    adapted value to save time
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VisualFieldFastThresholdTestStrategy = DICOMControlledTerminologyDefinitionsCode(
        "111835"
    )
    """
    Continuous Luminance Incremental Perimetry, which measures at first the
    individual reaction time of the patient and threshold values in every
    quadrant. The starting value for the main test is slightly below in individual
    threshold
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VisualFieldCLIPTestStrategy = DICOMControlledTerminologyDefinitionsCode("111836")
    """
    A supra threshold screening strategy. The starting stimuli intensities depend
    on the classification of the patient's visual hill by measuring the central
    (fovea) or peripheral (15° meridian) threshold. The result of each dot
    slightly underestimates the sensitivity value (within 5 dB)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VisualFieldCLASSStrategy = DICOMControlledTerminologyDefinitionsCode("111837")
    """
    Mode for determining the starting luminance for screening test points - the
    starting luminance s is chosen based on the age of the patient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AgeCorrected = DICOMControlledTerminologyDefinitionsCode("111838")
    """
    Mode for determining the starting luminance for screening test points - the
    starting luminance is chosen based on the results of thresholding a set of
    "primary" test points (one in each quadrant)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ThresholdRelated = DICOMControlledTerminologyDefinitionsCode("111839")
    """
    Mode for determining the starting luminance for screening test points - in
    this case, all starting luminance is set to the same value
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SingleLuminance = DICOMControlledTerminologyDefinitionsCode("111840")
    """
    Mode for determining the starting luminance for screening test points - the
    starting luminance is chosen based on the result of the foveal threshold value
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FovealSensitivityRelated = DICOMControlledTerminologyDefinitionsCode("111841")
    """
    Mode for determining the starting luminance for screening test points - the
    starting luminance is chosen based on the result of four threshold values
    measured near the 15° meridian (one in each quadrant)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RelatedToNonMacularSensitivity = DICOMControlledTerminologyDefinitionsCode("111842")
    """
    Real time evaluation of the camera image to recognize blinks and fixation
    losses with influence on the test procedure. Blinks that interfere with
    stimuli presentation cause the automated repetition of such stimulus
    presentations. Fixation losses can be used to delay the stimulus presentation
    until correct fixation is regained
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AutomatedOptical = DICOMControlledTerminologyDefinitionsCode("111843")
    """
    A method of monitoring the patient's fixation by periodically presenting
    stimulus in a location on the background surface that corresponds to the
    patient's blind spot
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BlindSpotMonitoring = DICOMControlledTerminologyDefinitionsCode("111844")
    """
    A method of monitoring the patient's fixation by presenting the stimulus to
    the patient's macula
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MacularFixationTesting = DICOMControlledTerminologyDefinitionsCode("111845")
    """
    A method of monitoring the patient's fixation by observation from the examiner
    of the patient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ObservationByExaminer = DICOMControlledTerminologyDefinitionsCode("111846")
    """
    Analysis Results are outside normal limits
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OutsideNormalLimits = DICOMControlledTerminologyDefinitionsCode("111847")
    """
    Analysis Results are borderline
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Borderline = DICOMControlledTerminologyDefinitionsCode("111848")
    """
    Analysis Results identify abnormally high sensitivity
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AbnormallyHighSensitivity = DICOMControlledTerminologyDefinitionsCode("111849")
    """
    Analysis Results identify general reduction in sensitivity
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    GeneralReductionInSensitivity = DICOMControlledTerminologyDefinitionsCode("111850")
    """
    Analysis Results identify Borderline and general reduction in sensitivity
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BorderlineAndGeneralReductionInSensitivity = (
        DICOMControlledTerminologyDefinitionsCode("111851")
    )
    """
    Index of a patient's remaining visual field normalized for both age and
    generalized defect
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VisualFieldIndex = DICOMControlledTerminologyDefinitionsCode("111852")
    """
    Estimate of the portion of a patient's visual field loss that is diffuse
    (i.e., spread evenly across all portions of the visual field)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VisualFieldLossDueToDiffuseDefect = DICOMControlledTerminologyDefinitionsCode(
        "111853"
    )
    """
    Estimate of the portion of a patient's visual field loss that is local (i.e.,
    not spread evenly across all portions of the visual field)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VisualFieldLossDueToLocalDefect = DICOMControlledTerminologyDefinitionsCode(
        "111854"
    )
    """
    An analysis of asymmetry between zones of the superior and inferior visual
    field. It is designed to be specific for defects due to glaucoma
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    GlaucomaHemifieldTestAnalysis = DICOMControlledTerminologyDefinitionsCode("111855")
    """
    The data output of an optical fixation monitoring process, consisting of a
    list of positive and negative numbers indicating the quality of patient
    fixation over the course of a visual field test. The value 0 represents the
    initial fixation. Negative numbers indicate a measuring error (i.e., the
    patient blinked). Positive numbers quantify the degree of eccentricity from
    initial fixation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OpticalFixationMeasurements = DICOMControlledTerminologyDefinitionsCode("111856")
    """
    An image of at least 15° angular subtend that is centered on the macula; see
    Section U.1.8 "Relative Image Position Definitions" in PS3.17
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MaculaCentered = DICOMControlledTerminologyDefinitionsCode("111900")
    """
    An image of at least 15° angular subtend that is centered on the optic disc;
    see Section U.1.8 "Relative Image Position Definitions" in PS3.17
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DiscCentered = DICOMControlledTerminologyDefinitionsCode("111901")
    """
    An image of any angular subtend that is centered on a lesion located in any
    region of the fundus; see Section U.1.8 "Relative Image Position Definitions"
    in PS3.17
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LesionCentered = DICOMControlledTerminologyDefinitionsCode("111902")
    """
    An image of at least 15° angular subtend centered midway between the disc and
    macula and containing at least a portion of the disc and both the disc and the
    macula; see Section U.1.8 "Relative Image Position Definitions" in PS3.17
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Disc_maculaCentered = DICOMControlledTerminologyDefinitionsCode("111903")
    """
    An image of at least 15° angular subtend positioned between the central zone
    and the equator, and spanning both the superior-temporal and superior-nasal
    quadrants of the fundus; see Section U.1.8 "Relative Image Position
    Definitions" in PS3.17
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Mid_peripheral_superior = DICOMControlledTerminologyDefinitionsCode("111904")
    """
    An image of at least 15° angular subtend positioned between the central zone
    and the equator in the superior-temporal quadrant of the fundus; see Section
    U.1.8 "Relative Image Position Definitions" in PS3.17
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Mid_peripheral_superiorTemporal = DICOMControlledTerminologyDefinitionsCode(
        "111905"
    )
    """
    An image of at least 15° angular subtend positioned between the central zone
    and the equator, and spanning both the superior-temporal and inferior-temporal
    quadrants of the fundus; see Section U.1.8 "Relative Image Position
    Definitions" in PS3.17
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Mid_peripheral_temporal = DICOMControlledTerminologyDefinitionsCode("111906")
    """
    An image of at least 15° angular subtend positioned between the central zone
    and the equator in the inferior-temporal quadrant of the fundus; see Section
    U.1.8 "Relative Image Position Definitions" in PS3.17
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Mid_peripheral_inferiorTemporal = DICOMControlledTerminologyDefinitionsCode(
        "111907"
    )
    """
    An image of at least 15° angular subtend positioned between the central zone
    and the equator, and spanning both the inferior-temporal and inferior-nasal
    quadrants of the fundus; see Section U.1.8 "Relative Image Position
    Definitions" in PS3.17
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Mid_peripheral_inferior = DICOMControlledTerminologyDefinitionsCode("111908")
    """
    An image of at least 15° angular subtend positioned between the central zone
    and the equator in the inferior-nasal quadrant of the fundus; see Section
    U.1.8 "Relative Image Position Definitions" in PS3.17
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Mid_peripheral_inferiorNasal = DICOMControlledTerminologyDefinitionsCode("111909")
    """
    An image of at least 15° angular subtend positioned between the central zone
    and the equator, and spanning both the superior-nasal and inferior-nasal
    quadrants of the fundus; see Section U.1.8 "Relative Image Position
    Definitions" in PS3.17
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Mid_peripheral_nasal = DICOMControlledTerminologyDefinitionsCode("111910")
    """
    An image of at least 15° angular subtend positioned between the central zone
    and the equator in the superior-nasal quadrant of the fundus; see Section
    U.1.8 "Relative Image Position Definitions" in PS3.17
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Mid_peripheral_superiorNasal = DICOMControlledTerminologyDefinitionsCode("111911")
    """
    An image of at least 15° angular subtend positioned between the equator and
    the ora serrata, and spanning both the superior temporal and superior nasal
    quadrants of the fundus; see Section U.1.8 "Relative Image Position
    Definitions" in PS3.17
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Peripheral_superior = DICOMControlledTerminologyDefinitionsCode("111912")
    """
    An image of at least 15° angular subtend positioned between the equator and
    ora serrata in the superior-temporal quadrant of the fundus; see Section U.1.8
    "Relative Image Position Definitions" in PS3.17
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Peripheral_superiorTemporal = DICOMControlledTerminologyDefinitionsCode("111913")
    """
    An image of at least 15° angular subtend positioned between the equator and
    ora serrata, and spanning both the superior-temporal and inferior-temporal
    quadrants of the fundus; see Section U.1.8 "Relative Image Position
    Definitions" in PS3.17
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Peripheral_temporal = DICOMControlledTerminologyDefinitionsCode("111914")
    """
    An image of at least 15° angular subtend positioned between the equator and
    ora serrata in the inferior-temporal quadrant of the fundus; see Section U.1.8
    "Relative Image Position Definitions" in PS3.17
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Peripheral_inferiorTemporal = DICOMControlledTerminologyDefinitionsCode("111915")
    """
    An image of at least 15° angular subtend positioned between the equator and
    ora serrata, and spanning both the inferior-temporal and inferior-nasal
    quadrants of the fundus; see Section U.1.8 "Relative Image Position
    Definitions" in PS3.17
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Peripheral_inferior = DICOMControlledTerminologyDefinitionsCode("111916")
    """
    An image of at least 15° angular subtend positioned between the equator and
    ora serrata in the inferior-nasal quadrant of the fundus; see Section U.1.8
    "Relative Image Position Definitions" in PS3.17
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Peripheral_inferiorNasal = DICOMControlledTerminologyDefinitionsCode("111917")
    """
    An image of at least 15° angular subtend positioned between the equator and
    ora serrata, and spanning both the superior-nasal and inferior-nasal quadrants
    of the fundus; see Section U.1.8 "Relative Image Position Definitions" in
    PS3.17
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Peripheral_nasal = DICOMControlledTerminologyDefinitionsCode("111918")
    """
    An image of at least 15° angular subtend positioned between the equator and
    ora serrata in the superior-nasal quadrant of the fundus; see Section U.1.8
    "Relative Image Position Definitions" in PS3.17
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Peripheral_superiorNasal = DICOMControlledTerminologyDefinitionsCode("111919")
    """
    Identifies the use of physical signals with respect to time to capture
    information
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TimeDomain = DICOMControlledTerminologyDefinitionsCode("111920")
    """
    Identifies the use of physical signals with respect to multiple frequencies to
    capture information
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SpectralDomain = DICOMControlledTerminologyDefinitionsCode("111921")
    """
    No compensation algorithm for corneal birefringence
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NoCornealCompensation = DICOMControlledTerminologyDefinitionsCode("111922")
    """
    Algorithm to compensate for variability in corneal birefringence
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CornealBirefringenceCompensation = DICOMControlledTerminologyDefinitionsCode(
        "111923"
    )
    """
    Measurement of the retinal surface contour relative to an assigned datum plane
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RetinalTopography = DICOMControlledTerminologyDefinitionsCode("111924")
    """
    Measurement approximating the distance related to the structure between the
    internal limiting membrane (ILM) and the outer boarder of the retinal nerve
    fiber layer (RNFL); see Section III.6 "Retinal Thickness Definition" in PS3.17
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RetinalNerveFiberLayerThickness = DICOMControlledTerminologyDefinitionsCode(
        "111925"
    )
    """
    Measurement approximating the distance related to the structure between the
    ILM and the outer border of the inner plexiform layer (IPL), called the
    ganglion cell complex (GCC); see Section III.6 "Retinal Thickness Definition"
    in PS3.17
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    GanglionCellComplexThickness = DICOMControlledTerminologyDefinitionsCode("111926")
    """
    Measurement approximating the distance related to the structure between the
    ILM and the inner-outer segment junction (IS-OS); see Section III.6 "Retinal
    Thickness Definition" in PS3.17
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TotalRetinalThickness_ILMToIS_OS_ = DICOMControlledTerminologyDefinitionsCode(
        "111927"
    )
    """
    Measurement approximating the distance related to the structure between the
    ILM and the retinal pigment epithelium (RPE); see Section III.6 "Retinal
    Thickness Definition" in PS3.17
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TotalRetinalThickness_ILMToRPE_ = DICOMControlledTerminologyDefinitionsCode(
        "111928"
    )
    """
    Measurement approximating the distance related to the structure between the
    ILM and the Bruch's membrane (BM); see Section III.6 "Retinal Thickness
    Definition" in PS3.17
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TotalRetinalThickness_ILMToBM_ = DICOMControlledTerminologyDefinitionsCode("111929")
    """
    Thickness of a component of the posterior segment of the eye; e.g. thickness
    of retina, choroid, etc.
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AbsoluteOphthalmicThickness = DICOMControlledTerminologyDefinitionsCode("111930")
    """
    Ophthalmic Thickness map based upon statistical significance category (such as
    percentile) from a normative data set
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ThicknessDeviationCategoryFromNormativeData = (
        DICOMControlledTerminologyDefinitionsCode("111931")
    )
    """
    Ophthalmic Thickness map based upon deviation (such as microns) from a
    normative data set
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ThicknessDeviationFromNormativeData = DICOMControlledTerminologyDefinitionsCode(
        "111932"
    )
    """
    Ophthalmic Thickness Map related to another Ophthalmic Thickness Map or
    another SOP Instance
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RelatedOphthalmicThicknessMap = DICOMControlledTerminologyDefinitionsCode("111933")
    """
    An anatomic point centered midway between the disc and fovea centralis
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Disc_Fovea = DICOMControlledTerminologyDefinitionsCode("111934")
    """
    Assuming the null hypothesis is true, the conditional percent probability of
    observing this result is not statistically significant
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    P_5_ = DICOMControlledTerminologyDefinitionsCode("111935")
    """
    Assuming the null hypothesis is true, the conditional percent probability of
    observing this result is statistically significant, 95% unlikely to happen by
    chance
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    P_5_ = DICOMControlledTerminologyDefinitionsCode("111936")
    """
    Assuming the null hypothesis is true, the conditional percent probability of
    observing this result is statistically significant, 98% unlikely to happen by
    chance
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    P_2_ = DICOMControlledTerminologyDefinitionsCode("111937")
    """
    Assuming the null hypothesis is true, the conditional percent probability of
    observing this result is statistically significant, 99% unlikely to happen by
    chance
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    P_1_ = DICOMControlledTerminologyDefinitionsCode("111938")
    """
    Assuming the null hypothesis is true, the conditional percent probability of
    observing this result is statistically significant, 99.5% unlikely to happen
    by chance
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    P_0_5_ = DICOMControlledTerminologyDefinitionsCode("111939")
    """
    A two dimensional representation of the axial curvature of the cornea. Axial
    curvature is calculated from the reciprocal of the distance from a point on a
    meridian normal at the point to the corneal topographer axis. Also known as
    sagittal curvature
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CornealAxialPowerMap = DICOMControlledTerminologyDefinitionsCode("111940")
    """
    A two dimensional representation of the instantaneous curvature of the cornea.
    Instantaneous curvature is calculated from the reciprocal of the distance from
    a point on a meridian normal at the point to the center of curvature of that
    point. Also called tangential curvature
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CornealInstantaneousPowerMap = DICOMControlledTerminologyDefinitionsCode("111941")
    """
    A two dimensional representation of the refractive power of the cornea.
    Corneal refractive power is calculated using Snell's Law
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CornealRefractivePowerMap = DICOMControlledTerminologyDefinitionsCode("111942")
    """
    A two dimensional representation of the elevation of the cornea. Elevation is
    calculated as the distance from a point on the corneal surface to a point on a
    reference surface along a line parallel to the corneal topographer axis. For
    the purpose of visualization the reference surface is usually a sphere or an
    ellipse
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CornealElevationMap = DICOMControlledTerminologyDefinitionsCode("111943")
    """
    A two dimensional representation of a wavefront aberration surface of the
    cornea. Wavefront aberration surface is calculated from the corneal elevation
    data fit with either the Zernike polynomial series or the Fourier Series. Maps
    generally display total aberrations and selectable higher order aberrations
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CornealWavefrontMap = DICOMControlledTerminologyDefinitionsCode("111944")
    """
    A device that measures corneal anterior surface shape using elevation-based
    methods (stereographic and light slit-based). Rasterstereography images a grid
    pattern illuminating the fluorescein dyed tear film with 2 cameras to produce
    3D. Slit-based devices scan the cornea, usually by rotation about the
    instrument axis centered on the cornea vertex
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Elevation_basedCornealTomographer = DICOMControlledTerminologyDefinitionsCode(
        "111945"
    )
    """
    A reflection-based device that projects a pattern of light onto the cornea and
    an image of the reflection of that pattern from the tear film is recorded in
    one video frame. Light patterns include the circular mire pattern (Placido
    disc) and spot matrix patterns. Sequential scanning of light spots reflected
    from the corneal surface is also used requiring multiple video frames for
    recording
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Reflection_basedCornealTopographer = DICOMControlledTerminologyDefinitionsCode(
        "111946"
    )
    """
    An Interference-based device that projects a beam of light onto and through
    the cornea. Light reflected from within the cornea is combined with a
    reference beam giving rise to an interference pattern. Appropriately scanned,
    this imaging is used to construct 3-dimensional images of the cornea from
    anterior to posterior surfaces; e.g. swept source OCT
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Interferometry_basedCornealTomographer = DICOMControlledTerminologyDefinitionsCode(
        "111947"
    )
    """
    A structured report containing the results of computer-aided detection or
    diagnosis applied to chest imaging and associated clinical information
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ChestCADReport = DICOMControlledTerminologyDefinitionsCode("112000")
    """
    The shadow of an absorber that attenuates the X-Ray beam more effectively than
    do surrounding absorbers. In a radiograph, any circumscribed area that appears
    more nearly white (of lesser photometric density) than its surround [Fraser
    and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Opacity = DICOMControlledTerminologyDefinitionsCode("112001")
    """
    A unique identifier for a series of DICOM SOP instances
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SeriesInstanceUID = DICOMControlledTerminologyDefinitionsCode("112002")
    """
    A named anatomic region within the chest cavity
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AssociatedChestComponent = DICOMControlledTerminologyDefinitionsCode("112003")
    """
    A collection of opacities detected within the continuum of loose connective
    tissue throughout the lung, that is not expected in a diagnostically normal
    radiograph
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AbnormalInterstitialPattern = DICOMControlledTerminologyDefinitionsCode("112004")
    """
    A type of anatomy that is expected to be detectable on a radiographic (X-Ray
    based) image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RadiographicAnatomy = DICOMControlledTerminologyDefinitionsCode("112005")
    """
    Characteristic of the extent of spreading of a finding or feature
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DistributionDescriptor = DICOMControlledTerminologyDefinitionsCode("112006")
    """
    Characteristic of the clarity of the boundary or edges of a finding or feature
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BorderDefinition = DICOMControlledTerminologyDefinitionsCode("112007")
    """
    The part(s) of the anatomy affected or encompassed by a finding or feature
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SiteInvolvement = DICOMControlledTerminologyDefinitionsCode("112008")
    """
    Characteristic of the matter or substance within a finding or feature
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TypeOfContent = DICOMControlledTerminologyDefinitionsCode("112009")
    """
    Characteristic of the surface or consistency of a finding or feature
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TextureDescriptor = DICOMControlledTerminologyDefinitionsCode("112010")
    """
    Position of the X-Ray beam about the patient from the RAO to LAO direction
    where movement from RAO to vertical is positive
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PositionerPrimaryAngle = DICOMControlledTerminologyDefinitionsCode("112011")
    """
    Position of the X-Ray beam about the patient from the caudal to cranial
    direction where movement from caudal to vertical is positive
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PositionerSecondaryAngle = DICOMControlledTerminologyDefinitionsCode("112012")
    """
    The zone, lobe or segment within the chest cavity in which a finding or
    feature is situated
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LocationInChest = DICOMControlledTerminologyDefinitionsCode("112013")
    """
    Vertical refers to orientation parallel to the superior-inferior (cephalad-
    caudad) axis of the body, with horizontal being perpendicular to this, and an
    oblique orientation having projections in both the horizontal and vertical
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OrientationDescriptor = DICOMControlledTerminologyDefinitionsCode("112014")
    """
    Characteristic of the shape formed by the boundary or edges of a finding or
    feature
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BorderShape = DICOMControlledTerminologyDefinitionsCode("112015")
    """
    Indicates whether a finding was considered a target lesion, non-target lesion,
    or non-lesion during evaluation of a baseline series, according to a method
    such as RECIST
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BaselineCategory = DICOMControlledTerminologyDefinitionsCode("112016")
    """
    The extent of a detected cavity, represented as the percent of the surrounding
    volume that it occupies
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CavityExtentAsPercentOfVolume = DICOMControlledTerminologyDefinitionsCode("112017")
    """
    The extent of a detected calcification, represented as the percent of the
    surrounding surface that it occupies
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CalcificationExtentAsPercentOfSurface = DICOMControlledTerminologyDefinitionsCode(
        "112018"
    )
    """
    The extent of a detected calcification, represented as the percent of the
    surrounding volume that it occupies
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CalcificationExtentAsPercentOfVolume = DICOMControlledTerminologyDefinitionsCode(
        "112019"
    )
    """
    A heading for the reporting of response evaluation for treatment of solid
    tumors
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ResponseEvaluation = DICOMControlledTerminologyDefinitionsCode("112020")
    """
    The system applied in the reporting of response evaluation for treatment of
    solid tumors
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ResponseEvaluationMethod = DICOMControlledTerminologyDefinitionsCode("112021")
    """
    Response Evaluation Criteria In Solid Tumors; see Normative References
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RECIST = DICOMControlledTerminologyDefinitionsCode("112022")
    """
    A term that further specifies the name of an item that is an inferred
    correlation relating two or more individual findings or features
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CompositeFeatureModifier = DICOMControlledTerminologyDefinitionsCode("112023")
    """
    A term that further specifies the name of an item that was detected on one
    image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SingleImageFindingModifier = DICOMControlledTerminologyDefinitionsCode("112024")
    """
    A qualitative descriptor for the extent of a finding or feature
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SizeDescriptor = DICOMControlledTerminologyDefinitionsCode("112025")
    """
    A qualitative descriptor for the thickness of tubular structures, such as
    blood vessels
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    WidthDescriptor = DICOMControlledTerminologyDefinitionsCode("112026")
    """
    A characteristic that further describes the nature of an opacity
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OpacityDescriptor = DICOMControlledTerminologyDefinitionsCode("112027")
    """
    The type of adverse affect that a finding or feature is having on the
    surrounding anatomy
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AbnormalDistributionOfAnatomicStructure = DICOMControlledTerminologyDefinitionsCode(
        "112028"
    )
    """
    Response evaluation method as defined in chapter 5, "Reporting of Response" of
    the WHO Handbook for Reporting Results for Cancer Treatment; see Normative
    References
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    WHO = DICOMControlledTerminologyDefinitionsCode("112029")
    """
    Identification of the morphology of detected calcifications
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CalcificationDescriptor = DICOMControlledTerminologyDefinitionsCode("112030")
    """
    A quantitative numerical statement of the relative attenuation of the X-Ray
    beam at a specified point. Coefficient that describes the fraction of a beam
    of X-Rays or gamma rays that is absorbed or scattered per unit thickness of
    the absorber. This value basically accounts for the number of atoms in a cubic
    cm volume of material and the probability of a photon being scattered or
    absorbed from the nucleus or an electron of one of these atoms. Usually
    expressed in Hounsfield units [referred to as CT Number in Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AttenuationCoefficient = DICOMControlledTerminologyDefinitionsCode("112031")
    """
    An X-Ray attenuation coefficient that is used as a threshold; e.g. in calcium
    scoring
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ThresholdAttenuationCoefficient = DICOMControlledTerminologyDefinitionsCode(
        "112032"
    )
    """
    An opacity that is not expected in a diagnostically normal radiograph
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AbnormalOpacity = DICOMControlledTerminologyDefinitionsCode("112033")
    """
    A textual description of the mathematical method of calculation that resulted
    in a calculated value
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CalculationDescription = DICOMControlledTerminologyDefinitionsCode("112034")
    """
    American College of Radiology. ACR Standard for the Performance of Pediatric
    and Adult Chest Radiography. In: Standards. Reston, Va: 2001:95-98
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PerformanceOfPediatricAndAdultChestRadiography_ACR = (
        DICOMControlledTerminologyDefinitionsCode("112035")
    )
    """
    American College of Radiology. ACR Position Statement for Quality Control and
    Improvement, Safety, Infection Control, and Patient Concerns. In: Practice
    Guidelines and Technical Standards. Reston, Va: 2001:iv
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ACRPositionStatement = DICOMControlledTerminologyDefinitionsCode("112036")
    """
    A descriptor for a non-lesion object finding or feature, used to indicate
    whether the object was detected as being internal or external to the patient's
    body
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Non_lesionModifier = DICOMControlledTerminologyDefinitionsCode("112037")
    """
    A concept modifier for an Osseous Anatomy, or bone related, finding
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OsseousModifier = DICOMControlledTerminologyDefinitionsCode("112038")
    """
    A text label used for tracking a finding or feature, potentially across
    multiple reporting objects, over time. This label shall be unique within the
    domain in which it is used
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TrackingIdentifier = DICOMControlledTerminologyDefinitionsCode("112039")
    """
    A unique identifier used for tracking a finding or feature, potentially across
    multiple reporting objects, over time
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TrackingUniqueIdentifier = DICOMControlledTerminologyDefinitionsCode("112040")
    """
    Disappearance of all target lesions
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TargetLesionCompleteResponse = DICOMControlledTerminologyDefinitionsCode("112041")
    """
    At least a 30% decrease in the sum of the Longest Diameter of target lesions,
    taking as reference the baseline sum Longest Diameter
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TargetLesionPartialResponse = DICOMControlledTerminologyDefinitionsCode("112042")
    """
    At least a 20% increase in the sum of the Longest Diameter of target lesions,
    taking as reference the smallest sum Longest Diameter recorded since the
    treatment started, or the appearance of one or more new lesions
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TargetLesionProgressiveDisease = DICOMControlledTerminologyDefinitionsCode("112043")
    """
    Neither sufficient shrinkage to qualify for Partial Response nor sufficient
    increase to qualify for Progressive Disease, taking as reference the smallest
    sum Longest Diameter since the treatment started
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TargetLesionStableDisease = DICOMControlledTerminologyDefinitionsCode("112044")
    """
    Disappearance of all non-target lesions and normalization of tumor marker
    level
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Non_TargetLesionCompleteResponse = DICOMControlledTerminologyDefinitionsCode(
        "112045"
    )
    """
    Persistence of one or more non-target lesions and/or maintenance of tumor
    marker level above the normal limits
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Non_TargetLesionIncompleteResponseOrStableDisease = (
        DICOMControlledTerminologyDefinitionsCode("112046")
    )
    """
    Appearance of one or more new lesions and/or unequivocal progression of
    existing non-target lesions
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Non_TargetLesionProgressiveDisease = DICOMControlledTerminologyDefinitionsCode(
        "112047"
    )
    """
    The current response evaluation for treatment of solid tumors, according to a
    method such as RECIST
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CurrentResponse = DICOMControlledTerminologyDefinitionsCode("112048")
    """
    Best response recorded from the start of the treatment until disease
    progression/recurrence, taking as reference for Progressive Disease the
    smallest measurements recorded since the treatment started, according to a
    method such as RECIST
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BestOverallResponse = DICOMControlledTerminologyDefinitionsCode("112049")
    """
    A text identifier of an anatomic feature when a multiplicity of features of
    that type may be present, such as "Rib 1", "Rib 2" or thoracic vertebrae "T1"
    or "T2"
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AnatomicIdentifier = DICOMControlledTerminologyDefinitionsCode("112050")
    """
    A measured or calculated evaluation of response; e.g. according to a method
    such as RECIST, the value would be the calculated sum of the lengths of the
    longest axes of a set of target lesions
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MeasurementOfResponse = DICOMControlledTerminologyDefinitionsCode("112051")
    """
    Of or relating to a bronchial (lung) specific channel for the conveyance of a
    body fluid
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Bronchovascular = DICOMControlledTerminologyDefinitionsCode("112052")
    """
    Of, relating to, or composed of bone
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Osseous = DICOMControlledTerminologyDefinitionsCode("112053")
    """
    The smallest unit of lung surrounded by connective tissue septa; the unit of
    lung subtended by any bronchiole that gives off three to five terminal
    bronchioles [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SecondaryPulmonaryLobule = DICOMControlledTerminologyDefinitionsCode("112054")
    """
    A method of calculating an overall calcium score, reflecting the calcification
    of coronary arteries, based on the maximum X-Ray attenuation coefficient and
    the area of calcium deposits
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AgatstonScoringMethod = DICOMControlledTerminologyDefinitionsCode("112055")
    """
    A method of calculating an overall calcium score, reflecting the calcification
    of coronary arteries, based on the volume of each calcification, typically
    expressed in mm3
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VolumeScoringMethod = DICOMControlledTerminologyDefinitionsCode("112056")
    """
    A method of calculating an overall calcium score, reflecting the calcification
    of coronary arteries, based on the total mass of calcification, typically
    expressed in mg
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MassScoringMethod = DICOMControlledTerminologyDefinitionsCode("112057")
    """
    A measure often arrived at through calculation of findings from CT
    examination, which is a common predictor of significant stenosis of the
    coronary arteries
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CalciumScore = DICOMControlledTerminologyDefinitionsCode("112058")
    """
    The combination of a focus of pneumonia due to a primary infection with
    granulomas in the draining hilar or mediastinal lymph nodes [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PrimaryComplex = DICOMControlledTerminologyDefinitionsCode("112059")
    """
    General or local decrease in the apparent width of visible pulmonary vessels,
    suggesting less than normal blood flow (reduced blood flow) [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Oligemia = DICOMControlledTerminologyDefinitionsCode("112060")
    """
    Linear opacity of very fine width, i.e., a nearly one dimensional opacity
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AbnormalLines_1D_ = DICOMControlledTerminologyDefinitionsCode("112061")
    """
    Area of abnormal very low X-Ray attenuation, typically lower than aerated lung
    when occurring in or projecting over lung, or lower than soft tissue when
    occurring in or projecting over soft tissue
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AbnormalLucency = DICOMControlledTerminologyDefinitionsCode("112062")
    """
    A calcific opacity within the lung that may be organized, but does not display
    the trabecular organization of true bone [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AbnormalCalcifications = DICOMControlledTerminologyDefinitionsCode("112063")
    """
    Relatively homogeneous, extended, pattern of abnormal opacity in the lung,
    typically low in contrast
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AbnormalTexture = DICOMControlledTerminologyDefinitionsCode("112064")
    """
    A collection of innumerable small, linear, and nodular opacities that together
    produce a composite appearance resembling a net with small superimposed
    nodules. The reticular and nodular elements are dimensionally of similar
    magnitude [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ReticulonodularPattern = DICOMControlledTerminologyDefinitionsCode("112065")
    """
    Irregular septal thickening that suggests the appearance of a row of beads;
    usually a sign of lymphangitic carcinomatosis, but may also occur rarely in
    sarcoidosis [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BeadedSeptumSign = DICOMControlledTerminologyDefinitionsCode("112066")
    """
    A collection of innumerable, small discrete opacities ranging in diameter from
    2-10 mm, generally uniform in size and widespread in distribution, and without
    marginal spiculation [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NodularPattern = DICOMControlledTerminologyDefinitionsCode("112067")
    """
    An irregular band of peripheral pulmonary opacity adjacent to visceral pleura
    that simulates the appearance of a pleural plaque and is formed by coalescence
    of small nodules [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Pseudoplaque = DICOMControlledTerminologyDefinitionsCode("112068")
    """
    A ring of opacities (usually representing a dilated, thick-walled bronchus) in
    association with a smaller, round, soft tissue opacity (the adjacent pulmonary
    artery) suggesting a "signet ring" [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Signet_ringSign = DICOMControlledTerminologyDefinitionsCode("112069")
    """
    Equivalent of air bronchogram, but in airways assumed to be bronchioles
    because of peripheral location and diameter [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AirBronchiologram = DICOMControlledTerminologyDefinitionsCode("112070")
    """
    Radiographic shadow of an air-containing bronchus; presumed to represent an
    air-containing segment of the bronchial tree (identity often inferred) [Fraser
    and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AirBronchogram = DICOMControlledTerminologyDefinitionsCode("112071")
    """
    Air in a crescentic shape in a nodule or mass, in which the air separates the
    outer wall of the lesion from an inner sequestrum, which most commonly is a
    fungus ball of Aspergillusspecies [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AirCrescent = DICOMControlledTerminologyDefinitionsCode("112072")
    """
    Ground-glass opacity surrounding the circumference of a nodule or mass. May be
    a sign of invasive aspergillosis or hemorrhage of various causes [Fraser and
    Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    HaloSign = DICOMControlledTerminologyDefinitionsCode("112073")
    """
    Flag denoting that this lesion was identified, at baseline, as a target lesion
    intended for tracking over time [RECIST]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TargetLesionAtBaseline = DICOMControlledTerminologyDefinitionsCode("112074")
    """
    Flag denoting that this lesion was not identified, at baseline, as a target
    lesion, and was not intended for tracking over time [RECIST]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Non_TargetLesionAtBaseline = DICOMControlledTerminologyDefinitionsCode("112075")
    """
    Flag denoting that this finding was identified, at baseline, as a category
    other than a lesion, and was not intended for tracking over time [RECIST]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Non_LesionAtBaseline = DICOMControlledTerminologyDefinitionsCode("112076")
    """
    Local or general reduction in the caliber of visible pulmonary vessels,
    presumed to result from decreased flow occasioned by contraction of muscular
    pulmonary arteries [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Vasoconstriction = DICOMControlledTerminologyDefinitionsCode("112077")
    """
    Local or general increase in the width of visible pulmonary vessels resulting
    from increased pulmonary blood flow [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Vasodilation = DICOMControlledTerminologyDefinitionsCode("112078")
    """
    A manifestation of lung disease in which bronchi, pulmonary vessels, a fissure
    or fissures, or septa of secondary pulmonary lobules are abnormally displaced
    [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ArchitecturalDistortion = DICOMControlledTerminologyDefinitionsCode("112079")
    """
    A patchwork of regions of varied attenuation, interpreted as secondary to
    regional differences in perfusion [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MosaicPerfusion = DICOMControlledTerminologyDefinitionsCode("112080")
    """
    Increased blood flow to the lungs or a portion thereof, manifested by a
    general or local increase in the width of visible pulmonary vessels [Fraser
    and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Pleonemia = DICOMControlledTerminologyDefinitionsCode("112081")
    """
    The common boundary between the shadows of two juxtaposed structures or
    tissues of different texture or opacity (edge, border) [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Interface = DICOMControlledTerminologyDefinitionsCode("112082")
    """
    A longitudinal opacity no greater than 2 mm in width [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Line = DICOMControlledTerminologyDefinitionsCode("112083")
    """
    The shadow of an absorber that attenuates the primary X-Ray beam less
    effectively than do surrounding absorbers. In a radiograph, any circumscribed
    area that appears more nearly black (of greater photometric density) than its
    surround [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Lucency = DICOMControlledTerminologyDefinitionsCode("112084")
    """
    A midlung region, characterized by the absence of large blood vessels and by a
    paucity of small blood vessels, that corresponds to the minor fissure and
    adjacent peripheral lung [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MidlungWindow = DICOMControlledTerminologyDefinitionsCode("112085")
    """
    The angle formed by the right and left main bronchi at the tracheal
    bifurcation [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CarinaAngle = DICOMControlledTerminologyDefinitionsCode("112086")
    """
    The pulmonary artery and its immediate branches in a secondary lobule; HRCT
    depicts these vessels in certain cases; a.k.a. core structures or lobular core
    structures [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CentrilobularStructures = DICOMControlledTerminologyDefinitionsCode("112087")
    """
    A vertically oriented linear or curvilinear opacity approximately 1-2 mm wide,
    commonly projected on the tracheal air shadow [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AnteriorJunctionLine = DICOMControlledTerminologyDefinitionsCode("112088")
    """
    A vertically oriented, linear or curvilinear opacity approximately 2 mm wide,
    commonly projected on the tracheal air shadow, and usually slightly concave to
    the right [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PosteriorJunctionLine = DICOMControlledTerminologyDefinitionsCode("112089")
    """
    A space in the right side of the mediastinum into which the medial edge of the
    right lower lobe extends [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AzygoesophagealRecessInterface = DICOMControlledTerminologyDefinitionsCode("112090")
    """
    A vertically oriented interface usually seen in a frontal chest radiograph to
    the left of the thoracic vertebral column [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ParaspinalLine = DICOMControlledTerminologyDefinitionsCode("112091")
    """
    A vertically oriented linear opacity ranging in width from 2-5 mm, extending
    from the thoracic inlet to the bifurcation of the trachea, and visible only on
    lateral radiographs of the chest [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PosteriorTrachealStripe = DICOMControlledTerminologyDefinitionsCode("112092")
    """
    A vertically oriented linear opacity approximately 2-3 mm wide extending from
    the thoracic inlet to the right tracheobronchial angle [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RightTrachealStripe = DICOMControlledTerminologyDefinitionsCode("112093")
    """
    A longitudinal composite opacity measuring 2-5 mm in width; acceptable when
    limited to anatomic structures within the mediastinum [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Stripe = DICOMControlledTerminologyDefinitionsCode("112094")
    """
    A gap or passage through an anatomical part or organ; especially : a gap
    through which another part or organ passes
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Hiatus = DICOMControlledTerminologyDefinitionsCode("112095")
    """
    A small rounded elevation or eminence on the first rib for the attachment of
    the scalenus anterior
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RibScaleneTubercle = DICOMControlledTerminologyDefinitionsCode("112096")
    """
    A groove that serves for the transmission of the vertebral artery
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VertebralIntervertebralNotch = DICOMControlledTerminologyDefinitionsCode("112097")
    """
    The concave depression of the anterior surface of the scapula
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SubscapularFossa = DICOMControlledTerminologyDefinitionsCode("112098")
    """
    A sloping ridge dividing the dorsal surface of the scapula into the
    supraspinatous fossa (above), and the infraspinatous fossa (below)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ScapularSpine = DICOMControlledTerminologyDefinitionsCode("112099")
    """
    The portion of the dorsal surface of the scapula above the scapular spine
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ScapularSupraspinatusFossa = DICOMControlledTerminologyDefinitionsCode("112100")
    """
    The portion of the dorsal surface of the scapula below the scapular spine
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ScapularInfraspinatusFossa = DICOMControlledTerminologyDefinitionsCode("112101")
    """
    The portion of the aortic arch that defines the transition between its
    ascending and descending limbs
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AorticKnob = DICOMControlledTerminologyDefinitionsCode("112102")
    """
    Section of Azygos vein near the fourth thoracic vertebra, where it arches
    forward over the root of the right lung, and ends in the superior vena cava,
    just before that vessel pierces the pericardium
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ArchOfTheAzygosVein = DICOMControlledTerminologyDefinitionsCode("112103")
    """
    A local collection of gas and liquid that, when traversed by a horizontal
    X-Ray beam, creates a shadow characterized by a sharp horizontal interface
    between gas density above and liquid density below [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Air_fluidLevel = DICOMControlledTerminologyDefinitionsCode("112104")
    """
    A circumferential pattern of fine linear spicules, approximately 5 mm long,
    extending outward from the margin of a solitary pulmonary nodule through a
    zone of relative lucency [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CoronaRadiata = DICOMControlledTerminologyDefinitionsCode("112105")
    """
    A number of closely approximated ring shadows representing air spaces 5-10 mm
    in diameter with walls 2-3 mm thick that resemble a true honeycomb; implies
    "end-stage" lung [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    HoneycombPattern = DICOMControlledTerminologyDefinitionsCode("112106")
    """
    A straight, curved, or irregular linear opacity that is visible in multiple
    projections; usually situated in the lower half of the lung; vary markedly in
    length and width [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Fleischner_sLine_s_ = DICOMControlledTerminologyDefinitionsCode("112107")
    """
    Fine linear opacities present in a lobule when the intralobular interstitium
    is thickened. When numerous, they may appear as a fine reticular pattern
    [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IntralobularLines = DICOMControlledTerminologyDefinitionsCode("112108")
    """
    Essentially straight linear opacity 2-6 cm in length and 1-3 mm in width,
    usually in an upper lung zone [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    KerleyALine = DICOMControlledTerminologyDefinitionsCode("112109")
    """
    A straight linear opacity 1.5-2 cm in length and 1-2 mm in width, usually at
    the lung base [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    KerleyBLine = DICOMControlledTerminologyDefinitionsCode("112110")
    """
    A group of branching, linear opacities producing the appearing of a fine net,
    at the lung base [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    KerleyCLines = DICOMControlledTerminologyDefinitionsCode("112111")
    """
    Elongated opacity, usually several millimeters wide and up to about 5 cm long,
    often extending to the pleura, which may be thickened and retracted at the
    site of contact [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ParenchymalBand = DICOMControlledTerminologyDefinitionsCode("112112")
    """
    A collection of innumerable small linear opacities that together produce an
    appearance resembling a net [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ReticularPattern = DICOMControlledTerminologyDefinitionsCode("112113")
    """
    Usually used in the plural, a generic term for linear opacities of varied
    distribution produced when the interstitium between pulmonary lobules is
    thickened [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SeptalLine_s_ = DICOMControlledTerminologyDefinitionsCode("112114")
    """
    A thin curvilinear opacity, a few millimeters or less in thickness, usually
    less than 1 cm from the pleural surface and paralleling the pleura [Fraser and
    Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SubpleuralLine = DICOMControlledTerminologyDefinitionsCode("112115")
    """
    Parallel or slightly convergent linear opacities that suggest the planar
    projection of tubular structures and that correspond in location and
    orientation to elements of the bronchial tree [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TramlineShadow = DICOMControlledTerminologyDefinitionsCode("112116")
    """
    Paired, parallel, or slightly convergent linear opacities presumed to
    represent the walls of a tubular structure seen en face; used if the anatomic
    nature of a shadow is obscure [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TubularShadow = DICOMControlledTerminologyDefinitionsCode("112117")
    """
    The opacity of a radiographic shadow to visible light; film blackening; the
    term should never be used to mean an "opacity" or "radiopacity" [Fraser and
    Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Density = DICOMControlledTerminologyDefinitionsCode("112118")
    """
    Subpleural increased attenuation in dependent lung. The increased attenuation
    disappears when the region of lung is nondependent; a.k.a. dependent increased
    attenuation [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DependentOpacity = DICOMControlledTerminologyDefinitionsCode("112119")
    """
    Hazy increased attenuation of lung, but with preservation of bronchial and
    vascular margins; caused by partial filling of air spaces, interstitial
    thickening, partial collapse of alveoli, normal expiration, or increased
    capillary blood volume [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    GroundGlassOpacity = DICOMControlledTerminologyDefinitionsCode("112120")
    """
    Any ill-defined opacity in the lung [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Infiltrate = DICOMControlledTerminologyDefinitionsCode("112121")
    """
    Discrete, small, round, focal opacity of at least soft tissue attenuation and
    with a diameter no greater than 7 mm [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Micronodule = DICOMControlledTerminologyDefinitionsCode("112122")
    """
    A shadow produced by a local collection of fluid in one of the interlobar
    fissures, usually elliptic in one radiographic projection and rounded in the
    other, resembling a tumor [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PhantomTumor_pseudotumor_ = DICOMControlledTerminologyDefinitionsCode("112123")
    """
    Any perceptible discontinuity in film blackening attributed to the attenuation
    of the X-Ray beam by a specific anatomic absorber or lesion on or within the
    body of the patient; to be employed only when more specific identification is
    not possible [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Shadow = DICOMControlledTerminologyDefinitionsCode("112124")
    """
    Term used to define a reticular pattern specific to pneumoconioses [Fraser and
    Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SmallIrregularOpacities = DICOMControlledTerminologyDefinitionsCode("112125")
    """
    Term used to define a nodular pattern specific to pneumoconioses [Fraser and
    Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SmallRoundedOpacities = DICOMControlledTerminologyDefinitionsCode("112126")
    """
    Nodular dilation of centrilobular branching structures that resembles a
    budding tree and represents exudative bronchiolar dilation [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Tree_in_budSign = DICOMControlledTerminologyDefinitionsCode("112127")
    """
    Any extended, finely granular pattern of pulmonary opacity within which normal
    anatomic details are partly obscured [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    GranularPattern = DICOMControlledTerminologyDefinitionsCode("112128")
    """
    A collection of tiny discrete opacities in the lungs, each measuring 2 mm or
    less in diameter, generally uniform in size and widespread in distribution
    [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MiliaryPattern = DICOMControlledTerminologyDefinitionsCode("112129")
    """
    Generalized pattern of relatively well defined areas in the lung having
    different X-Ray attenuations due to a longstanding underlying pulmonary
    disease
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MosaicPattern = DICOMControlledTerminologyDefinitionsCode("112130")
    """
    A qualitative descriptor of a size that is dramatically less than typical
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ExtremelySmall = DICOMControlledTerminologyDefinitionsCode("112131")
    """
    A qualitative descriptor of a size that is considerably less than typical
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VerySmall = DICOMControlledTerminologyDefinitionsCode("112132")
    """
    A qualitative descriptor of a size that is so small as to be abnormal versus
    expected size
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TooSmall = DICOMControlledTerminologyDefinitionsCode("112133")
    """
    Shaped like an ellipse (oval)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Elliptic = DICOMControlledTerminologyDefinitionsCode("112134")
    """
    A border shape that is made up of, provided with, or divided into lobules
    (small lobes, curved or rounded projections or divisions)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Lobulated = DICOMControlledTerminologyDefinitionsCode("112135")
    """
    Radially orientated border shape
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Spiculated = DICOMControlledTerminologyDefinitionsCode("112136")
    """
    The border of a shadow (opacity) is sharply defined [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SharplyDefined = DICOMControlledTerminologyDefinitionsCode("112137")
    """
    The border of a shadow (opacity) is distinctly defined [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DistinctlyDefined = DICOMControlledTerminologyDefinitionsCode("112138")
    """
    The border of a shadow (opacity) is well distinct from adjacent structures
    [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    WellDemarcated = DICOMControlledTerminologyDefinitionsCode("112139")
    """
    The border of a shadow (opacity) is sharply distinct from adjacent structures
    [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SharplyDemarcated = DICOMControlledTerminologyDefinitionsCode("112140")
    """
    The border of a shadow (opacity) is poorly distinct from adjacent structures
    [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PoorlyDemarcated = DICOMControlledTerminologyDefinitionsCode("112141")
    """
    A shadow (opacity) possessing a complete or nearly complete visible border
    [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Circumscribed = DICOMControlledTerminologyDefinitionsCode("112142")
    """
    Inspired atmospheric gas. The word is sometimes used to describe gas within
    the body regardless of its composition or site [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Air = DICOMControlledTerminologyDefinitionsCode("112143")
    """
    Material having X-Ray attenuation properties similar to muscle
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SoftTissue = DICOMControlledTerminologyDefinitionsCode("112144")
    """
    Material having X-Ray attenuation properties similar to calcium, a silver-
    white bivalent metallic element occurring in plants and animals
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Calcium = DICOMControlledTerminologyDefinitionsCode("112145")
    """
    A pulmonary opacity 4-8 mm in diameter, presumed to represent anatomic acinus,
    or a collection of opacities in the lung, each measuring 4-8 mm in diameter,
    and together producing an extended, homogeneous shadow [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Acinar = DICOMControlledTerminologyDefinitionsCode("112146")
    """
    The gas-containing portion of the lung parenchyma, including the acini and
    excluding the interstitium [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AirSpace = DICOMControlledTerminologyDefinitionsCode("112147")
    """
    Sharply defined, approximately circular opacities occurring singly or in
    clusters, usually in the upper lobes [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Fibronodular = DICOMControlledTerminologyDefinitionsCode("112148")
    """
    A shadow (opacity) that is ill-defined, lacking clear-cut margins [Fraser and
    Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Fluffy = DICOMControlledTerminologyDefinitionsCode("112149")
    """
    A shadow resembling a line; any elongated opacity of approximately uniform
    width [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Linear = DICOMControlledTerminologyDefinitionsCode("112150")
    """
    The number of small opacities per unit area or zone of lung. In the
    International Labor Organization (ILO) classification of radiographs of the
    pneumoconioses, the qualifiers 0 through 3 subdivide the profusion into 4
    categories. The profusion categories may be further subdivided by employing a
    12-point scale [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Profusion = DICOMControlledTerminologyDefinitionsCode("112151")
    """
    The effacement of an anatomic soft tissue border by either a normal anatomic
    structure or a pathologic state such as airlessness of adjacent lung or
    accumulation of fluid in the contiguous pleural space; useful in detecting and
    localizing an opacity along the axis of the X-Ray beam [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SilhouetteSign = DICOMControlledTerminologyDefinitionsCode("112152")
    """
    Situated or occurring between the pleura and the body wall
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Subpleural = DICOMControlledTerminologyDefinitionsCode("112153")
    """
    Spatial arrangement of opacities that bears vague resemblance to the shape of
    a bat in flight; bilaterally symmetric [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Bat_sWingDistribution = DICOMControlledTerminologyDefinitionsCode("112154")
    """
    Spatial arrangement of opacities that bears vague resemblance to the shape of
    a butterfly in flight; bilaterally symmetric [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ButterflyDistribution = DICOMControlledTerminologyDefinitionsCode("112155")
    """
    Referring to the region of the bronchioloarteriolar core of a secondary
    pulmonary lobule [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Centrilobular = DICOMControlledTerminologyDefinitionsCode("112156")
    """
    The joining together of a number of opacities into a single opacity [Fraser
    and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Coalescent = DICOMControlledTerminologyDefinitionsCode("112157")
    """
    Of or relating to a lobe (a curved or rounded projection or division); e.g.
    involving an entire lobe of the lung
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Lobar = DICOMControlledTerminologyDefinitionsCode("112158")
    """
    Extremely or excessively acute, as a qualitative measure of severity
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Hyper_acute = DICOMControlledTerminologyDefinitionsCode("112159")
    """
    Of uniform opacity or texture throughout [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Homogeneous_uniformOpacity_ = DICOMControlledTerminologyDefinitionsCode("112160")
    """
    Lack of homogeneity in opacity or texture
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Inhomogeneous = DICOMControlledTerminologyDefinitionsCode("112161")
    """
    Discrete opacity centrally within a larger opacity, as a calcification
    descriptor
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Target = DICOMControlledTerminologyDefinitionsCode("112162")
    """
    Pertaining to sharply defined, linear, and/or nodular opacities containing
    calcification(s) [Fraser and Pare]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Fibrocalcific = DICOMControlledTerminologyDefinitionsCode("112163")
    """
    Calcifications made up of loosely aggregated particles, resembling wool
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Flocculent = DICOMControlledTerminologyDefinitionsCode("112164")
    """
    A change in the shape formed by the boundary or edges of a finding or feature
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DifferenceInBorderShape = DICOMControlledTerminologyDefinitionsCode("112165")
    """
    A change in the clarity of the boundary or edges of a finding or feature
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DifferenceInBorderDefinition = DICOMControlledTerminologyDefinitionsCode("112166")
    """
    A change in the extent of spreading of a finding or feature
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DifferenceInDistribution = DICOMControlledTerminologyDefinitionsCode("112167")
    """
    A change in the part(s) of the anatomy affected or encompassed by a finding or
    feature
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DifferenceInSiteInvolvement = DICOMControlledTerminologyDefinitionsCode("112168")
    """
    A change in the matter or substance within a finding or feature
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DifferenceInTypeOfContent = DICOMControlledTerminologyDefinitionsCode("112169")
    """
    A change in the surface or consistency of a finding or feature
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DifferenceInTexture = DICOMControlledTerminologyDefinitionsCode("112170")
    """
    A location in image space, which may or may not correspond to an anatomical
    reference, which is often used for registering data sets
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FiducialMark = DICOMControlledTerminologyDefinitionsCode("112171")
    """
    Connected to an injection chamber placed under the skin in the upper part of
    the chest. When it is necessary to inject some drug, a specific needle is put
    in the chamber through the skin and a silicon membrane. The advantage of a
    portacath is that it may be left in place several months contrarily of
    "classical" catheters
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Portacath = DICOMControlledTerminologyDefinitionsCode("112172")
    """
    A tube inserted into the chest wall from outside the body, for drainage.
    Sometimes used for collapsed lung. Usually connected to a receptor placed
    lower than the insertion site
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ChestTube = DICOMControlledTerminologyDefinitionsCode("112173")
    """
    A tube placed into the subclavian vein to deliver medication directly into the
    venous system
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CentralLine = DICOMControlledTerminologyDefinitionsCode("112174")
    """
    A stent is a tube inserted into another tube. Kidney stent is a tube that is
    inserted into the kidney, ureter, and bladder, to help drain urine. Usually
    inserted through a scoping device presented through the urethra
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    KidneyStent = DICOMControlledTerminologyDefinitionsCode("112175")
    """
    A stent is a tube inserted into another tube. Pancreatic stent is inserted
    through the common bile duct to the pancreatic duct, to drain bile
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PancreaticStent = DICOMControlledTerminologyDefinitionsCode("112176")
    """
    A non-lesion object that appears to be a circular band, attached to the body
    via pierced nipple
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NippleRing = DICOMControlledTerminologyDefinitionsCode("112177")
    """
    A non-lesion object that appears to be a flat round piece of metal
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Coin = DICOMControlledTerminologyDefinitionsCode("112178")
    """
    The least quantity assignable, admissible, or possible; the least of a set of
    X-Ray attenuation coefficients
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MinimumAttenuationCoefficient = DICOMControlledTerminologyDefinitionsCode("112179")
    """
    The greatest quantity or value attainable or attained; the largest of a set of
    X-Ray attenuation coefficients
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MaximumAttenuationCoefficient = DICOMControlledTerminologyDefinitionsCode("112180")
    """
    The value that is computed by dividing the sum of a set of X-Ray attenuation
    coefficients by the number of values
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MeanAttenuationCoefficient = DICOMControlledTerminologyDefinitionsCode("112181")
    """
    The value in an ordered set of X-Ray attenuation coefficients, below and above
    which there is an equal number of values
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MedianAttenuationCoefficient = DICOMControlledTerminologyDefinitionsCode("112182")
    """
    For a set of X-Ray attenuation coefficients: 1) a measure of the dispersion of
    a frequency distribution that is the square root of the arithmetic mean of the
    squares of the deviation of each of the class frequencies from the arithmetic
    mean of the frequency distribution; 2) a parameter that indicates the way in
    which a probability function or a probability density function is centered
    around its mean and that is equal to the square root of the moment in which
    the deviation from the mean is squared
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StandardDeviationOfAttenuationCoefficient = (
        DICOMControlledTerminologyDefinitionsCode("112183")
    )
    """
    American College of Radiology. ACR Standard for the Performance of Pediatric
    and Adult Thoracic Computed Tomography (CT). In: Standards. Reston, Va:
    2001:103-107
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PerformanceOfPediatricAndAdultThoracicCT = (
        DICOMControlledTerminologyDefinitionsCode("112184")
    )
    """
    American College of Radiology. ACR Standard for the Performance of Computed
    Tomography for the Detection of Pulmonary Embolism in Adults. In: Standards.
    Reston, Va: 2001:109-113
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PerformanceOfCTForDetectionOfPulmonaryEmbolismInAdults = (
        DICOMControlledTerminologyDefinitionsCode("112185")
    )
    """
    American College of Radiology. ACR Standard for the Performance of High-
    Resolution Computed Tomography (HRCT) of the Lungs in Adults. In: Standards.
    Reston, Va: 2001:115-118
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PerformanceOfHigh_ResolutionCTOfTheLungsInAdults = (
        DICOMControlledTerminologyDefinitionsCode("112186")
    )
    """
    The method of calculation of a measurement or other type of numeric value is
    not specified
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    UnspecifiedMethodOfCalculation = DICOMControlledTerminologyDefinitionsCode("112187")
    """
    The calculation method was performed in two-dimensional space
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Two_dimensionalMethod = DICOMControlledTerminologyDefinitionsCode("112188")
    """
    The calculation method was performed in three-dimensional space
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Three_dimensionalMethod = DICOMControlledTerminologyDefinitionsCode("112189")
    """
    The relative density of parenchymal tissue as a proportion of breast volume
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BreastTissueDensity = DICOMControlledTerminologyDefinitionsCode("112191")
    """
    The volume of parenchymal tissue
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VolumeOfParenchymalTissue = DICOMControlledTerminologyDefinitionsCode("112192")
    """
    The volume of the breast
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VolumeOfBreast = DICOMControlledTerminologyDefinitionsCode("112193")
    """
    The mass of parenchymal tissue
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MassOfParenchymalTissue = DICOMControlledTerminologyDefinitionsCode("112194")
    """
    The mass of the breast
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MassOfBreast = DICOMControlledTerminologyDefinitionsCode("112195")
    """
    A measured or calculated area of vascular calcification
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AreaOfVascularCalcification = DICOMControlledTerminologyDefinitionsCode("112196")
    """
    A measured or calculated volume of vascular calcification
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VolumeOfVascularCalcification = DICOMControlledTerminologyDefinitionsCode("112197")
    """
    A measured or calculated percentage of vascular calcification
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PercentageOfVascularCalcification = DICOMControlledTerminologyDefinitionsCode(
        "112198"
    )
    """
    A measured or calculated mass of vascular calcification
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MassOfVascularCalcification = DICOMControlledTerminologyDefinitionsCode("112199")
    """
    The average nearest neighbor distance of all individual microcalcifications in
    a cluster
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AverageCalcificationDistanceInACalcificationCluster = (
        DICOMControlledTerminologyDefinitionsCode("112200")
    )
    """
    The standard deviation of nearest neighbor distance of all individual
    microcalcifications in a cluster
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StandardDeviationDistanceOfCalcificationsInACluster = (
        DICOMControlledTerminologyDefinitionsCode("112201")
    )
    """
    A structured report containing the results of computer-aided detection or
    diagnosis applied to colon imaging and associated clinical information
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ColonCADReport = DICOMControlledTerminologyDefinitionsCode("112220")
    """
    Overall interpretation of the colon using C-RADS categorization system
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ColonOverallAssessment = DICOMControlledTerminologyDefinitionsCode("112222")
    """
    Characteristics of a set of images
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ImageSetProperties = DICOMControlledTerminologyDefinitionsCode("112224")
    """
    Nominal slice thickness, in mm
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SliceThickness = DICOMControlledTerminologyDefinitionsCode("112225")
    """
    Distance between contiguous images, measured from the center-to-center of each
    image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SpacingBetweenSlices = DICOMControlledTerminologyDefinitionsCode("112226")
    """
    Uniquely identifies groups of composite instances that have the same
    coordinate system that conveys spatial and/or temporal information
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FrameOfReferenceUID = DICOMControlledTerminologyDefinitionsCode("112227")
    """
    Patient orientation with respect to downward direction (gravity)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RecumbentPatientPositionWithRespectToGravity = (
        DICOMControlledTerminologyDefinitionsCode("112228")
    )
    """
    Distinguishes a part of a segmentation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IdentifyingSegment = DICOMControlledTerminologyDefinitionsCode("112229")
    """
    The diameter of a polyp stalk measured perpendicular to the axis of the stalk
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PolypStalkWidth = DICOMControlledTerminologyDefinitionsCode("112232")
    """
    The length of the path following the centerline of the colon from the anus to
    the area of interest
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DistanceFromAnus = DICOMControlledTerminologyDefinitionsCode("112233")
    """
    A location in the body that is outside the colon
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AnatomicNon_colon = DICOMControlledTerminologyDefinitionsCode("112238")
    """
    An inadequate study or a study that is awaiting prior comparisons. The study
    may have inadequate preparation and cannot exclude lesions greater than or
    equal to ten millimeters owing to presence of fluid or feces. The study may
    have inadequate insufflation where one or more colonic segments collapsed on
    both views. Based on "CT Colonography Reporting and Data System: A Consensus
    Proposal", Radiology, July 2005; 236:3-9
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    C0_InadequateStudy_AwaitingPriorComparisons = (
        DICOMControlledTerminologyDefinitionsCode("112240")
    )
    """
    The study has a normal colon or benign lesion, with the recommendation to
    continue routine screening. The study has no visible abnormalities of the
    colon. The study has no polyps greater than six millimeters. The study may
    have lipoma, inverted diverticulum, or nonneoplastic findings, such as colonic
    diverticula. Based on "CT Colonography Reporting and Data System: A Consensus
    Proposal", Radiology, July 2005; 236:3-9
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    C1_NormalColonOrBenignLesion = DICOMControlledTerminologyDefinitionsCode("112241")
    """
    The study has an intermediate polyp or indeterminate finding and surveillance
    or colonoscopy is recommended. There may be intermediate polyps between six
    and nine millimeters and there are less than three in number. The study may
    have an intermediate finding and cannot exclude a polyp that is greater than
    or equal to six millimeters in a technically adequate exam. Based on "CT
    Colonography Reporting and Data System: A Consensus Proposal", Radiology, July
    2005; 236:3-9
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    C2_IntermediatePolypOrIndeterminateFinding = (
        DICOMControlledTerminologyDefinitionsCode("112242")
    )
    """
    The study has a polyp, possibly advanced adenoma, and a follow-up colonoscopy
    is recommended. The study has a polyp greater than or equal to ten millimeters
    or the study has three or more polyps that are each between six to nine
    millimeters. Based on "CT Colonography Reporting and Data System: A Consensus
    Proposal", Radiology, July 2005; 236:3-9
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    C3_Polyp_PossiblyAdvancedAdenoma = DICOMControlledTerminologyDefinitionsCode(
        "112243"
    )
    """
    The study has a colonic mass, likely malignant, and surgical consultation is
    recommended. The lesion compromises bowel lumen and demonstrates extracolonic
    invasion. Based on "CT Colonography Reporting and Data System: A Consensus
    Proposal", Radiology, July 2005; 236:3-9
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    C4_ColonicMass_LikelyMalignant = DICOMControlledTerminologyDefinitionsCode("112244")
    """
    American College of Radiology Practice Guideline for the Performance of
    Computed Tomography (CT) Colonography in Adults. In: Practice Guidelines and
    Technical Standards.Reston, Va: American College of Radiology;2006:371-376
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ACRGuideline_PerformanceOfAdultCTColonography = (
        DICOMControlledTerminologyDefinitionsCode("112248")
    )
    """
    American College of Radiology Technical Standard for Diagnostic Medical
    Physics Performance Monitoring of Computed Tomography (CT) Equipment. In:
    Practice Guidelines and Technical Standards.Reston, Va: American College of
    Radiology;2006:945-948
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ACRStandard_CTMedicalPhysicsPerformanceMonitoring = (
        DICOMControlledTerminologyDefinitionsCode("112249")
    )
    """
    View Orientation Modifier indicates that the view orientation of the imaging
    plane is rotated +45° along the cranial-caudal axis
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AP_45 = DICOMControlledTerminologyDefinitionsCode("112300")
    """
    View Orientation Modifier indicates that the view orientation of the imaging
    plane is rotated -45° along the cranial-caudal axis
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AP_45 = DICOMControlledTerminologyDefinitionsCode("112301")
    """
    The axis following the shaft of the femur
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AnatomicalAxisOfFemur = DICOMControlledTerminologyDefinitionsCode("112302")
    """
    Center of Rotation of the natural Acetabulum
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AcetabularCenterOfRotation = DICOMControlledTerminologyDefinitionsCode("112303")
    """
    Center of Rotation of the natural femur head
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FemurHeadCenterOfRotation = DICOMControlledTerminologyDefinitionsCode("112304")
    """
    Prosthetic component implanted into the acetabulum. Provides hold for the
    insert that is mounted inside the cup
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AcetabularCupShell = DICOMControlledTerminologyDefinitionsCode("112305")
    """
    Prosthetic pelvic joint component. Inserted into the cup, takes in the femoral
    head replacement
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AcetabularCupInsert = DICOMControlledTerminologyDefinitionsCode("112306")
    """
    Prosthetic pelvic joint cup including insert
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AcetabularCupMonoblock = DICOMControlledTerminologyDefinitionsCode("112307")
    """
    Component for Femoral Head Prosthesis where the conic intake for the stem neck
    can be exchanged. Combined with a Femoral Head Cone Taper Component
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FemoralHeadBallComponent = DICOMControlledTerminologyDefinitionsCode("112308")
    """
    Exchangeable neck intake for composite femoral head prosthesis. Combined with
    a Femoral Head Ball Component
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FemoralHeadConeTaperComponent = DICOMControlledTerminologyDefinitionsCode("112309")
    """
    Prosthesis Implanted into the femoral bone to provide force transmission
    between joint replacement and bone. On the proximal end a conic neck holds the
    femoral head replacement
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FemoralStem = DICOMControlledTerminologyDefinitionsCode("112310")
    """
    Distal half of a modular stem prosthesis system. Combined with a Stem Proximal
    Component
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FemoralStemDistalComponent = DICOMControlledTerminologyDefinitionsCode("112311")
    """
    Proximal half of a modular stem prosthesis system. Combined with a Stem Distal
    Component
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FemoralStemProximalComponent = DICOMControlledTerminologyDefinitionsCode("112312")
    """
    Stem prosthetic component with a modular insert for an exchangeable neck
    component. Combined with a Neck Component
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FemoralStemComponent = DICOMControlledTerminologyDefinitionsCode("112313")
    """
    Prosthetic Neck to be combined with a Stem Component
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NeckComponent = DICOMControlledTerminologyDefinitionsCode("112314")
    """
    Prosthetic Stem and Femoral Head in one piece
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MonoblockStem = DICOMControlledTerminologyDefinitionsCode("112315")
    """
    A proximal attachment to the shaft used to compensate for bone deficiencies or
    bone loss
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ProstheticShaftAugment = DICOMControlledTerminologyDefinitionsCode("112316")
    """
    Artificial femur head surface needed for the partial replacement of the
    femoral head where only the surface is replaced
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FemoralHeadResurfacingComponent = DICOMControlledTerminologyDefinitionsCode(
        "112317"
    )
    """
    Fixation using a pin
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Pinning = DICOMControlledTerminologyDefinitionsCode("112318")
    """
    Fixation sewing several objects together
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Sewing = DICOMControlledTerminologyDefinitionsCode("112319")
    """
    Fixation using a bolt
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Bolting = DICOMControlledTerminologyDefinitionsCode("112320")
    """
    Fixation due to forcing an object into a narrow space
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Wedging = DICOMControlledTerminologyDefinitionsCode("112321")
    """
    Attachment to the distal end of a cemented stem assuring that the stem is in a
    central position inside the drilled femoral canal before cementation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DistalCentralizer = DICOMControlledTerminologyDefinitionsCode("112325")
    """
    Planning by an unspecified 2D method
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Generic2DPlanning = DICOMControlledTerminologyDefinitionsCode("112340")
    """
    Planning by an unspecified 3D method
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Generic3DPlanning = DICOMControlledTerminologyDefinitionsCode("112341")
    """
    Planning of a Hip Replacement, by an unspecified method
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    GenericPlanningForHipReplacement = DICOMControlledTerminologyDefinitionsCode(
        "112342"
    )
    """
    Planning of Knee Replacement, by an unspecified method
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    GenericPlanningForKneeReplacement = DICOMControlledTerminologyDefinitionsCode(
        "112343"
    )
    """
    Planning of Hip Replacement according to the procedure of M. E. Müller [Eggli
    et. al.1998]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    M_llerMethodPlanningForHipReplacement = DICOMControlledTerminologyDefinitionsCode(
        "112344"
    )
    """
    A Report containing the results of an Implantation Planning Activity
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ImplantationPlan = DICOMControlledTerminologyDefinitionsCode("112345")
    """
    A selection of one Implant Component
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SelectedImplantComponent = DICOMControlledTerminologyDefinitionsCode("112346")
    """
    Identification ID of an Implant Component
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ComponentID = DICOMControlledTerminologyDefinitionsCode("112347")
    """
    An implant template describing the properties (2D/3D geometry and other data)
    of one Implant Component
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ImplantTemplate = DICOMControlledTerminologyDefinitionsCode("112348")
    """
    A connection of two Connected Implantation Plan Components
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ComponentConnection = DICOMControlledTerminologyDefinitionsCode("112350")
    """
    ID of a Mating Feature Set in an Implant Component
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MatingFeatureSetID = DICOMControlledTerminologyDefinitionsCode("112351")
    """
    ID of the Mating Feature in a Mating Feature Set in an Implant Component
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MatingFeatureID = DICOMControlledTerminologyDefinitionsCode("112352")
    """
    The Spatial Registration of one or more Implant Components
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SpatialRegistration = DICOMControlledTerminologyDefinitionsCode("112353")
    """
    Patient Images used for an implantation planning activity
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientImage = DICOMControlledTerminologyDefinitionsCode("112354")
    """
    A collection of Component Connections of Implant Components
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Assembly = DICOMControlledTerminologyDefinitionsCode("112355")
    """
    Fiducials that are selected by the user and may or may not belong to
    anatomical landmarks
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    UserSelectedFiducial = DICOMControlledTerminologyDefinitionsCode("112356")
    """
    Fiducials that represent geometric characteristics, such as center of
    rotation, and are derived from other fiducials
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DerivedFiducial = DICOMControlledTerminologyDefinitionsCode("112357")
    """
    All parameters and data that were used for the planning activity
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    InformationUsedForPlanning = DICOMControlledTerminologyDefinitionsCode("112358")
    """
    A description of the plan as encapsulated PDF SOP Instance
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SupportingInformation = DICOMControlledTerminologyDefinitionsCode("112359")
    """
    A list of all Implant Components selected for an implantation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ImplantComponentList = DICOMControlledTerminologyDefinitionsCode("112360")
    """
    Reference to objects containing patient data that is used for planning
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientDataUsedDuringPlanning = DICOMControlledTerminologyDefinitionsCode("112361")
    """
    A specification of the values from one or more Degrees of Freedom
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DegreesOfFreedomSpecification = DICOMControlledTerminologyDefinitionsCode("112362")
    """
    ID of one Degree of Freedom
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DegreeOfFreedomID = DICOMControlledTerminologyDefinitionsCode("112363")
    """
    Reference to objects containing patient data that were not used for planning
    but are somehow related
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RelatedPatientDataNotUsedDuringPlanning = DICOMControlledTerminologyDefinitionsCode(
        "112364"
    )
    """
    Implantation Reports that are somehow related; e.g. contemporaneous
    implantations that are independent
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RelatedImplantationReports = DICOMControlledTerminologyDefinitionsCode("112365")
    """
    Implant Assembly Template
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ImplantAssemblyTemplate = DICOMControlledTerminologyDefinitionsCode("112366")
    """
    Information that is intended to be used intra-operatively
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PlanningInformationForIntraoperativeUsage = (
        DICOMControlledTerminologyDefinitionsCode("112367")
    )
    """
    Position of the patient on the operating room table
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ImplantationPatientPositioning = DICOMControlledTerminologyDefinitionsCode("112368")
    """
    Intended use of the fiducial
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FiducialIntent = DICOMControlledTerminologyDefinitionsCode("112369")
    """
    Type of an Implant Component
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ComponentType = DICOMControlledTerminologyDefinitionsCode("112370")
    """
    Implant Template released by the Manufacturer
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ManufacturerImplantTemplate = DICOMControlledTerminologyDefinitionsCode("112371")
    """
    Images that are created by a planning application
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DerivedPlanningImages = DICOMControlledTerminologyDefinitionsCode("112372")
    """
    Data that is created by a planning application
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OtherDerivedPlanningData = DICOMControlledTerminologyDefinitionsCode("112373")
    """
    One Implant Component that is connected to another Implant Component
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ConnectedImplantationPlanComponent = DICOMControlledTerminologyDefinitionsCode(
        "112374"
    )
    """
    The method used for planning
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PlanningMethod = DICOMControlledTerminologyDefinitionsCode("112375")
    """
    Defines the exact value that was planned for translation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DegreeOfFreedomExactTranslationalValue = DICOMControlledTerminologyDefinitionsCode(
        "112376"
    )
    """
    Defines the minimum value that was planned for translation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DegreeOfFreedomMinimumTranslationalValue = (
        DICOMControlledTerminologyDefinitionsCode("112377")
    )
    """
    Defines the maximum value that was planned for translation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DegreeOfFreedomMaximumTranslationalValue = (
        DICOMControlledTerminologyDefinitionsCode("112378")
    )
    """
    Defines the exact value that was planned for rotation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DegreeOfFreedomExactRotationalTranslationValue = (
        DICOMControlledTerminologyDefinitionsCode("112379")
    )
    """
    Defines the minimum value that was planned for rotation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DegreeOfFreedomMinimumRotationalValue = DICOMControlledTerminologyDefinitionsCode(
        "112380"
    )
    """
    Defines the maximum value that was planned for rotation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DegreeOfFreedomMaximumRotationalValue = DICOMControlledTerminologyDefinitionsCode(
        "112381"
    )
    """
    Procedure step protocol for photographic imaging of surgical procedures,
    including photography of specimens collected
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Peri_operativePhotographicImaging = DICOMControlledTerminologyDefinitionsCode(
        "112700"
    )
    """
    Procedure step protocol for imaging gross specimens, typically with a
    photographic camera (modality XC), and planning further dissection
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    GrossSpecimenImaging = DICOMControlledTerminologyDefinitionsCode("112701")
    """
    Procedure step protocol for imaging slide specimens
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SlideMicroscopy = DICOMControlledTerminologyDefinitionsCode("112702")
    """
    Procedure step protocol for imaging slide specimens using a whole slide
    scanner
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    WholeSlideImaging = DICOMControlledTerminologyDefinitionsCode("112703")
    """
    Procedure step protocol for imaging slide specimens using a whole slide
    scanner with a 20X nominal objective lens, in full color, with a single
    imaging focal plane across the image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    WSI20XRGB = DICOMControlledTerminologyDefinitionsCode("112704")
    """
    Procedure step protocol for imaging slide specimens using a whole slide
    scanner with a 40X nominal objective lens, in full color, with a single
    imaging focal plane across the image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    WSI40XRGB = DICOMControlledTerminologyDefinitionsCode("112705")
    """
    Technique of illuminating specimen
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IlluminationMethod = DICOMControlledTerminologyDefinitionsCode("112706")
    """
    Number of focal planes for a microscopy image acquisition
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NumberOfFocalPlanes = DICOMControlledTerminologyDefinitionsCode("112707")
    """
    Nominal distance above a reference plane (typically a slide glass substrate
    top surface) of the focal plane
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FocalPlaneZOffset = DICOMControlledTerminologyDefinitionsCode("112708")
    """
    Microscope magnification based on nominal objective lens power
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MagnificationSelection = DICOMControlledTerminologyDefinitionsCode("112709")
    """
    Nominal center wavelength for an imaging spectral band
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IlluminationWavelength = DICOMControlledTerminologyDefinitionsCode("112710")
    """
    Name (coded) for an imaging spectral band
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IlluminationSpectralBand = DICOMControlledTerminologyDefinitionsCode("112711")
    """
    Type of filter inserted into the optical imaging path
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OpticalFilterType = DICOMControlledTerminologyDefinitionsCode("112712")
    """
    Technique for identifying tissue to be imaged versus area of slide not to be
    imaged
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TissueSelectionMethod = DICOMControlledTerminologyDefinitionsCode("112713")
    """
    Imaging performed at multiple imaging (focal) planes
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MultiplePlanes = DICOMControlledTerminologyDefinitionsCode("112714")
    """
    Nominal 5 power objective lens, resulting in a digital image at approximately
    2 um/pixel spacing
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    _5X = DICOMControlledTerminologyDefinitionsCode("112715")
    """
    Nominal 10 power objective lens, resulting in a digital image at approximately
    1 um/pixel spacing
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    _10X = DICOMControlledTerminologyDefinitionsCode("112716")
    """
    Nominal 20 power microscope objective lens, resulting in a digital image at
    approximately 0.5 um/pixel spacing
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    _20X = DICOMControlledTerminologyDefinitionsCode("112717")
    """
    Nominal 40 power microscope objective lens, with a combined condenser and
    objective lens numerical aperture of approximately 1.3, resulting in a digital
    image at approximately 0.25 um/pixel spacing
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    _40X = DICOMControlledTerminologyDefinitionsCode("112718")
    """
    Equipment-specific nominal or default method for identifying tiles without
    tissue imaged for suppression from inclusion in image object
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NominalEmptyTileSuppression = DICOMControlledTerminologyDefinitionsCode("112719")
    """
    Equipment-specific high threshold method for identifying tiles without tissue
    imaged for suppression from inclusion in image object
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    HighThresholdEmptyTileSuppression = DICOMControlledTerminologyDefinitionsCode(
        "112720"
    )
    """
    Tiles without tissue imaged are not suppressed from inclusion in image object
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NoEmptyTileSuppression = DICOMControlledTerminologyDefinitionsCode("112721")
    """
    Of Interest
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OfInterest = DICOMControlledTerminologyDefinitionsCode("113000")
    """
    Rejected for Quality Reasons
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RejectedForQualityReasons = DICOMControlledTerminologyDefinitionsCode("113001")
    """
    For Referring Provider
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ForReferringProvider = DICOMControlledTerminologyDefinitionsCode("113002")
    """
    For Surgery
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ForSurgery = DICOMControlledTerminologyDefinitionsCode("113003")
    """
    For Teaching
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ForTeaching = DICOMControlledTerminologyDefinitionsCode("113004")
    """
    For Conference
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ForConference = DICOMControlledTerminologyDefinitionsCode("113005")
    """
    For Therapy
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ForTherapy = DICOMControlledTerminologyDefinitionsCode("113006")
    """
    For Patient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ForPatient = DICOMControlledTerminologyDefinitionsCode("113007")
    """
    For Peer Review
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ForPeerReview = DICOMControlledTerminologyDefinitionsCode("113008")
    """
    For Research
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ForResearch = DICOMControlledTerminologyDefinitionsCode("113009")
    """
    Quality Issue
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    QualityIssue = DICOMControlledTerminologyDefinitionsCode("113010")
    """
    Document Title Modifier
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DocumentTitleModifier = DICOMControlledTerminologyDefinitionsCode("113011")
    """
    Key Object Description
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    KeyObjectDescription = DICOMControlledTerminologyDefinitionsCode("113012")
    """
    A selection that represents the "best" chosen from a larger set of items; e.g.
    the best images within a Study or Series. The criteria against which "best" is
    measured is not defined. Contrast this with the more specific term "Best
    illustration of finding"
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BestInSet = DICOMControlledTerminologyDefinitionsCode("113013")
    """
    A study is a collection of one or more series of medical images, presentation
    states, and/or SR documents that are logically related for the purpose of
    diagnosing a patient. A study may include composite instances that are created
    by a single modality, multiple modalities or by multiple devices of the same
    modality. [From Section A.1.2.2 "Study IE" in PS3.3 ]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Study = DICOMControlledTerminologyDefinitionsCode("113014")
    """
    A distinct logical set used to group composite instances. All instances within
    a Series are of the same modality, in the same Frame of Reference (if any),
    and created by the same equipment. [See Section A.1.2.3 "Series IE" in PS3.3 ]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Series = DICOMControlledTerminologyDefinitionsCode("113015")
    """
    An arbitrarily defined unit of service that has actually been performed (not
    just scheduled). [From Section 7.3.1.9 "Modality Performed Procedure Step" in
    PS3.3 ]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PerformedProcedureStep = DICOMControlledTerminologyDefinitionsCode("113016")
    """
    An image or set of images illustrating a specific stage (phase in a stress
    echo exam protocol) and view (combination of the transducer position and
    orientation at the time of image acquisition)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Stage_View = DICOMControlledTerminologyDefinitionsCode("113017")
    """
    For Printing
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ForPrinting = DICOMControlledTerminologyDefinitionsCode("113018")
    """
    Selection of information objects for attachment to the clinical report of the
    Current Requested Procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ForReportAttachment = DICOMControlledTerminologyDefinitionsCode("113020")
    """
    List of objects that are related to litigation and should be specially
    handled; e.g. may apply if a complaint has been received regarding a patient,
    or a specific set of images has been the subject of a subpoena, and needs to
    be sequestered or excluded from automatic purging according to retention
    policy
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ForLitigation = DICOMControlledTerminologyDefinitionsCode("113021")
    """
    Double exposure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DoubleExposure = DICOMControlledTerminologyDefinitionsCode("113026")
    """
    A list of objects that have been exported out of one organizational domain
    into another domain. Typically, the first domain has no direct control over
    what the second domain will do with the objects
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Manifest = DICOMControlledTerminologyDefinitionsCode("113030")
    """
    A signed list of objects that have been exported out of one organizational
    domain into another domain, referenced securely with either Digital Signatures
    or MACs. Typically, the first domain has no direct control over what the
    second domain will do with the objects
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SignedManifest = DICOMControlledTerminologyDefinitionsCode("113031")
    """
    The list of objects that constitute a study at the time that the list was
    created
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CompleteStudyContent = DICOMControlledTerminologyDefinitionsCode("113032")
    """
    The signed list of objects that constitute a study at the time that the list
    was created, referenced securely with either Digital Signatures or MACs
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SignedCompleteStudyContent = DICOMControlledTerminologyDefinitionsCode("113033")
    """
    The list of objects that were generated in a single procedure step
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CompleteAcquisitionContent = DICOMControlledTerminologyDefinitionsCode("113034")
    """
    The signed list of objects that were generated in a single procedure step,
    referenced securely with either Digital Signatures or MACs
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SignedCompleteAcquisitionContent = DICOMControlledTerminologyDefinitionsCode(
        "113035"
    )
    """
    A list of frames or single-frame or entire multi-frame instances that together
    constitute a set for some purpose, such as might be displayed together in the
    same viewport, as distinct from another set that might be displayed in a
    separate viewport
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    GroupOfFramesForDisplay = DICOMControlledTerminologyDefinitionsCode("113036")
    """
    List of objects whose use is potentially harmful to the patient; e.g. an
    improperly labeled image could lead to dangerous surgical decisions
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RejectedForPatientSafetyReasons = DICOMControlledTerminologyDefinitionsCode(
        "113037"
    )
    """
    List of objects that were acquired using an incorrect modality worklist entry,
    and that should not be used, since they may be incorrectly identified
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IncorrectModalityWorklistEntry = DICOMControlledTerminologyDefinitionsCode("113038")
    """
    List of objects that have expired according to a defined data retention policy
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DataRetentionPolicyExpired = DICOMControlledTerminologyDefinitionsCode("113039")
    """
    Lossy compression has been applied to an image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LossyCompression = DICOMControlledTerminologyDefinitionsCode("113040")
    """
    Values are derived by calculation of the apparent diffusion coefficient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ApparentDiffusionCoefficient = DICOMControlledTerminologyDefinitionsCode("113041")
    """
    Values are derived by the pixel by pixel addition of two images
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PixelByPixelAddition = DICOMControlledTerminologyDefinitionsCode("113042")
    """
    Values are derived by calculation of the diffusion weighting
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DiffusionWeighted = DICOMControlledTerminologyDefinitionsCode("113043")
    """
    Values are derived by calculation of the diffusion anisotropy
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DiffusionAnisotropy = DICOMControlledTerminologyDefinitionsCode("113044")
    """
    Values are derived by calculation of the diffusion attenuation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DiffusionAttenuated = DICOMControlledTerminologyDefinitionsCode("113045")
    """
    Values are derived by the pixel by pixel division of two images
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PixelByPixelDivision = DICOMControlledTerminologyDefinitionsCode("113046")
    """
    Values are derived by the pixel by pixel masking of one image by another
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PixelByPixelMask = DICOMControlledTerminologyDefinitionsCode("113047")
    """
    Values are derived by calculating the pixel by pixel maximum of two or more
    images
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PixelByPixelMaximum = DICOMControlledTerminologyDefinitionsCode("113048")
    """
    Values are derived by calculating the pixel by pixel mean of two or more
    images
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PixelByPixelMean = DICOMControlledTerminologyDefinitionsCode("113049")
    """
    Values are derived by calculating from spectroscopy data pixel values
    localized in two dimensional space based on the concentration of specific
    metabolites (i.e, at specific frequencies)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MetaboliteMapsFromSpectroscopyData = DICOMControlledTerminologyDefinitionsCode(
        "113050"
    )
    """
    Values are derived by calculating the pixel by pixel minimum of two or more
    images
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PixelByPixelMinimum = DICOMControlledTerminologyDefinitionsCode("113051")
    """
    The time required for blood to pass through a region of tissue
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MeanTransitTime = DICOMControlledTerminologyDefinitionsCode("113052")
    """
    Values are derived by the pixel by pixel multiplication of two images
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PixelByPixelMultiplication = DICOMControlledTerminologyDefinitionsCode("113053")
    """
    Values are derived by calculating negative enhancement integral values
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NegativeEnhancementIntegral = DICOMControlledTerminologyDefinitionsCode("113054")
    """
    The flow rate of blood perfusing a region of the brain as volume per mass per
    unit of time
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RegionalCerebralBloodFlow = DICOMControlledTerminologyDefinitionsCode("113055")
    """
    The volume of blood perfusing a region of brain as volume per mass
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RegionalCerebralBloodVolume = DICOMControlledTerminologyDefinitionsCode("113056")
    """
    Correlation Coefficient, r
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    R_Coefficient = DICOMControlledTerminologyDefinitionsCode("113057")
    """
    Values are derived by calculating proton density values
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ProtonDensity = DICOMControlledTerminologyDefinitionsCode("113058")
    """
    Values are derived by calculating signal change values
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SignalChange = DICOMControlledTerminologyDefinitionsCode("113059")
    """
    Values are derived by calculating the signal to noise ratio
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SignalToNoise = DICOMControlledTerminologyDefinitionsCode("113060")
    """
    Values are derived by calculating the standard deviation of two or more images
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StandardDeviation = DICOMControlledTerminologyDefinitionsCode("113061")
    """
    Values are derived by the pixel by pixel subtraction of two images
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PixelByPixelSubtraction = DICOMControlledTerminologyDefinitionsCode("113062")
    """
    Values are derived by calculating T1 values
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    T1 = DICOMControlledTerminologyDefinitionsCode("113063")
    """
    Values are derived by calculating T2* values
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    T2_ = DICOMControlledTerminologyDefinitionsCode("113064")
    """
    Values are derived by calculating T2 values
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    T2 = DICOMControlledTerminologyDefinitionsCode("113065")
    """
    Values are derived by calculating values based on the time course of signal
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TimeCourseOfSignal = DICOMControlledTerminologyDefinitionsCode("113066")
    """
    Values are derived by calculating values based on temperature encoding
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TemperatureEncoded = DICOMControlledTerminologyDefinitionsCode("113067")
    """
    Values are derived by calculating the value of the Student's T-Test statistic
    from multiple image samples
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Student_sT_Test = DICOMControlledTerminologyDefinitionsCode("113068")
    """
    The time from the start of the contrast agent injection to the maximum
    enhancement value
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TimeToPeak = DICOMControlledTerminologyDefinitionsCode("113069")
    """
    Values are derived by calculating values based on velocity encoded; e.g. phase
    contrast
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VelocityEncoded = DICOMControlledTerminologyDefinitionsCode("113070")
    """
    Values are derived by calculating the value of the Z-Score statistic from
    multiple image samples
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Z_Score = DICOMControlledTerminologyDefinitionsCode("113071")
    """
    Values are derived by reformatting in a flat plane other than that originally
    acquired
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MultiplanarReformatting = DICOMControlledTerminologyDefinitionsCode("113072")
    """
    Values are derived by reformatting in a curve plane other than that originally
    acquired
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CurvedMultiplanarReformatting = DICOMControlledTerminologyDefinitionsCode("113073")
    """
    Values are derived by volume rendering of acquired data
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VolumeRendering = DICOMControlledTerminologyDefinitionsCode("113074")
    """
    Values are derived by surface rendering of acquired data
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SurfaceRendering = DICOMControlledTerminologyDefinitionsCode("113075")
    """
    Values are derived by segmentation (classification into tissue types) of
    acquired data
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Segmentation = DICOMControlledTerminologyDefinitionsCode("113076")
    """
    Values are derived by selectively editing acquired data (removing values from
    the volume), such as in order to remove obscuring structures or noise
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VolumeEditing = DICOMControlledTerminologyDefinitionsCode("113077")
    """
    Values are derived by maximum intensity projection of acquired data
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MaximumIntensityProjection = DICOMControlledTerminologyDefinitionsCode("113078")
    """
    Values are derived by minimum intensity projection of acquired data
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MinimumIntensityProjection = DICOMControlledTerminologyDefinitionsCode("113079")
    """
    For single-proton MR spectroscopy, the resonance peak corresponding to
    glutamate and glutamine
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    GlutamateAndGlutamine = DICOMControlledTerminologyDefinitionsCode("113080")
    """
    For single-proton MR spectroscopy, the ratio between the Choline and Creatine
    resonance peaks
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Choline_CreatineRatio = DICOMControlledTerminologyDefinitionsCode("113081")
    """
    For single-proton MR spectroscopy, the ratio between the N-acetylaspartate and
    Creatine resonance peaks
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    N_acetylaspartate_CreatineRatio = DICOMControlledTerminologyDefinitionsCode(
        "113082"
    )
    """
    For single-proton MR spectroscopy, the ratio between the N-acetylaspartate and
    Choline resonance peaks
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    N_acetylaspartate_CholineRatio = DICOMControlledTerminologyDefinitionsCode("113083")
    """
    Values are derived by spatial resampling of acquired data
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SpatialResampling = DICOMControlledTerminologyDefinitionsCode("113085")
    """
    Values are derived by edge enhancement
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EdgeEnhancement = DICOMControlledTerminologyDefinitionsCode("113086")
    """
    Values are derived by smoothing
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Smoothing = DICOMControlledTerminologyDefinitionsCode("113087")
    """
    Values are derived by Gaussian blurring
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    GaussianBlur = DICOMControlledTerminologyDefinitionsCode("113088")
    """
    Values are derived by unsharp masking
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    UnsharpMask = DICOMControlledTerminologyDefinitionsCode("113089")
    """
    Values are derived by stitching two or more images together
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ImageStitching = DICOMControlledTerminologyDefinitionsCode("113090")
    """
    Spatially-related frames in this image are representative frames from the
    referenced 3D volume data set
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Spatially_relatedFramesExtractedFromTheVolume = (
        DICOMControlledTerminologyDefinitionsCode("113091")
    )
    """
    Temporally-related frames in this image are representative frames from the
    referenced 3D volume data set
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Temporally_relatedFramesExtractedFromTheSetOfVolumes = (
        DICOMControlledTerminologyDefinitionsCode("113092")
    )
    """
    Conversion of a polar coordinate image to rectangular (Cartesian) coordinate
    image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PolarToRectangularScanConversion = DICOMControlledTerminologyDefinitionsCode(
        "113093"
    )
    """
    For single-proton MR spectroscopy, the resonance peak corresponding to
    creatine and choline
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CreatineAndCholine = DICOMControlledTerminologyDefinitionsCode("113094")
    """
    For single-proton MR spectroscopy, the resonance peak corresponding to lipid
    and lactate
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LipidAndLactate = DICOMControlledTerminologyDefinitionsCode("113095")
    """
    For single-proton MR spectroscopy, the ratio between the Choline and Creatine
    resonance peak and the Citrate resonance peak
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Creatine_Choline_CitrateRatio = DICOMControlledTerminologyDefinitionsCode("113096")
    """
    Image pixels created through proportional weighting of multiple acquisitions
    at distinct X-Ray energies
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Multi_energyProportionalWeighting = DICOMControlledTerminologyDefinitionsCode(
        "113097"
    )
    """
    De-identification using a profile defined in PS3.15 that requires removing all
    information related to the identity and demographic characteristics of the
    patient, any responsible parties or family members, any personnel involved in
    the procedure, the organizations involved in ordering or performing the
    procedure, additional information that could be used to match instances if
    given access to the originals, such as UIDs, dates and times, and private
    attributes, when that information is present in the non-Pixel Data Attributes,
    including graphics or overlays
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BasicApplicationConfidentialityProfile = DICOMControlledTerminologyDefinitionsCode(
        "113100"
    )
    """
    Additional de-identification according to an option defined in PS3.15 that
    requires any information burned in to the Pixel Data corresponding to the
    Attribute information specified to be removed by the Profile and any other
    Options specified also be removed
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CleanPixelDataOption = DICOMControlledTerminologyDefinitionsCode("113101")
    """
    Additional de-identification according to an option defined in PS3.15 that
    requires that sufficient removal or distortion of the Pixel Data shall be
    applied to prevent recognition of an individual from the instances themselves
    or a reconstruction of a set of instances
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CleanRecognizableVisualFeaturesOption = DICOMControlledTerminologyDefinitionsCode(
        "113102"
    )
    """
    Additional de-identification according to an option defined in PS3.15 that
    requires that any information encoded in graphics, text annotations or
    overlays corresponding to the Attribute information specified to be removed by
    the Profile and any other Options specified also be removed
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CleanGraphicsOption = DICOMControlledTerminologyDefinitionsCode("113103")
    """
    Additional de-identification according to an option defined in PS3.15 that
    requires that any information encoded in SR Content Items or Acquisition
    Context Sequence Items corresponding to the Attribute information specified to
    be removed by the Profile and any other Options specified also be removed
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CleanStructuredContentOption = DICOMControlledTerminologyDefinitionsCode("113104")
    """
    Additional de-identification according to an option defined in PS3.15 that
    requires that any information that is embedded in text or string Attributes
    corresponding to the Attribute information specified to be removed by the
    Profile and any other Options specified also be removed
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CleanDescriptorsOption = DICOMControlledTerminologyDefinitionsCode("113105")
    """
    Retention of information that would otherwise be removed during de-
    identification according to an option defined in PS3.15 that requires that any
    dates and times be retained,
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RetainLongitudinalTemporalInformationFullDatesOption = (
        DICOMControlledTerminologyDefinitionsCode("113106")
    )
    """
    Retention of information that would otherwise be removed during de-
    identification according to an option defined in PS3.15 that requires that any
    dates and times be modified in a manner that preserves temporal relationships;
    e.g. Study Date and Time
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RetainLongitudinalTemporalInformationModifiedDatesOption = (
        DICOMControlledTerminologyDefinitionsCode("113107")
    )
    """
    Retention of information that would otherwise be removed during de-
    identification according to an option defined in PS3.15 that requires that any
    physical characteristics of the patient, which are descriptive rather than
    identifying information per se, be retained; e.g. Patient's Age, Sex, Size
    (height) and Weight
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RetainPatientCharacteristicsOption = DICOMControlledTerminologyDefinitionsCode(
        "113108"
    )
    """
    Retention of information that would otherwise be removed during de-
    identification according to an option defined in PS3.15 that requires that any
    information that identifies a device be retained; e.g. Device Serial Number
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RetainDeviceIdentityOption = DICOMControlledTerminologyDefinitionsCode("113109")
    """
    Retention of information that would otherwise be removed during de-
    identification according to an option defined in PS3.15 that requires that
    UIDs be retained; e.g. SOP Instance UID
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RetainUIDsOption = DICOMControlledTerminologyDefinitionsCode("113110")
    """
    Retention of information that would otherwise be removed during de-
    identification according to an option defined in PS3.15 that requires that
    private attributes that are known not to contain identity information be
    retained; e.g. private SUV scale factor
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RetainSafePrivateOption = DICOMControlledTerminologyDefinitionsCode("113111")
    """
    The procedure report is a Radiopharmaceutical Radiation Dose report
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RadiopharmaceuticalRadiationDoseReport = DICOMControlledTerminologyDefinitionsCode(
        "113500"
    )
    """
    Information pertaining to the administration of a radiopharmaceutical
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RadiopharmaceuticalAdministration = DICOMControlledTerminologyDefinitionsCode(
        "113502"
    )
    """
    Unique identification of a single radiopharmaceutical administration event
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RadiopharmaceuticalAdministrationEventUID = (
        DICOMControlledTerminologyDefinitionsCode("113503")
    )
    """
    Initial signs or symptoms of extravasation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IntravenousExtravasationSymptoms = DICOMControlledTerminologyDefinitionsCode(
        "113505"
    )
    """
    The estimated percentage of administered activity lost at the injection site.
    The estimation includes extravasation, paravenous administration and leakage
    at the injection site
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EstimatedExtravasationActivity = DICOMControlledTerminologyDefinitionsCode("113506")
    """
    The calculated activity at the Radiopharmaceutical Start Time when the
    radiopharmaceutical is administered to the patient. The residual activity
    (i.e. radiopharmaceutical not administered) , if measured, is reflected in the
    calculated value. The estimated extravasation is not reflected in the
    calculated value
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AdministeredActivity = DICOMControlledTerminologyDefinitionsCode("113507")
    """
    Radioactivity measurement of radiopharmaceutical before or during the
    administration
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Pre_AdministrationMeasuredActivity = DICOMControlledTerminologyDefinitionsCode(
        "113508"
    )
    """
    Radioactivity measurement of radiopharmaceutical after the administration
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Post_AdministrationMeasuredActivity = DICOMControlledTerminologyDefinitionsCode(
        "113509"
    )
    """
    Registered drug establishment code for product, coding scheme example is NDC
    or RxNorm
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DrugProductIdentifier = DICOMControlledTerminologyDefinitionsCode("113510")
    """
    The human readable identification of the specific radiopharmaceutical
    dispensed quantity or dose ("dose" as unit of medication delivery, not
    radiation dose measure) to be administered to the patient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RadiopharmaceuticalDispenseUnitIdentifier = (
        DICOMControlledTerminologyDefinitionsCode("113511")
    )
    """
    Identifies the vial, batch or lot number from which the individual dispense
    radiopharmaceutical quantity (dose) is produced. The Radiopharmaceutical
    Dispense Unit Identifier records the identification for each individual dose
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RadiopharmaceuticalLotIdentifier = DICOMControlledTerminologyDefinitionsCode(
        "113512"
    )
    """
    Identifies the lot or unit serial number for the reagent component for the
    radiopharmaceutical
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ReagentVialIdentifier = DICOMControlledTerminologyDefinitionsCode("113513")
    """
    Identifies the lot or unit serial number for the radionuclide component for
    the radiopharmaceutical
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RadionuclideVialIdentifier = DICOMControlledTerminologyDefinitionsCode("113514")
    """
    Administered Product's Prescription Number
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PrescriptionIdentifier = DICOMControlledTerminologyDefinitionsCode("113516")
    """
    Information pertaining to the estimated absorbed radiation dose to an organ
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OrganDoseInformation = DICOMControlledTerminologyDefinitionsCode("113517")
    """
    The absorbed radiation dose to organ
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OrganDose = DICOMControlledTerminologyDefinitionsCode("113518")
    """
    Reference authority MIRD Pamphlet No.1 (rev) ,Society of Nuclear Medicine,
    1976
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MIRDPamphlet1 = DICOMControlledTerminologyDefinitionsCode("113520")
    """
    Reference authority ICRP, 1988. Radiation Dose to Patients from
    Radiopharmaceuticals. ICRP Publication 53. Ann. ICRP 18 (1-4)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ICRPPublication53 = DICOMControlledTerminologyDefinitionsCode("113521")
    """
    Reference authority ICRP, 1998. Radiation Dose to Patients from
    Radiopharmaceuticals (Addendum to ICRP Publication 53). ICRP Publication 80.
    Ann. ICRP 28 (3)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ICRPPublication80 = DICOMControlledTerminologyDefinitionsCode("113522")
    """
    Reference authority ICRP, 2008. Radiation Dose to Patients from
    Radiopharmaceuticals - Addendum 3 to ICRP Publication 53. ICRP Publication
    106. Ann. ICRP 38 (1-2)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ICRPPublication106 = DICOMControlledTerminologyDefinitionsCode("113523")
    """
    Reference authority Stabin MG, Sparks RB, Crowe E (1994) MIRDOSE: personal
    computer software for internal dose assessment in nuclear medicine [Computer
    program]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MIRDOSE = DICOMControlledTerminologyDefinitionsCode("113526")
    """
    Reference authority Stabin MG, Sparks RB, Crowe E (2005) OLINDA/EXM: The
    Second-Generation Personal Computer Software for Internal Dose Assessment in
    Nuclear Medicine [Computer program]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OLINDA_EXM = DICOMControlledTerminologyDefinitionsCode("113527")
    """
    Reference authority The reported organ dose is based on radiopharmaceutical's
    package insert
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PackageInsert = DICOMControlledTerminologyDefinitionsCode("113528")
    """
    Reference authority The reported organ dose is based on Institutionally
    approved estimates from the Radioactive Drug Research Committee (RDRC) of the
    institution itself
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    InstitutionallyApprovedEstimates = DICOMControlledTerminologyDefinitionsCode(
        "113529"
    )
    """
    Reference authority The reported organ dose is based on an Investigation new
    drug
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    InvestigationalNewDrug = DICOMControlledTerminologyDefinitionsCode("113530")
    """
    The type of device that performed the activity measurement
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ActivityMeasurementDevice = DICOMControlledTerminologyDefinitionsCode("113540")
    """
    The device that measures the radiation activity of the radiopharmaceutical
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DoseCalibrator = DICOMControlledTerminologyDefinitionsCode("113541")
    """
    Radiopharmaceutical Infusion System
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    InfusionSystem = DICOMControlledTerminologyDefinitionsCode("113542")
    """
    Radioisotope Generator
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Generator = DICOMControlledTerminologyDefinitionsCode("113543")
    """
    The number hours the patient has gone without food
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FastingDuration = DICOMControlledTerminologyDefinitionsCode("113550")
    """
    The amount of fluids the patient has consumed before the procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    HydrationVolume = DICOMControlledTerminologyDefinitionsCode("113551")
    """
    A description of physical activity the patient performed before the start of
    the procedure, such as that which may affect imaging agent biodistribution
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RecentPhysicalActivity = DICOMControlledTerminologyDefinitionsCode("113552")
    """
    Blockage in one of the tubes (ureters) that drain urine from the kidneys
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AcuteUnilateralRenalBlockage = DICOMControlledTerminologyDefinitionsCode("113560")
    """
    5% or less Thyroid Uptake of Iodine
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LowThyroidUptake = DICOMControlledTerminologyDefinitionsCode("113561")
    """
    25% or higher Thyroid Uptake of Iodine
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    HighThyroidUptake = DICOMControlledTerminologyDefinitionsCode("113562")
    """
    The patient exhibits symptoms severe of jaundice and/or has a Bilirubin >10
    mg/dL
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SeverelyJaundiced = DICOMControlledTerminologyDefinitionsCode("113563")
    """
    Extravasation or paravenous administration of the product is visible in the
    images
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ExtravasationVisibleInImage = DICOMControlledTerminologyDefinitionsCode("113568")
    """
    The measurement method of the Glomerular Filtration Rate is Cockroft-Gault
    Formula
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Cockroft_GaultFormulaEstimationOfGFR = DICOMControlledTerminologyDefinitionsCode(
        "113570"
    )
    """
    The measurement method of the Glomerular Filtration Rate is CKD-EPI Formula
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CKD_EPIFormulaEstimationOfGFR = DICOMControlledTerminologyDefinitionsCode("113571")
    """
    The measurement method of the Glomerular Filtration Rate is MDRD
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    GlomerularFiltrationRate_MDRD_ = DICOMControlledTerminologyDefinitionsCode("113572")
    """
    The measurement method of the Glomerular Filtration Rate is non-black MDRD
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    GlomerularFiltrationRateNon_black_MDRD_ = DICOMControlledTerminologyDefinitionsCode(
        "113573"
    )
    """
    The measurement method of the Glomerular Filtration Rate is black (MDRD)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    GlomerularFiltrationRateBlack_MDRD_ = DICOMControlledTerminologyDefinitionsCode(
        "113574"
    )
    """
    The measurement method of the Glomerular Filtration Rate is female (MDRD)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    GlomerularFiltrationRateFemale_MDRD_ = DICOMControlledTerminologyDefinitionsCode(
        "113575"
    )
    """
    The measurement method of the Glomerular Filtration Rate is Cystatin-based
    formula
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    GlomerularFiltrationRateCystatin_basedFormula = (
        DICOMControlledTerminologyDefinitionsCode("113576")
    )
    """
    The measurement method of the Glomerular Filtration Rate is Creatinine-based
    formula (Schwartz)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    GlomerularFiltrationRateCreatinine_basedFormula_Schwartz_ = (
        DICOMControlledTerminologyDefinitionsCode("113577")
    )
    """
    Small body thickness for calcium scoring adjustment. Lateral thickness is
    measured from skin-to-skin, at the level of the proximal ascending aorta, from
    an A/P localizer image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Small_32_0CmLateralThickness = DICOMControlledTerminologyDefinitionsCode("113601")
    """
    Medium body thickness for calcium scoring adjustment. Lateral thickness is
    measured from skin-to-skin, at the level of the proximal ascending aorta, from
    an A/P localizer image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Medium_32_0_38_0CmLateralThickness = DICOMControlledTerminologyDefinitionsCode(
        "113602"
    )
    """
    Large body thickness for calcium scoring adjustment. Lateral thickness is
    measured from skin-to-skin, at the level of the proximal ascending aorta, from
    an A/P localizer image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Large_38_0CmLateralThickness = DICOMControlledTerminologyDefinitionsCode("113603")
    """
    A human-readable label identifying an irradiation event
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IrradiationEventLabel = DICOMControlledTerminologyDefinitionsCode("113605")
    """
    The type of a human-readable label
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LabelType = DICOMControlledTerminologyDefinitionsCode("113606")
    """
    A number that identifies a Series. Corresponds to (0020,0011) in PS3.3
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SeriesNumber = DICOMControlledTerminologyDefinitionsCode("113607")
    """
    A number that identifies an Acquisition. Corresponds to (0020,0012) in PS3.3
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AcquisitionNumber = DICOMControlledTerminologyDefinitionsCode("113608")
    """
    A number that identifies an Instance. Corresponds to (0020,0013) in PS3.3
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    InstanceNumber = DICOMControlledTerminologyDefinitionsCode("113609")
    """
    Acquisition where the X-Ray source does not move in relation to the patient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StationaryAcquisition = DICOMControlledTerminologyDefinitionsCode("113611")
    """
    Acquisition where the X-Ray source moves laterally in relation to the patient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SteppingAcquisition = DICOMControlledTerminologyDefinitionsCode("113612")
    """
    Acquisition where the X-Ray source moves angularly in relation to the patient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RotationalAcquisition = DICOMControlledTerminologyDefinitionsCode("113613")
    """
    Primary plane of a Biplane acquisition equipment
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PlaneA = DICOMControlledTerminologyDefinitionsCode("113620")
    """
    Secondary plane of a Biplane acquisition equipment
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PlaneB = DICOMControlledTerminologyDefinitionsCode("113621")
    """
    Single plane acquisition equipment
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SinglePlane = DICOMControlledTerminologyDefinitionsCode("113622")
    """
    Continuous X-Ray radiation is applied during an irradiation event
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Continuous = DICOMControlledTerminologyDefinitionsCode("113630")
    """
    Pulsed X-Ray radiation is applied during an irradiation event
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Pulsed = DICOMControlledTerminologyDefinitionsCode("113631")
    """
    Filter with uniform thickness
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StripFilter = DICOMControlledTerminologyDefinitionsCode("113650")
    """
    Filter with variation in thickness from one edge to the opposite edge
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    WedgeFilter = DICOMControlledTerminologyDefinitionsCode("113651")
    """
    Filter with two triangular sections
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ButterflyFilter = DICOMControlledTerminologyDefinitionsCode("113652")
    """
    Filter with uniform thickness that is for spectral filtering only; e.g. filter
    out low energy portion of the X-Ray that would only contribute to skin dose,
    but not to image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FlatFilter = DICOMControlledTerminologyDefinitionsCode("113653")
    """
    A polyline defining the outline of a lobulated finding
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OutlineOfLobulations = DICOMControlledTerminologyDefinitionsCode("113661")
    """
    A polyline defining the inner limits of a finding with fuzzy margin
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    InnerLimitsOfFuzzyMargin = DICOMControlledTerminologyDefinitionsCode("113662")
    """
    A polyline defining the outer limits of a finding with fuzzy margin
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OuterLimitsOfFuzzyMargin = DICOMControlledTerminologyDefinitionsCode("113663")
    """
    A polyline defining the outline of the spiculations of a finding
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OutlineOfSpiculations = DICOMControlledTerminologyDefinitionsCode("113664")
    """
    A polyline segment graphically indicating the location and direction of a
    spiculation of a finding
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LinearSpiculation = DICOMControlledTerminologyDefinitionsCode("113665")
    """
    A collection of points indicating the pixel locations of the spiculations of a
    finding
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PixelatedSpiculations = DICOMControlledTerminologyDefinitionsCode("113666")
    """
    Connected line segments indicating the center of location of a finding on an
    orthogonal view
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OrthogonalLocationArc = DICOMControlledTerminologyDefinitionsCode("113669")
    """
    Connected line segments indicating the inner margin of the location of a
    finding on an orthogonal view
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OrthogonalLocationArcInnerMargin = DICOMControlledTerminologyDefinitionsCode(
        "113670"
    )
    """
    Connected line segments indicating the outer location of a finding on an
    orthogonal view
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OrthogonalLocationArcOuterMargin = DICOMControlledTerminologyDefinitionsCode(
        "113671"
    )
    """
    This procedure is intended to gather data that is used for calibration or
    other quality control purposes
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    QualityControlIntent = DICOMControlledTerminologyDefinitionsCode("113680")
    """
    An artificial subject of an imaging study
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Phantom = DICOMControlledTerminologyDefinitionsCode("113681")
    """
    A phantom acceptable for the ACR Computed Tomography Accreditation program
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ACRAccreditationPhantom_CT = DICOMControlledTerminologyDefinitionsCode("113682")
    """
    A phantom acceptable for the ACR Magnetic Resonance Imaging Accreditation
    program
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ACRAccreditationPhantom_MR = DICOMControlledTerminologyDefinitionsCode("113683")
    """
    A phantom acceptable for the ACR Mammography Accreditation program
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ACRAccreditationPhantom_Mammography = DICOMControlledTerminologyDefinitionsCode(
        "113684"
    )
    """
    A phantom acceptable for the ACR Stereotactic Breast Biopsy Accreditation
    program
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ACRAccreditationPhantom_StereotacticBreastBiopsy = (
        DICOMControlledTerminologyDefinitionsCode("113685")
    )
    """
    A phantom acceptable for the ACR SPECT Accreditation program (but not for PET)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ACRAccreditationPhantom_ECT = DICOMControlledTerminologyDefinitionsCode("113686")
    """
    A phantom acceptable for the ACR PET Accreditation program (but not for SPECT)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ACRAccreditationPhantom_PET = DICOMControlledTerminologyDefinitionsCode("113687")
    """
    A SPECT phantom with a PET faceplate acceptable for both the ACR SPECT and PET
    Accreditation programs
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ACRAccreditationPhantom_ECT_PET = DICOMControlledTerminologyDefinitionsCode(
        "113688"
    )
    """
    A PET faceplate (made to fit an existing flangeless or flanged ECT phantom)
    acceptable for the ACR PET Accreditation program
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ACRAccreditationPhantom_PETFaceplate = DICOMControlledTerminologyDefinitionsCode(
        "113689"
    )
    """
    A phantom used for CTDI measurement in head modes according to IEC 60601-2-44,
    Ed.2.1 (Head 16 cm diameter Polymethyl methacrylate PMMA)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IECHeadDosimetryPhantom = DICOMControlledTerminologyDefinitionsCode("113690")
    """
    A phantom used for CTDI measurement in body modes according to IEC 60601-2-44,
    Ed.2.1 (Body 32cm diameter Polymethyl methacrylate PMMA)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IECBodyDosimetryPhantom = DICOMControlledTerminologyDefinitionsCode("113691")
    """
    A phantom in accordance with NEMA standard XR-21-2000
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NEMAXR21_2000Phantom = DICOMControlledTerminologyDefinitionsCode("113692")
    """
    X-Ray Radiation Dose Report
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    X_RayRadiationDoseReport = DICOMControlledTerminologyDefinitionsCode("113701")
    """
    X-Ray dose data accumulated over multiple irradiation events; e.g. for a study
    or a performed procedure step
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AccumulatedX_RayDoseData = DICOMControlledTerminologyDefinitionsCode("113702")
    """
    Imaging using a point X-Ray source with a diverging beam projected onto a 2
    dimensional detector
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ProjectionX_Ray = DICOMControlledTerminologyDefinitionsCode("113704")
    """
    Entity over which dose accumulation values are integrated
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ScopeOfAccumulation = DICOMControlledTerminologyDefinitionsCode("113705")
    """
    X-Ray dose data for a single Irradiation Event
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IrradiationEventX_RayData = DICOMControlledTerminologyDefinitionsCode("113706")
    """
    Material containing Niobium or a Niobium compound
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NiobiumOrNiobiumCompound = DICOMControlledTerminologyDefinitionsCode("113710")
    """
    Material containing Europium or a Europium compound
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EuropiumOrEuropiumCompound = DICOMControlledTerminologyDefinitionsCode("113711")
    """
    Describes the method used to derive the calibration factor
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CalibrationProtocol = DICOMControlledTerminologyDefinitionsCode("113720")
    """
    Denotes the type of irradiation event recorded
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IrradiationEventType = DICOMControlledTerminologyDefinitionsCode("113721")
    """
    Total calculated Dose Area Product (in the scope of the including report)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DoseAreaProductTotal = DICOMControlledTerminologyDefinitionsCode("113722")
    """
    Last calibration Date for the integrated dose meter or dose calculation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CalibrationDate = DICOMControlledTerminologyDefinitionsCode("113723")
    """
    Individual or organization responsible for calibration
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CalibrationResponsibleParty = DICOMControlledTerminologyDefinitionsCode("113724")
    """
    Total Dose related to Reference Point (RP). (in the scope of the including
    report)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Dose_RP_Total = DICOMControlledTerminologyDefinitionsCode("113725")
    """
    Total calculated Dose Area Product applied in Fluoroscopy Modes (in the scope
    of the including report)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FluoroDoseAreaProductTotal = DICOMControlledTerminologyDefinitionsCode("113726")
    """
    Total calculated Dose Area Product applied in Acquisition Modes (in the scope
    of the including report)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AcquisitionDoseAreaProductTotal = DICOMControlledTerminologyDefinitionsCode(
        "113727"
    )
    """
    Dose applied in Fluoroscopy Modes, related to Reference Point (RP). (in the
    scope of the including report)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FluoroDose_RP_Total = DICOMControlledTerminologyDefinitionsCode("113728")
    """
    Dose applied in Acquisition Modes, related to Reference Point (RP). (in the
    scope of the including report)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AcquisitionDose_RP_Total = DICOMControlledTerminologyDefinitionsCode("113729")
    """
    Total accumulated clock time of Fluoroscopy in the scope of the including
    report (i.e., the sum of the Irradiation Duration values for accumulated
    fluoroscopy irradiation events)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TotalFluoroTime = DICOMControlledTerminologyDefinitionsCode("113730")
    """
    Accumulated Count of exposure pulses (single or multi-frame encoded) created
    from irradiation events performed with high dose (acquisition)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TotalNumberOfRadiographicFrames = DICOMControlledTerminologyDefinitionsCode(
        "113731"
    )
    """
    Mode of application of X-Rays during Fluoroscopy
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FluoroMode = DICOMControlledTerminologyDefinitionsCode("113732")
    """
    Applied X-Ray Tube voltage at peak of X-Ray generation, in kilovolts; Mean
    value if measured over multiple peaks (pulses)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    KVP = DICOMControlledTerminologyDefinitionsCode("113733")
    """
    Mean value of applied Tube Current
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    X_RayTubeCurrent = DICOMControlledTerminologyDefinitionsCode("113734")
    """
    Cumulative time the patient has received X-Ray exposure during the irradiation
    event
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ExposureTime = DICOMControlledTerminologyDefinitionsCode("113735")
    """
    Mean value of X-Ray Current Time product
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Exposure = DICOMControlledTerminologyDefinitionsCode("113736")
    """
    Distance to the Reference Point (RP) defined according to IEC 60601-2-43 or
    equipment defined
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DistanceSourceToReferencePoint = DICOMControlledTerminologyDefinitionsCode("113737")
    """
    Dose applied at the Reference Point (RP)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Dose_RP_ = DICOMControlledTerminologyDefinitionsCode("113738")
    """
    Positioner Primary Angle at the end of an irradiation event. For further
    definition see (112011, DCM, "Positioner Primary Angle")
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PositionerPrimaryEndAngle = DICOMControlledTerminologyDefinitionsCode("113739")
    """
    Positioner Secondary Angle at the end of an irradiation event. For further
    definition see (112012, DCM, "Positioner Secondary Angle")
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PositionerSecondaryEndAngle = DICOMControlledTerminologyDefinitionsCode("113740")
    """
    Clock time from the start of loading time of the first pulse until the loading
    time trailing edge of the final pulse in the same irradiation event. Note
    Loading time is defined in IEC 60601-1-3:2008, 3.37, and described in IEC
    60601-2-54:2009, 203.4.101.3
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IrradiationDuration = DICOMControlledTerminologyDefinitionsCode("113742")
    """
    Orientation of the Patient with respect to Gravity
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientOrientation = DICOMControlledTerminologyDefinitionsCode("113743")
    """
    Enhances or modifies the Patient orientation specified in Patient Orientation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientOrientationModifier = DICOMControlledTerminologyDefinitionsCode("113744")
    """
    Orientation of the Patient with respect to the Head of the Table
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientTableRelationship = DICOMControlledTerminologyDefinitionsCode("113745")
    """
    Distance from the X-Ray Source to the Equipment C-Arm Isocenter.(Center of
    Rotation)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DistanceSourceToIsocenter = DICOMControlledTerminologyDefinitionsCode("113748")
    """
    Measured or calculated distance from the X-Ray source to the detector plane in
    the center of the beam
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DistanceSourceToDetector = DICOMControlledTerminologyDefinitionsCode("113750")
    """
    Table Longitudinal Position with respect to an arbitrary chosen reference by
    the equipment. Table motion towards LAO is positive assuming that the patient
    is positioned supine and its head is in normal position
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TableLongitudinalPosition = DICOMControlledTerminologyDefinitionsCode("113751")
    """
    Table Lateral Position with respect to an arbitrary chosen reference by the
    equipment. Table motion towards CRA is positive assuming that the patient is
    positioned supine and its head is in normal position
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TableLateralPosition = DICOMControlledTerminologyDefinitionsCode("113752")
    """
    Table Height Position with respect to an arbitrary chosen reference by the
    equipment in (mm). Table motion downwards is positive
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TableHeightPosition = DICOMControlledTerminologyDefinitionsCode("113753")
    """
    Angle of the head-feet axis of the table in degrees relative to the horizontal
    plane. Positive values indicate that the head of the table is upwards
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TableHeadTiltAngle = DICOMControlledTerminologyDefinitionsCode("113754")
    """
    Rotation of the table in the horizontal plane (clockwise when looking from
    above the table)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TableHorizontalRotationAngle = DICOMControlledTerminologyDefinitionsCode("113755")
    """
    Angle of the left-right axis of the table in degrees relative to the
    horizontal plane. Positive values indicate that the left of the table is
    upwards
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TableCradleTiltAngle = DICOMControlledTerminologyDefinitionsCode("113756")
    """
    X-Ray absorbing material used in the filter
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    X_RayFilterMaterial = DICOMControlledTerminologyDefinitionsCode("113757")
    """
    The minimum thickness of the X-Ray absorbing material used in the filters
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    X_RayFilterThicknessMinimum = DICOMControlledTerminologyDefinitionsCode("113758")
    """
    Table Longitudinal Position at the end of an irradiation event; see (113751,
    DCM, "Table Longitudinal Position")
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TableLongitudinalEndPosition = DICOMControlledTerminologyDefinitionsCode("113759")
    """
    Table Lateral Position at the end of an irradiation event; see (113752, DCM,
    "Table Lateral Position")
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TableLateralEndPosition = DICOMControlledTerminologyDefinitionsCode("113760")
    """
    Table Height Position at the end of an irradiation event; see (113753, DCM,
    "Table Height Position")
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TableHeightEndPosition = DICOMControlledTerminologyDefinitionsCode("113761")
    """
    Uncertainty of the 'actual' value
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CalibrationUncertainty = DICOMControlledTerminologyDefinitionsCode("113763")
    """
    Identification of Acquisition Plane with Biplane systems
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AcquisitionPlane = DICOMControlledTerminologyDefinitionsCode("113764")
    """
    Nominal Size of Focal Spot of X-Ray Tube
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FocalSpotSize = DICOMControlledTerminologyDefinitionsCode("113766")
    """
    Average X-Ray Tube Current averaged over time for pulse or for continuous
    Fluoroscopy
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AverageX_RayTubeCurrent = DICOMControlledTerminologyDefinitionsCode("113767")
    """
    Number of pulses applied by X-Ray systems during an irradiation event
    (acquisition run or pulsed fluoro)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NumberOfPulses = DICOMControlledTerminologyDefinitionsCode("113768")
    """
    Unique identification of a single irradiation event
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IrradiationEventUID = DICOMControlledTerminologyDefinitionsCode("113769")
    """
    Angle of the X-Ray beam in degree relative to an orthogonal axis to the
    detector plane
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ColumnAngulation = DICOMControlledTerminologyDefinitionsCode("113770")
    """
    Devices used to modify the energy or energy distribution of X-Rays
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    X_RayFilters = DICOMControlledTerminologyDefinitionsCode("113771")
    """
    Type of filter(s) inserted into the X-Ray beam; e.g. wedges
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    X_RayFilterType = DICOMControlledTerminologyDefinitionsCode("113772")
    """
    The maximum thickness of the X-Ray absorbing material used in the filters
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    X_RayFilterThicknessMaximum = DICOMControlledTerminologyDefinitionsCode("113773")
    """
    System provided definition of the Reference Point used for Dose calculations
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ReferencePointDefinition = DICOMControlledTerminologyDefinitionsCode("113780")
    """
    Distance between the collimator blades in pixel column direction as projected
    at the detector plane
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CollimatedFieldHeight = DICOMControlledTerminologyDefinitionsCode("113788")
    """
    Distance between the collimator blades in pixel row direction as projected at
    the detector plane
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CollimatedFieldWidth = DICOMControlledTerminologyDefinitionsCode("113789")
    """
    Collimated field area at image receptor. Area for compatibility with IEC
    60601-2-43
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CollimatedFieldArea = DICOMControlledTerminologyDefinitionsCode("113790")
    """
    Pulse rate applied by equipment during Fluoroscopy
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PulseRate = DICOMControlledTerminologyDefinitionsCode("113791")
    """
    Measured or calculated distance from the X-Ray source to the table plane in
    the center of the beam
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DistanceSourceToTablePlane = DICOMControlledTerminologyDefinitionsCode("113792")
    """
    (Average) X-Ray pulse width
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PulseWidth = DICOMControlledTerminologyDefinitionsCode("113793")
    """
    Calibrated device to perform dose measurements
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DoseMeasurementDevice = DICOMControlledTerminologyDefinitionsCode("113794")
    """
    Image acquired during a specified event
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AcquiredImage = DICOMControlledTerminologyDefinitionsCode("113795")
    """
    Effective Dose evaluation from the product of Dose Length Product (DLP) and
    the Effective Dose Conversion Factor (E/DLP in units of mSv/mGy-cm), where the
    ratio is derived by means of Monte Carlo computations
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DLPToEConversionViaMCComputation = DICOMControlledTerminologyDefinitionsCode(
        "113800"
    )
    """
    Effective Dose evaluation from the product of the Mean CTDIfreeair and the
    ratio E/CTDIfreeair (mSv/mGy), where the ratio is derived by means of Monte
    Carlo computations
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CTDIfreeairToEConversionViaMCComputation = (
        DICOMControlledTerminologyDefinitionsCode("113801")
    )
    """
    Effective Dose evaluation from the product of Dose Length Product (DLP) and
    the Effective Dose Conversion Factor (E/DLP in units of mSv/mGy-cm), where the
    ratio is derived by means of dosimetric measurements with an anthropomorphic
    phantom
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DLPToEConversionViaMeasurement = DICOMControlledTerminologyDefinitionsCode("113802")
    """
    Effective Dose evaluation from the product of the Mean CTDIfreeair and the
    ratio E/CTDIfreeair (mSv/mGy), where the ratio is derived by means of
    dosimetric measurements with an anthropomorphic phantom
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CTDIfreeairToEConversionViaMeasurement = DICOMControlledTerminologyDefinitionsCode(
        "113803"
    )
    """
    The CT acquisition was performed by acquiring single or multi detector data
    while rotating the source about the gantry while the table is not moving.
    Additional slices are acquired by incrementing the table position and again
    rotating the source about the gantry while the table is not moving
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SequencedAcquisition = DICOMControlledTerminologyDefinitionsCode("113804")
    """
    The CT acquisition was performed by holding the source at a constant angle and
    moving the table to obtain a projection image; e.g. localizer
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ConstantAngleAcquisition = DICOMControlledTerminologyDefinitionsCode("113805")
    """
    The CT acquisition was performed by holding the table at a constant position
    and acquiring multiple slices over time at the same location
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StationaryAcquisition = DICOMControlledTerminologyDefinitionsCode("113806")
    """
    The CT acquisition was performed while rotating the source about the gantry
    while the table movement is under direct control of a human operator or under
    the control of an analysis application; e.g. fluoro
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FreeAcquisition = DICOMControlledTerminologyDefinitionsCode("113807")
    """
    Reference authority 1990 Recommendations of the International Commission on
    Radiological Protection (ICRP Publication 60, published as the Annals of the
    ICRP Vol. 21, No. 1-3, Pergamon Press,1991)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ICRPPub60 = DICOMControlledTerminologyDefinitionsCode("113808")
    """
    Start, DateTime of the first X-Ray Irradiation Event of the accumulation
    within a Study
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StartOfX_RayIrradiation = DICOMControlledTerminologyDefinitionsCode("113809")
    """
    End, DateTime of the last X-Ray Irradiation Event of the accumulation within a
    Study
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EndOfX_RayIrradiation = DICOMControlledTerminologyDefinitionsCode("113810")
    """
    X-Ray dose accumulated over multiple CT irradiation events; e.g. for a study
    or a performed procedure step
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CTAccumulatedDoseData = DICOMControlledTerminologyDefinitionsCode("113811")
    """
    Total number of events during the defined scope of accumulation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TotalNumberOfIrradiationEvents = DICOMControlledTerminologyDefinitionsCode("113812")
    """
    The total dose length product defined scope of accumulation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CTDoseLengthProductTotal = DICOMControlledTerminologyDefinitionsCode("113813")
    """
    The total Effective Dose at the defined scope of accumulation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CTEffectiveDoseTotal = DICOMControlledTerminologyDefinitionsCode("113814")
    """
    Identification of the reference-patient model used when Effective Dose is
    evaluated via Monte Carlo calculations or from a Dose Length Product
    conversion factor based on Monte Carlo calculations
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientModel = DICOMControlledTerminologyDefinitionsCode("113815")
    """
    References the physical phantom and the type of dosimeter used when
    measurements are done to establish Effective Dose Conversion Factors (E/DLP)
    or ratios E/CTDIfreeair
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ConditionEffectiveDoseMeasured = DICOMControlledTerminologyDefinitionsCode("113816")
    """
    Type of Effective Dose phantom used
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EffectiveDosePhantomType = DICOMControlledTerminologyDefinitionsCode("113817")
    """
    Type of dosimeter used
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DosimeterType = DICOMControlledTerminologyDefinitionsCode("113818")
    """
    General description of the CT Irradiation event
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CTAcquisition = DICOMControlledTerminologyDefinitionsCode("113819")
    """
    Method of the CT acquisition
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CTAcquisitionType = DICOMControlledTerminologyDefinitionsCode("113820")
    """
    Thickness of an equivalent filter in mm in Aluminum
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    X_RayFilterAluminumEquivalent = DICOMControlledTerminologyDefinitionsCode("113821")
    """
    General description of the acquisition parameters
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CTAcquisitionParameters = DICOMControlledTerminologyDefinitionsCode("113822")
    """
    Number of X-Ray sources
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NumberOfX_RaySources = DICOMControlledTerminologyDefinitionsCode("113823")
    """
    Total time the patient has received X-Ray exposure during the irradiation
    event
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ExposureTime = DICOMControlledTerminologyDefinitionsCode("113824")
    """
    Length of the table travel during the entire tube loading, according to IEC
    60601-2-44 Note Scanning Length might be longer than the programmed
    acquisition length (Length of Reconstructable Volume)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ScanningLength = DICOMControlledTerminologyDefinitionsCode("113825")
    """
    The value of the nominal width referenced to the location of the isocenter
    along the z axis of a single row of acquired data in mm
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NominalSingleCollimationWidth = DICOMControlledTerminologyDefinitionsCode("113826")
    """
    The value of the nominal width referenced to the location of the isocenter
    along the z axis of the total collimation in mm over the area of active X-Ray
    detection
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NominalTotalCollimationWidth = DICOMControlledTerminologyDefinitionsCode("113827")
    """
    For Spiral scanning: Pitch Factor = (Table Feed per Rotation (mm)) /(Nominal
    Total Collimation Width (mm)) For Sequenced scanning: Pitch Factor = (Table
    Feed per single Sequenced scan (mm)) /(Nominal Total Collimation Width (mm))
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PitchFactor = DICOMControlledTerminologyDefinitionsCode("113828")
    """
    General description of CT dose values
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CTDose = DICOMControlledTerminologyDefinitionsCode("113829")
    """
    "Mean CTDIvol" refers to the average value of the CTDIvol associated with this
    acquisition
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MeanCTDIvol = DICOMControlledTerminologyDefinitionsCode("113830")
    """
    Identification, tube-potential, tube-current, and exposure-time parameters
    associated with an X-Ray source during an acquisition
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CTX_RaySourceParameters = DICOMControlledTerminologyDefinitionsCode("113831")
    """
    Identifies the particular X-Ray source (in a multi-source CT system) for which
    the set of X-Ray source parameter values is reported
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IdentificationOfTheX_RaySource = DICOMControlledTerminologyDefinitionsCode("113832")
    """
    Maximum X-Ray tube current
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MaximumX_RayTubeCurrent = DICOMControlledTerminologyDefinitionsCode("113833")
    """
    The exposure time for one rotation of the source around the object in s
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ExposureTimePerRotation = DICOMControlledTerminologyDefinitionsCode("113834")
    """
    A label describing the type of phantom used for CTDIW measurement according to
    IEC 60601-2-44 (Head 16 cm diameter PMMA, Body 32 cm diameter PMMA)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CTDIwPhantomType = DICOMControlledTerminologyDefinitionsCode("113835")
    """
    The CTDIfreeair Calculation Factor is the CTDIfreeair per mAs, expressed in
    units of mGy/mAs. The CTDIfreeair Calculation Factor may be used in one method
    calculating Dose
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CTDIfreeairCalculationFactor = DICOMControlledTerminologyDefinitionsCode("113836")
    """
    The average value of the free-in-air CTDI associated with this acquisition
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MeanCTDIfreeair = DICOMControlledTerminologyDefinitionsCode("113837")
    """
    Dose Length Product (DLP), expressed in mGy-cm, is an index characterizing the
    product of the CTDIvol and the length scanned. For Spiral scanning, DLP =
    CTDIvol x Scanning Length. For Sequenced scanning, DLP = CTDIvol x Nominal
    Total Collimation Width x Cumulative Exposure Time / Exposure Time per
    Rotation. For Stationary and Free scanning, DLP = CTDIvol x Nominal Total
    Collimation Width
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DLP = DICOMControlledTerminologyDefinitionsCode("113838")
    """
    Effective dose in mSv
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EffectiveDose = DICOMControlledTerminologyDefinitionsCode("113839")
    """
    Effective Dose per DLP, reference value for Effective Dose calculation,
    expressed in mSv/mGY.cm
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EffectiveDoseConversionFactor = DICOMControlledTerminologyDefinitionsCode("113840")
    """
    Effective Dose Reference authority 2007 Recommendations of the International
    Commission on Radiological Protection (ICRP Publication 103, published as the
    Annals of the ICRP Vol. 37, No. 2-4, Elsevier, 2007)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ICRPPub103 = DICOMControlledTerminologyDefinitionsCode("113841")
    """
    The type of exposure modulation used for the purpose of limiting the dose
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    X_RayModulationType = DICOMControlledTerminologyDefinitionsCode("113842")
    """
    Measure of the detector response to radiation in the relevant image region of
    an image acquired with a digital X-Ray imaging system as defined in IEC
    62494-1; see PS3.3 definition of Exposure Index Macro
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ExposureIndex = DICOMControlledTerminologyDefinitionsCode("113845")
    """
    The target value used to calculate the Deviation Index as defined in IEC
    62494-1; see PS3.3 definition of Exposure Index Macro
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TargetExposureIndex = DICOMControlledTerminologyDefinitionsCode("113846")
    """
    A scaled representation of the accuracy of the Exposure Index compared to the
    Target Exposure Index as defined in IEC 62494-1; see PS3.3 definition of
    Exposure Index Macro
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DeviationIndex = DICOMControlledTerminologyDefinitionsCode("113847")
    """
    The clinician responsible for determining that the irradiating procedure was
    appropriate for the indications
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IrradiationAuthorizing = DICOMControlledTerminologyDefinitionsCode("113850")
    """
    The person responsible for the administration of radiation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IrradiationAdministering = DICOMControlledTerminologyDefinitionsCode("113851")
    """
    An irradiation event is the loading of X-Ray equipment caused by a single
    continuous actuation of the equipment's irradiation switch, from the start of
    the loading time of the first pulse until the loading time trailing edge of
    the final pulse. Any automatic on-off switching of the irradiation source
    during the event is not treated as separate events, rather the event includes
    the time between start and stop of irradiation as triggered by the user; e.g.
    a pulsed fluoro X-Ray acquisition shall be treated as a single irradiation
    event
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IrradiationEvent = DICOMControlledTerminologyDefinitionsCode("113852")
    """
    Unique Identifier of an Irradiation Event
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IrradiationEventUID = DICOMControlledTerminologyDefinitionsCode("113853")
    """
    Method by which dose-related details of an Irradiation Event were obtained
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SourceOfDoseInformation = DICOMControlledTerminologyDefinitionsCode("113854")
    """
    Total accumulated acquisition clock time in the scope of the including report
    (i.e., the sum of the Irradiation Duration values for accumulated acquisition
    irradiation events)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TotalAcquisitionTime = DICOMControlledTerminologyDefinitionsCode("113855")
    """
    Direct recording of data by a relevant system
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AutomatedDataCollection = DICOMControlledTerminologyDefinitionsCode("113856")
    """
    Recording of data by a human operator, including manual transcription of
    electronic data
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ManualEntry = DICOMControlledTerminologyDefinitionsCode("113857")
    """
    The data is taken from an MPPS SOP Instance
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MPPSContent = DICOMControlledTerminologyDefinitionsCode("113858")
    """
    A device exposing a patient to ionizing radiation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IrradiatingDevice = DICOMControlledTerminologyDefinitionsCode("113859")
    """
    15cm from the isocenter towards the X-Ray source; See IEC 60601-2-43
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    _15cmFromIsocenterTowardSource = DICOMControlledTerminologyDefinitionsCode("113860")
    """
    30cm in front (towards the tube) of the input surface of the image receptor;
    See FDA Federal Performance Standard for Diagnostic X-Ray Systems §1020.32(d)
    (7)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    _30cmInFrontOfImageInputSurface = DICOMControlledTerminologyDefinitionsCode(
        "113861"
    )
    """
    1cm above the patient tabletop or cradle; See FDA Federal Performance Standard
    for Diagnostic X-Ray Systems §1020.32(d) (7)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    _1cmAboveTabletop = DICOMControlledTerminologyDefinitionsCode("113862")
    """
    30cm above the patient tabletop of cradle; See FDA Federal Performance
    Standard for Diagnostic X-Ray Systems §1020.32(d) (7)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    _30cmAboveTabletop = DICOMControlledTerminologyDefinitionsCode("113863")
    """
    15cm from the centerline of the X-Ray table and in the direction of the X-Ray
    source; See FDA Federal Performance Standard for Diagnostic X-Ray Systems
    §1020.32(d) (7)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    _15cmFromTableCenterline = DICOMControlledTerminologyDefinitionsCode("113864")
    """
    Standard breast means a 4.2 centimeter (cm) thick compressed breast consisting
    of 50 percent glandular and 50 percent adipose tissue. See Department of
    Health and Human Services, Food and Drug Administration. Mammography quality
    standards; final rule. Federal Register. Oct. 28, 1997; 68(208):55852-55994;
    see 900.2(uu)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EntranceExposureToA4_2CmBreastThickness = DICOMControlledTerminologyDefinitionsCode(
        "113865"
    )
    """
    The data is copied from information present in the image attributes; e.g. dose
    attributes such as CTDIvol (0018,9345)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CopiedFromImageAttributes = DICOMControlledTerminologyDefinitionsCode("113866")
    """
    The data is computed from information present in the image attributes; e.g. by
    using dosimetry information for the specific irradiating device make and
    model, applied to technique information such as KVP and mAs
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ComputedFromImageAttributes = DICOMControlledTerminologyDefinitionsCode("113867")
    """
    The data is derived from human-readable reports; e.g. by natural language
    parsing of text reports, or optical character recognition from reports saved
    as images by the irradiating device
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DerivedFromHuman_ReadableReports = DICOMControlledTerminologyDefinitionsCode(
        "113868"
    )
    """
    The name of a specific person
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PersonName = DICOMControlledTerminologyDefinitionsCode("113870")
    """
    An identification number or code for a specific person
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PersonID = DICOMControlledTerminologyDefinitionsCode("113871")
    """
    The organization that issued a Person ID
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PersonIDIssuer = DICOMControlledTerminologyDefinitionsCode("113872")
    """
    The name of an organization
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OrganizationName = DICOMControlledTerminologyDefinitionsCode("113873")
    """
    The role played by a person in an organization
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PersonRoleInOrganization = DICOMControlledTerminologyDefinitionsCode("113874")
    """
    The role played by a person in a procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PersonRoleInProcedure = DICOMControlledTerminologyDefinitionsCode("113875")
    """
    The role played by a device in a procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DeviceRoleInProcedure = DICOMControlledTerminologyDefinitionsCode("113876")
    """
    The name used to refer to a device; usually locally unique
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DeviceName = DICOMControlledTerminologyDefinitionsCode("113877")
    """
    Manufacturer of a device
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DeviceManufacturer = DICOMControlledTerminologyDefinitionsCode("113878")
    """
    Model Name of a device
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DeviceModelName = DICOMControlledTerminologyDefinitionsCode("113879")
    """
    Serial Number of a device
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DeviceSerialNumber = DICOMControlledTerminologyDefinitionsCode("113880")
    """
    All planes of a multi-plane acquisition equipment
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AllPlanes = DICOMControlledTerminologyDefinitionsCode("113890")
    """
    The length from which images may be reconstructed (i.e., excluding any
    overranging performed in a spiral acquisition that is required for data
    interpolation). Value is distinct from (1113825, DCM, "Scanning Length"),
    which is the actual length of the table travel during the entire tube loading,
    according to IEC 60601-2-44, and includes overranging. Also distinct from any
    actual Reconstructed Volume, which may depend on the slice thickness chosen
    for a particular reconstruction
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LengthOfReconstructableVolume = DICOMControlledTerminologyDefinitionsCode("113893")
    """
    The Z location that is the top (highest Z value) of the Reconstructable
    Volume. Specified as the Z component within the Patient Coordinate System
    defined by a specified Frame of Reference
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TopZLocationOfReconstructableVolume = DICOMControlledTerminologyDefinitionsCode(
        "113895"
    )
    """
    The Z location that is the bottom (lowest Z value) of the Reconstructable
    Volume. Specified as the Z component within the Patient Coordinate System
    defined by a specified Frame of Reference
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BottomZLocationOfReconstructableVolume = DICOMControlledTerminologyDefinitionsCode(
        "113896"
    )
    """
    The Z location that is the top (highest Z value) of the scanning length.
    Specified as the Z component within the Patient Coordinate System defined by a
    specified Frame of Reference
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TopZLocationOfScanningLength = DICOMControlledTerminologyDefinitionsCode("113897")
    """
    The Z location that is the bottom (lowest Z value) of the scanning length.
    Specified as the Z component within the Patient Coordinate System defined by a
    specified Frame of Reference
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BottomZLocationOfScanningLength = DICOMControlledTerminologyDefinitionsCode(
        "113898"
    )
    """
    The range along the z axis of the total volume irradiated, per IEC 60601-2-44,
    Ed. 3, 203.115(b). The start and stop of loading corresponding to the outer
    edge of the full width half maximum of the free-in-air dose profile for the
    beam collimation used
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ExposedRange = DICOMControlledTerminologyDefinitionsCode("113899")
    """
    Report section about cumulative dose alerts during an examination
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DoseCheckAlertDetails = DICOMControlledTerminologyDefinitionsCode("113900")
    """
    Flag denoting whether a DLP Alert Value was configured
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DLPAlertValueConfigured = DICOMControlledTerminologyDefinitionsCode("113901")
    """
    Flag denoting whether a CTDIvol Alert Value was configured
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CTDIvolAlertValueConfigured = DICOMControlledTerminologyDefinitionsCode("113902")
    """
    Cumulative Dose Length Product value configured to trigger an alert; see NEMA
    XR 25-2010 Dose Check Standard
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DLPAlertValue = DICOMControlledTerminologyDefinitionsCode("113903")
    """
    Cumulative CTDIvol value configured to trigger an alert; see NEMA XR 25-2010
    Dose Check Standard
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CTDIvolAlertValue = DICOMControlledTerminologyDefinitionsCode("113904")
    """
    A forward estimate of the accumulated DLP plus the estimated DLP for the next
    Protocol Element Group; see NEMA XR 25-2010 Dose Check Standard
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AccumulatedDLPForwardEstimate = DICOMControlledTerminologyDefinitionsCode("113905")
    """
    A forward estimate at a given location of the accumulated CTDIvol plus the
    estimated CTDIvol for the next Protocol Element Group; see NEMA XR 25-2010
    Dose Check Standard
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AccumulatedCTDIvolForwardEstimate = DICOMControlledTerminologyDefinitionsCode(
        "113906"
    )
    """
    Reason provided for proceeding with a procedure that is projected to exceed a
    configured dose value
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ReasonForProceeding = DICOMControlledTerminologyDefinitionsCode("113907")
    """
    Report section about dose notifications during a protocol element
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DoseCheckNotificationDetails = DICOMControlledTerminologyDefinitionsCode("113908")
    """
    Flag denoting whether a DLP Notification Value was configured
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DLPNotificationValueConfigured = DICOMControlledTerminologyDefinitionsCode("113909")
    """
    Flag denoting whether a CTDIvol Notification Value was configured
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CTDIvolNotificationValueConfigured = DICOMControlledTerminologyDefinitionsCode(
        "113910"
    )
    """
    Dose Length Product value configured to trigger a notification for a given
    protocol element
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DLPNotificationValue = DICOMControlledTerminologyDefinitionsCode("113911")
    """
    CTDIvol value configured to trigger a notification for a given protocol
    element
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CTDIvolNotificationValue = DICOMControlledTerminologyDefinitionsCode("113912")
    """
    A forward estimate of the DLP for the next Protocol Element Group; see NEMA XR
    25-2010 Dose Check Standard
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DLPForwardEstimate = DICOMControlledTerminologyDefinitionsCode("113913")
    """
    A forward estimate of the CTDIvol for the next Protocol Element Group; see
    NEMA XR 25-2010 Dose Check Standard
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CTDIvolForwardEstimate = DICOMControlledTerminologyDefinitionsCode("113914")
    """
    The amount of ionizing radiation to which the patient was exposed
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RadiationExposure = DICOMControlledTerminologyDefinitionsCode("113921")
    """
    Type, amount and route of radioactive substance administered
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RadioactiveSubstanceAdministered = DICOMControlledTerminologyDefinitionsCode(
        "113922"
    )
    """
    Exposure to ionizing radiation and associated preventive measures used to
    reduce the exposure of parts of the body like lead apron or eye, thyroid gland
    or gonad protection
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RadiationExposureAndProtectionInformation = (
        DICOMControlledTerminologyDefinitionsCode("113923")
    )
    """
    The Size-Specific Dose Estimate is a patient dose estimate that takes into
    account the size of the patient, such as described in AAPM Report 204 by using
    linear dimensions measured on the patient or patient images or estimated from
    patient age
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SizeSpecificDoseEstimation = DICOMControlledTerminologyDefinitionsCode("113930")
    """
    The side-to-side (left to right) dimension of the body part being scanned (per
    AAPM Report 204)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MeasuredLateralDimension = DICOMControlledTerminologyDefinitionsCode("113931")
    """
    The thickness of the body part being scanned, in the antero-posterior
    dimension (per AAPM Report 204)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MeasuredAPDimension = DICOMControlledTerminologyDefinitionsCode("113932")
    """
    The diameter of the patient at a given location along the Z-axis of the
    patient, assuming that the patient has a circular cross-section (per AAPM
    Report 204)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DerivedEffectiveDiameter = DICOMControlledTerminologyDefinitionsCode("113933")
    """
    The Size Specific Dose Estimation is computed using Table 1B (32cm phantom) or
    Table 2B (16cm phantom) of AAPM Report 204
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AAPM204LateralDimension = DICOMControlledTerminologyDefinitionsCode("113934")
    """
    The Size Specific Dose Estimation is computed using Table 1C (32cm phantom) or
    Table 2C (16cm phantom) of AAPM Report 204
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AAPM204APDimension = DICOMControlledTerminologyDefinitionsCode("113935")
    """
    The Size Specific Dose Estimation is computed using Table 1A (32cm phantom) or
    Table 2A (16cm phantom) of AAPM Report 204
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AAPM204SumOfLateralAndAPDimension = DICOMControlledTerminologyDefinitionsCode(
        "113936"
    )
    """
    The Size Specific Dose Estimation is computed using Table 1D (32cm phantom) or
    Table 2D (16cm phantom) using an effective diameter estimated from the
    patient's age using Table 3 of AAPM Report 204
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AAPM204EffectiveDiameterEstimatedFromPatientAge = (
        DICOMControlledTerminologyDefinitionsCode("113937")
    )
    """
    Values calculated from other existing parameters
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SystemCalculated = DICOMControlledTerminologyDefinitionsCode("113940")
    """
    A segmented region of the detector surface within the irradiated area (but
    might not be near the center of the detector)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    InDetectorPlane = DICOMControlledTerminologyDefinitionsCode("113941")
    """
    A device that creates digital images from X-Ray detectors (Direct, Indirect or
    Storage)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    X_RayReadingDevice = DICOMControlledTerminologyDefinitionsCode("113942")
    """
    Parameters related to the X-Ray source (generator, tube, etc.) are available
    to the recording application
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    X_RaySourceDataAvailable = DICOMControlledTerminologyDefinitionsCode("113943")
    """
    Parameters related to the X-Ray Mechanical System (Stand, Table) are available
    to the recording application
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    X_RayMechanicalDataAvailable = DICOMControlledTerminologyDefinitionsCode("113944")
    """
    Parameters related to the X-Ray Detector are available to the recording
    application
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    X_RayDetectorDataAvailable = DICOMControlledTerminologyDefinitionsCode("113945")
    """
    Describes the radiographic method of patient, tube and detector positioning to
    achieve a well described projection or view
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ProjectionEponymousName = DICOMControlledTerminologyDefinitionsCode("113946")
    """
    Type of Detector used to acquire data; e.g. Images
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DetectorType = DICOMControlledTerminologyDefinitionsCode("113947")
    """
    Detector that directly transforms the input signal to pixel values
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DirectDetector = DICOMControlledTerminologyDefinitionsCode("113948")
    """
    Detector that transforms an intermediate signal into pixel values; e.g. a
    scintillator-based detector
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IndirectDetector = DICOMControlledTerminologyDefinitionsCode("113949")
    """
    Storage detector that stores a signal that is later transformed by a reader
    into pixel values; e.g. a phosphor-based detector
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StorageDetector = DICOMControlledTerminologyDefinitionsCode("113950")
    """
    Film that is scanned to create pixel values
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Film = DICOMControlledTerminologyDefinitionsCode("113951")
    """
    The cassette/detector is mounted in the patient table
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TableMount = DICOMControlledTerminologyDefinitionsCode("113952")
    """
    The cassette/detector is not mounted.; e.g. a cassette placed underneath the
    patient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    UnmountedDetector = DICOMControlledTerminologyDefinitionsCode("113953")
    """
    The cassette/detector is mounted in an upright stand
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    UprightStandMount = DICOMControlledTerminologyDefinitionsCode("113954")
    """
    The cassette/detector is mounted on a c-arm
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    C_ArmMount = DICOMControlledTerminologyDefinitionsCode("113955")
    """
    Method of mounting or positioning a CR/DR cassette or detector
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CR_DRMechanicalConfiguration = DICOMControlledTerminologyDefinitionsCode("113956")
    """
    An integrated projection radiography system capable of fluoroscopy
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Fluoroscopy_GuidedProjectionRadiographySystem = (
        DICOMControlledTerminologyDefinitionsCode("113957")
    )
    """
    A projection radiography system where the X-Ray detector, X-Ray Source and
    gantry components are integrated and the managing system is able to access
    details of each component
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IntegratedProjectionRadiographySystem = DICOMControlledTerminologyDefinitionsCode(
        "113958"
    )
    """
    A projection radiography system where the X-Ray detector, X-Ray Source and
    gantry components are not integrated; e.g. cassette-based CR and DR systems
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Cassette_basedProjectionRadiographySystem = (
        DICOMControlledTerminologyDefinitionsCode("113959")
    )
    """
    Description of the algorithm used when reconstructing the image from the data
    acquired during the acquisition process
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ReconstructionAlgorithm = DICOMControlledTerminologyDefinitionsCode("113961")
    """
    An algorithm for reconstructing an image from multiple projections by back-
    projecting the measured values along the line of the projection and filtering
    the result to reduce blurring
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FilteredBackProjection = DICOMControlledTerminologyDefinitionsCode("113962")
    """
    An algorithm for reconstructing an image from multiple projections by starting
    with an assumed reconstructed image, computing projections from the image,
    comparing the original projection data and updating the reconstructed image
    based upon the difference between the calculated and the actual projections
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IterativeReconstruction = DICOMControlledTerminologyDefinitionsCode("113963")
    """
    The period of time from the start of a Procedure Step until the time point
    established by the context of the reference
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ProcedureStepToThisPoint = DICOMControlledTerminologyDefinitionsCode("113970")
    """
    Measurement not available: Not a number (per IEEE 754)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NotANumber = DICOMControlledTerminologyDefinitionsCode("114000")
    """
    Measurement not available: Negative Infinity (per IEEE 754)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NegativeInfinity = DICOMControlledTerminologyDefinitionsCode("114001")
    """
    Measurement not available: Positive Infinity (per IEEE 754)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PositiveInfinity = DICOMControlledTerminologyDefinitionsCode("114002")
    """
    Measurement not available: Divide by zero (per IEEE 754)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DivideByZero = DICOMControlledTerminologyDefinitionsCode("114003")
    """
    Measurement not available: Underflow (per IEEE 754)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Underflow = DICOMControlledTerminologyDefinitionsCode("114004")
    """
    Measurement not available: Overflow (per IEEE 754)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Overflow = DICOMControlledTerminologyDefinitionsCode("114005")
    """
    Measurement not available: Measurement failure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MeasurementFailure = DICOMControlledTerminologyDefinitionsCode("114006")
    """
    Measurement not available: Measurement not attempted
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MeasurementNotAttempted = DICOMControlledTerminologyDefinitionsCode("114007")
    """
    Measurement not available: Calculation failure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CalculationFailure = DICOMControlledTerminologyDefinitionsCode("114008")
    """
    Measurement not available: Value out of range
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ValueOutOfRange = DICOMControlledTerminologyDefinitionsCode("114009")
    """
    Measurement not available: Value unknown
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ValueUnknown = DICOMControlledTerminologyDefinitionsCode("114010")
    """
    Measurement not available: Value indeterminate
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ValueIndeterminate = DICOMControlledTerminologyDefinitionsCode("114011")
    """
    Measures the time-of-flight of a light signal between the camera and the
    subject for each point of the image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TimeOfFlight = DICOMControlledTerminologyDefinitionsCode("114201")
    """
    Interferometry is a family of techniques in which waves are superimposed in
    order to extract depth information about the scanned object
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Interferometry = DICOMControlledTerminologyDefinitionsCode("114202")
    """
    Laser scanning describes the general method to sample or scan a surface using
    laser technology
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LaserScanning = DICOMControlledTerminologyDefinitionsCode("114203")
    """
    Projecting a narrow band of light onto a three-dimensionally shaped surface
    produces a line of illumination that appears distorted from other perspectives
    than that of the projector. It can be used for an exact geometric
    reconstruction of the surface shape
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatternProjection = DICOMControlledTerminologyDefinitionsCode("114204")
    """
    A technique for estimating the surface normal of an object by observing that
    object under different lighting conditions
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ShapeFromShading = DICOMControlledTerminologyDefinitionsCode("114205")
    """
    A technique for estimating the surface normal of an object by observing that
    object under different motions
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ShapeFromMotion = DICOMControlledTerminologyDefinitionsCode("114206")
    """
    An optical imaging technique used to increase optical resolution and contrast
    of a micrograph by using point illumination and a spatial pinhole to eliminate
    out-of-focus light in specimens that are thicker than the focal plane. It
    enables the reconstruction of 3D structures from the obtained images
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ConfocalImaging = DICOMControlledTerminologyDefinitionsCode("114207")
    """
    Point cloud that was calculated by an algorithm
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PointCloudAlgorithmic = DICOMControlledTerminologyDefinitionsCode("114208")
    """
    Scanning the object from different views by placing it on a rotating table
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TurntableScanMethod = DICOMControlledTerminologyDefinitionsCode("114209")
    """
    Higher resolution with a longer acquisition time
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    HighResolution = DICOMControlledTerminologyDefinitionsCode("114210")
    """
    Lower resolution with a shorter acquisition time
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FastMode = DICOMControlledTerminologyDefinitionsCode("114211")
    """
    An algorithm employed to minimize the difference between two clouds of points.
    It iteratively revises the transformation (translation, rotation) needed to
    minimize the distance between the points of two point clouds
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IterativeClosestPoint = DICOMControlledTerminologyDefinitionsCode("114213")
    """
    Human controlled minimization of the distance between the points of two point
    clouds
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Freehand = DICOMControlledTerminologyDefinitionsCode("114215")
    """
    Scanning the object from different views by placing it in front of a
    checkerboard pattern
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Checkerboard = DICOMControlledTerminologyDefinitionsCode("114216")
    """
    Type of source for observations quoted from an external source
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    QuotationMode = DICOMControlledTerminologyDefinitionsCode("121001")
    """
    Reference to external source of quoted observations
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    QuotedSource = DICOMControlledTerminologyDefinitionsCode("121002")
    """
    Documentary source of quoted observations
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Document = DICOMControlledTerminologyDefinitionsCode("121003")
    """
    Verbal source of quoted observations
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Verbal = DICOMControlledTerminologyDefinitionsCode("121004")
    """
    Type of observer that created the observations
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ObserverType = DICOMControlledTerminologyDefinitionsCode("121005")
    """
    Human observer created the observations
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Person = DICOMControlledTerminologyDefinitionsCode("121006")
    """
    Automated device created the observations
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Device = DICOMControlledTerminologyDefinitionsCode("121007")
    """
    Name of human observer that created the observations
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PersonObserverName = DICOMControlledTerminologyDefinitionsCode("121008")
    """
    Organization or institution with which the human observer is affiliated for
    the context of the current observation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PersonObserver_sOrganizationName = DICOMControlledTerminologyDefinitionsCode(
        "121009"
    )
    """
    Organizational role of human observer for the context of the current
    observation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PersonObserver_sRoleInTheOrganization = DICOMControlledTerminologyDefinitionsCode(
        "121010"
    )
    """
    Procedural role of human observer for the context of the current observation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PersonObserver_sRoleInThisProcedure = DICOMControlledTerminologyDefinitionsCode(
        "121011"
    )
    """
    Unique identifier of automated device that created the observations
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DeviceObserverUID = DICOMControlledTerminologyDefinitionsCode("121012")
    """
    Institution-provided identifier of automated device that created the
    observations
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DeviceObserverName = DICOMControlledTerminologyDefinitionsCode("121013")
    """
    Manufacturer of automated device that created the observations
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DeviceObserverManufacturer = DICOMControlledTerminologyDefinitionsCode("121014")
    """
    Manufacturer-provided model name of automated device that created the
    observations
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DeviceObserverModelName = DICOMControlledTerminologyDefinitionsCode("121015")
    """
    Manufacturer-provided serial number of automated device that created the
    observations
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DeviceObserverSerialNumber = DICOMControlledTerminologyDefinitionsCode("121016")
    """
    Location of automated device that created the observations whilst the
    observations were being made
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DeviceObserverPhysicalLocationDuringObservation = (
        DICOMControlledTerminologyDefinitionsCode("121017")
    )
    """
    Unique identifier for the Study or Requested Procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ProcedureStudyInstanceUID = DICOMControlledTerminologyDefinitionsCode("121018")
    """
    Unique identifier for the Performed Procedure Step
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ProcedureStudyComponentUID = DICOMControlledTerminologyDefinitionsCode("121019")
    """
    Identifier for the Order (or Service Request) assigned by the order placer
    system
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PlacerNumber = DICOMControlledTerminologyDefinitionsCode("121020")
    """
    Identifier for the Order (or Service Request) assigned by the order filler
    system
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FillerNumber = DICOMControlledTerminologyDefinitionsCode("121021")
    """
    Identifier for the Order (or Service Request) assigned by the department
    information system
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AccessionNumber = DICOMControlledTerminologyDefinitionsCode("121022")
    """
    Type of procedure scheduled or performed
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ProcedureCode = DICOMControlledTerminologyDefinitionsCode("121023")
    """
    Type of observation subject
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SubjectClass = DICOMControlledTerminologyDefinitionsCode("121024")
    """
    A patient is the subject of observations
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Patient = DICOMControlledTerminologyDefinitionsCode("121025")
    """
    Fetus of patient is the subject of observations
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Fetus = DICOMControlledTerminologyDefinitionsCode("121026")
    """
    Specimen is the subject of observations
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Specimen = DICOMControlledTerminologyDefinitionsCode("121027")
    """
    Unique Identifier of patient or fetus who is the subject of observations
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SubjectUID = DICOMControlledTerminologyDefinitionsCode("121028")
    """
    Name of patient who is the subject of observations
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SubjectName = DICOMControlledTerminologyDefinitionsCode("121029")
    """
    Identifier of patient or fetus who is the subject of observations
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SubjectID = DICOMControlledTerminologyDefinitionsCode("121030")
    """
    Birth Date of patient who is the subject of observations
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SubjectBirthDate = DICOMControlledTerminologyDefinitionsCode("121031")
    """
    Sex of patient who is the subject of observations
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SubjectSex = DICOMControlledTerminologyDefinitionsCode("121032")
    """
    Age of patient who is the subject of observations
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SubjectAge = DICOMControlledTerminologyDefinitionsCode("121033")
    """
    Species of patient who is the subject of observations
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SubjectSpecies = DICOMControlledTerminologyDefinitionsCode("121034")
    """
    The breed of the subject
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SubjectBreed = DICOMControlledTerminologyDefinitionsCode("121035")
    """
    Name of mother of fetus that is the subject of observations
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MotherOfFetus = DICOMControlledTerminologyDefinitionsCode("121036")
    """
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FetusNumber = DICOMControlledTerminologyDefinitionsCode("121037")
    """
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NumberOfFetuses = DICOMControlledTerminologyDefinitionsCode("121038")
    """
    Unique Identifier of specimen that is the subject of observations
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SpecimenUID = DICOMControlledTerminologyDefinitionsCode("121039")
    """
    Accession Number of specimen that is the subject of observations
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SpecimenAccessionNumber = DICOMControlledTerminologyDefinitionsCode("121040")
    """
    Identifier of specimen that is the subject of observations
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SpecimenIdentifier = DICOMControlledTerminologyDefinitionsCode("121041")
    """
    Coded category of specimen that is the subject of observations
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SpecimenType = DICOMControlledTerminologyDefinitionsCode("121042")
    """
    Identifier of specimen microscope slide that is the subject of observations
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SlideIdentifier = DICOMControlledTerminologyDefinitionsCode("121043")
    """
    Unique Identifier of specimen microscope slide that is the subject of
    observations
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SlideUID = DICOMControlledTerminologyDefinitionsCode("121044")
    """
    The language of the content, being a language that is primarily used for human
    communication; e.g. English, French
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Language = DICOMControlledTerminologyDefinitionsCode("121045")
    """
    The country-specific variant of language; e.g. Canada for Candadian French
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CountryOfLanguage = DICOMControlledTerminologyDefinitionsCode("121046")
    """
    The language of the value component of a name-value pair
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LanguageOfValue = DICOMControlledTerminologyDefinitionsCode("121047")
    """
    The language of both the name component and the value component of a name-
    value pair
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LanguageOfNameAndValue = DICOMControlledTerminologyDefinitionsCode("121048")
    """
    The language of the current content item (node in a tree of content) and all
    its descendants
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LanguageOfContentItemAndDescendants = DICOMControlledTerminologyDefinitionsCode(
        "121049"
    )
    """
    The human readable meaning of the name component of a name-value pair that is
    equivalent to the post-coordinated meaning conveyed by the coded name and its
    concept modifier children
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EquivalentMeaningOfConceptName = DICOMControlledTerminologyDefinitionsCode("121050")
    """
    The human readable meaning of the value component of a name-value pair that is
    equivalent to the post-coordinated meaning conveyed by the coded value and its
    concept modifier children
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EquivalentMeaningOfValue = DICOMControlledTerminologyDefinitionsCode("121051")
    """
    Whether or not the property concept being modified is present or absent
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PresenceOfProperty = DICOMControlledTerminologyDefinitionsCode("121052")
    """
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Present = DICOMControlledTerminologyDefinitionsCode("121053")
    """
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Absent = DICOMControlledTerminologyDefinitionsCode("121054")
    """
    A set of points on an image, that when connected by line segments, provide a
    polyline from which a linear measurement was inferred
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Path = DICOMControlledTerminologyDefinitionsCode("121055")
    """
    A set of points on an image, that when connected by line segments, provide a
    closed polyline that is the border of a defined region from which an area, or
    two-dimensional measurement, was inferred
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AreaOutline = DICOMControlledTerminologyDefinitionsCode("121056")
    """
    A set of points on an image, that when connected by line segments, provide a
    closed polyline that is a two-dimensional border of a three-dimensional
    region's intersection with, or projection into the image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PerimeterOutline = DICOMControlledTerminologyDefinitionsCode("121057")
    """
    The imaging procedure whose results are reported
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ProcedureReported = DICOMControlledTerminologyDefinitionsCode("121058")
    """
    Presence or absence of a property is undetermined
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PresenceUndetermined = DICOMControlledTerminologyDefinitionsCode("121059")
    """
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    History = DICOMControlledTerminologyDefinitionsCode("121060")
    """
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Request = DICOMControlledTerminologyDefinitionsCode("121062")
    """
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CurrentProcedureDescriptions = DICOMControlledTerminologyDefinitionsCode("121064")
    """
    A description of the imaging procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ProcedureDescription = DICOMControlledTerminologyDefinitionsCode("121065")
    """
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PriorProcedureDescriptions = DICOMControlledTerminologyDefinitionsCode("121066")
    """
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PreviousFindings = DICOMControlledTerminologyDefinitionsCode("121068")
    """
    An observation found on a prior imaging study
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PreviousFinding = DICOMControlledTerminologyDefinitionsCode("121069")
    """
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Findings = DICOMControlledTerminologyDefinitionsCode("121070")
    """
    An observation found on an imaging study
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Finding = DICOMControlledTerminologyDefinitionsCode("121071")
    """
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Impressions = DICOMControlledTerminologyDefinitionsCode("121072")
    """
    An interpretation in the clinical context of the finding(s) on an imaging
    study
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Impression = DICOMControlledTerminologyDefinitionsCode("121073")
    """
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Recommendations = DICOMControlledTerminologyDefinitionsCode("121074")
    """
    A recommendation for management or investigation based on the findings and
    impressions of an imaging study
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Recommendation = DICOMControlledTerminologyDefinitionsCode("121075")
    """
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Conclusions = DICOMControlledTerminologyDefinitionsCode("121076")
    """
    An interpretation in the clinical context of the finding(s) on an imaging
    study
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Conclusion = DICOMControlledTerminologyDefinitionsCode("121077")
    """
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Addendum = DICOMControlledTerminologyDefinitionsCode("121078")
    """
    Initial images used to esyablish a beginning condition that is used for
    comparison over time to look for changes. [Paraphrases NCI-PT (C1442488, UMLS,
    "Baseline"), which is defined as "An initial measurement that is taken at an
    early time point to represent a beginning condition, and is used for
    comparison over time to look for changes. For example, the size of a tumor
    will be measured before treatment (baseline) and then afterwards to see if the
    treatment had an effect. A starting point to which things may be compared."]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Baseline = DICOMControlledTerminologyDefinitionsCode("121079")
    """
    A selection of composite instances that best illustrates a particular finding;
    e.g. an image slice at the location of the largest extent of a tumor
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BestIllustrationOfFinding = DICOMControlledTerminologyDefinitionsCode("121080")
    """
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Physician = DICOMControlledTerminologyDefinitionsCode("121081")
    """
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Nurse = DICOMControlledTerminologyDefinitionsCode("121082")
    """
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Technologist = DICOMControlledTerminologyDefinitionsCode("121083")
    """
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Radiographer = DICOMControlledTerminologyDefinitionsCode("121084")
    """
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Intern = DICOMControlledTerminologyDefinitionsCode("121085")
    """
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Resident = DICOMControlledTerminologyDefinitionsCode("121086")
    """
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Registrar = DICOMControlledTerminologyDefinitionsCode("121087")
    """
    A medical practitioner undergoing sub-specialty training; e.g. during the
    period after specialty training (residency)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Fellow = DICOMControlledTerminologyDefinitionsCode("121088")
    """
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Attending_Consultant_ = DICOMControlledTerminologyDefinitionsCode("121089")
    """
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ScrubNurse = DICOMControlledTerminologyDefinitionsCode("121090")
    """
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Surgeon = DICOMControlledTerminologyDefinitionsCode("121091")
    """
    A medical practitioner with sub-specialty training in Ultrasound
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Sonologist = DICOMControlledTerminologyDefinitionsCode("121092")
    """
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Sonographer = DICOMControlledTerminologyDefinitionsCode("121093")
    """
    The person responsible for performing the procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Performing = DICOMControlledTerminologyDefinitionsCode("121094")
    """
    The person responsible for referring the patient for the procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Referring = DICOMControlledTerminologyDefinitionsCode("121095")
    """
    The person responsible for requesting the procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Requesting = DICOMControlledTerminologyDefinitionsCode("121096")
    """
    The person responsible for recording the procedure or observation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Recording = DICOMControlledTerminologyDefinitionsCode("121097")
    """
    The person responsible for verifying the recorded procedure or observation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Verifying = DICOMControlledTerminologyDefinitionsCode("121098")
    """
    The person responsible for assisting with the procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Assisting = DICOMControlledTerminologyDefinitionsCode("121099")
    """
    The person responsible for making preparations for and monitoring the
    procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Circulating = DICOMControlledTerminologyDefinitionsCode("121100")
    """
    The person responsible for standing by to assist with the precedure if
    required
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Standby = DICOMControlledTerminologyDefinitionsCode("121101")
    """
    Other sex
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OtherSex = DICOMControlledTerminologyDefinitionsCode("121102")
    """
    Sex of subject undetermined at time of encoding
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    UndeterminedSex = DICOMControlledTerminologyDefinitionsCode("121103")
    """
    Ambiguous sex
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AmbiguousSex = DICOMControlledTerminologyDefinitionsCode("121104")
    """
    Radiation Physicist
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RadiationPhysicist = DICOMControlledTerminologyDefinitionsCode("121105")
    """
    Comment
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Comment = DICOMControlledTerminologyDefinitionsCode("121106")
    """
    Indications for Procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IndicationsForProcedure = DICOMControlledTerminologyDefinitionsCode("121109")
    """
    Patient condition at the beginning of a healthcare encounter
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientPresentation = DICOMControlledTerminologyDefinitionsCode("121110")
    """
    Summary of a procedure, including most significant findings
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Summary = DICOMControlledTerminologyDefinitionsCode("121111")
    """
    Image or waveform used as source for measurement
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SourceOfMeasurement = DICOMControlledTerminologyDefinitionsCode("121112")
    """
    Complications from a procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Complications = DICOMControlledTerminologyDefinitionsCode("121113")
    """
    Physician who performed a procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PerformingPhysician = DICOMControlledTerminologyDefinitionsCode("121114")
    """
    Summary of patient condition upon Discharge from a healthcare facility
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DischargeSummary = DICOMControlledTerminologyDefinitionsCode("121115")
    """
    Proximal Anatomic Location for a differential measurement; may be considered
    subtype of term (G-C0E3, SRT, "Finding Site"); e.g. distance or pressure
    gradient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ProximalFindingSite = DICOMControlledTerminologyDefinitionsCode("121116")
    """
    Distal Anatomic Location for a differential measurement; may be considered
    subtype of term (G-C0E3, SRT, "Finding Site"); e.g. distance or pressure
    gradient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DistalFindingSite = DICOMControlledTerminologyDefinitionsCode("121117")
    """
    Patient Characteristics (findings)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientCharacteristics = DICOMControlledTerminologyDefinitionsCode("121118")
    """
    Time-stamped record of events that occur during a catheterization procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CathLabProcedureLog = DICOMControlledTerminologyDefinitionsCode("121120")
    """
    Room identification
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RoomIdentification = DICOMControlledTerminologyDefinitionsCode("121121")
    """
    Equipment identification
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EquipmentIdentification = DICOMControlledTerminologyDefinitionsCode("121122")
    """
    A recorded Patient Status or an event involving a patient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientStatusOrEvent = DICOMControlledTerminologyDefinitionsCode("121123")
    """
    Identification of a step, action, or phase of a procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ProcedureActionItemID = DICOMControlledTerminologyDefinitionsCode("121124")
    """
    DateTime of Recording of an Entry in an Event Log
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DateTimeOfRecordingOfLogEntry = DICOMControlledTerminologyDefinitionsCode("121125")
    """
    SOP Instance UID of a Performed Procedure Step
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PerformedProcedureStepSOPInstanceUID = DICOMControlledTerminologyDefinitionsCode(
        "121126"
    )
    """
    SOP Class UID of a Performed Procedure Step
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PerformedProcedureStepSOPClassUID = DICOMControlledTerminologyDefinitionsCode(
        "121127"
    )
    """
    Duration of a step, action, or phase of a procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ProcedureActionDuration = DICOMControlledTerminologyDefinitionsCode("121128")
    """
    Beginning of a step, action, or phase of a procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StartProcedureActionItem = DICOMControlledTerminologyDefinitionsCode("121130")
    """
    End of a step, action, or phase of a procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EndProcedureActionItem = DICOMControlledTerminologyDefinitionsCode("121131")
    """
    Suspension of a step, action, or phase of a procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SuspendProcedureActionItem = DICOMControlledTerminologyDefinitionsCode("121132")
    """
    Resumption of a step, action, or phase of a procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ResumeProcedureActionItem = DICOMControlledTerminologyDefinitionsCode("121133")
    """
    Concept modifier for the DateTime of Recording of an Entry in an Event Log
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ObservationDateTimeQualifier = DICOMControlledTerminologyDefinitionsCode("121135")
    """
    Recorded DateTime had its source in a system clock not synchronized to other
    recorded DateTimes
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DateTimeUnsynchronized = DICOMControlledTerminologyDefinitionsCode("121136")
    """
    Recorded DateTime is estimated
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DateTimeEstimated = DICOMControlledTerminologyDefinitionsCode("121137")
    """
    Event of the acquisition of an image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ImageAcquired = DICOMControlledTerminologyDefinitionsCode("121138")
    """
    Type of data acquisition device
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Modality = DICOMControlledTerminologyDefinitionsCode("121139")
    """
    Number of Frames in a multi-frame image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NumberOfFrames = DICOMControlledTerminologyDefinitionsCode("121140")
    """
    Descriptor of an Image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ImageType = DICOMControlledTerminologyDefinitionsCode("121141")
    """
    Duration of the acquisition of an image or a waveform
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AcquisitionDuration = DICOMControlledTerminologyDefinitionsCode("121142")
    """
    Event of the acquisition of an image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    WaveformAcquired = DICOMControlledTerminologyDefinitionsCode("121143")
    """
    Document Title
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DocumentTitle = DICOMControlledTerminologyDefinitionsCode("121144")
    """
    Description of Material used in a procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DescriptionOfMaterial = DICOMControlledTerminologyDefinitionsCode("121145")
    """
    Quantity of Material used in a procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    QuantityOfMaterial = DICOMControlledTerminologyDefinitionsCode("121146")
    """
    Billing Code for materials used in a procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BillingCode = DICOMControlledTerminologyDefinitionsCode("121147")
    """
    Unit or Device Serial Identifier
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    UnitSerialIdentifier = DICOMControlledTerminologyDefinitionsCode("121148")
    """
    Lot Identifier
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LotIdentifier = DICOMControlledTerminologyDefinitionsCode("121149")
    """
    Vendor or local coded value identifying a device
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DeviceCode = DICOMControlledTerminologyDefinitionsCode("121150")
    """
    Identification of a Lesion observed during an imaging procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LesionIdentifier = DICOMControlledTerminologyDefinitionsCode("121151")
    """
    Person administering drug/contrast
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PersonAdministeringDrug_contrast = DICOMControlledTerminologyDefinitionsCode(
        "121152"
    )
    """
    Assessment of the risk a coronary lesion presents to the health of a patient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LesionRisk = DICOMControlledTerminologyDefinitionsCode("121153")
    """
    Identifier for an attempted Intervention
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    InterventionAttemptIdentifier = DICOMControlledTerminologyDefinitionsCode("121154")
    """
    Use of a device to deploy another device
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Deployment = DICOMControlledTerminologyDefinitionsCode("121155")
    """
    Action of a clinical professional at the site of percutaneous access to a
    patient's cardiovascular system
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PercutaneousEntryAction = DICOMControlledTerminologyDefinitionsCode("121156")
    """
    The action or event of beginning circulatory support for a patient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BeginCirculatorySupport = DICOMControlledTerminologyDefinitionsCode("121157")
    """
    The action or event of ending circulatory support for a patient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EndCirculatorySupport = DICOMControlledTerminologyDefinitionsCode("121158")
    """
    Rate of Oxygen Administration
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OxygenAdministrationRate = DICOMControlledTerminologyDefinitionsCode("121160")
    """
    The action or event of beginning administration of oxygen to a patient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BeginOxygenAdministration = DICOMControlledTerminologyDefinitionsCode("121161")
    """
    The action or event of ending administration of oxygen to a patient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EndOxygenAdministration = DICOMControlledTerminologyDefinitionsCode("121162")
    """
    Method of administration of oxygen to a patient by ventilator
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ByVentilator = DICOMControlledTerminologyDefinitionsCode("121163")
    """
    The action or event of assessing the clinical status of a patient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientAssessmentPerformed = DICOMControlledTerminologyDefinitionsCode("121165")
    """
    The action or event of beginning pacing support for a patient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BeginPacing = DICOMControlledTerminologyDefinitionsCode("121166")
    """
    The action or event of ending pacing support for a patient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EndPacing = DICOMControlledTerminologyDefinitionsCode("121167")
    """
    The action or event of beginning ventilation support for a patient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BeginVentilation = DICOMControlledTerminologyDefinitionsCode("121168")
    """
    The action or event of ending ventilation support for a patient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EndVentilation = DICOMControlledTerminologyDefinitionsCode("121169")
    """
    Procedural note originated by a technologist
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TechNote = DICOMControlledTerminologyDefinitionsCode("121171")
    """
    Procedural note originated by a nurse
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NursingNote = DICOMControlledTerminologyDefinitionsCode("121172")
    """
    Procedural note originated by a Physician
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PhysicianNote = DICOMControlledTerminologyDefinitionsCode("121173")
    """
    General procedural note
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ProcedureNote = DICOMControlledTerminologyDefinitionsCode("121174")
    """
    List of references to images considered significant
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    KeyImages = DICOMControlledTerminologyDefinitionsCode("121180")
    """
    List of references to DICOM SOP Instances
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DICOMObjectCatalog = DICOMControlledTerminologyDefinitionsCode("121181")
    """
    Individual frames selected as a subset of a multi-frame image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ReferencedFrames = DICOMControlledTerminologyDefinitionsCode("121190")
    """
    Segment selected as a subset of a segmentation image, specifically the
    pixels/voxels identified as belonging to the classification of the identified
    segment
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ReferencedSegment = DICOMControlledTerminologyDefinitionsCode("121191")
    """
    A device is the subject of observations
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DeviceSubject = DICOMControlledTerminologyDefinitionsCode("121192")
    """
    Name or other identifier of a device that is the subject of observations
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DeviceSubjectName = DICOMControlledTerminologyDefinitionsCode("121193")
    """
    Manufacturer of a device that is the subject of observations
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DeviceSubjectManufacturer = DICOMControlledTerminologyDefinitionsCode("121194")
    """
    Model Name of a device that is the subject of observations
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DeviceSubjectModelName = DICOMControlledTerminologyDefinitionsCode("121195")
    """
    Serial Number of a device that is the subject of observations
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DeviceSubjectSerialNumber = DICOMControlledTerminologyDefinitionsCode("121196")
    """
    Physical Location of a device that is the subject of observations during those
    observations
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DeviceSubjectPhysicalLocationDuringObservation = (
        DICOMControlledTerminologyDefinitionsCode("121197")
    )
    """
    Unique Identifier of a device that is the subject of observations
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DeviceSubjectUID = DICOMControlledTerminologyDefinitionsCode("121198")
    """
    Illustration of a region of interest
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IllustrationOfROI = DICOMControlledTerminologyDefinitionsCode("121200")
    """
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AreaOutline = DICOMControlledTerminologyDefinitionsCode("121201")
    """
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AreaOfDefinedRegion = DICOMControlledTerminologyDefinitionsCode("121202")
    """
    A one dimensional, or linear, numeric measurement
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Distance = DICOMControlledTerminologyDefinitionsCode("121206")
    """
    Vertical measurement value
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Height = DICOMControlledTerminologyDefinitionsCode("121207")
    """
    Distance between marks on a device of calibrated size; e.g. a ruler
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Inter_MarkerDistance = DICOMControlledTerminologyDefinitionsCode("121208")
    """
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Path = DICOMControlledTerminologyDefinitionsCode("121210")
    """
    A one dimensional, or linear, numeric measurement along a polyline
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PathLength = DICOMControlledTerminologyDefinitionsCode("121211")
    """
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PerimeterOutline = DICOMControlledTerminologyDefinitionsCode("121213")
    """
    Frame selected from a segmentation image, specifically the pixels/voxels
    identified as belonging to the classification of the segment encompassing the
    identified frame
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ReferencedSegmentationFrame = DICOMControlledTerminologyDefinitionsCode("121214")
    """
    A three-dimensional numeric measurement that is approximate, based on a two-
    dimensional region in a single image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VolumeEstimatedFromSingle2DRegion = DICOMControlledTerminologyDefinitionsCode(
        "121216"
    )
    """
    A three-dimensional numeric measurement that is approximate, based on three or
    more non-coplanar two-dimensional image regions
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VolumeEstimatedFromThreeOrMoreNon_coplanar2DRegions = (
        DICOMControlledTerminologyDefinitionsCode("121217")
    )
    """
    A three-dimensional numeric measurement that is approximate, based on two non-
    coplanar two-dimensional image regions
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VolumeEstimatedFromTwoNon_coplanar2DRegions = (
        DICOMControlledTerminologyDefinitionsCode("121218")
    )
    """
    A three-dimensional numeric measurement of the bounding region of a three-
    dimensional region of interest in an image set
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VolumeOfBoundingThreeDimensionalRegion = DICOMControlledTerminologyDefinitionsCode(
        "121219"
    )
    """
    A three-dimensional numeric measurement of the bounding sphere of a three-
    dimensional region of interest in an image set
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VolumeOfCircumscribedSphere = DICOMControlledTerminologyDefinitionsCode("121220")
    """
    A three-dimensional numeric measurement of an ellipsoid shaped three-
    dimensional region of interest in an image set
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VolumeOfEllipsoid = DICOMControlledTerminologyDefinitionsCode("121221")
    """
    A three-dimensional numeric measurement of a sphere shaped three-dimensional
    region of interest in an image set
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VolumeOfSphere = DICOMControlledTerminologyDefinitionsCode("121222")
    """
    Coordinates of a point on a defined path
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PathVertex = DICOMControlledTerminologyDefinitionsCode("121230")
    """
    Surface of an identified or measured volume
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VolumeSurface = DICOMControlledTerminologyDefinitionsCode("121231")
    """
    Series of image instances used as source data for a segmentation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SourceSeriesForSegmentation = DICOMControlledTerminologyDefinitionsCode("121232")
    """
    Image instances used as source data for a segmentation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SourceImageForSegmentation = DICOMControlledTerminologyDefinitionsCode("121233")
    """
    Indicates the location of the area of interest as measured from the nipple of
    the breast
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DistanceFromNipple = DICOMControlledTerminologyDefinitionsCode("121242")
    """
    Indicates the location of the area of interest as measured from the most
    direct skin point of the breast
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DistanceFromSkin = DICOMControlledTerminologyDefinitionsCode("121243")
    """
    Indicates the location of the area of interest as measured from the chest wall
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DistanceFromChestWall = DICOMControlledTerminologyDefinitionsCode("121244")
    """
    Patient exposure to ionizing radiation (procedure)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientExposureToIonizingRadiation = DICOMControlledTerminologyDefinitionsCode(
        "121290"
    )
    """
    The act of communicating actionable findings to a responsible receiver
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ResultsCommunicated = DICOMControlledTerminologyDefinitionsCode("121291")
    """
    Reference is to a Doppler waveform acquired simultaneously with an image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SimultaneousDoppler = DICOMControlledTerminologyDefinitionsCode("121301")
    """
    Reference is to a Hemodynamic waveform acquired simultaneously with an image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SimultaneousHemodynamic = DICOMControlledTerminologyDefinitionsCode("121302")
    """
    Reference is to a ECG waveform acquired simultaneously with an image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SimultaneousECG = DICOMControlledTerminologyDefinitionsCode("121303")
    """
    Reference is to a voice narrative recording acquired simultaneously with an
    image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SimultaneousVoiceNarrative = DICOMControlledTerminologyDefinitionsCode("121304")
    """
    A waveform representing chest expansion and contraction due to respiratory
    activity, measured simultaneously with the acquisition of this Image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SimultaneousRespiratoryWaveform = DICOMControlledTerminologyDefinitionsCode(
        "121305"
    )
    """
    Arterial pulse waveform obtained simultaneously with acquisition of a
    referencing image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SimultaneousArterialPulseWaveform = DICOMControlledTerminologyDefinitionsCode(
        "121306"
    )
    """
    Phonocardiographic waveform obtained simultaneously with acquisition of a
    referencing image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SimultaneousPhonocardiographicWaveform = DICOMControlledTerminologyDefinitionsCode(
        "121307"
    )
    """
    Image providing an anatomical reference on the patient under examination, for
    the purpose of defining the location of the ensuing imaging
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Localizer = DICOMControlledTerminologyDefinitionsCode("121311")
    """
    Image providing an anatomical reference on the patient under examination, for
    the purpose of planning or documenting a biopsy
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BiopsyLocalizer = DICOMControlledTerminologyDefinitionsCode("121312")
    """
    Image providing a partial view of the target anatomy, when the target anatomy
    is too large for a single image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OtherPartialViews = DICOMControlledTerminologyDefinitionsCode("121313")
    """
    Image providing a view of the target anatomy in a different imaging plane,
    typically from a near perpendicular angle
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OtherImageOfBiplanePair = DICOMControlledTerminologyDefinitionsCode("121314")
    """
    Image providing a view of the target anatomy in a different imaging plane,
    typically with a small angular difference
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OtherImageOfStereoscopicPair = DICOMControlledTerminologyDefinitionsCode("121315")
    """
    Image related to a non-image information object
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ImagesRelatedToStandaloneObject = DICOMControlledTerminologyDefinitionsCode(
        "121316"
    )
    """
    Image where signals are identified and separated according to their
    frequencies; e.g. to identify individual chemicals, or individual nuclei in a
    chemical compound
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Spectroscopy = DICOMControlledTerminologyDefinitionsCode("121317")
    """
    MR spectroscopy data acquired to correct the phase of the diagnostic data for
    the phase signal of the Water
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SpectroscopyDataForWaterPhaseCorrection = DICOMControlledTerminologyDefinitionsCode(
        "121318"
    )
    """
    An image that has not already been lossy compressed that is used as the source
    for creation of a lossy compressed image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    UncompressedPredecessor = DICOMControlledTerminologyDefinitionsCode("121320")
    """
    Image used as the mask for an image processing operation, such as subtraction
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MaskImageForImageProcessingOperation = DICOMControlledTerminologyDefinitionsCode(
        "121321"
    )
    """
    Image used as the source for an image processing operation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SourceImageForImageProcessingOperation = DICOMControlledTerminologyDefinitionsCode(
        "121322"
    )
    """
    Series used as the source for an image processing operation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SourceSeriesForImageProcessingOperation = DICOMControlledTerminologyDefinitionsCode(
        "121323"
    )
    """
    Image used as the source for a derived or compressed image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SourceImage = DICOMControlledTerminologyDefinitionsCode("121324")
    """
    Image encoded with a lossy compression transfer syntax
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LossyCompressedImage = DICOMControlledTerminologyDefinitionsCode("121325")
    """
    SOP Instance encoded with a different SOP Class but otherwise equivalent data
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AlternateSOPClassInstance = DICOMControlledTerminologyDefinitionsCode("121326")
    """
    Full fidelity image, uncompressed or lossless compressed
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FullFidelityImage = DICOMControlledTerminologyDefinitionsCode("121327")
    """
    Image encoded with a different photometric interpretation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AlternatePhotometricInterpretationImage = DICOMControlledTerminologyDefinitionsCode(
        "121328"
    )
    """
    Image used as a source for a montage (stitched) image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SourceImageForMontage = DICOMControlledTerminologyDefinitionsCode("121329")
    """
    An image that has previously been lossy compressed that is used as the source
    for creation of another lossy compressed image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LossyCompressedPredecessor = DICOMControlledTerminologyDefinitionsCode("121330")
    """
    HL7 Document Architecture (CDA) Document that contains clinical content
    equivalent to the referencing Instance
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EquivalentCDADocument = DICOMControlledTerminologyDefinitionsCode("121331")
    """
    Instance that contains a displayable complete rendering of the referencing
    Instance
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CompleteRenderingForPresentation = DICOMControlledTerminologyDefinitionsCode(
        "121332"
    )
    """
    Instance that contains a displayable partial rendering of the referencing
    Instance
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PartialRenderingForPresentation = DICOMControlledTerminologyDefinitionsCode(
        "121333"
    )
    """
    Instance that contains a displayable complete rendering of the referencing
    Instance, plus additional content such as inline rendering of referenced
    images
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ExtendedRenderingForPresentation = DICOMControlledTerminologyDefinitionsCode(
        "121334"
    )
    """
    Document whose content has been wholly or partially transformed to create the
    referencing document
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SourceDocument = DICOMControlledTerminologyDefinitionsCode("121335")
    """
    Image showing structural anatomic features
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AnatomicImage = DICOMControlledTerminologyDefinitionsCode("121338")
    """
    Image showing physical or chemical activity
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FunctionalImage = DICOMControlledTerminologyDefinitionsCode("121339")
    """
    Image providing the same view of the target anatomy acquired using only a
    specific imaging wavelength, frequency or energy
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SpectralFilteredImage = DICOMControlledTerminologyDefinitionsCode("121340")
    """
    Image providing an anatomical reference on the patient under examination, for
    the purpose of documenting the location of device such as a diagnostic or
    therapeutic catheter
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DeviceLocalizer = DICOMControlledTerminologyDefinitionsCode("121341")
    """
    Image providing a graphic view of the distribution of radiation dose
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DoseImage = DICOMControlledTerminologyDefinitionsCode("121342")
    """
    The referenced image is the source of spatially-related frames from which the
    referencing 3D volume data set was derived
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AcquisitionFramesCorrespondingToVolume = DICOMControlledTerminologyDefinitionsCode(
        "121346"
    )
    """
    3D Volume containing the spatially-related frames in the referencing instance
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VolumeCorrespondingToSpatially_relatedAcquisitionFrames = (
        DICOMControlledTerminologyDefinitionsCode("121347")
    )
    """
    Instance acquired prior to the referencing instance in a set of consecutively
    acquired instances
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TemporalPredecessor = DICOMControlledTerminologyDefinitionsCode("121348")
    """
    Instance acquired subsequent to the referencing instance in a set of
    consecutively acquired instances
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TemporalSuccessor = DICOMControlledTerminologyDefinitionsCode("121349")
    """
    Image of the same target area at lower resolution acquired in the same
    acquisition process
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SameAcquisitionAtLowerResolution = DICOMControlledTerminologyDefinitionsCode(
        "121350"
    )
    """
    Image of the same target area at higher resolution acquired in the same
    acquisition process
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SameAcquisitionAtHigherResolution = DICOMControlledTerminologyDefinitionsCode(
        "121351"
    )
    """
    Image of the same target area at different focal depth (Z-plane) acquired in
    the same acquisition process
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SameAcquisitionAtDifferentFocalDepth = DICOMControlledTerminologyDefinitionsCode(
        "121352"
    )
    """
    Image of the same target area at different spectral band acquired in the same
    acquisition process
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SameAcquisitionAtDifferentSpectralBand = DICOMControlledTerminologyDefinitionsCode(
        "121353"
    )
    """
    Image specifically targeting the container label
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ImagedContainerLabel = DICOMControlledTerminologyDefinitionsCode("121354")
    """
    Source image from which FOR PRESENTATION images were created
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ForProcessingPredecessor = DICOMControlledTerminologyDefinitionsCode("121358")
    """
    The reference is to a predecessor report that has been replaced by the current
    report
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ReplacedReport = DICOMControlledTerminologyDefinitionsCode("121360")
    """
    The reference is to a predecessor report to which the current report provides
    and addendum
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AddendedReport = DICOMControlledTerminologyDefinitionsCode("121361")
    """
    A report that precedes the final report and may contain only limited
    information; it may be time sensitive, and it is not expected to contain all
    the reportable findings
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PreliminaryReport = DICOMControlledTerminologyDefinitionsCode("121362")
    """
    A report that is not complete
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PartialReport = DICOMControlledTerminologyDefinitionsCode("121363")
    """
    The dose object created was calculated by summation of existing, previously
    calculated, RT Dose instances
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ComposedFromPriorDoses = DICOMControlledTerminologyDefinitionsCode("121370")
    """
    The dose object created was calculated by summation of existing, previously
    calculated, RT Dose instances and dose newly calculated by the application.
    The newly calculated dose may or may not exist as an independent object
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ComposedFromPriorDosesAndCurrentPlan = DICOMControlledTerminologyDefinitionsCode(
        "121371"
    )
    """
    RT Dose Instances used as source for calculated dose
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SourceDoseForComposingCurrentDose = DICOMControlledTerminologyDefinitionsCode(
        "121372"
    )
    """
    Concentration of the chemically or physically interesting (active) ingredient
    of a drug or contrast agent as delivered in product form from the
    manufacturer, typically in mg/ml
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ActiveIngredientUndilutedConcentration = DICOMControlledTerminologyDefinitionsCode(
        "121380"
    )
    """
    X-Ray absorption of the active ingredient of a contrast agent ingredient is
    greater than the absorption of water (tissue)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Contrast_BolusIngredientOpaque = DICOMControlledTerminologyDefinitionsCode("121381")
    """
    Number of units of substance administered to a patient; e.g. tablets
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    QuantityAdministered = DICOMControlledTerminologyDefinitionsCode("121382")
    """
    Mass of substance administered to a patient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MassAdministered = DICOMControlledTerminologyDefinitionsCode("121383")
    """
    Method of deriving or calculating a measured value; e.g. mean, or maximum of
    set
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Derivation = DICOMControlledTerminologyDefinitionsCode("121401")
    """
    Assessment of a measurement relative to a normal range of values; may be
    considered subtype of term (G-C0F2, SRT, "has interpretation")
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Normality = DICOMControlledTerminologyDefinitionsCode("121402")
    """
    Significance of a measurement
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LevelOfSignificance = DICOMControlledTerminologyDefinitionsCode("121403")
    """
    Status of selection of a measurement for further processing or use
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SelectionStatus = DICOMControlledTerminologyDefinitionsCode("121404")
    """
    Description of a population of measurements
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PopulationDescription = DICOMControlledTerminologyDefinitionsCode("121405")
    """
    Bibliographic or clinical reference for a Description of a population of
    measurements
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ReferenceAuthority = DICOMControlledTerminologyDefinitionsCode("121406")
    """
    Description of a normal range of values for a measurement concept
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NormalRangeDescription = DICOMControlledTerminologyDefinitionsCode("121407")
    """
    Bibliographic or clinical reference for a Description of a normal range of
    values
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NormalRangeAuthority = DICOMControlledTerminologyDefinitionsCode("121408")
    """
    Observation value selected by user for further processing or use, or as most
    representative
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    UserChosenValue = DICOMControlledTerminologyDefinitionsCode("121410")
    """
    Observation value is the recently obtained, and has been selected for further
    processing or use
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MostRecentValueChosen = DICOMControlledTerminologyDefinitionsCode("121411")
    """
    Observation value is the mean of several measurements, and has been selected
    for further processing or use
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MeanValueChosen = DICOMControlledTerminologyDefinitionsCode("121412")
    """
    Standard deviation of a measurement in a reference population
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StandardDeviationOfPopulation = DICOMControlledTerminologyDefinitionsCode("121414")
    """
    Percentile Ranking of an observation value with respect a reference population
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PercentileRankingOfMeasurement = DICOMControlledTerminologyDefinitionsCode("121415")
    """
    Z-score of an observation value with respect a reference population, expressed
    as the dimensionless quantity (x-m) /s, where (x-m) is the deviation of the
    observation value (x) from the population mean (m), and s is the standard
    deviation of the population
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Z_ScoreOfMeasurement = DICOMControlledTerminologyDefinitionsCode("121416")
    """
    2 Sigma deviation of a measurement in a reference population
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    _2SigmaDeviationOfPopulation = DICOMControlledTerminologyDefinitionsCode("121417")
    """
    Formula used to compute a derived measurement
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Equation = DICOMControlledTerminologyDefinitionsCode("121420")
    """
    Bibliographic reference to a formula used to compute a derived measurement;
    reference may be to a specific equation in a journal article
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EquationCitation = DICOMControlledTerminologyDefinitionsCode("121421")
    """
    Bibliographic reference to a Table of Values used to look up a derived
    measurement
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TableOfValuesCitation = DICOMControlledTerminologyDefinitionsCode("121422")
    """
    Bibliographic reference to a method used to compute a derived measurement
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MethodCitation = DICOMControlledTerminologyDefinitionsCode("121423")
    """
    A Table of Values used to look up a derived measurement
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TableOfValues = DICOMControlledTerminologyDefinitionsCode("121424")
    """
    Factor (divisor or multiplicand) for normalizing a measurement; e.g. body
    surface area used for normalizing hemodynamic measurements
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Index = DICOMControlledTerminologyDefinitionsCode("121425")
    """
    Measurement obtained by observer estimation, rather than with a measurement
    tool or by calculation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Estimated = DICOMControlledTerminologyDefinitionsCode("121427")
    """
    Measurement obtained by calculation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Calculated = DICOMControlledTerminologyDefinitionsCode("121428")
    """
    Identified issue about a state or process that has the potential to require
    intervention or management
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Concern = DICOMControlledTerminologyDefinitionsCode("121430")
    """
    DateTime concern noted (noted by whom is determined by context of use)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DateTimeConcernNoted = DICOMControlledTerminologyDefinitionsCode("121431")
    """
    DateTime the concern was resolved
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DateTimeConcernResolved = DICOMControlledTerminologyDefinitionsCode("121432")
    """
    DateTime the problem was resolved
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DateTimeProblemResolved = DICOMControlledTerminologyDefinitionsCode("121433")
    """
    Place at which healthcare services may be provided
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ServiceDeliveryLocation = DICOMControlledTerminologyDefinitionsCode("121434")
    """
    Identification of a healthcare provider who performed a healthcare service;
    may be either a person or an organization
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ServicePerformer = DICOMControlledTerminologyDefinitionsCode("121435")
    """
    Type or identifier of a medical device used on, in, or by a patient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MedicalDeviceUsed = DICOMControlledTerminologyDefinitionsCode("121436")
    """
    Cardiac stress test using pharmacologic and exercise stressors
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PharmacologicAndExerciseStressTest = DICOMControlledTerminologyDefinitionsCode(
        "121437"
    )
    """
    Cardiac stress test using an implanted or external cardiac pacing device
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PacedStressTest = DICOMControlledTerminologyDefinitionsCode("121438")
    """
    Procedure for correction of congenital cardiovascular deformity
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CorrectionOfCongenitalCardiovascularDeformity = (
        DICOMControlledTerminologyDefinitionsCode("121439")
    )
    """
    Process of placing patient in the anticipated treatment position, including
    specification and location of positioning aids, and other treatment delivery
    accessories
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RTPatientSetup = DICOMControlledTerminologyDefinitionsCode("121701")
    """
    Acquisition of patient positioning information prior to treatment delivery,
    using single-plane megavoltage imaging
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RTPatientPositionAcquisition_SinglePlaneMV = (
        DICOMControlledTerminologyDefinitionsCode("121702")
    )
    """
    Acquisition of patient positioning information prior to treatment delivery,
    using dual-plane megavoltage imaging
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RTPatientPositionAcquisition_DualPlaneMV = (
        DICOMControlledTerminologyDefinitionsCode("121703")
    )
    """
    Acquisition of patient positioning information prior to treatment delivery,
    using single-plane kilovoltage imaging
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RTPatientPositionAcquisition_SinglePlaneKV = (
        DICOMControlledTerminologyDefinitionsCode("121704")
    )
    """
    Acquisition of patient positioning information prior to treatment delivery,
    using dual-plane kilovoltage imaging
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RTPatientPositionAcquisition_DualPlaneKV = (
        DICOMControlledTerminologyDefinitionsCode("121705")
    )
    """
    Acquisition of patient positioning information prior to treatment delivery,
    using dual-plane combination kilovoltage and megavoltage imaging
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RTPatientPositionAcquisition_DualPlaneKV_MV = (
        DICOMControlledTerminologyDefinitionsCode("121706")
    )
    """
    Acquisition of patient positioning information prior to treatment delivery,
    using kilovoltage CT imaging
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RTPatientPositionAcquisition_CTKV = DICOMControlledTerminologyDefinitionsCode(
        "121707"
    )
    """
    Acquisition of patient positioning information prior to treatment delivery,
    using megavoltage CT imaging
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RTPatientPositionAcquisition_CTMV = DICOMControlledTerminologyDefinitionsCode(
        "121708"
    )
    """
    Acquisition of patient positioning information prior to treatment delivery,
    using optical imaging
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RTPatientPositionAcquisition_Optical = DICOMControlledTerminologyDefinitionsCode(
        "121709"
    )
    """
    Acquisition of patient positioning information prior to treatment delivery,
    using ultrasound imaging
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RTPatientPositionAcquisition_Ultrasound = DICOMControlledTerminologyDefinitionsCode(
        "121710"
    )
    """
    Acquisition of patient positioning information prior to treatment delivery,
    using spatial fiducials
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RTPatientPositionAcquisition_SpatialFiducials = (
        DICOMControlledTerminologyDefinitionsCode("121711")
    )
    """
    Registration of intended and actual patient position prior to treatment
    delivery, using single-plane images
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RTPatientPositionRegistration_SinglePlane = (
        DICOMControlledTerminologyDefinitionsCode("121712")
    )
    """
    Registration of intended and actual patient position prior to treatment
    delivery, using dual-plane images
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RTPatientPositionRegistration_DualPlane = DICOMControlledTerminologyDefinitionsCode(
        "121713"
    )
    """
    Registration of intended and actual patient position prior to treatment
    delivery, using 3D CT images and an unspecified registration approach
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RTPatientPositionRegistration_3DCTGeneral = (
        DICOMControlledTerminologyDefinitionsCode("121714")
    )
    """
    Registration of intended and actual patient position prior to treatment
    delivery, using 3D CT images and a marker-based registration approach
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RTPatientPositionRegistration_3DCTMarker_based = (
        DICOMControlledTerminologyDefinitionsCode("121715")
    )
    """
    Registration of intended and actual patient position prior to treatment
    delivery, using 3D CT images and a volume-based registration approach
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RTPatientPositionRegistration_3DCTVolume_based = (
        DICOMControlledTerminologyDefinitionsCode("121716")
    )
    """
    Registration of intended and actual patient position prior to treatment
    delivery, using 3D verification images and 2D reference images
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RTPatientPositionRegistration_3DOn2DReference = (
        DICOMControlledTerminologyDefinitionsCode("121717")
    )
    """
    Registration of intended and actual patient position prior to treatment
    delivery, using 2D verification images and 3D reference images
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RTPatientPositionRegistration_2DOn3DReference = (
        DICOMControlledTerminologyDefinitionsCode("121718")
    )
    """
    Registration of intended and actual patient position prior to treatment
    delivery, using optical images
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RTPatientPositionRegistration_Optical = DICOMControlledTerminologyDefinitionsCode(
        "121719"
    )
    """
    Registration of intended and actual patient position prior to treatment
    delivery, using ultrasound images
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RTPatientPositionRegistration_Ultrasound = (
        DICOMControlledTerminologyDefinitionsCode("121720")
    )
    """
    Registration of intended and actual patient position prior to treatment
    delivery, using spatial fiducials
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RTPatientPositionRegistration_SpatialFiducials = (
        DICOMControlledTerminologyDefinitionsCode("121721")
    )
    """
    Adjustment of patient position such that the patient is correctly positioned
    for treatment
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RTPatientPositionAdjustment = DICOMControlledTerminologyDefinitionsCode("121722")
    """
    Review of patient positioning information in the process of delivering a
    treatment session
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RTPatientPositionIn_treatment_sessionReview = (
        DICOMControlledTerminologyDefinitionsCode("121723")
    )
    """
    Simulated radiotherapy treatment delivery using verification integral to the
    Treatment Delivery System
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RTTreatmentSimulationWithInternalVerification = (
        DICOMControlledTerminologyDefinitionsCode("121724")
    )
    """
    Simulated radiotherapy treatment delivery using verification by a external
    Machine Parameter Verifier
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RTTreatmentSimulationWithExternalVerification = (
        DICOMControlledTerminologyDefinitionsCode("121725")
    )
    """
    Radiotherapy treatment delivery using verification integral to the Treatment
    Delivery System
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RTTreatmentWithInternalVerification = DICOMControlledTerminologyDefinitionsCode(
        "121726"
    )
    """
    Radiotherapy treatment delivery using verification by an external Machine
    Parameter Verifier
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RTTreatmentWithExternalVerification = DICOMControlledTerminologyDefinitionsCode(
        "121727"
    )
    """
    Quality assurance of a radiotherapy treatment delivery using verification
    integral to the Treatment Delivery System
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RTTreatmentQAWithInternalVerification = DICOMControlledTerminologyDefinitionsCode(
        "121728"
    )
    """
    Quality assurance of a radiotherapy treatment delivery using verification by
    an external Machine Parameter Verifier
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RTTreatmentQAWithExternalVerification = DICOMControlledTerminologyDefinitionsCode(
        "121729"
    )
    """
    Quality assurance of a Treatment Delivery Device
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RTMachineQA = DICOMControlledTerminologyDefinitionsCode("121730")
    """
    Perform Quality Assurance on an RT Plan by evaluating dosimetric content of
    the current RT Plan
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RTTreatmentQAByRTPlanDoseCheck = DICOMControlledTerminologyDefinitionsCode("121731")
    """
    Perform Quality Assurance on an RT Plan by comparing the content of previously
    quality-assessed RT Plans with the current RT Plan
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RTTreatmentQAByRTPlanDifferenceCheck = DICOMControlledTerminologyDefinitionsCode(
        "121732"
    )
    """
    Perform Quality Assurance on an RT Ion Plan by evaluating dosimetric content
    of the current RT Ion Plan
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RTTreatmentQAByRTIonPlanDoseCheck = DICOMControlledTerminologyDefinitionsCode(
        "121733"
    )
    """
    Perform Quality Assurance on an RT Ion Plan by comparing the content of
    previously quality-assessed RT Ion Plans with the current RT Ion Plan
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RTTreatmentQAWithRTIonPlanDifferenceCheck = (
        DICOMControlledTerminologyDefinitionsCode("121734")
    )
    """
    Indicates whether the treatment to be delivered is a complete fraction or a
    continuation of previous incompletely treated fraction
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TreatmentDeliveryType = DICOMControlledTerminologyDefinitionsCode("121740")
    """
    Patient called to procedure room
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientCalledToProcedureRoom = DICOMControlledTerminologyDefinitionsCode("122001")
    """
    Patient admitted to procedure room
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientAdmittedToProcedureRoom = DICOMControlledTerminologyDefinitionsCode("122002")
    """
    Patient given pre-procedure instruction
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientGivenPre_procedureInstruction = DICOMControlledTerminologyDefinitionsCode(
        "122003"
    )
    """
    Patient informed consent given
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientInformedConsentGiven = DICOMControlledTerminologyDefinitionsCode("122004")
    """
    Patient advance directive given
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientAdvanceDirectiveGiven = DICOMControlledTerminologyDefinitionsCode("122005")
    """
    Nil Per Os (NPO) status confirmed
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NilPerOs_NPO_StatusConfirmed = DICOMControlledTerminologyDefinitionsCode("122006")
    """
    Patient assisted to table
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientAssistedToTable = DICOMControlledTerminologyDefinitionsCode("122007")
    """
    Patient prepped and draped
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientPreppedAndDraped = DICOMControlledTerminologyDefinitionsCode("122008")
    """
    Patient connected to continuous monitoring
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientConnectedToContinuousMonitoring = DICOMControlledTerminologyDefinitionsCode(
        "122009"
    )
    """
    Patient transferred to holding area
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientTransferredToHoldingArea = DICOMControlledTerminologyDefinitionsCode(
        "122010"
    )
    """
    Patient transferred to surgery
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientTransferredToSurgery = DICOMControlledTerminologyDefinitionsCode("122011")
    """
    Patient transferred to CCU
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientTransferredToCCU = DICOMControlledTerminologyDefinitionsCode("122012")
    """
    Patient disoriented
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientDisoriented = DICOMControlledTerminologyDefinitionsCode("122020")
    """
    Patient reports nausea
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientReportsNausea = DICOMControlledTerminologyDefinitionsCode("122021")
    """
    Patient reports discomfort
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientReportsDiscomfort = DICOMControlledTerminologyDefinitionsCode("122022")
    """
    Patient reports chest pain
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientReportsChestPain = DICOMControlledTerminologyDefinitionsCode("122023")
    """
    Patient reports no pain
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientReportsNoPain = DICOMControlledTerminologyDefinitionsCode("122024")
    """
    Patient alert
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientAlert = DICOMControlledTerminologyDefinitionsCode("122025")
    """
    Patient restless
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientRestless = DICOMControlledTerminologyDefinitionsCode("122026")
    """
    Patient sedated
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientSedated = DICOMControlledTerminologyDefinitionsCode("122027")
    """
    Patient asleep
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientAsleep = DICOMControlledTerminologyDefinitionsCode("122028")
    """
    Patient unresponsive
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientUnresponsive = DICOMControlledTerminologyDefinitionsCode("122029")
    """
    Patient has respiratory difficulty
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientHasRespiratoryDifficulty = DICOMControlledTerminologyDefinitionsCode(
        "122030"
    )
    """
    Patient coughed
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientCoughed = DICOMControlledTerminologyDefinitionsCode("122031")
    """
    Patient disconnected from continuous monitoring
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientDisconnectedFromContinuousMonitoring = (
        DICOMControlledTerminologyDefinitionsCode("122032")
    )
    """
    Hemostasis achieved
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    HemostasisAchieved = DICOMControlledTerminologyDefinitionsCode("122033")
    """
    Hemostasis not achieved - oozing
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    HemostasisNotAchieved_Oozing = DICOMControlledTerminologyDefinitionsCode("122034")
    """
    Hemostasis not achieved - actively bleeding
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    HemostasisNotAchieved_ActivelyBleeding = DICOMControlledTerminologyDefinitionsCode(
        "122035"
    )
    """
    Patient given post-procedure instruction
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientGivenPost_procedureInstruction = DICOMControlledTerminologyDefinitionsCode(
        "122036"
    )
    """
    Patient discharged from department or laboratory
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientDischargedFromDepartment = DICOMControlledTerminologyDefinitionsCode(
        "122037"
    )
    """
    Patient pronounced dead
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientPronouncedDead = DICOMControlledTerminologyDefinitionsCode("122038")
    """
    Patient transferred to morgue
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientTransferredToMorgue = DICOMControlledTerminologyDefinitionsCode("122039")
    """
    Identified personnel or staff arrived in procedure room
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PersonnelArrived = DICOMControlledTerminologyDefinitionsCode("122041")
    """
    Identified personnel or staff departed procedure room
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PersonnelDeparted = DICOMControlledTerminologyDefinitionsCode("122042")
    """
    Page sent to identified personnel or staff
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PageSentTo = DICOMControlledTerminologyDefinitionsCode("122043")
    """
    Consultation with identified personnel or staff
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ConsultationWith = DICOMControlledTerminologyDefinitionsCode("122044")
    """
    Office of identified personnel or staff was called
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OfficeCalled = DICOMControlledTerminologyDefinitionsCode("122045")
    """
    Equipment failure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EquipmentFailure = DICOMControlledTerminologyDefinitionsCode("122046")
    """
    Equipment brought to procedure room
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EquipmentBroughtToProcedureRoom = DICOMControlledTerminologyDefinitionsCode(
        "122047"
    )
    """
    Equipment ready for procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EquipmentReady = DICOMControlledTerminologyDefinitionsCode("122048")
    """
    Equipment removed from procedure room
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EquipmentRemoved = DICOMControlledTerminologyDefinitionsCode("122049")
    """
    Device for obtaining biopsy sample
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Bioptome = DICOMControlledTerminologyDefinitionsCode("122052")
    """
    Valvular Intervention
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ValvularIntervention = DICOMControlledTerminologyDefinitionsCode("122053")
    """
    Aortic Intervention
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AorticIntervention = DICOMControlledTerminologyDefinitionsCode("122054")
    """
    Septal Defect Intervention
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SeptalDefectIntervention = DICOMControlledTerminologyDefinitionsCode("122055")
    """
    Vascular Intervention
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VascularIntervention = DICOMControlledTerminologyDefinitionsCode("122056")
    """
    Myocardial biopsy
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MyocardialBiopsy = DICOMControlledTerminologyDefinitionsCode("122057")
    """
    Arterial conduit angiography
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ArterialConduitAngiography = DICOMControlledTerminologyDefinitionsCode("122058")
    """
    Single plane Angiography
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SinglePlaneAngiography = DICOMControlledTerminologyDefinitionsCode("122059")
    """
    Bi-plane Angiography
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Bi_planeAngiography = DICOMControlledTerminologyDefinitionsCode("122060")
    """
    Percutaneous Coronary Intervention
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PercutaneousCoronaryIntervention = DICOMControlledTerminologyDefinitionsCode(
        "122061"
    )
    """
    15-Lead electrocardiography
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    _15_LeadECG = DICOMControlledTerminologyDefinitionsCode("122062")
    """
    Log of events occurring prior to the current procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Pre_procedureLog = DICOMControlledTerminologyDefinitionsCode("122072")
    """
    Analysis or measurements for current procedure (purpose of reference to
    evidence document)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CurrentProcedureEvidence = DICOMControlledTerminologyDefinitionsCode("122073")
    """
    Prior report for current patient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PriorReportForCurrentPatient = DICOMControlledTerminologyDefinitionsCode("122075")
    """
    Identifier of Consumable taken from inventory
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ConsumableTakenFromInventory = DICOMControlledTerminologyDefinitionsCode("122076")
    """
    Identifier of Consumable returned to inventory
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ConsumableReturnedToInventory = DICOMControlledTerminologyDefinitionsCode("122077")
    """
    Identifier of consumable whose remaining content has been disposed
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RemainingConsumableDisposed = DICOMControlledTerminologyDefinitionsCode("122078")
    """
    Identifier of Consumable determined to be unusable
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ConsumableUnusable = DICOMControlledTerminologyDefinitionsCode("122079")
    """
    Identifier of Drug whose administration has started
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DrugStart = DICOMControlledTerminologyDefinitionsCode("122081")
    """
    Identifier of Drug whose administration has ended
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DrugEnd = DICOMControlledTerminologyDefinitionsCode("122082")
    """
    Identifier of Drug administered as part of procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DrugAdministered = DICOMControlledTerminologyDefinitionsCode("122083")
    """
    Identifier of Contrast agent whose administration has started
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ContrastStart = DICOMControlledTerminologyDefinitionsCode("122084")
    """
    Identifier of Contrast agent whose administration has ended
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ContrastEnd = DICOMControlledTerminologyDefinitionsCode("122085")
    """
    Identifier of Contrast agent administered
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ContrastAdministered = DICOMControlledTerminologyDefinitionsCode("122086")
    """
    Identifier of Infusate whose administration has started
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    InfusateStart = DICOMControlledTerminologyDefinitionsCode("122087")
    """
    Identifier of Infusate whose administration has ended
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    InfusateEnd = DICOMControlledTerminologyDefinitionsCode("122088")
    """
    Action of a device traversing a vascular lesion
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DeviceCrossedLesion = DICOMControlledTerminologyDefinitionsCode("122089")
    """
    Action of a clinical professional performed on a patient for therapeutic
    purpose
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    InterventionAction = DICOMControlledTerminologyDefinitionsCode("122090")
    """
    Volume of Drug, Contrast agent, or Infusate administered
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VolumeAdministered = DICOMControlledTerminologyDefinitionsCode("122091")
    """
    Undiluted dose of Drug, Contrast agent, or Infusate administered
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    UndilutedDoseAdministered = DICOMControlledTerminologyDefinitionsCode("122092")
    """
    Concentration of Drug, Contrast agent, or Infusate administered
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Concentration = DICOMControlledTerminologyDefinitionsCode("122093")
    """
    Rate of Drug, Contrast agent, or Infusate administration
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RateOfAdministration = DICOMControlledTerminologyDefinitionsCode("122094")
    """
    Duration of Drug, Contrast agent, or Infusate administration
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DurationOfAdministration = DICOMControlledTerminologyDefinitionsCode("122095")
    """
    Volume of Drug, Contrast agent, or Infusate unadministered or discarded
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VolumeUnadministeredOrDiscarded = DICOMControlledTerminologyDefinitionsCode(
        "122096"
    )
    """
    Numeric parameter of Curvature of Catheter
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CatheterCurve = DICOMControlledTerminologyDefinitionsCode("122097")
    """
    Transmit Frequency
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TransmitFrequency = DICOMControlledTerminologyDefinitionsCode("122098")
    """
    Measured change of patient electrocardiographic ST level relative to baseline
    measurement
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    STChangeFromBaseline = DICOMControlledTerminologyDefinitionsCode("122099")
    """
    Anatomic term modifier indicating aneurysm on cited vessel is the subject of
    the finding
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AneurysmOnCitedVessel = DICOMControlledTerminologyDefinitionsCode("122101")
    """
    Anatomic term modifier indicating proximal section of graft to cited vessel is
    the subject of the finding
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    GraftToCitedSegment_ProximalSection = DICOMControlledTerminologyDefinitionsCode(
        "122102"
    )
    """
    Anatomic term modifier indicating mid section of graft to cited vessel is the
    subject of the finding
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    GraftToCitedSegment_MidSection = DICOMControlledTerminologyDefinitionsCode("122103")
    """
    Anatomic term modifier indicating distal section of graft to cited vessel is
    the subject of the finding
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    GraftToCitedSegment_DistalSection = DICOMControlledTerminologyDefinitionsCode(
        "122104"
    )
    """
    DateTime of Intervention
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DateTimeOfIntervention = DICOMControlledTerminologyDefinitionsCode("122105")
    """
    Duration of Intervention
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DurationOfIntervention = DICOMControlledTerminologyDefinitionsCode("122106")
    """
    Lesion stenosis measured prior to any interventional procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BaselineStenosisMeasurement = DICOMControlledTerminologyDefinitionsCode("122107")
    """
    Lesion stenosis measured after an interventional procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Post_InterventionStenosisMeasurement = DICOMControlledTerminologyDefinitionsCode(
        "122108"
    )
    """
    Assessment of perfusion across a coronary lesion measured prior to any
    interventional procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BaselineTIMIFlow = DICOMControlledTerminologyDefinitionsCode("122109")
    """
    Assessment of perfusion across a coronary lesion measured after an
    interventional procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Post_InterventionTIMIFlow = DICOMControlledTerminologyDefinitionsCode("122110")
    """
    Indication that device is the primary (first and/or most significant) device
    used for interventional therapy of a particular pathology; e.g. lesion
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PrimaryInterventionDevice = DICOMControlledTerminologyDefinitionsCode("122111")
    """
    Normal Myocardium
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NormalMyocardium = DICOMControlledTerminologyDefinitionsCode("122112")
    """
    Sacrred Myocardial
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SacrredMyocardial = DICOMControlledTerminologyDefinitionsCode("122113")
    """
    Thinning Myocardium
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ThinningMyocardium = DICOMControlledTerminologyDefinitionsCode("122114")
    """
    Hemodynamics Report
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    HemodynamicsReport = DICOMControlledTerminologyDefinitionsCode("122120")
    """
    Atrial pressure measurements, report section
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AtrialPressureMeasurements = DICOMControlledTerminologyDefinitionsCode("122121")
    """
    Ventricular pressure measurements, report section
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VentricularPressureMeasurements = DICOMControlledTerminologyDefinitionsCode(
        "122122"
    )
    """
    Gradient assessment, report section
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    GradientAssessment = DICOMControlledTerminologyDefinitionsCode("122123")
    """
    Blood velocity measurements, report section
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BloodVelocityMeasurements = DICOMControlledTerminologyDefinitionsCode("122124")
    """
    Blood lab measurements, report section
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BloodLabMeasurements = DICOMControlledTerminologyDefinitionsCode("122125")
    """
    Derived Hemodynamic Measurements, report section
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DerivedHemodynamicMeasurements = DICOMControlledTerminologyDefinitionsCode("122126")
    """
    Clinical Context, report section
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ClinicalContext = DICOMControlledTerminologyDefinitionsCode("122127")
    """
    Location from which the patient was transferred
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PatientTransferredFrom = DICOMControlledTerminologyDefinitionsCode("122128")
    """
    Indication that the procedure includes a percutaneous coronary intervention
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PCIDuringThisProcedure = DICOMControlledTerminologyDefinitionsCode("122129")
    """
    Radiation dose times area of exposure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DoseAreaProduct = DICOMControlledTerminologyDefinitionsCode("122130")
    """
    Finding of probability and/or severity of thrombus
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DegreeOfThrombus = DICOMControlledTerminologyDefinitionsCode("122131")
    """
    Severity of Calcification, property of lesion
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SeverityOfCalcification = DICOMControlledTerminologyDefinitionsCode("122132")
    """
    Lesion Morphology; form and/or structural properties of lesion
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LesionMorphology = DICOMControlledTerminologyDefinitionsCode("122133")
    """
    Vessel Morphology; form and/or structural properties of vessel
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VesselMorphology = DICOMControlledTerminologyDefinitionsCode("122134")
    """
    Technique (device or procedure) of support for patient circulatory system;
    hemodynamic support
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CirculatorySupport = DICOMControlledTerminologyDefinitionsCode("122138")
    """
    Reason for Exam
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ReasonForExam = DICOMControlledTerminologyDefinitionsCode("122139")
    """
    Indication that the current exam data has been compared with prior exam data
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ComparisonWithPriorExamDone = DICOMControlledTerminologyDefinitionsCode("122140")
    """
    Electrocardiographic electrode placement technique
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ElectrodePlacement = DICOMControlledTerminologyDefinitionsCode("122141")
    """
    Acquisition Device Type
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AcquisitionDeviceType = DICOMControlledTerminologyDefinitionsCode("122142")
    """
    Acquisition Device ID
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AcquisitionDeviceID = DICOMControlledTerminologyDefinitionsCode("122143")
    """
    Quantitative Analysis, report section
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    QuantitativeAnalysis = DICOMControlledTerminologyDefinitionsCode("122144")
    """
    Qualitative Analysis, report section
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    QualitativeAnalysis = DICOMControlledTerminologyDefinitionsCode("122145")
    """
    The date and time on which a procedure was performed on a patient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ProcedureDateTime = DICOMControlledTerminologyDefinitionsCode("122146")
    """
    Clinical Interpretation, report section
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ClinicalInterpretation = DICOMControlledTerminologyDefinitionsCode("122147")
    """
    ECG Lead Identifier
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LeadID = DICOMControlledTerminologyDefinitionsCode("122148")
    """
    Beat Number; ordinal of cardiac cycle within an acquisition
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BeatNumber = DICOMControlledTerminologyDefinitionsCode("122149")
    """
    Complex coded semantic unit, consisting of several coded components
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CompoundStatement = DICOMControlledTerminologyDefinitionsCode("122150")
    """
    Trend (temporal progression) of a clinical condition, finding, or disease
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Trend = DICOMControlledTerminologyDefinitionsCode("122151")
    """
    Coded semantic unit
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Statement = DICOMControlledTerminologyDefinitionsCode("122152")
    """
    Coded modifier for a semantic unit
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StatementModifier = DICOMControlledTerminologyDefinitionsCode("122153")
    """
    Conjunctive term between semantic units
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ConjunctiveTerm = DICOMControlledTerminologyDefinitionsCode("122154")
    """
    Probability
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Probability = DICOMControlledTerminologyDefinitionsCode("122157")
    """
    ECG Global Measurements, report section
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ECGGlobalMeasurements = DICOMControlledTerminologyDefinitionsCode("122158")
    """
    ECG Lead Measurements, report section
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ECGLeadMeasurements = DICOMControlledTerminologyDefinitionsCode("122159")
    """
    Derived cross-sectional area of a vessel or anatomic feature, other than a
    cardiac valve
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DerivedArea_Non_Valve = DICOMControlledTerminologyDefinitionsCode("122160")
    """
    Rate of blood flow through Pulmonary artery
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PulmonaryFlow = DICOMControlledTerminologyDefinitionsCode("122161")
    """
    Rate of blood flow through the aorta
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SystemicFlow = DICOMControlledTerminologyDefinitionsCode("122162")
    """
    DateTime of patient discharge from hospital admission
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DischargeDateTime = DICOMControlledTerminologyDefinitionsCode("122163")
    """
    Indication that a Coronary Artery Bypass operation was performed during the
    current hospital admission
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CoronaryArteryBypassDuringThisAdmission = DICOMControlledTerminologyDefinitionsCode(
        "122164"
    )
    """
    Date of Death
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DateOfDeath = DICOMControlledTerminologyDefinitionsCode("122165")
    """
    Indication that the patient died during the current hospital admission
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DeathDuringThisAdmission = DICOMControlledTerminologyDefinitionsCode("122166")
    """
    Indication that the patient died during the current Catheterization procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DeathDuringCatheterization = DICOMControlledTerminologyDefinitionsCode("122167")
    """
    Finding of type of Myocardial Infarction
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TypeOfMyocardialInfarction = DICOMControlledTerminologyDefinitionsCode("122170")
    """
    Finding of Coronary lesion with greater than 50% stenosis
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CoronaryLesion_50_Stenosis = DICOMControlledTerminologyDefinitionsCode("122171")
    """
    Finding of Acute Myocardial Infarction Presence as indication for
    interventional procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AcuteMIPresent = DICOMControlledTerminologyDefinitionsCode("122172")
    """
    DateTime of first determination of elevated ECG ST segment, as indication of
    Myocardial Infarction
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    STElevationOnsetDateTime = DICOMControlledTerminologyDefinitionsCode("122173")
    """
    Number of lesion interventions attempted during current procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NumberOfLesionInterventionsAttempted = DICOMControlledTerminologyDefinitionsCode(
        "122175"
    )
    """
    Number of lesion interventions successful during current procedure, where the
    residual post intervention stenosis is less than or equal to 50% of the
    arterial luminal diameter, TIMI Flow is 3 and the minimal decrease in stenosis
    was 20%
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NumberOfLesionInterventionsSuccessful = DICOMControlledTerminologyDefinitionsCode(
        "122176"
    )
    """
    Overall success of interventional procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ProcedureResult = DICOMControlledTerminologyDefinitionsCode("122177")
    """
    Lesion Intervention Information, report section
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LesionInterventionInformation = DICOMControlledTerminologyDefinitionsCode("122178")
    """
    Indication that Myocardial Infarction occurred during current procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Peri_proceduralMIOccurred = DICOMControlledTerminologyDefinitionsCode("122179")
    """
    Creatine Kinase-MB value at baseline (start of procedure)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CK_MBBaseline = DICOMControlledTerminologyDefinitionsCode("122180")
    """
    Creatine Kinase-MB highest value measured during procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CK_MBPeak = DICOMControlledTerminologyDefinitionsCode("122181")
    """
    Time interval between ECG R-wave peaks in subsequent cardiac cycles
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    R_RInterval = DICOMControlledTerminologyDefinitionsCode("122182")
    """
    Blood temperature
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BloodTemperature = DICOMControlledTerminologyDefinitionsCode("122183")
    """
    Blood Oxygen content
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BloodOxygenContent = DICOMControlledTerminologyDefinitionsCode("122185")
    """
    Blood Carbon dioxide saturation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BloodCarbonDioxideSaturation = DICOMControlledTerminologyDefinitionsCode("122187")
    """
    Pulmonary Arterial Content (FCpa)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PulmonaryArterialContent_FCpa_ = DICOMControlledTerminologyDefinitionsCode("122188")
    """
    Pulmonary Venous Content (FCpv)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PulmonaryVenousContent_FCpv_ = DICOMControlledTerminologyDefinitionsCode("122189")
    """
    Max dp/dt/P
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MaxDp_dt_P = DICOMControlledTerminologyDefinitionsCode("122190")
    """
    Ventricular End Diastolic pressure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VentricularEndDiastolicPressure = DICOMControlledTerminologyDefinitionsCode(
        "122191"
    )
    """
    Elapsed time from injection of an indicator bolus until it is observed at
    another location
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IndicatorAppearanceTime = DICOMControlledTerminologyDefinitionsCode("122192")
    """
    Maximum pressure acceleration
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MaximumPressureAcceleration = DICOMControlledTerminologyDefinitionsCode("122193")
    """
    Ventricular Systolic blood pressure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VentricularSystolicBloodPressure = DICOMControlledTerminologyDefinitionsCode(
        "122194"
    )
    """
    Pulse Strength; palpable strength of systolic flow
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PulseStrength = DICOMControlledTerminologyDefinitionsCode("122195")
    """
    The secondary peak pressure in the atrium during atrial contraction
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CWavePressure = DICOMControlledTerminologyDefinitionsCode("122196")
    """
    Gradient pressure, average
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    GradientPressure_Average = DICOMControlledTerminologyDefinitionsCode("122197")
    """
    Gradient pressure, peak
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    GradientPressure_Peak = DICOMControlledTerminologyDefinitionsCode("122198")
    """
    Pressure at dp/dt max
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PressureAtDp_dtMax = DICOMControlledTerminologyDefinitionsCode("122199")
    """
    Diastolic blood velocity, mean
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DiastolicBloodVelocity_Mean = DICOMControlledTerminologyDefinitionsCode("122201")
    """
    Diastolic blood velocity, peak
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DiastolicBloodVelocity_Peak = DICOMControlledTerminologyDefinitionsCode("122202")
    """
    Systolic blood velocity, mean
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SystolicBloodVelocity_Mean = DICOMControlledTerminologyDefinitionsCode("122203")
    """
    Systolic blood velocity, peak
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SystolicBloodVelocity_Peak = DICOMControlledTerminologyDefinitionsCode("122204")
    """
    Blood velocity, mean
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BloodVelocity_Mean = DICOMControlledTerminologyDefinitionsCode("122205")
    """
    Blood velocity, minimum
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BloodVelocity_Minimum = DICOMControlledTerminologyDefinitionsCode("122206")
    """
    Blood velocity, peak
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BloodVelocity_Peak = DICOMControlledTerminologyDefinitionsCode("122207")
    """
    Venous or atrial pressure minimum during ventricular systole, after A-wave
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    X_descentPressure = DICOMControlledTerminologyDefinitionsCode("122208")
    """
    Venous or atrial pressure minimum when tricuspid valve opens during diastole,
    after V-wave
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Y_descentPressure = DICOMControlledTerminologyDefinitionsCode("122209")
    """
    Atrial pressure upon closure of tricuspid and mitral valves
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Z_pointPressure = DICOMControlledTerminologyDefinitionsCode("122210")
    """
    Left Ventricular ejection time
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LeftVentricularEjectionTime = DICOMControlledTerminologyDefinitionsCode("122211")
    """
    Left Ventricular filling time
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LeftVentricularFillingTime = DICOMControlledTerminologyDefinitionsCode("122212")
    """
    Right Ventricular ejection time
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RightVentricularEjectionTime = DICOMControlledTerminologyDefinitionsCode("122213")
    """
    Right Ventricular filling time
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RightVentricularFillingTime = DICOMControlledTerminologyDefinitionsCode("122214")
    """
    Total Pulmonary Resistance
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TotalPulmonaryResistance = DICOMControlledTerminologyDefinitionsCode("122215")
    """
    Total Vascular Resistance
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TotalVascularResistance = DICOMControlledTerminologyDefinitionsCode("122216")
    """
    Coronary Flow reserve
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CoronaryFlowReserve = DICOMControlledTerminologyDefinitionsCode("122217")
    """
    Diastolic/Systolic velocity ratio
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Diastolic_SystolicVelocityRatio = DICOMControlledTerminologyDefinitionsCode(
        "122218"
    )
    """
    Hyperemic ratio
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    HyperemicRatio = DICOMControlledTerminologyDefinitionsCode("122219")
    """
    Hemodynamic Resistance Index
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    HemodynamicResistanceIndex = DICOMControlledTerminologyDefinitionsCode("122220")
    """
    Thorax diameter, sagittal
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ThoraxDiameter_Sagittal = DICOMControlledTerminologyDefinitionsCode("122221")
    """
    Environmental characteristics in the procedure room
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ProcedureEnvironmentalCharacteristics = DICOMControlledTerminologyDefinitionsCode(
        "122222"
    )
    """
    Oxygen concentration in the procedure room
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RoomOxygenConcentration = DICOMControlledTerminologyDefinitionsCode("122223")
    """
    Temperature in the procedure room
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RoomTemperature = DICOMControlledTerminologyDefinitionsCode("122224")
    """
    Barometric pressure in the procedure room
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RoomBarometricPressure = DICOMControlledTerminologyDefinitionsCode("122225")
    """
    Left to Right Flow
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LeftToRightFlow = DICOMControlledTerminologyDefinitionsCode("122227")
    """
    Right to Left Flow
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RightToLeftFlow = DICOMControlledTerminologyDefinitionsCode("122228")
    """
    Arteriovenous oxygen content difference
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ArteriovenousDifference = DICOMControlledTerminologyDefinitionsCode("122229")
    """
    Framingham Study 10 Year CHD Risk
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    _10YearCHDRisk = DICOMControlledTerminologyDefinitionsCode("122230")
    """
    Framingham Study Comparative Average10 Year CHD Risk
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ComparativeAverage10YearCHDRisk = DICOMControlledTerminologyDefinitionsCode(
        "122231"
    )
    """
    Framingham Study Comparative Low10 Year CHD Risk
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ComparativeLow10YearCHDRisk = DICOMControlledTerminologyDefinitionsCode("122232")
    """
    Framingham Study LDL Cholesterol Score Sheet for Men
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LDLCholesterolScoreSheetForMen = DICOMControlledTerminologyDefinitionsCode("122233")
    """
    Framingham Study LDL Cholesterol Score Sheet for Women
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LDLCholesterolScoreSheetForWomen = DICOMControlledTerminologyDefinitionsCode(
        "122234"
    )
    """
    Framingham Study Total Cholesterol Score Sheet for Men
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TotalCholesterolScoreSheetForMen = DICOMControlledTerminologyDefinitionsCode(
        "122235"
    )
    """
    Framingham Study Total Cholesterol Score Sheet for Women
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TotalCholesterolScoreSheetForWomen = DICOMControlledTerminologyDefinitionsCode(
        "122236"
    )
    """
    Corrected Sinus Node Recovery Time
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CorrectedSinusNodeRecoveryTime = DICOMControlledTerminologyDefinitionsCode("122237")
    """
    Max volume normalized to 50mmHg pulse pressure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MaxVolumeNormalizedTo50mmHgPulsePressure = (
        DICOMControlledTerminologyDefinitionsCode("122238")
    )
    """
    Oxygen Consumption
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OxygenConsumption = DICOMControlledTerminologyDefinitionsCode("122239")
    """
    Body Surface Area computed from patient height and weight: BSA =
    3.207*WT[g]^(0.7285-0.0188 log (WT[g])) *HT[cm] ^ 0.3 [Boyd E, The growth of
    the surface area of the human body. Minneapolis: University of Minnesota
    Press, 1935, eq. (36) ]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BSA_3_207_WT_0_7285_0_0188Log_WT_HT_0_3 = DICOMControlledTerminologyDefinitionsCode(
        "122240"
    )
    """
    Body Surface Area computed from patient height and weight: BSA = 0.007184*
    WT[kg] ^ 0.425*HT[cm] ^ 0.725 [Dubois and Dubois, Arch Int Med 1916 17:863-71]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BSA_0_007184_WT_0_425_HT_0_725 = DICOMControlledTerminologyDefinitionsCode("122241")
    """
    Body Surface Area computed from patient height and weight: BSA = 0.0235*
    WT[kg] ^0.51456*HT[cm]^ 0.42246 [Gehan EA, George SL, 'Estimation of human
    body surface area from height and weight', Cancer Chemother Rep 1970
    54:225-35]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BSA_0_0235_WT_0_51456_HT_0_42246 = DICOMControlledTerminologyDefinitionsCode(
        "122242"
    )
    """
    Body Surface Area computed from patient height and weight: BSA = 0.024265 *
    WT[kg] ^ 0.5378 * HT[cm] ^ 0.3964 [Haycock G.B., Schwartz G.J., Wisotsky D.H.
    'Geometric method for measuring body surface area: A height weight formula
    validated in infants, children and adults.' The Journal of Pediatrics 1978
    93:1:62-66]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BSA_0_024265_WT_0_5378_HT_0_3964 = DICOMControlledTerminologyDefinitionsCode(
        "122243"
    )
    """
    Body Surface Area computed from patient height and weight: BSA = (HT[m] *
    WT[kg] / 36) ^ 0.5 [Mosteller, R.D. 'Simplified Calculation of Body Surface
    Area.' N Engl J Med 1987 Oct 22;317(17):1098]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BSA_HT_WT_36_0_5 = DICOMControlledTerminologyDefinitionsCode("122244")
    """
    Body Surface Area computed from patient weight:BSA = 1321 + 0.3433 * WT[kg]
    (for pediatrics 3-30 kg) [Current, J.D. 'A Linear Equation For Estimating The
    Body Surface Area In Infants And Children', The Internet Journal of
    Anesthesiology. 1998. 2:2]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BSA_1321_0_3433_WT = DICOMControlledTerminologyDefinitionsCode("122245")
    """
    BSA = 0.0004688 * (1000 * WT) ^ (0.8168 - 0.0154 * log(1000 * WT)) Where (WT
    is weight in kilogram) Units = m2 Boyd, Edith. The Growth of the Surface Area
    of the Human Body(originally published in 1935 by the University of Minnesota
    Press), Greenwood Press, Westport, Connecticut, 1975, p. 102.Equation (35)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BSA_0_0004688_WT_0_8168_0_0154_Log_WT_ = DICOMControlledTerminologyDefinitionsCode(
        "122246"
    )
    """
    Equation for estimated oxygen consumption: VO2male = BSA (138.1 - 11.49 *
    loge(age) + 0.378 * HRf)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VO2male_BSA_138_1_11_49_Loge_age_0_378_HRf_ = (
        DICOMControlledTerminologyDefinitionsCode("122247")
    )
    """
    Equation for estimated oxygen consumption: VO2female = BSA (138.1 - 17.04 *
    loge(age) + 0.378 * HRf)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VO2female_BSA_138_1_17_04_Loge_age_0_378_HRf_ = (
        DICOMControlledTerminologyDefinitionsCode("122248")
    )
    """
    Equation for estimated oxygen consumption: VO2 = VeSTPD * 10 * (FIO2 - FE02)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VO2_VeSTPD_10_FIO2_FE02_ = DICOMControlledTerminologyDefinitionsCode("122249")
    """
    Equation for estimated oxygen consumption: VO2 = 152 * BSA
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VO2_152_BSA = DICOMControlledTerminologyDefinitionsCode("122250")
    """
    Equation for estimated oxygen consumption: VO2 = 175 * BSA
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VO2_175_BSA = DICOMControlledTerminologyDefinitionsCode("122251")
    """
    Equation for estimated oxygen consumption: VO2 = 176 * BSA
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VO2_176_BSA = DICOMControlledTerminologyDefinitionsCode("122252")
    """
    Robertson & Reid Table for estimated oxygen consumption
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Robertson_ReidTable = DICOMControlledTerminologyDefinitionsCode("122253")
    """
    Fleisch table for estimated oxygen consumption
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FleischTable = DICOMControlledTerminologyDefinitionsCode("122254")
    """
    Boothby table for estimated oxygen consumption
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BoothbyTable = DICOMControlledTerminologyDefinitionsCode("122255")
    """
    Estimate of Oxygen partial pressure at 50% saturation for premature infants
    less than 3 days old: P50 = 19.9
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    If_premAge_3days_P50_19_9 = DICOMControlledTerminologyDefinitionsCode("122256")
    """
    Estimate of Oxygen partial pressure at 50% saturation for infants less than 1
    day old: P50 = 21.6
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    If_age_1day_P50_21_6 = DICOMControlledTerminologyDefinitionsCode("122257")
    """
    Estimate of Oxygen partial pressure at 50% saturation for infants less than 30
    days old: P50 = 24.6
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    If_age_30day_P50_24_6 = DICOMControlledTerminologyDefinitionsCode("122258")
    """
    Estimate of Oxygen partial pressure at 50% saturation for patients less than
    18 years old: P50 = 27.2
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    If_age_18y_P50_27_2 = DICOMControlledTerminologyDefinitionsCode("122259")
    """
    Estimate of Oxygen partial pressure at 50% saturation for patients less than
    40 years old: P50 = 27.4
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    If_age_40y_P50_27_4 = DICOMControlledTerminologyDefinitionsCode("122260")
    """
    Estimate of Oxygen partial pressure at 50% saturation for patients more than
    60 years old: P50 = 29.3
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    If_age_60y_P50_29_3 = DICOMControlledTerminologyDefinitionsCode("122261")
    """
    Cardiac valve area computed from flow and pressure gradient: Area = Flow /
    44.5 * sqrt(Gradient[mmHg]) [Gorlin and Gorlin, Am Heart J, 1951]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Area_Flow_44_5_Sqrt_Gradient_mmHg_ = DICOMControlledTerminologyDefinitionsCode(
        "122262"
    )
    """
    Mitral valve area computed from flow and pressure gradient: Mitral valve Area
    = Flow / 38.0 * sqrt(Gradient[mmHg]) [Gorlin and Gorlin, Am Heart J, 1951]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MVA_Flow_38_0_Sqrt_Gradient_mmHg_ = DICOMControlledTerminologyDefinitionsCode(
        "122263"
    )
    """
    Body Mass Index computed from weight and height: BMI = Wt/Ht^2
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BMI_Wt_Ht_2 = DICOMControlledTerminologyDefinitionsCode("122265")
    """
    Body Surface Area computed from patient height and weight: BSA = 0.007358 *
    WT[kg] ^ 0.425 * HT[cm] ^ 0.725 (for East Asian adult, aged 15+ years) [Kanai
    Izumi, Masamitsu Kanai, 'Clinical examination method summary']
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BSA_0_007358_WT_0_425_HT_0_725 = DICOMControlledTerminologyDefinitionsCode("122266")
    """
    Body Surface Area computed from patient height and weight: BSA = 0.010265 *
    WT[kg] ^ 0.423 * HT[cm] ^ 0.651 (For East Asian child aged 12-14 years)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BSA_0_010265_WT_0_423_HT_0_651 = DICOMControlledTerminologyDefinitionsCode("122267")
    """
    Body Surface Area computed from patient height and weight: BSA = 0.008883*
    WT[kg] ^ 0.444 * HT[cm] ^ 0.663 (For East Asian child aged 6-11 years)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BSA_0_008883_WT_0_444_HT_0_663 = DICOMControlledTerminologyDefinitionsCode("122268")
    """
    Body Surface Area computed from patient height and weight: BSA = 0.038189 *
    WT[kg] ^ 0.423 * HT[cm] ^ 0.362 (For East Asian child aged 1-5 years)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BSA_0_038189_WT_0_423_HT_0_362 = DICOMControlledTerminologyDefinitionsCode("122269")
    """
    Body Surface Area computed from patient height and weight: BSA = 0.009568*
    WT[kg] ^ 0.473 * HT[cm] ^ 0.655 (For East Asian child aged 0-12 months)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BSA_0_009568_WT_0_473_HT_0_655 = DICOMControlledTerminologyDefinitionsCode("122270")
    """
    Skin Condition Warm
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SkinConditionWarm = DICOMControlledTerminologyDefinitionsCode("122271")
    """
    Skin Condition Cool
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SkinConditionCool = DICOMControlledTerminologyDefinitionsCode("122272")
    """
    Skin Condition Cold
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SkinConditionCold = DICOMControlledTerminologyDefinitionsCode("122273")
    """
    Skin Condition Dry
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SkinConditionDry = DICOMControlledTerminologyDefinitionsCode("122274")
    """
    Skin Condition Clammy
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SkinConditionClammy = DICOMControlledTerminologyDefinitionsCode("122275")
    """
    Skin Condition Diaphoretic
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SkinConditionDiaphoretic = DICOMControlledTerminologyDefinitionsCode("122276")
    """
    Skin Condition Flush
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SkinConditionFlush = DICOMControlledTerminologyDefinitionsCode("122277")
    """
    Skin Condition Mottled
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SkinConditionMottled = DICOMControlledTerminologyDefinitionsCode("122278")
    """
    Skin Condition Pale
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SkinConditionPale = DICOMControlledTerminologyDefinitionsCode("122279")
    """
    Airway unobstructed
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AirwayUnobstructed = DICOMControlledTerminologyDefinitionsCode("122281")
    """
    Airway partially obstructed
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AirwayPartiallyObstructed = DICOMControlledTerminologyDefinitionsCode("122282")
    """
    Airway severely obstructed
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AirwaySeverelyObstructed = DICOMControlledTerminologyDefinitionsCode("122283")
    """
    Anatomy could not be visualized for the purpose of evaluation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NotVisualized = DICOMControlledTerminologyDefinitionsCode("122288")
    """
    Quantitative Arteriography Report
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    QuantitativeArteriographyReport = DICOMControlledTerminologyDefinitionsCode(
        "122291"
    )
    """
    Quantitative Ventriculography Report
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    QuantitativeVentriculographyReport = DICOMControlledTerminologyDefinitionsCode(
        "122292"
    )
    """
    Guidewire crossing lesion unsuccessful
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    GuidewireCrossingLesionUnsuccessful = DICOMControlledTerminologyDefinitionsCode(
        "122301"
    )
    """
    Guidewire crossing lesion successful
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    GuidewireCrossingLesionSuccessful = DICOMControlledTerminologyDefinitionsCode(
        "122302"
    )
    """
    Angioplasty balloon inflated
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AngioplastyBalloonInflated = DICOMControlledTerminologyDefinitionsCode("122303")
    """
    Angioplasty balloon deflated
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AngioplastyBalloonDeflated = DICOMControlledTerminologyDefinitionsCode("122304")
    """
    Device deployed
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DeviceDeployed = DICOMControlledTerminologyDefinitionsCode("122305")
    """
    Stent re-expanded
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StentRe_expanded = DICOMControlledTerminologyDefinitionsCode("122306")
    """
    Object removed
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ObjectRemoved = DICOMControlledTerminologyDefinitionsCode("122307")
    """
    Radiation applied
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RadiationApplied = DICOMControlledTerminologyDefinitionsCode("122308")
    """
    Radiation removed
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RadiationRemoved = DICOMControlledTerminologyDefinitionsCode("122309")
    """
    Interventional device placement unsuccessful
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    InterventionalDevicePlacementUnsuccessful = (
        DICOMControlledTerminologyDefinitionsCode("122310")
    )
    """
    Interventional device placed
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    InterventionalDevicePlaced = DICOMControlledTerminologyDefinitionsCode("122311")
    """
    Intervention performed
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    InterventionPerformed = DICOMControlledTerminologyDefinitionsCode("122312")
    """
    Interventional device withdrawn
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    InterventionalDeviceWithdrawn = DICOMControlledTerminologyDefinitionsCode("122313")
    """
    Catheter Size
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CatheterSize = DICOMControlledTerminologyDefinitionsCode("122319")
    """
    Injectate Temperature
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    InjectateTemperature = DICOMControlledTerminologyDefinitionsCode("122320")
    """
    Injectate Volume
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    InjectateVolume = DICOMControlledTerminologyDefinitionsCode("122321")
    """
    Factor by which a measured or calculated value is multiplied to obtain the
    estimated real-world value
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CalibrationFactor = DICOMControlledTerminologyDefinitionsCode("122322")
    """
    Intravascular Ultrasound Report
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IVUSReport = DICOMControlledTerminologyDefinitionsCode("122325")
    """
    External Elastic Membrane (EEM) diameter measured through the center point of
    the vessel. Center point of the vessel is defined as the center of gravity of
    the EEM area. The EEM is a discrete interface at the border between the media
    and the adventitia
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EEMDiameter = DICOMControlledTerminologyDefinitionsCode("122330")
    """
    The distance from intimal leading edge to the external elastic membrane along
    any line passing through the luminal center, which is defined as the center of
    gravity of the lumen area
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PlaquePlusMediaThickness = DICOMControlledTerminologyDefinitionsCode("122331")
    """
    Planimetered perimeter of the lumen
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LumenPerimeter = DICOMControlledTerminologyDefinitionsCode("122332")
    """
    Vessel area measured at the External Elastic Membrane (EEM), a discrete
    interface at the border between the media and the adventitia
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EEMCross_SectionalArea = DICOMControlledTerminologyDefinitionsCode("122333")
    """
    Area within the EEM occupied by atheroma, regardless of lumen compromise.
    Plaque plus Media Area = EEM cross-sectional area - vessel lumen cross-
    sectional area
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PlaquePlusMediaCross_SectionalArea = DICOMControlledTerminologyDefinitionsCode(
        "122334"
    )
    """
    Measurement of in-stent restenosis. In-Stent Intimal Area = Stent cross-
    sectional area - vessel lumen cross-sectional area
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    In_StentNeointimalCross_SectionalArea = DICOMControlledTerminologyDefinitionsCode(
        "122335"
    )
    """
    Longitudinal extent of the Vascular Volume Measurement. This is the distance
    from the distal edge to the proximal edge of the Volume measurement
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VascularVolumeMeasurementLength = DICOMControlledTerminologyDefinitionsCode(
        "122336"
    )
    """
    Longitudinal distance from the closest edge of a fiducial feature or reference
    location to the start of the vascular measurement. This value will be a
    positive if the measurement is distal to the fiducial feature or reference
    location, or negative if the measurement is proximal to the fiducial feature
    or reference location
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RelativePosition = DICOMControlledTerminologyDefinitionsCode("122337")
    """
    In-Stent Neointimal Volume / Stent Volume
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StentVolumeObstruction = DICOMControlledTerminologyDefinitionsCode("122339")
    """
    Reference, normally anatomical, which is used for locating the position of a
    measurement
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FiducialFeature = DICOMControlledTerminologyDefinitionsCode("122340")
    """
    Longitudinal calcium length measurement
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CalciumLength = DICOMControlledTerminologyDefinitionsCode("122341")
    """
    Measurement of vessel lumen eccentricity. Lumen Eccentricity Index = (maximum
    vessel lumen diameter - minimum vessel lumen diameter) / maximum vessel lumen
    diameter. Lumen diameters are measured through the center point of the lumen,
    which is defined as the center of gravity of the lumen area
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LumenEccentricityIndex = DICOMControlledTerminologyDefinitionsCode("122343")
    """
    Plaque plus Media Eccentricity Index = (maximum Plaque plus media thickness -
    minimum Plaque plus media thickness) / maximum Plaque plus media thickness
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PlaquePlusMediaEccentricityIndex = DICOMControlledTerminologyDefinitionsCode(
        "122344"
    )
    """
    Measurement of increase or decrease in EEM area that occurs during the
    development of atherosclerosis. Remodeling Index = Lesion EEM area / reference
    EEM area
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RemodelingIndex = DICOMControlledTerminologyDefinitionsCode("122345")
    """
    Measurement of stent circularity. Stent Symmetry Index = (maximum stent
    diameter - minimum stent diameter) / maximum stent diameter
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StentSymmetryIndex = DICOMControlledTerminologyDefinitionsCode("122346")
    """
    Measurement of stent area relative to the reference lumen area. Stent
    Expansion Index = Minimum stent area / reference vessel lumen cross-sectional
    area
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StentExpansionIndex = DICOMControlledTerminologyDefinitionsCode("122347")
    """
    Measurement of vessel lumen eccentricity. Lumen Shape Index = (2p *
    sqrt(Vessel lumen cross-sectional area / p) / Lumen Perimeter) 2 Reference:
    Tobis & Yock, "Intravascular Ultrasound Imaging", Chapter 7
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LumenShapeIndex = DICOMControlledTerminologyDefinitionsCode("122348")
    """
    Lumen diameter ratio = minimum vessel lumen diameter / maximum vessel lumen
    diameter, measured at the same cross section in the vessel. Lumen diameters
    are measured through the center point of the lumen, which is defined as the
    center of gravity of the lumen area
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LumenDiameterRatio = DICOMControlledTerminologyDefinitionsCode("122350")
    """
    Stent diameter ratio = Minimum stent diameter / Maximum stent diameter,
    measured at the same cross section in the vessel. Stent diameters are measured
    through the center point of the stent, which is defined as the center of
    gravity of the stent area
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StentDiameterRatio = DICOMControlledTerminologyDefinitionsCode("122351")
    """
    EEM diameter ratio = minimum EEM diameter / maximum EEM diameter. Measured at
    the same cross section in the vessel
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EEMDiameterRatio = DICOMControlledTerminologyDefinitionsCode("122352")
    """
    Fractional area within the External Elastic Membrane (EEM) occupied by
    atheroma. Plaque Burden = (EEM area - vessel lumen cross-sectional area) / EEM
    area
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PlaqueBurden = DICOMControlledTerminologyDefinitionsCode("122354")
    """
    Angular measurement of a Calcium deposit with the apex located at the center
    of the lumen, which is defined as the center of gravity of the lumen area
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ArcOfCalcium = DICOMControlledTerminologyDefinitionsCode("122355")
    """
    Plaque characterized by low density or echogenicity
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SoftPlaque = DICOMControlledTerminologyDefinitionsCode("122356")
    """
    Abnormal thickening of the intima within the stented segment
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    In_StentNeointima = DICOMControlledTerminologyDefinitionsCode("122357")
    """
    Lumen surrounded by all three layers of the vessel-intima, media, and
    adventitia
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TrueLumen = DICOMControlledTerminologyDefinitionsCode("122360")
    """
    A channel, usually parallel to the true lumen, which does not communicate with
    the true lumen over a portion of its length
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FalseLumen = DICOMControlledTerminologyDefinitionsCode("122361")
    """
    Plaque ulceration with a tear detected in a fibrous cap
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PlaqueRupture = DICOMControlledTerminologyDefinitionsCode("122363")
    """
    Length of gap between two consecutive stents
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StentGap = DICOMControlledTerminologyDefinitionsCode("122364")
    """
    Worst stenosis - the stenosis with the smallest lumen size within a vessel
    segment
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    T_1Worst = DICOMControlledTerminologyDefinitionsCode("122367")
    """
    2nd most severe stenosis within a vessel segment
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    T_2Secondary = DICOMControlledTerminologyDefinitionsCode("122368")
    """
    3rd most severe stenosis within a vessel segment
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    T_3Secondary = DICOMControlledTerminologyDefinitionsCode("122369")
    """
    4th most severe stenosis within a vessel segment
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    T_4Secondary = DICOMControlledTerminologyDefinitionsCode("122370")
    """
    External Elastic Membrane (EEM) volume measured within a specified region. The
    EEM is a discrete interface at the border between the media and the Adventitia
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EEMVolume = DICOMControlledTerminologyDefinitionsCode("122371")
    """
    Lumen volume measured within a specified region
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LumenVolume = DICOMControlledTerminologyDefinitionsCode("122372")
    """
    The amount of plaque between the lumen and stent, within the stent region; In-
    stent restenosis. In-Stent Neointimal Volume = Stent Volume - Lumen Volume
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    In_StentNeointimalVolume = DICOMControlledTerminologyDefinitionsCode("122374")
    """
    The amount of plaque between the stent and the EEM, within the stent region.
    Native Plaque Volume = EEM Volume - Stent Volume
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NativePlaqueVolume = DICOMControlledTerminologyDefinitionsCode("122375")
    """
    Total amount of plaque between the EEM and the Lumen, over the entire region
    that is measured. Total Plaque Volume = EEM Volume - Lumen Volume
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TotalPlaqueVolume = DICOMControlledTerminologyDefinitionsCode("122376")
    """
    Proximal reference segment measurement site. Typically the site with the
    largest lumen proximal to a stenosis but within the same segment (usually
    within 10 mm of the stenosis with no major intervening branches)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ProximalReference = DICOMControlledTerminologyDefinitionsCode("122380")
    """
    Distal reference segment measurement site. Typically the site with the largest
    lumen distal to a stenosis but within the same segment (usually within 10 mm
    of the stenosis with no major intervening branches)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DistalReference = DICOMControlledTerminologyDefinitionsCode("122381")
    """
    Site of the smallest lumen in a vessel; e.g. due to a stenotic lesion
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SiteOfLumenMinimum = DICOMControlledTerminologyDefinitionsCode("122382")
    """
    Measurement region that encompasses the entire vessel imaged in a single
    pullback acquisition
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EntirePullback = DICOMControlledTerminologyDefinitionsCode("122383")
    """
    Measurement region occupied by the stent
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StentedRegion = DICOMControlledTerminologyDefinitionsCode("122384")
    """
    Region starting at the proximal edge of the Stent and extending several
    millimeters (usually 5 mm) proximal to the Stent edge
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ProximalStentMargin = DICOMControlledTerminologyDefinitionsCode("122385")
    """
    Region starting at the distal edge of the Stent and extending several
    millimeters (usually 5 mm) distal to the Stent edge
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DistalStentMargin = DICOMControlledTerminologyDefinitionsCode("122386")
    """
    Classification of dissections in a vessel
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DissectionClassification = DICOMControlledTerminologyDefinitionsCode("122387")
    """
    Separation of neointimal hyperplasia from stent struts, usually seen only
    after treatment of in-stent restenosis
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Intra_stentDissection = DICOMControlledTerminologyDefinitionsCode("122388")
    """
    Plaque with a thin cap fibrous atheroma that is at increased risk of rupture
    and thrombosis (or re-thrombosis) and rapid stenosis progression
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VulnerablePlaque = DICOMControlledTerminologyDefinitionsCode("122389")
    """
    Plaque erosions with no structural defect (beyond endothelial injury) or gap
    in the plaque
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ErodedPlaque = DICOMControlledTerminologyDefinitionsCode("122390")
    """
    Stenosis severity classifications of multiple lesions in a vessel
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RelativeStenosisSeverity = DICOMControlledTerminologyDefinitionsCode("122391")
    """
    A finding of a previously treated lesion in which stenosis has reoccurred
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RestenoticLesion = DICOMControlledTerminologyDefinitionsCode("122393")
    """
    Loosely packed bundles of collagen fibers with regions of lipid deposition
    present. Region is cellular and no cholesterol clefts or necrosis are present.
    Some macrophage infiltration. Increase in extra cellular matrix
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Fibro_LipidicPlaque = DICOMControlledTerminologyDefinitionsCode("122394")
    """
    Area within the plaque with very low echogenicity separated from the lumen and
    surrounded by more echogenic structures (fibrous cap). Highly lipidic necrotic
    region with remnants of foam cells and dead lymphocytes present. No collagen
    fibers are visible and mechanical integrity is poor. Cholesterol clefts and
    micro calcifications are visible
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Necrotic_LipidicPlaque = DICOMControlledTerminologyDefinitionsCode("122395")
    """
    Dissection limited to the intima or atheroma, and not extending to the media
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IntimalDissection = DICOMControlledTerminologyDefinitionsCode("122398")
    """
    Dissection in the arterial Media, extending into the media
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MedialDissection = DICOMControlledTerminologyDefinitionsCode("122399")
    """
    The referenced information was acquired simultaneously with the information in
    the object in which the reference occurs
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SimultaneouslyAcquired = DICOMControlledTerminologyDefinitionsCode("122400")
    """
    Information acquired for the same anatomic region
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SameAnatomy = DICOMControlledTerminologyDefinitionsCode("122401")
    """
    Information acquired for the same indication; e.g. to elucidate the same
    diagnostic question
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SameIndication = DICOMControlledTerminologyDefinitionsCode("122402")
    """
    The referenced information was used to correct the data for differential
    attenuation through different anatomic tissue
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ForAttenuationCorrection = DICOMControlledTerminologyDefinitionsCode("122403")
    """
    Value estimated for a vessel in the absence of a stenosis
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Reconstructed = DICOMControlledTerminologyDefinitionsCode("122404")
    """
    Manufacturer of application used
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AlgorithmManufacturer = DICOMControlledTerminologyDefinitionsCode("122405")
    """
    Left Atrial Ejection Fraction by Angiography
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LeftAtrialEjectionFractionByAngiography = DICOMControlledTerminologyDefinitionsCode(
        "122406"
    )
    """
    Left Atrial End Diastolic Volume
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LeftAtrialEDVolume = DICOMControlledTerminologyDefinitionsCode("122407")
    """
    Left Atrial End Systolic Volume
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LeftAtrialESVolume = DICOMControlledTerminologyDefinitionsCode("122408")
    """
    Contour repositioning of End Diastolic relative to End Systolic contour
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ContourRealignment = DICOMControlledTerminologyDefinitionsCode("122410")
    """
    The minimum standard deviation to define the hypokinesis and hyperkinesis
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ThresholdValue = DICOMControlledTerminologyDefinitionsCode("122411")
    """
    Report of differentiation of wall motion compared to normal
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RegionalAbnormalWallMotion = DICOMControlledTerminologyDefinitionsCode("122417")
    """
    Object used for Calibration
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CalibrationObject = DICOMControlledTerminologyDefinitionsCode("122421")
    """
    Method used for Calibration
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CalibrationMethod = DICOMControlledTerminologyDefinitionsCode("122422")
    """
    Size of calibration object
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CalibrationObjectSize = DICOMControlledTerminologyDefinitionsCode("122423")
    """
    Method how long axis is positioned
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AreaLengthMethod = DICOMControlledTerminologyDefinitionsCode("122428")
    """
    Model for cardiac chamber volume calculation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VolumeMethod = DICOMControlledTerminologyDefinitionsCode("122429")
    """
    Method to define original diameter of the artery
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ReferenceMethod = DICOMControlledTerminologyDefinitionsCode("122430")
    """
    Relation between calculated End Diastolic volume and ventricular End Diastolic
    volume. The specific meaning is dependent on volume method used
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RegressionSlopeED = DICOMControlledTerminologyDefinitionsCode("122431")
    """
    Correction factor for the calculated End Diastolic volume and ventricular End
    Diastolic volume. The specific meaning is dependent on volume method used
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RegressionOffsetED = DICOMControlledTerminologyDefinitionsCode("122432")
    """
    Relation between calculated End Systolic volume and ventricular End Systolic
    volume. The specific meaning is dependent on volume method used
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RegressionSlopeES = DICOMControlledTerminologyDefinitionsCode("122433")
    """
    Correction factor for the calculated End Systolic volume and ventricular End
    Systolic volume. The specific meaning is dependent on volume method used
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RegressionOffsetES = DICOMControlledTerminologyDefinitionsCode("122434")
    """
    Exponent of volume in regression formula
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RegressionVolumeExponent = DICOMControlledTerminologyDefinitionsCode("122435")
    """
    Container for spatial locations or coordinates used for calculation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ReferencePoints = DICOMControlledTerminologyDefinitionsCode("122438")
    """
    Average thickness of the chamber wall in the current view
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    WallThickness = DICOMControlledTerminologyDefinitionsCode("122445")
    """
    Volume of the chamber wall estimated from the current view
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    WallVolume = DICOMControlledTerminologyDefinitionsCode("122446")
    """
    Mass of the chamber wall (myocardium)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    WallMass = DICOMControlledTerminologyDefinitionsCode("122447")
    """
    Peak systolic stress of chamber wall
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    WallStress = DICOMControlledTerminologyDefinitionsCode("122448")
    """
    Method to calculate wall motion [example: Sheehan, 1986]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CenterlineWallMotionAnalysis = DICOMControlledTerminologyDefinitionsCode("122449")
    """
    The length between End Diastolic and End Systolic contour perpendicular on the
    centerline normalized by a method dependent ventricular perimeter length. The
    centerline is the line equidistant between the End Diastolic and End Systolic
    contour [example: Sheehan, 1986]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NormalizedChordLength = DICOMControlledTerminologyDefinitionsCode("122450")
    """
    The report of the boundaries of the abnormal (hyperkinetic, hypokinetic,
    a-kinetic) regions associated with the territory of the artery [example:
    Sheehan, 1986]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AbnormalRegion = DICOMControlledTerminologyDefinitionsCode("122451")
    """
    The chord number specifying the begin of abnormal region [example: Sheehan,
    1986]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FirstChordOfAbnormalRegion = DICOMControlledTerminologyDefinitionsCode("122452")
    """
    The chord number specifying the end of abnormal region [example: Sheehan,
    1986]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LastChordOfAbnormalRegion = DICOMControlledTerminologyDefinitionsCode("122453")
    """
    Severity at the regional abnormality extent [example: Sheehan, 1986]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TerritoryRegionSeverity = DICOMControlledTerminologyDefinitionsCode("122459")
    """
    Severity at the opposite regional abnormality extent [example: Sheehan, 1986]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OppositeRegionSeverity = DICOMControlledTerminologyDefinitionsCode("122461")
    """
    Based on a total number of chords of 100 and RAO project the range of chords
    belonging to this circumferential extent lies between 5 - 85. [Sheehan, 1986]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LADRegionInRAOProjection = DICOMControlledTerminologyDefinitionsCode("122464")
    """
    Based on a total number of chords of 100 and RAO project the range of chords
    belonging to this circumferential extent lies between 25 - 85. [Sheehan, 1986]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RCARegionInROAProjection = DICOMControlledTerminologyDefinitionsCode("122465")
    """
    Based on a total number of chords of 100 and RAO projection the range of
    chords belonging to this regional extent lies between 10 - 66 (hypokinetic)
    and 67 - 80 (hyperkinetic). [Sheehan, 1986]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SingleLADRegionInRAOProjection = DICOMControlledTerminologyDefinitionsCode("122466")
    """
    Based on a total number of chords of 100 and RAO projection the range of
    chords belonging to this regional extent lies between 51 - 80 (hypokinetic)
    and 10 - 50 (hyperkinetic). [Sheehan, 1986]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SingleRCARegionInRAOProjection = DICOMControlledTerminologyDefinitionsCode("122467")
    """
    Based on a total number of chords of 100 and RAO projection the range of
    chords belonging to this regional extent lies between 10 - 58 (hypokinetic)
    and 59 -80 (hyperkinetic). [Sheehan, 1986]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MultipleLADRegionInRAOProjection = DICOMControlledTerminologyDefinitionsCode(
        "122468"
    )
    """
    Based on a total number of chords of 100 and RAO projection the range of
    chords belonging to this regional extent lies between 59 - 80 (hypokinetic)
    and 10 - 58 (hyperkinetic). [Sheehan, 1986]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MultipleRCARegionInRAOProjection = DICOMControlledTerminologyDefinitionsCode(
        "122469"
    )
    """
    Based on a total number of chords of 100 and LAO projection the range of
    chords belonging to this regional extent lies between 50 -100 (hypokinetic)
    and 20 - 49 (hyperkinetic). [Sheehan, 1986]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LADRegionInLAOProjection = DICOMControlledTerminologyDefinitionsCode("122470")
    """
    Based on a total number of chords of 100 and LAO projection the range of
    chords belonging to this regional extent lies between 19 - 67 (hypokinetic)
    and 68 - 100 (hyperkinetic). [Sheehan, 1986]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RCARegionInLAOProjection = DICOMControlledTerminologyDefinitionsCode("122471")
    """
    Based on a total number of chords of 100 and LAO projection the range of
    chords belonging to this regional extent lies between 38 -74 (hypokinetic) and
    75 - 100 (hyperkinetic). [Sheehan, 1986]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CFXRegionInLAOProjection = DICOMControlledTerminologyDefinitionsCode("122472")
    """
    Method based on assumption that the image object is circular
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CircularMethod = DICOMControlledTerminologyDefinitionsCode("122473")
    """
    Method based on the gray value distribution of the image
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DensitometricMethod = DICOMControlledTerminologyDefinitionsCode("122474")
    """
    End Systolic contour realigned to End Diastolic contour based on the center of
    gravity
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CenterOfGravity = DICOMControlledTerminologyDefinitionsCode("122475")
    """
    End Systolic contour realigned to End Diastolic contour based on the mid point
    of the long axis. The long axis end-points are defined as the posterior and
    apex
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LongAxisBased = DICOMControlledTerminologyDefinitionsCode("122476")
    """
    No Contour Realignment applied
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NoRealignment = DICOMControlledTerminologyDefinitionsCode("122477")
    """
    Calculated Vessel Lumen Cross-Sectional Area based on the referenced method
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VesselLumenCross_SectionalArea = DICOMControlledTerminologyDefinitionsCode("122480")
    """
    Location of the beginning of a contour
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ContourStart = DICOMControlledTerminologyDefinitionsCode("122481")
    """
    Location of the end of a contour
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ContourEnd = DICOMControlledTerminologyDefinitionsCode("122482")
    """
    Sphere is used as calibration object
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Sphere = DICOMControlledTerminologyDefinitionsCode("122485")
    """
    Object of interest in isocenter of image and pixel separation is calculated
    from geometric data
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    GeometricIsocenter = DICOMControlledTerminologyDefinitionsCode("122486")
    """
    Object of interest not in isocenter of image and pixel separation is
    calculated from geometric data and out of isocenter distances
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    GeometricNon_Isocenter = DICOMControlledTerminologyDefinitionsCode("122487")
    """
    Object used for calibration; e.g. sphere
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CalibrationObjectUsed = DICOMControlledTerminologyDefinitionsCode("122488")
    """
    Application dependent method to calculate the reference diameter based on the
    multiple diameter values
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CurveFittedReference = DICOMControlledTerminologyDefinitionsCode("122489")
    """
    Application dependent method to calculate reference by interpolation, based on
    the diameter of two or more user defined reference positions
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    InterpolatedLocalReference = DICOMControlledTerminologyDefinitionsCode("122490")
    """
    Application dependent method to calculate by averaging the reference, based on
    the diameter of one or more user defined reference positions
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MeanLocalReference = DICOMControlledTerminologyDefinitionsCode("122491")
    """
    Method to calculate wall motion based on the lengths of the radials in the
    predefined regions [Ingels]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RadialBasedWallMotionAnalysis = DICOMControlledTerminologyDefinitionsCode("122493")
    """
    Contribution of Region to global Ejection factor based on radial or landmark
    based wall motion method
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RegionalContributionToEjectionFraction = DICOMControlledTerminologyDefinitionsCode(
        "122495"
    )
    """
    The reduction of area between End Systolic and End Diastolic based on radial
    wall motion analysis
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RadialShortening = DICOMControlledTerminologyDefinitionsCode("122496")
    """
    Method to calculate wall motion based on the move of landmarks on the wall
    [Slager]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LandmarkBasedWallMotionAnalysis = DICOMControlledTerminologyDefinitionsCode(
        "122497"
    )
    """
    Contribution to the ejection fraction of a specific slice region [Slager]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SliceContributionToEjectionFraction = DICOMControlledTerminologyDefinitionsCode(
        "122498"
    )
    """
    Method to calculate volumes of heart chambers for every image in a range
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FrameToFrameAnalysis = DICOMControlledTerminologyDefinitionsCode("122499")
    """
    The area is derived by considering a set of coordinates as a closed irregular
    polygon, accounting for inner angles. The exact method, such as by
    decomposition into triangles or quadrilaterals, is not specified, since it
    does not affect the numeric result, apart from the effect of numeric precision
    during computation of intermediate results
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AreaOfClosedIrregularPolygon = DICOMControlledTerminologyDefinitionsCode("122501")
    """
    The area is derived by using a set of coordinates as control points for a Non
    Uniform Rational B-Spline (NURBS)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AreaOfAClosedNURBS = DICOMControlledTerminologyDefinitionsCode("122502")
    """
    The volume derived by integrating the sum of the areas on adjacent slices
    across the slice interval; each area is defined by a regular planar shape or
    by considering a set of coordinates as a closed irregular polygon, accounting
    for inner angles
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IntegrationOfSumOfClosedAreasOnContiguousSlices = (
        DICOMControlledTerminologyDefinitionsCode("122503")
    )
    """
    Procedure used to calibrate measurements or measurement devices
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Calibration = DICOMControlledTerminologyDefinitionsCode("122505")
    """
    Left contour of lumen (direction proximal to distal)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LeftContour = DICOMControlledTerminologyDefinitionsCode("122507")
    """
    Right contour of lumen (direction proximal to distal)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RightContour = DICOMControlledTerminologyDefinitionsCode("122508")
    """
    Ordered set of diameters values derived from contours (direction proximal to
    distal)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DiameterGraph = DICOMControlledTerminologyDefinitionsCode("122509")
    """
    Length Luminal Segment
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LengthLuminalSegment = DICOMControlledTerminologyDefinitionsCode("122510")
    """
    Increment value along X-axis in Diameter Graph
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    GraphIncrement = DICOMControlledTerminologyDefinitionsCode("122511")
    """
    Location of the maximum lumen area in a lesion or vessel
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SiteOfMaximumLuminal = DICOMControlledTerminologyDefinitionsCode("122516")
    """
    Ordered set of cross-sectional Vessel Lumen Cross-Sectional Area values
    derived from contours (direction proximal to distal) based on densitometric
    method
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DensitometricLuminalCross_sectionalAreaGraph = (
        DICOMControlledTerminologyDefinitionsCode("122517")
    )
    """
    Position of proximal border of segment relative to the contour start (proximal
    end of analysis area)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PositionOfProximalBorder = DICOMControlledTerminologyDefinitionsCode("122528")
    """
    Position of distal border of segment relative to the contour start (proximal
    end of analysis area)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PositionOfDistalBorder = DICOMControlledTerminologyDefinitionsCode("122529")
    """
    Longitudinal cross sectional area of plaque
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PlaqueArea = DICOMControlledTerminologyDefinitionsCode("122542")
    """
    Symmetry of stenosis (0 = complete asymmetry, 1 = complete symmetry); see
    Section T.2 "Definition of Diameter Symmetry with Arterial Plaques" in PS3.17
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DiameterSymmetry = DICOMControlledTerminologyDefinitionsCode("122544")
    """
    Symmetry of plaque (0 = complete asymmetry, 1 = complete symmetry); see
    Section T.2 "Definition of Diameter Symmetry with Arterial Plaques" in PS3.17
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AreaSymmetry = DICOMControlledTerminologyDefinitionsCode("122545")
    """
    The average slope of the diameter function between the position of the minimum
    luminal diameter and the position of the proximal border of the segment
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    InflowAngle = DICOMControlledTerminologyDefinitionsCode("122546")
    """
    The average slope of the diameter function between the position of the minimum
    luminal diameter and the position of the distal border of the segment
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OutflowAngle = DICOMControlledTerminologyDefinitionsCode("122547")
    """
    The relation between coronary pressure and coronary flow
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StenoticFlowReserve = DICOMControlledTerminologyDefinitionsCode("122548")
    """
    Poiseuille Resistance at the location of the stenosis
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PoiseuilleResistance = DICOMControlledTerminologyDefinitionsCode("122549")
    """
    Turbulence Resistance at the location of the stenosis
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TurbulenceResistance = DICOMControlledTerminologyDefinitionsCode("122550")
    """
    Pressure drop over the stenosis at maximum heart output
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PressureDropAtSFR = DICOMControlledTerminologyDefinitionsCode("122551")
    """
    Method for selection of vessel sub-segments
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SegmentationMethod = DICOMControlledTerminologyDefinitionsCode("122554")
    """
    Estimate of the volume of blood flow in the absence of stenosis
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EstimatedNormalFlow = DICOMControlledTerminologyDefinitionsCode("122555")
    """
    Area Length method defined by Kennedy [Kennedy, 1970]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AreaLengthKennedy = DICOMControlledTerminologyDefinitionsCode("122558")
    """
    Area Length method defined by Dodge [Dodge, 1960]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AreaLengthDodge = DICOMControlledTerminologyDefinitionsCode("122559")
    """
    Area Length method defined by Wynne [Wynne]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AreaLengthWynne = DICOMControlledTerminologyDefinitionsCode("122560")
    """
    Volume method based on multiple slice
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MultipleSlices = DICOMControlledTerminologyDefinitionsCode("122562")
    """
    Volume method defined by Boak [Boak]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Boak = DICOMControlledTerminologyDefinitionsCode("122563")
    """
    Volume method defined by Ferlinz [Ferlinz]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TSPyramid = DICOMControlledTerminologyDefinitionsCode("122564")
    """
    Volume method defined by Graham [Graham]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TwoChamber = DICOMControlledTerminologyDefinitionsCode("122565")
    """
    Volume method defined by Arcilla [Arcilla]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Parallelepiped = DICOMControlledTerminologyDefinitionsCode("122566")
    """
    Corrected Body Surface area for indexing the hemodynamic measurements for a
    pediatric patient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BSA_1_219 = DICOMControlledTerminologyDefinitionsCode("122572")
    """
    Method for selecting sub-segments that are all of the same length
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EquidistantMethod = DICOMControlledTerminologyDefinitionsCode("122574")
    """
    Manually selected start and end of sub-segment
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    UserSelectedMethod = DICOMControlledTerminologyDefinitionsCode("122575")
    """
    Left ventricular posterobasal segment
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LeftVentricularPosterobasalSegment = DICOMControlledTerminologyDefinitionsCode(
        "122582"
    )
    """
    Report of a Cardiovascular Analysis, typically from a CT or MR study
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CardiovascularAnalysisReport = DICOMControlledTerminologyDefinitionsCode("122600")
    """
    Ventricular Analysis
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VentricularAnalysis = DICOMControlledTerminologyDefinitionsCode("122601")
    """
    Myocardial Perfusion Analysis
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MyocardialPerfusionAnalysis = DICOMControlledTerminologyDefinitionsCode("122602")
    """
    Calcium Scoring Analysis
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CalciumScoringAnalysis = DICOMControlledTerminologyDefinitionsCode("122603")
    """
    Flow Quantification Analysis
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FlowQuantification = DICOMControlledTerminologyDefinitionsCode("122604")
    """
    Vascular Morphological Analysis
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VascularMorphologicalAnalysis = DICOMControlledTerminologyDefinitionsCode("122605")
    """
    Vascular Functional Analysis
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VascularFunctionalAnalysis = DICOMControlledTerminologyDefinitionsCode("122606")
    """
    Analysis of myocardial wall thickening
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ThickeningAnalysis = DICOMControlledTerminologyDefinitionsCode("122607")
    """
    Section Heading for absolute values of ventricular measurements
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AbsoluteValuesOfVentricularMeasurements = DICOMControlledTerminologyDefinitionsCode(
        "122608"
    )
    """
    Results of normalizing ventricular measurements
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NormalizedValuesOfVentricularMeasurements = (
        DICOMControlledTerminologyDefinitionsCode("122609")
    )
    """
    Reference Point of a measurement
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ReferencePoint = DICOMControlledTerminologyDefinitionsCode("122611")
    """
    Central breathing position between inspiration and expiration
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CentralBreathingPosition = DICOMControlledTerminologyDefinitionsCode("122612")
    """
    Peak of the ventricular ejection rate
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PeakEjectionRate = DICOMControlledTerminologyDefinitionsCode("122616")
    """
    Time of the peak of ventricular ejection
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PeakEjectionTime = DICOMControlledTerminologyDefinitionsCode("122617")
    """
    Peak of the fluid filling rate
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PeakFillingRate = DICOMControlledTerminologyDefinitionsCode("122618")
    """
    Time interval until time of peak filling from a given reference point; e.g.
    end systole
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PeakFillingTime = DICOMControlledTerminologyDefinitionsCode("122619")
    """
    Papillary muscle was excluded from the measurement
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PapillaryMuscleExcluded = DICOMControlledTerminologyDefinitionsCode("122620")
    """
    Papillary muscle was included in the measurement
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PapillaryMuscleIncluded = DICOMControlledTerminologyDefinitionsCode("122621")
    """
    The ratio of the end-systolic wall thickness compared to the end-diastolic
    wall thickness
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    WallThicknessRatioEnd_systolicToEnd_diastolic = (
        DICOMControlledTerminologyDefinitionsCode("122624")
    )
    """
    The method to smooth a ventricular volume as a function of time
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CurveFitMethod = DICOMControlledTerminologyDefinitionsCode("122627")
    """
    Baseline correction used in the calculation of the results
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BaselineResultCorrection = DICOMControlledTerminologyDefinitionsCode("122628")
    """
    The time in a dynamic set of images at which the first peak of the signal is
    observed for the analyzed myocardial wall segments
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SignalEarliestPeakTime = DICOMControlledTerminologyDefinitionsCode("122631")
    """
    This is the time at which the signal begins to increase
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SignalIncreaseStartTime = DICOMControlledTerminologyDefinitionsCode("122633")
    """
    Time interval between the beginning of the signal increase to the time at
    which the signal intensity reaches its first maximum in a dynamic set of
    images
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SignalTimeToPeak = DICOMControlledTerminologyDefinitionsCode("122634")
    """
    Peak of the MR perfusion signal
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MRPerfusionPeak = DICOMControlledTerminologyDefinitionsCode("122635")
    """
    Signal intensity as a function of time. It is the change in the signal
    intensity divided by the change in the time
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MRPerfusionSlope = DICOMControlledTerminologyDefinitionsCode("122636")
    """
    MR perfusion time integral from baseline (foot time) to earliest peak
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MRPerfusionTimeIntegral = DICOMControlledTerminologyDefinitionsCode("122637")
    """
    First time point in a dynamic set of images used in the calculation of the
    baseline signal intensity for each myocardial wall segment
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SignalBaselineStart = DICOMControlledTerminologyDefinitionsCode("122638")
    """
    Last time point in a dynamic set of images used in the calculation of the
    baseline signal intensity for each myocardial wall segment
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SignalBaselineEnd = DICOMControlledTerminologyDefinitionsCode("122639")
    """
    The time delta between images in a dynamic set of images
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ImageInterval = DICOMControlledTerminologyDefinitionsCode("122640")
    """
    The minimum velocity encoded by the phase encoding gradient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VelocityEncodingMinimumValue = DICOMControlledTerminologyDefinitionsCode("122642")
    """
    The maximum velocity encoded by the phase encoding gradient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VelocityEncodingMaximumValue = DICOMControlledTerminologyDefinitionsCode("122643")
    """
    Forward volume-reverse volume
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NetForwardVolume = DICOMControlledTerminologyDefinitionsCode("122645")
    """
    Area Based Method for estimating volume or area
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AreaBasedMethod = DICOMControlledTerminologyDefinitionsCode("122650")
    """
    Diameter Based Method for estimating volume, area or diameter
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DiameterBasedMethod = DICOMControlledTerminologyDefinitionsCode("122651")
    """
    Volume Based Method for estimating volume
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VolumeBasedMethod = DICOMControlledTerminologyDefinitionsCode("122652")
    """
    A method of diameter measurements according to NASCET (North American
    Symptomatic Carotid Endarterectomy Trial)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NASCET = DICOMControlledTerminologyDefinitionsCode("122655")
    """
    A method of diameter measurements according to ECST (European Carotid Surgery
    Trial)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ECST = DICOMControlledTerminologyDefinitionsCode("122656")
    """
    Agatston Score Threshold
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AgatstonScoreThreshold = DICOMControlledTerminologyDefinitionsCode("122657")
    """
    Calcium Mass Threshold
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CalciumMassThreshold = DICOMControlledTerminologyDefinitionsCode("122658")
    """
    Calcium Scoring Calibration
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CalciumScoringCalibration = DICOMControlledTerminologyDefinitionsCode("122659")
    """
    Calcium Volume
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CalciumVolume = DICOMControlledTerminologyDefinitionsCode("122660")
    """
    Calcium Mass
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CalciumMass = DICOMControlledTerminologyDefinitionsCode("122661")
    """
    Delayed hyperenhancement of a tissue observed in an image acquired after
    injection of contrast media
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LateContrastEnhancement = DICOMControlledTerminologyDefinitionsCode("122664")
    """
    Time interval since injection of contrast media
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TimeIntervalSinceInjectionOfContrastMedia = (
        DICOMControlledTerminologyDefinitionsCode("122665")
    )
    """
    Time relative to R-wave peak
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TimeRelativeToR_wavePeak = DICOMControlledTerminologyDefinitionsCode("122666")
    """
    Relationship between blood velocity and time relative to R-wave peak
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BloodVelocityVs_TimeOfCardiacCycle = DICOMControlledTerminologyDefinitionsCode(
        "122667"
    )
    """
    Time interval since detection of contrast bolus
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TimeIntervalSinceDetectionOfContrastBolus = (
        DICOMControlledTerminologyDefinitionsCode("122668")
    )
    """
    Indicates if the papillary muscle was included or excluded in the measurement
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PapillaryMuscleIncluded_Excluded = DICOMControlledTerminologyDefinitionsCode(
        "122670"
    )
    """
    Anterior to Posterior direction
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Anterior_Posterior = DICOMControlledTerminologyDefinitionsCode("122675")
    """
    Persistent flow of blood into the stent-grafting
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Endoleak = DICOMControlledTerminologyDefinitionsCode("122680")
    """
    Fracture of a stent
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StentFracture = DICOMControlledTerminologyDefinitionsCode("122683")
    """
    Disintegration of a stent
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StentDisintegration = DICOMControlledTerminologyDefinitionsCode("122684")
    """
    Material that a stent consists of
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StentComposition = DICOMControlledTerminologyDefinitionsCode("122685")
    """
    Finding about the characteristics of the parent vessel of a vessel
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ParentVesselFinding = DICOMControlledTerminologyDefinitionsCode("122686")
    """
    Site of Maximal lumen diameter of a vessel
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SiteOfLumenMaximum = DICOMControlledTerminologyDefinitionsCode("122687")
    """
    The physical domain (time, space, etc.) to the horizontal axis of the
    graphical presentation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    X_Concept = DICOMControlledTerminologyDefinitionsCode("122698")
    """
    The physical domain (time, space, etc.) to the vertical axis of the graphical
    presentation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Y_Concept = DICOMControlledTerminologyDefinitionsCode("122699")
    """
    Indications for Pharmacological Stress
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IndicationsForPharmacologicalStress = DICOMControlledTerminologyDefinitionsCode(
        "122700"
    )
    """
    Reference time for measurement of elapsed time in a procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ProcedureTimeBase = DICOMControlledTerminologyDefinitionsCode("122701")
    """
    Treadmill speed
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TreadmillSpeed = DICOMControlledTerminologyDefinitionsCode("122702")
    """
    Treadmill gradient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TreadmillGradient = DICOMControlledTerminologyDefinitionsCode("122703")
    """
    Ergometer power
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ErgometerPower = DICOMControlledTerminologyDefinitionsCode("122704")
    """
    Pharmacological Stress Agent Dose Rate
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PharmacologicalStressAgentDoseRate = DICOMControlledTerminologyDefinitionsCode(
        "122705"
    )
    """
    Rating of Perceived Exertion
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RatingOfPerceivedExertion = DICOMControlledTerminologyDefinitionsCode("122706")
    """
    Number of ectopic beats during a period of collection
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NumberOfEctopicBeats = DICOMControlledTerminologyDefinitionsCode("122707")
    """
    Heart rate times systolic blood pressure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DoubleProduct = DICOMControlledTerminologyDefinitionsCode("122708")
    """
    Physical activity workload (intensity) measurement
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ActivityWorkload = DICOMControlledTerminologyDefinitionsCode("122709")
    """
    Elapsed time at stage
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TimeSinceStartOfStage = DICOMControlledTerminologyDefinitionsCode("122710")
    """
    Exercise duration after stress agent injection
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ExerciseDurationAfterStressAgentInjection = (
        DICOMControlledTerminologyDefinitionsCode("122711")
    )
    """
    Imaging Start Time
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ImagingStartTime = DICOMControlledTerminologyDefinitionsCode("122712")
    """
    Attenuation correction method
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AttenuationCorrectionMethod = DICOMControlledTerminologyDefinitionsCode("122713")
    """
    Pharmacological Stress Agent Dose
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PharmacologicalStressAgentDose = DICOMControlledTerminologyDefinitionsCode("122715")
    """
    Maximum power output achieved during course of procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MaximumPowerOutputAchieved = DICOMControlledTerminologyDefinitionsCode("122716")
    """
    Peak physical activity intensity measurement during course of procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PeakActivityWorkload = DICOMControlledTerminologyDefinitionsCode("122717")
    """
    Peak Double Product measurement during course of procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PeakDoubleProduct = DICOMControlledTerminologyDefinitionsCode("122718")
    """
    Ordered subsets expectation maximization reconstruction algorithm
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OSEMAlgorithm = DICOMControlledTerminologyDefinitionsCode("122720")
    """
    Chang attenuation correction method
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ChangMethod = DICOMControlledTerminologyDefinitionsCode("122721")
    """
    Attenuation correction not based on image-based attenuation maps
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AlgorithmicAttenuationCorrection = DICOMControlledTerminologyDefinitionsCode(
        "122726"
    )
    """
    NM transmission attenuation correction
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NMTransmissionAttenuationCorrection = DICOMControlledTerminologyDefinitionsCode(
        "122727"
    )
    """
    CT-based attenuation correction
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CT_basedAttenuationCorrection = DICOMControlledTerminologyDefinitionsCode("122728")
    """
    No attenuation correction
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NoAttenuationCorrection = DICOMControlledTerminologyDefinitionsCode("122729")
    """
    Bazett QT Correction Algorithm; QT/(RR ^ 0.5); Bazett HC. "An analysis of the
    time-relations of electrocardiograms" Heart7:353-370 (1920)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BazettQTcAlgorithm = DICOMControlledTerminologyDefinitionsCode("122730")
    """
    Hodges QT Correction Algorithm; QT + 1.75 (heart rate-60); Hodges M, Salerno
    Q, Erlien D. "Bazett's QT correction reviewed. Evidence that a linear QT
    correction for heart rate is better." J Am Coll Cardiol1:694 (1983)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    HodgesQTcAlgorithm = DICOMControlledTerminologyDefinitionsCode("122731")
    """
    Fridericia QT Correction Algorithm; QT/(RR ^ 0.333); Fridericia LS. "The
    duration of systole in the electrocardiogram of normal subjects and of
    patients with heart disease" Acta Med Scand53:469-486 (1920)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FridericiaQTcAlgorithm = DICOMControlledTerminologyDefinitionsCode("122732")
    """
    Framingham QT Correction Algorithm; QT + 0.154 (1- RR); Sagie A, Larson MG,
    Goldberg RJ, et al. "An improved method for adjusting the QT interval for
    heart rate (the Framingham Heart Study)." Am J Cardiol70:797-801(1992)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FraminghamQTcAlgorithm = DICOMControlledTerminologyDefinitionsCode("122733")
    """
    Borg Rating of Perceived Exertion Scale, range 6:20
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BorgRPEScale = DICOMControlledTerminologyDefinitionsCode("122734")
    """
    Borg category ratio scale, open ended range with nominal range 0:10
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BorgCR10Scale = DICOMControlledTerminologyDefinitionsCode("122735")
    """
    Overall study quality
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OverallStudyQuality = DICOMControlledTerminologyDefinitionsCode("122739")
    """
    Excellent image quality
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ExcellentImageQuality = DICOMControlledTerminologyDefinitionsCode("122740")
    """
    Good image quality
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    GoodImageQuality = DICOMControlledTerminologyDefinitionsCode("122741")
    """
    Poor image quality
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PoorImageQuality = DICOMControlledTerminologyDefinitionsCode("122742")
    """
    Image attenuation due to body physique (overweight)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BodyHabitusAttenuation = DICOMControlledTerminologyDefinitionsCode("122743")
    """
    Image attenuation due to breast tissue
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BreastAttenuation = DICOMControlledTerminologyDefinitionsCode("122744")
    """
    Image attenuation due to diaphragm
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DiaphragmaticAttenuation = DICOMControlledTerminologyDefinitionsCode("122745")
    """
    Finding of a defect is incorrect; e.g. from automated analysis
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FalsePositiveDefectFinding = DICOMControlledTerminologyDefinitionsCode("122748")
    """
    ECG is non-diagnostic due to low heart rate
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Non_diagnostic_LowHeartRate = DICOMControlledTerminologyDefinitionsCode("122750")
    """
    ECG is non-diagnostic due to resting ST abnormalities
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Non_diagnostic_RestingSTAbnormalities = DICOMControlledTerminologyDefinitionsCode(
        "122751"
    )
    """
    ECG is non-diagnostic due to ventricular pacing or Left Bundle Branch Block
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Non_diagnostic_VentricularPacingOrLBBB = DICOMControlledTerminologyDefinitionsCode(
        "122752"
    )
    """
    ECG is non-diagnostic for presence of acute coronary syndrome
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Non_diagnosticECG = DICOMControlledTerminologyDefinitionsCode("122753")
    """
    Strongly positive finding
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StronglyPositive = DICOMControlledTerminologyDefinitionsCode("122755")
    """
    Strongly positive finding - ST elevation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StronglyPositive_STElevation = DICOMControlledTerminologyDefinitionsCode("122756")
    """
    Finding of ST segment depression with no slope
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    STDepression_Horizontal = DICOMControlledTerminologyDefinitionsCode("122757")
    """
    Finding of ST segment depression with upslope
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    STDepression_Upsloping = DICOMControlledTerminologyDefinitionsCode("122758")
    """
    Finding of ST segment depression with downslope
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    STDepression_Downsloping = DICOMControlledTerminologyDefinitionsCode("122759")
    """
    Stress test score
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StressTestScore = DICOMControlledTerminologyDefinitionsCode("122760")
    """
    Number of diseased vessel territories
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NumberOfDiseasedVesselTerritories = DICOMControlledTerminologyDefinitionsCode(
        "122762"
    )
    """
    Patient weight exceeds equipment limit
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    WeightExceedsEquipmentLimit = DICOMControlledTerminologyDefinitionsCode("122764")
    """
    Difference in Ejection Fraction
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DifferenceInEjectionFraction = DICOMControlledTerminologyDefinitionsCode("122768")
    """
    Difference in End Diastolic Left Ventricular Volume
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DifferenceInEDLVVolume = DICOMControlledTerminologyDefinitionsCode("122769")
    """
    Ratio of achieved to predicted maximal oxygen consumption
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RatioOfAchievedToPredictedMaximalOxygenConsumption = (
        DICOMControlledTerminologyDefinitionsCode("122770")
    )
    """
    Ratio of achieved to predicted functional capacity
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RatioOfAchievedToPredictedFunctionalCapacity = (
        DICOMControlledTerminologyDefinitionsCode("122771")
    )
    """
    Workload (Watts) at target heart rate divided by body weight
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AerobicIndex = DICOMControlledTerminologyDefinitionsCode("122772")
    """
    ST depression at peak exercise divided by the exercise-induced increase in
    heart rate [Kligfield P, Ameisen O, Okin PM. "Heart rate adjustment of ST
    segment depression for improved detection of coronary artery disease."
    Circulation 1989;79:245-55.]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ST_HRIndex = DICOMControlledTerminologyDefinitionsCode("122773")
    """
    Agreement with prior findings
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AgreementWithPriorFindings = DICOMControlledTerminologyDefinitionsCode("122775")
    """
    Disagreement with prior findings
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DisagreementWithPriorFindings = DICOMControlledTerminologyDefinitionsCode("122776")
    """
    Nuclear Medicine Rest thallium/stress technetium procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RestThallium_stressTechnetiumProcedure = DICOMControlledTerminologyDefinitionsCode(
        "122781"
    )
    """
    Nuclear Medicine Rest technetium/stress technetium 1 day procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RestTechnetium_stressTechnetium1DayProcedure = (
        DICOMControlledTerminologyDefinitionsCode("122782")
    )
    """
    Nuclear Medicine Rest technetium/stress technetium 2 day procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RestTechnetium_stressTechnetium2DayProcedure = (
        DICOMControlledTerminologyDefinitionsCode("122783")
    )
    """
    Nuclear Medicine Stress technetium/rest technetium 1 day procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StressTechnetium_restTechnetium1DayProcedure = (
        DICOMControlledTerminologyDefinitionsCode("122784")
    )
    """
    Nuclear Medicine Myocardial Viability procedure
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NMMyocardialViabilityProcedure = DICOMControlledTerminologyDefinitionsCode("122785")
    """
    Positron Emission Tomography Perfusion Imaging procedure, rest only
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PETMyocardialPerfusion_RestOnly = DICOMControlledTerminologyDefinitionsCode(
        "122791"
    )
    """
    Positron Emission Tomography Perfusion Imaging procedure, stress only
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PETMyocardialPerfusion_StressOnly = DICOMControlledTerminologyDefinitionsCode(
        "122792"
    )
    """
    Positron Emission Tomography Perfusion Imaging procedure, rest and stress
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PETMyocardialPerfusion_RestAndStress = DICOMControlledTerminologyDefinitionsCode(
        "122793"
    )
    """
    Positron Emission Tomography Myocardial Viability procedure, rest only
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PETMyocardialViability_RestOnly = DICOMControlledTerminologyDefinitionsCode(
        "122795"
    )
    """
    Positron Emission Tomography Myocardial Viability procedure, stress only
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PETMyocardialViability_StressOnly = DICOMControlledTerminologyDefinitionsCode(
        "122796"
    )
    """
    Positron Emission Tomography Myocardial Viability procedure, rest and stress
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PETMyocardialViability_RestAndStress = DICOMControlledTerminologyDefinitionsCode(
        "122797"
    )
    """
    Group of symptoms heralding angina pectoris that does not include chest pain
    (dyspnea, diaphoresis, profuse vomiting in a diabetic patient, or arm or jaw
    pain)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AnginalEquivalent = DICOMControlledTerminologyDefinitionsCode("122799")
    """
    Active ingredient (molecular) used for radioactive tracing
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Radiopharmaceutical = DICOMControlledTerminologyDefinitionsCode("123001")
    """
    Time of radiopharmaceutical administration to the patient for imaging purposes
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RadiopharmaceuticalStartTime = DICOMControlledTerminologyDefinitionsCode("123003")
    """
    Ending time of radiopharmaceutical administration to the patient for imaging
    purposes
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RadiopharmaceuticalStopTime = DICOMControlledTerminologyDefinitionsCode("123004")
    """
    Volume of radiopharmaceutical administered to the patient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RadiopharmaceuticalVolume = DICOMControlledTerminologyDefinitionsCode("123005")
    """
    Total amount of radionuclide administered to the patient at
    Radiopharmaceutical Start Time
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RadionuclideTotalDose = DICOMControlledTerminologyDefinitionsCode("123006")
    """
    Activity per unit mass of the radiopharmaceutical at Radiopharmaceutical Start
    Time
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RadiopharmaceuticalSpecificActivity = DICOMControlledTerminologyDefinitionsCode(
        "123007"
    )
    """
    Pre-injection syringe acquisition count rate
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RadionuclideSyringeCounts = DICOMControlledTerminologyDefinitionsCode("123009")
    """
    Syringe acquisition count rate following patient injection
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RadionuclideResidualSyringeCounts = DICOMControlledTerminologyDefinitionsCode(
        "123010"
    )
    """
    Contrast or bolus agent
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Contrast_BolusAgent = DICOMControlledTerminologyDefinitionsCode("123011")
    """
    Medication to be administered at the beginning of the Scheduled Procedure Step
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Pre_Medication = DICOMControlledTerminologyDefinitionsCode("123012")
    """
    Anatomic Region to be imaged
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TargetRegion = DICOMControlledTerminologyDefinitionsCode("123014")
    """
    Direction of imaging (includes view, transducer orientation, patient
    orientation, and/or projection)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ImagingDirection = DICOMControlledTerminologyDefinitionsCode("123015")
    """
    Imaging condition for refinement of protocol (includes secondary posture,
    instruction, X-Ray / electron beam energy or nuclide, and ultrasound modes),
    as used in JJ1017 v3.0
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ImagingConditions = DICOMControlledTerminologyDefinitionsCode("123016")
    """
    Caudal 10 degree distal-cranioproximal oblique radiographic projection,
    defined per Smallwood et al
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Caudal10DegreeDistal_cranioproximalOblique = (
        DICOMControlledTerminologyDefinitionsCode("123019")
    )
    """
    Surface processing utilizing predefined weighting factors (i.e., kernels)
    applied to different data values depending on their location relative to other
    data values within the data domain. Includes Low Pass, High Pass, Gaussian,
    Laplacian, etc.
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NeighborhoodAnalysis = DICOMControlledTerminologyDefinitionsCode("123101")
    """
    Surface processing applied non-uniformly utilizing a priori knowledge of the
    system and/or relative locations of the data values within the data domain.
    Example: Neighborhood analysis where weighting factors are modified
    continuously based on predefined criteria
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AdaptiveFiltering = DICOMControlledTerminologyDefinitionsCode("123102")
    """
    Surface processing through the exploitation of discontinuities in the data
    values within their domain. Includes Gradient filters
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EdgeDetection = DICOMControlledTerminologyDefinitionsCode("123103")
    """
    Surface processing based on the connectivity of values based on the shape or
    structure of the data values within their domain. Includes erode, dilate, etc.
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MorphologicalOperations = DICOMControlledTerminologyDefinitionsCode("123104")
    """
    Surface processing applied to the distribution of the data values. Includes
    thresholding, Bayesian Classification, etc.
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    HistogramAnalysis = DICOMControlledTerminologyDefinitionsCode("123105")
    """
    Surface processing accomplished through varying the data domain size. Include
    deformable models
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Multi_Scale_ResolutionFiltering = DICOMControlledTerminologyDefinitionsCode(
        "123106"
    )
    """
    Surface processing accomplished by combining data values based on their
    relative location within their domain or value distribution. Includes K- and
    C-means, Fuzzy Analysis, Watershed, Seed Growing, etc.
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ClusterAnalysis = DICOMControlledTerminologyDefinitionsCode("123107")
    """
    Surface processing accomplished through the weighted combination of multiple
    data sets. Includes Principle Component Analysis, linear and non-linear
    weighed combinations, etc.
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MultispectralProcessing = DICOMControlledTerminologyDefinitionsCode("123108")
    """
    Surface processing accomplished through human interaction. Region drawing
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ManualProcessing = DICOMControlledTerminologyDefinitionsCode("123109")
    """
    Surface processing using Artificial Intelligence techniques, such as Machine
    Learning, Neural Networks, etc.
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ArtificialIntelligence = DICOMControlledTerminologyDefinitionsCode("123110")
    """
    Surface processing using Deformable Model techniques, such as Point
    Distribution Models, Level Sets, Simplex Meshes, etc.
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DeformableModels = DICOMControlledTerminologyDefinitionsCode("123111")
    """
    Document Title of OB-GYN procedure report
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OB_GYNUltrasoundProcedureReport = DICOMControlledTerminologyDefinitionsCode(
        "125000"
    )
    """
    Report section for assessment of fetal growth using ratios and indexes
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FetalBiometryRatios = DICOMControlledTerminologyDefinitionsCode("125001")
    """
    Report section for assessment of fetal growth
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FetalBiometry = DICOMControlledTerminologyDefinitionsCode("125002")
    """
    Report section for assessment of fetal growth by long bone measurements
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FetalLongBones = DICOMControlledTerminologyDefinitionsCode("125003")
    """
    Report section for assessment of fetal cranium growth
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FetalCranium = DICOMControlledTerminologyDefinitionsCode("125004")
    """
    Biometric assessment of
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BiometryGroup = DICOMControlledTerminologyDefinitionsCode("125005")
    """
    Report section for assessment of biophysical observations that evaluate fetal
    well-being according to Manning, Antepartum Fetal Evaluation: Development of a
    Fetal Biophysical Profile Score, Am. J Obstet Gynecol, 1980;136:787
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BiophysicalProfile = DICOMControlledTerminologyDefinitionsCode("125006")
    """
    A grouping of related measurements and calculations that share a common
    context
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MeasurementGroup = DICOMControlledTerminologyDefinitionsCode("125007")
    """
    Report section for fetus specific procedure summary observations
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FetusSummary = DICOMControlledTerminologyDefinitionsCode("125008")
    """
    Report section for assessment of early gestation fetus
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EarlyGestation = DICOMControlledTerminologyDefinitionsCode("125009")
    """
    A name to differentiate between multiple instances of some item
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Identifier = DICOMControlledTerminologyDefinitionsCode("125010")
    """
    Report section for assessment of pelvis and uterus
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PelvisAndUterus = DICOMControlledTerminologyDefinitionsCode("125011")
    """
    The rank of a measured growth indicator relative to a normal distribution
    expressed as a percentage
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    GrowthPercentileRank = DICOMControlledTerminologyDefinitionsCode("125012")
    """
    The rank of a measured growth indicator relative to a normal distribution
    expressed as the dimensionless quantity z = (x-m) /s where (x-m) is the
    deviation of the value x, from the distribution mean, m, and s is the standard
    deviation of the distribution
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    GrowthZ_score = DICOMControlledTerminologyDefinitionsCode("125013")
    """
    Fetus characteristics (findings section title)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FetusCharacteristics = DICOMControlledTerminologyDefinitionsCode("125015")
    """
    Fetal Measurements (findings section title)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FetalMeasurements = DICOMControlledTerminologyDefinitionsCode("125016")
    """
    There is a defined equivalence between the Frame of Reference of the
    Registration SOP instance and the Frame of Reference of the referenced images
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FrameOfReferenceIdentity = DICOMControlledTerminologyDefinitionsCode("125021")
    """
    The registration is based on fiducials that represent patient or specimen
    features identified in each data set
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FiducialAlignment = DICOMControlledTerminologyDefinitionsCode("125022")
    """
    Registration based on a-priori knowledge of the acquisition geometry. This is
    not an object registration as in fiducial registration. Rather, it specifies a
    known spatial relationship
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AcquisitionEquipmentAlignment = DICOMControlledTerminologyDefinitionsCode("125023")
    """
    Computed registration based on global image information
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ImageContent_basedAlignment = DICOMControlledTerminologyDefinitionsCode("125024")
    """
    Registration by visually guided manipulation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VisualAlignment = DICOMControlledTerminologyDefinitionsCode("125025")
    """
    A plane fiducial that specifies the location of the plane separating the two
    hemispheres of the brain
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Inter_HemisphericPlane = DICOMControlledTerminologyDefinitionsCode("125030")
    """
    A point fiducial that specifies the location in the plane perpendicular to the
    Anterior- Posterior-Commissure axis and tangential to the anterior limit of
    the right brain hemisphere
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RightHemisphereMostAnterior = DICOMControlledTerminologyDefinitionsCode("125031")
    """
    A point fiducial that specifies the location in the plane perpendicular to the
    Anterior- Posterior-Commissure axis and tangential to the posterior limit of
    the right brain hemisphere
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RightHemisphereMostPosterior = DICOMControlledTerminologyDefinitionsCode("125032")
    """
    A point fiducial that specifies the location in the plane perpendicular to the
    Anterior- Posterior-Commissure axis and tangential to the superior limit of
    the right brain hemisphere
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RightHemisphereMostSuperior = DICOMControlledTerminologyDefinitionsCode("125033")
    """
    A point fiducial that specifies the location in the plane perpendicular to the
    Anterior- Posterior-Commissure axis and tangential to the inferior limit of
    the Right brain hemisphere
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RightHemisphereMostInferior = DICOMControlledTerminologyDefinitionsCode("125034")
    """
    A point fiducial that specifies the location in the plane perpendicular to the
    Anterior- Posterior-Commissure axis and tangential to the anterior limit of
    the left brain hemisphere
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LeftHemisphereMostAnterior = DICOMControlledTerminologyDefinitionsCode("125035")
    """
    A point fiducial that specifies the location in the plane perpendicular to the
    Anterior- Posterior-Commissure axis and tangential to the posterior limit of
    the left brain hemisphere
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LeftHemisphereMostPosterior = DICOMControlledTerminologyDefinitionsCode("125036")
    """
    A point fiducial that specifies the location in the plane perpendicular to the
    Anterior- Posterior-Commissure axis and tangential to the superior limit of
    the left brain hemisphere
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LeftHemisphereMostSuperior = DICOMControlledTerminologyDefinitionsCode("125037")
    """
    A point fiducial that specifies the location in the plane perpendicular to the
    Anterior- Posterior-Commissure axis and tangential to the inferior limit of
    the left brain hemisphere
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LeftHemisphereMostInferior = DICOMControlledTerminologyDefinitionsCode("125038")
    """
    That which is not part of an object
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Background = DICOMControlledTerminologyDefinitionsCode("125040")
    """
    A segment for use as an input to an image registration process; e.g. to
    specify the bounding region for determining a Frame of Reference
    Transformation Matrix
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RegistrationInput = DICOMControlledTerminologyDefinitionsCode("125041")
    """
    Root Document Title for ultrasound vascular evidence reports (worksheets)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VascularUltrasoundProcedureReport = DICOMControlledTerminologyDefinitionsCode(
        "125100"
    )
    """
    The particular vessel branch, such as the inferior, medial or lateral
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VesselBranch = DICOMControlledTerminologyDefinitionsCode("125101")
    """
    A descriptor or elaboration of the type of graft
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    GraftType = DICOMControlledTerminologyDefinitionsCode("125102")
    """
    A modifier to a 2D distance measurement to describe its orientation; e.g. a
    vascular distance measurement for a vessel plague could have a modifier
    Transverse or Longitudinal
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MeasurementOrientation = DICOMControlledTerminologyDefinitionsCode("125105")
    """
    The angle formed between the Doppler beam line and the direction of blood flow
    within a region of interest in the body defined by the sample volume
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DopplerAngle = DICOMControlledTerminologyDefinitionsCode("125106")
    """
    The depth of the center of the Doppler sample volume measured from skin line
    along the Doppler line
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SampleVolumeDepth = DICOMControlledTerminologyDefinitionsCode("125107")
    """
    Pediatric Cardiac Ultrasound Report (document title)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PediatricCardiacUltrasoundReport = DICOMControlledTerminologyDefinitionsCode(
        "125195"
    )
    """
    Fetal Cardiac Ultrasound Report (document title)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FetalCardiacUltrasoundReport = DICOMControlledTerminologyDefinitionsCode("125196")
    """
    Adult Congenital Cardiac Ultrasound Report (document title)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AdultCongenitalCardiacUltrasoundReport = DICOMControlledTerminologyDefinitionsCode(
        "125197"
    )
    """
    Document title of adult echocardiography procedure (evidence) report
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AdultEchocardiographyProcedureReport = DICOMControlledTerminologyDefinitionsCode(
        "125200"
    )
    """
    An image that is a pictorial representation of findings. The concept is
    typically used as a purpose of reference to an image, such as a depiction of
    myocardium segments depicting wall motion function
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IllustrationOfFinding = DICOMControlledTerminologyDefinitionsCode("125201")
    """
    The average of all scored (non-zero) Left Ventricle segment wall motion scores
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LVWallMotionScoreIndex = DICOMControlledTerminologyDefinitionsCode("125202")
    """
    A type of clinical acquisition protocol for creating images or image-derived
    measurements. Acquisition protocols may be specific to a manufacturer's
    product
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AcquisitionProtocol = DICOMControlledTerminologyDefinitionsCode("125203")
    """
    Method for calculating left ventricular volume from two orthogonal views
    containing the true long axis (usually the apical 4 and 2 chamber views).
    Volume = [pL1 / 6] * [(4A1) ÷ (pL1) ] * [(4A2) ÷ (pL2) ]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Area_lengthBiplane = DICOMControlledTerminologyDefinitionsCode("125204")
    """
    Method for calculating left ventricular volume from a view containing the true
    long axis (usually the apical 4-chamber view). Volume = [8(A)2]÷[3pL]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Area_LengthSinglePlane = DICOMControlledTerminologyDefinitionsCode("125205")
    """
    Method (formula) for calculating left ventricle volumes and function
    derivatives (EF, SV, SI, etc.) that estimates the volume as the cube of
    diameter
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Cube = DICOMControlledTerminologyDefinitionsCode("125206")
    """
    Method of calculating volume based on the summation of disk volumes. The disk
    axis is parallel to the left ventricular long axis and using a disk diameter
    averaged from the two chamber and four chamber views
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MethodOfDisks_Biplane = DICOMControlledTerminologyDefinitionsCode("125207")
    """
    Method of calculating volume based on the summation of disk volumes. The disk
    axis is parallel to the left ventricular long axis with disk diameter taken
    from the four-chamber view
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MethodOfDisks_SinglePlane = DICOMControlledTerminologyDefinitionsCode("125208")
    """
    Method (formula) for calculating left ventricle volumes and function
    derivatives (EF, SV, SI, etc.) Volume = [7.0/(2.4+D) ]*D3
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Teichholz = DICOMControlledTerminologyDefinitionsCode("125209")
    """
    Mitral valve area (cm2) by Pressure Half-time = 220 (cm2.ms) / PHT (ms)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AreaByPressureHalf_Time = DICOMControlledTerminologyDefinitionsCode("125210")
    """
    Area = P/4 X d1 X d2 d1 = anterior/posterior axis d2 = medial/lateral axis
    Hagen-Ansert, Sandra L., Textbook of Diagnostic Ultrasound, ed. 3, The
    C.V.Mosby Co., 1989, p. 73.
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BiplaneEllipse = DICOMControlledTerminologyDefinitionsCode("125211")
    """
    For conduits in series ("in continuity"), volume flow is equal: A1*V1 = A2*V2.
    where V is the velocity
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ContinuityEquation = DICOMControlledTerminologyDefinitionsCode("125212")
    """
    For conduits in series ("in continuity"), volume flow is equal: A1*V1 = A2*V2.
    where V is the mean velocity
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ContinuityEquationByMeanVelocity = DICOMControlledTerminologyDefinitionsCode(
        "125213"
    )
    """
    For conduits in series ("in continuity"), volume flow is equal: A1*V1 = A2*V2.
    where V is the peak velocity
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ContinuityEquationByPeakVelocity = DICOMControlledTerminologyDefinitionsCode(
        "125214"
    )
    """
    For conduits in series ("in continuity"), volume flow is equal: A1*V1 = A2*V2.
    where V is the velocity time integral
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ContinuityEquationByVelocityTimeIntegral = (
        DICOMControlledTerminologyDefinitionsCode("125215")
    )
    """
    Utilizes aliasing velocity (by color Doppler) of flow into an orifice (often
    regurgitant or stenotic) to measure instantaneous flow rate, orifice area, and
    flow volume. The instantaneous flow rate = (2πr2vav ) * (α / π) where vav is
    the constant velocity known as aliasing velocity at radius r, vp is the peak
    velocity at the orifice, and α is the angle in radians of the constant
    velocity surface. Estimated Orifice area = Flow rate / vp , where vp is the
    peak velocity at the orifice and the flow rate is the PISA peak flow rate. The
    volume flow is then the product of the orifice area and Velocity Time Integral
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ProximalIsovelocitySurfaceArea = DICOMControlledTerminologyDefinitionsCode("125216")
    """
    ΔP = 4*(V12 - V22)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FullBernoulli = DICOMControlledTerminologyDefinitionsCode("125217")
    """
    ΔP = 4*V2
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SimplifiedBernoulli = DICOMControlledTerminologyDefinitionsCode("125218")
    """
    Volume flow = Conduit CSA * (Velocity Time Integral)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DopplerVolumeFlow = DICOMControlledTerminologyDefinitionsCode("125219")
    """
    Direct measurement of an area by tracing an irregular perimeter
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Planimetry = DICOMControlledTerminologyDefinitionsCode("125220")
    """
    Mass = 1.04 * [(ST+LVID+PWT)3 - LVID3] * 0.8+ 0.6. Mass unit is grams and
    length in cm
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LeftVentricleMassByM_mode = DICOMControlledTerminologyDefinitionsCode("125221")
    """
    Mass = 1.05P ((b + t)2 X (2/3 (a + t) + d - d3 /3(a + t)2) - b2 (2/3a + d - d3
    /3a2)) a = Semi-major axis from widest minor axis radius to apex. b = Short
    axis radius calculated from short axis cavity area t = Myocardial thickness
    calculated from short axis epicardial and cavity areas d = Truncated semi-
    major axis from widest short axis diameter to plane of mitral annulus. Mass
    unit is grams and length in cm. Schiller NB et al: Recommendations for
    quantification of the left ventricle by two-dimensional echocardiography,
    American Society of Echocardiography 2:364, 1989.
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LeftVentricleMassByTruncatedEllipse = DICOMControlledTerminologyDefinitionsCode(
        "125222"
    )
    """
    A four point, echocardiographic numeric scoring scheme of myocardium segments
    based on evaluation of wall motion and ventricle morphology. Recommendations
    for Quantitation of the Left Ventricle by Two-Dimensional Echocardiography,
    Journal of the American Society of Echocardiography, 2:358-367, 1989
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    _4PointSegmentFindingScale = DICOMControlledTerminologyDefinitionsCode("125223")
    """
    A five point, echocardiographic numeric scoring scheme of myocardium segments
    based on evaluation of wall motion and ventricle morphology. Recommendations
    for Quantitation of the Left Ventricle by Two-Dimensional Echocardiography,
    Journal of the American Society of Echocardiography, 2:358-367, 1989
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    _5PointSegmentFindingScale = DICOMControlledTerminologyDefinitionsCode("125224")
    """
    A five point, echocardiographic numeric scoring scheme of myocardium segments
    based on evaluation of wall motion and ventricle morphology, with severity of
    hypokinesis graded. Recommendations for Quantitation of the Left Ventricle by
    Two-Dimensional Echocardiography, Journal of the American Society of
    Echocardiography, 2:358-367, 1989
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    _5PointSegmentFindingScaleWithGradedHypokinesis = (
        DICOMControlledTerminologyDefinitionsCode("125225")
    )
    """
    Method of estimating volume from a planar ellipse. Equivalent to Biplane
    Ellipse with an assumption that the ellipse in the orthogonal plane has
    identical major and minor diameters
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SinglePlaneEllipse = DICOMControlledTerminologyDefinitionsCode("125226")
    """
    Modified Simpson's Method of estimating ventricular volume, based on the
    method of disks with paired apical views. Schiller NB, et al. "Recommendations
    for quantitation of the left ventricle by two-dimensional echocardiography.
    American Society of Echocardiography Committee on Standards, Subcommittee on
    Quantitation of Two-Dimensional Echocardiograms". J Am Soc Echocardiogr.1989
    2(5):358-367. Sep-Oct
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ModifiedSimpson = DICOMControlledTerminologyDefinitionsCode("125227")
    """
    Bullet method of estimating ventricular volume. Volume = 5/6 * L * S L: Left
    ventricle long axis length S: Left ventricle area, SAX view at level of Mitral
    Valve
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BulletMethod = DICOMControlledTerminologyDefinitionsCode("125228")
    """
    Color coded ultrasound images of blood flow, which depict the amplitude, or
    power, of Doppler signals
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PowerDoppler = DICOMControlledTerminologyDefinitionsCode("125230")
    """
    Volumetric ultrasound imaging
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    _3DMode = DICOMControlledTerminologyDefinitionsCode("125231")
    """
    Onset of administration of dose of a drug
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StartOfDrugDoseAdministration = DICOMControlledTerminologyDefinitionsCode("125233")
    """
    Onset of contrast agent administration
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StartOfContrastAgentAdministration = DICOMControlledTerminologyDefinitionsCode(
        "125234"
    )
    """
    Destruction of ultrasonic contrast microbubbles by a high-energy ultrasound
    pulse
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DestructionOfMicrobubbles = DICOMControlledTerminologyDefinitionsCode("125235")
    """
    Instant at which exercise begins
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OnsetOfExercise = DICOMControlledTerminologyDefinitionsCode("125236")
    """
    Instant at which exercise ends
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CessationOfExercise = DICOMControlledTerminologyDefinitionsCode("125237")
    """
    Instant at which stimulation begins
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OnsetOfStimulation = DICOMControlledTerminologyDefinitionsCode("125238")
    """
    Instant at which stimulation ends
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CessationOfStimulation = DICOMControlledTerminologyDefinitionsCode("125239")
    """
    Ultrasound transducer scan pattern in which information is gathered along a
    line
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LineScanPattern = DICOMControlledTerminologyDefinitionsCode("125240")
    """
    Ultrasound transducer scan pattern in which information is gathered within a
    plane
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PlaneScanPattern = DICOMControlledTerminologyDefinitionsCode("125241")
    """
    Ultrasound transducer scan pattern in which information is gathered within a
    volume
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    VolumeScanPattern = DICOMControlledTerminologyDefinitionsCode("125242")
    """
    Ultrasound transducer geometry characterized by a single scan line used for PW
    or CW Doppler scanning
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Non_imagingDopplerUltrasoundTransducerGeometry = (
        DICOMControlledTerminologyDefinitionsCode("125251")
    )
    """
    Ultrasonic transducer geometry characterized by parallel lines
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LinearUltrasoundTransducerGeometry = DICOMControlledTerminologyDefinitionsCode(
        "125252"
    )
    """
    Ultrasonic transducer geometry characterized by radial lines normal to the
    outside of a curved surface
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CurvedLinearUltrasoundTransducerGeometry = (
        DICOMControlledTerminologyDefinitionsCode("125253")
    )
    """
    Ultrasonic transducer geometry characterized by lines originating from a
    common apex
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SectorUltrasoundTransducerGeometry = DICOMControlledTerminologyDefinitionsCode(
        "125254"
    )
    """
    Ultrasonic transducer geometry characterized by lines emanating radially from
    a single point
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RadialUltrasoundTransducerGeometry = DICOMControlledTerminologyDefinitionsCode(
        "125255"
    )
    """
    Ultrasonic transducer geometry characterized by a circular ring of transducer
    elements
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RingUltrasoundTransducerGeometry = DICOMControlledTerminologyDefinitionsCode(
        "125256"
    )
    """
    Ultrasonic steering technique consisting of a single beam normal to the
    transducer face steered by the orientation of the probe
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FixedBeamDirection = DICOMControlledTerminologyDefinitionsCode("125257")
    """
    Ultrasonic steering technique consisting of mechanically directing the beam
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MechanicalBeamSteering = DICOMControlledTerminologyDefinitionsCode("125258")
    """
    Ultrasonic steering technique consisting of electronically-steered beams
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PhasedBeamSteering = DICOMControlledTerminologyDefinitionsCode("125259")
    """
    Transducer is designed to be placed onto the surface of the subject
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ExternalTransducer = DICOMControlledTerminologyDefinitionsCode("125261")
    """
    Transducer is designed for insertion into the esophagus
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TransesophagealTransducer = DICOMControlledTerminologyDefinitionsCode("125262")
    """
    Transducer is designed for insertion into the vagina
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EndovaginalTransducer = DICOMControlledTerminologyDefinitionsCode("125263")
    """
    Transducer is designed for insertion into the rectum
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EndorectalTransducer = DICOMControlledTerminologyDefinitionsCode("125264")
    """
    Transducer is designed for insertion via a catheter
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IntravascularTransducer = DICOMControlledTerminologyDefinitionsCode("125265")
    """
    method to measure the mass of the Left Ventricle via the ASE area-length
    method at end diastole. LV Mass = 1.05*(5/6*(A1*(L+t)) - 5/6*(A2*L)) A1 = Left
    Ventricle epicardial SAX area at the level of the papillary muscle tips at end
    diastole. A2 = Left Ventricle endocardial SAX area cavity area at the level of
    the papillary muscle tips at end diastole. L = Left Ventricle apical view long
    axis length at end diastole. t = Myocardial thickness can be computed as: t =
    sqrt (A1/3.14) - sqrt (A2/3.14) Reference: 1) Schiller, N.B., et al.
    "Recommendations for Quantification of the LV by Two-dimensional
    Echocardiography." J Am Soc Echo, Vol. 2, No. 5: 358-367, Sep-Oct 1989. 2)
    Reichek, N., et al. "Anatomic Validation of Left Ventricular Mass Estimates
    from Clinical Two-dimensional Echocardiography: Initial Results." Circulation,
    Vol. 67, No. 2: 348-52, February 1983
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LeftVentricleMassByAreaLength = DICOMControlledTerminologyDefinitionsCode("125270")
    """
    Equation = Left Ventricle Mass by M-mode (in gram) / (Height (in meter)) ^2.7
    Reference: Giovanni De Simone, et al. "Effect of Growth on Variability of Left
    Ventricular Mass: Assessment of Allometric Signals in Adults and Children and
    Their Capacity to Predict Cardiovascular Risk". New York, New York and
    Cincinnati, Ohio
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LeftVentricleMassByM_mode_AdjustedByHeight = (
        DICOMControlledTerminologyDefinitionsCode("125271")
    )
    """
    Equation = Left Ventricle Mass by Truncated Ellipse / Height^2.7 Reference:
    Giovanni De Simone, et al. "Effect of Growth on Variability of Left
    Ventricular Mass: Assessment of Allometric Signals in Adults and Children and
    Their Capacity to Predict Cardiovascular Risk". New York, New York and
    Cincinnati, Ohio
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LeftVentricleMassByTruncatedEllipse_AdjustedByHeight = (
        DICOMControlledTerminologyDefinitionsCode("125272")
    )
    """
    Equation = Left Ventricle Mass by Area Length / Height^2.7 Reference: Giovanni
    De Simone, et al. "Effect of Growth on Variability of Left Ventricular Mass:
    Assessment of Allometric Signals in Adults and Children and Their Capacity to
    Predict Cardiovascular Risk". New York, New York and Cincinnati, Ohio
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LeftVentricleMassByAreaLength_AdjustedByHeight = (
        DICOMControlledTerminologyDefinitionsCode("125273")
    )
    """
    CARDIOsphere ultrasonic contrast agent produced by POINT Biomedical
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CARDIOsphere = DICOMControlledTerminologyDefinitionsCode("125901")
    """
    Echovist® ultrasonic contrast agent produced by Schering AG
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Echovist = DICOMControlledTerminologyDefinitionsCode("125902")
    """
    Imagify ultrasonic contrast agent produced by Accusphere Inc
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Imagify = DICOMControlledTerminologyDefinitionsCode("125903")
    """
    Levovist® ultrasonic contrast agent produced by Schering AG
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Levovist = DICOMControlledTerminologyDefinitionsCode("125904")
    """
    Sonazoid ultrasonic contrast agent produced by Daiichi Pharmaceutical /
    General Electric
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Sonazoid = DICOMControlledTerminologyDefinitionsCode("125905")
    """
    SonoVue ultrasonic contrast agent produced by Bracco Diagnostics
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SonoVue = DICOMControlledTerminologyDefinitionsCode("125906")
    """
    Targestar-B ultrasonic contrast agent produced by Targeson LLC
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Targestar_B = DICOMControlledTerminologyDefinitionsCode("125907")
    """
    Targestar-P ultrasonic contrast agent produced by Targeson LLC
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Targestar_P = DICOMControlledTerminologyDefinitionsCode("125908")
    """
    A structured report containing the quantitative results of human or machine
    analysis of images
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ImagingMeasurementReport = DICOMControlledTerminologyDefinitionsCode("126000")
    """
    A structured report containing the quantitative results of human or machine
    analysis of images for oncology evaluation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OncologyMeasurementReport = DICOMControlledTerminologyDefinitionsCode("126001")
    """
    A structured report containing the quantitative results of human or machine
    analysis of DCE-MR
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DynamicContrastMRMeasurementReport = DICOMControlledTerminologyDefinitionsCode(
        "126002"
    )
    """
    A structured report containing the quantitative results of human or machine
    analysis of PET images
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PETMeasurementReport = DICOMControlledTerminologyDefinitionsCode("126003")
    """
    Measurements made on images
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ImagingMeasurements = DICOMControlledTerminologyDefinitionsCode("126010")
    """
    Measurements derived from measurements made on images
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DerivedImagingMeasurements = DICOMControlledTerminologyDefinitionsCode("126011")
    """
    An MRI procedure in which multiple parameters including diffusion, dynamic
    contrast and T2 are measured
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MultiparametricMRI = DICOMControlledTerminologyDefinitionsCode("126020")
    """
    An MRI procedure of the prostate in which multiple parameters including
    diffusion, dynamic contrast and T2 are measured
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MultiparametricMRIOfProstate = DICOMControlledTerminologyDefinitionsCode("126021")
    """
    An MRI procedure of the whole body in which multiple parameters including
    diffusion, dynamic contrast and T2 are measured
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MultiparametricMRIOfWholeBody = DICOMControlledTerminologyDefinitionsCode("126022")
    """
    The volume derived by summing the volumes of all the voxels (and partial
    voxels if the segment contains partially occupied voxels) included in the
    segment
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SumOfSegmentedVoxelVolumes = DICOMControlledTerminologyDefinitionsCode("126030")
    """
    Maximum average gray value that is calculated from a 1 cubic centimeter sphere
    placed within the region of interest. Reference Wahl et al PERCIST article
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PeakValueWithinROI = DICOMControlledTerminologyDefinitionsCode("126031")
    """
    The volume of a lesion (e.g. a tumor) ascertained through information about
    its metabolic activity (e.g. SUV on PET). Abbreviated "MV". Synonymous with
    Metabolic Tumor Volume (MTV)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MetabolicVolume = DICOMControlledTerminologyDefinitionsCode("126032")
    """
    The total activity of a lesion obtained as the product of its volume and its
    glycolytic activity (on FDG-PET). The volume may be defined on the same
    modality (e.g. the MV on FDG-PET by some thresholding or other technique) or
    on another spatially registered modality (e.g. the lesion outline segmented on
    CT or MR). Does not apply to other radiopharmaceuticals than those involved in
    glucose metabolism. Abbreviated TLG. Synonymnous with "Tumor Lesion
    Glycolysis"
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TotalLesionGlycolysis = DICOMControlledTerminologyDefinitionsCode("126033")
    """
    The amount glycolytic activity summed across all voxels in a defined region or
    within a defined range of SUV (on FDG-PET)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Glycolysis = DICOMControlledTerminologyDefinitionsCode("126034")
    """
    The total activity of a lesion obtained as the product of its volume and its
    proliferative activity (on FLT-PET). The volume may be defined on the same
    modality (e.g. the MV on FDG-PET by some thresholding or other technique) or
    on another spatially registered modality (e.g. the lesion outline segmented on
    CT or MR). Does not apply to other radiopharmaceuticals than those involved in
    cellular proliferation. Abbreviated TLP. Synonymnous with "Tumor Lesion
    Proliferation"
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TotalLesionProliferation = DICOMControlledTerminologyDefinitionsCode("126035")
    """
    The amount proliferative activity summed across all voxels in a defined region
    or within a defined range of SUV (on FLT-PET)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ProliferativeActivity = DICOMControlledTerminologyDefinitionsCode("126036")
    """
    A background-corrected, partial volume independent version of TLG. SAM is
    calculated by drawing a volume of interest (VOI1) around the tumour and a
    larger VOI (VOI2) around VOI1. Subtracting the background activity in
    VOI2-VOI1 from VOI1 yields SAM. See Mertens et al. "Standardized added
    metabolic activity (SAM): a partial volume independent marker of total lesion
    glycolysis in liver metastases". Eur J Nucl Med Mol Imaging (2012)
    39:1441-1448
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StandardizedAddedMetabolicActivity_SAM_ = DICOMControlledTerminologyDefinitionsCode(
        "126037"
    )
    """
    The background value (VOI2-VOI1) used to calculate Standardized Added
    Metabolic Activity (SAM). SAM is calculated by drawing a volume of interest
    (VOI1) around the tumour and a larger VOI (VOI2) around VOI1. Subtracting the
    background activity in VOI2-VOI1 from VOI1 yields SAM. See Mertens et al.
    "Standardized added metabolic activity (SAM): a partial volume independent
    marker of total lesion glycolysis in liver metastases". Eur J Nucl Med Mol
    Imaging (2012) 39:1441-1448
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StandardizedAddedMetabolicActivity_SAM_Background = (
        DICOMControlledTerminologyDefinitionsCode("126038")
    )
    """
    The ratio of the SUV within a tumor to the SUV of a pre-defined background
    region. Need reference(s). A more general concept than Tumor to Background
    Ratio (TBR)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LesionToBackgroundSUVRatio = DICOMControlledTerminologyDefinitionsCode("126039")
    """
    The SUV of a pre-defined background region used to compute Lesion to
    Background SUV Ratio. Need reference(s)
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BackgroundForLesionToBackgroundSUVRatio = DICOMControlledTerminologyDefinitionsCode(
        "126040"
    )
    """
    A statistical index of complexity comparing how detail in a fractal pattern
    changes with the scale at which it is measured; a ratio of the change in
    detail to the change in scale
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FractalDimension = DICOMControlledTerminologyDefinitionsCode("126050")
    """
    Measure of the asymmetry of the probability distribution of a real-valued
    random variable about its mean
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Skewness = DICOMControlledTerminologyDefinitionsCode("126051")
    """
    Measure of the peakedness of the probability distribution of a real-valued
    random variable
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Kurtosis = DICOMControlledTerminologyDefinitionsCode("126052")
    """
    The zero order entropy of a Gray Level Co-occurrence Matrix (GLCM). A measure
    of disorder. See http://www.fp.ucalgary.ca/mhallbey/equations.htm
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EntropyOfGLCM = DICOMControlledTerminologyDefinitionsCode("126060")
    """
    The energy (uniformity) (square root of the Angular Second Moment (ASM)) of a
    Gray Level Co-occurrence Matrix (GLCM). A measure of orderliness. See
    http://www.fp.ucalgary.ca/mhallbey/equations.htm
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    EnergyOfGLCM = DICOMControlledTerminologyDefinitionsCode("126061")
    """
    The Inverse Difference Moment of a Gray Level Co-occurrence Matrix (GLCM). See
    http://www.fp.ucalgary.ca/mhallbey/equations.htm
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    HomogeneityOfGLCM = DICOMControlledTerminologyDefinitionsCode("126062")
    """
    The sum of squares variance of a Gray Level Co-occurrence Matrix (GLCM). See
    http://www.fp.ucalgary.ca/mhallbey/equations.htm
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ContrastOfGLCM = DICOMControlledTerminologyDefinitionsCode("126063")
    """
    The dissimilarity of a Gray Level Co-occurrence Matrix (GLCM). See
    http://www.fp.ucalgary.ca/mhallbey/equations.htm
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    DissimilarityOfGLCM = DICOMControlledTerminologyDefinitionsCode("126064")
    """
    The Angular Second Moment of a Gray Level Co-occurrence Matrix (GLCM). See
    http://www.fp.ucalgary.ca/mhallbey/equations.htm
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ASMOfGLCM = DICOMControlledTerminologyDefinitionsCode("126065")
    """
    A measure of the linear dependency of grey levels on those of neighbouring
    pixels of a Gray Level Co-occurrence Matrix (GLCM). See
    http://www.fp.ucalgary.ca/mhallbey/equations.htm
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CorrelationOfGLCM = DICOMControlledTerminologyDefinitionsCode("126066")
    """
    A tabulation of how often different combinations of pixel values (grey levels)
    occur in an image. See http://www.fp.ucalgary.ca/mhallbey/the_glcm.htm
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    GrayLevelCo_occurrenceMatrix_GLCM_ = DICOMControlledTerminologyDefinitionsCode(
        "126067"
    )
    """
    An identifier of a specific time point in a continuum, which is unique within
    an appropriate local context (such as an entire organization, system or
    treatment protocol), which identifies the time point for a specific patient
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SubjectTimePointIdentifier = DICOMControlledTerminologyDefinitionsCode("126070")
    """
    An identifier of a specific time point in a continuum, which is unique within
    an appropriate local context (such as an entire organization, system or
    treatment protocol), which identifies the time point "slot" within a treatment
    protocol using the same value for all patients in the protocol
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ProtocolTimePointIdentifier = DICOMControlledTerminologyDefinitionsCode("126071")
    """
    A pre-defined type of a specific time point in a continuum
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TimePointType = DICOMControlledTerminologyDefinitionsCode("126072")
    """
    A number indicating the order of a time point relative to other time points in
    the same continuum
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TimePointOrder = DICOMControlledTerminologyDefinitionsCode("126073")
    """
    The time after the treatment of interest
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Posttreatment = DICOMControlledTerminologyDefinitionsCode("126074")
    """
    For the purpose of determining eligibility for a protocol
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Eligibility = DICOMControlledTerminologyDefinitionsCode("126075")
    """
    Response Evaluation Criteria in Solid Tumors version 1.0. See [RECIST] in
    Normative References
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RECIST1_0 = DICOMControlledTerminologyDefinitionsCode("126080")
    """
    Response Evaluation Criteria in Solid Tumors Version 1.1. See Eisenhauer et
    al. "New Response Evaluation Criteria in Solid Tumours: Revised RECIST
    Guideline (version 1.1)." European Journal of Cancer 45, no. 2 (n.d.): 228-47.
    doi:10.1016/j.ejca.2008.10.026.
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RECIST1_1 = DICOMControlledTerminologyDefinitionsCode("126081")
    """
    A reference to the Real World Value Map applied to the stored image pixel
    values before their use for a measurement
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RealWorldValueMapUsedForMeasurement = DICOMControlledTerminologyDefinitionsCode(
        "126100"
    )
    """
    A container that groups common information about a set of images used as
    evidence to produce a report
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ImageLibraryGroup = DICOMControlledTerminologyDefinitionsCode("126200")
    """
    The date the acquisition of data started
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AcquisitionDate = DICOMControlledTerminologyDefinitionsCode("126201")
    """
    The time the acquisition of data started
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AcquisitionTime = DICOMControlledTerminologyDefinitionsCode("126202")
    """
    The time between the start of injection of the PET radionuclide and the start
    of acquisition of the PET data
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PETRadionuclideIncubationTime = DICOMControlledTerminologyDefinitionsCode("126203")
    """
    Coefficient of determination, R2. An indication of goodness of fit
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    R2_Coefficient = DICOMControlledTerminologyDefinitionsCode("126220")
    """
    Perfusion analysis by Stable Xenon CT technique
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PerfusionAnalysisByStableXenonCTTechnique = (
        DICOMControlledTerminologyDefinitionsCode("126300")
    )
    """
    Perfusion analysis by IV Iodinated Contrast CT technique
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PerfusionAnalysisByIVIodinatedContrastCTTechnique = (
        DICOMControlledTerminologyDefinitionsCode("126301")
    )
    """
    Perfusion analysis by Arterial Spin Labeling (ASL) MR technique
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PerfusionAnalysisByArterialSpinLabelingMRTechnique = (
        DICOMControlledTerminologyDefinitionsCode("126302")
    )
    """
    Perfusion analysis by Susceptibility (T2*) MR technique
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PerfusionAnalysisBySusceptibilityMRTechnique = (
        DICOMControlledTerminologyDefinitionsCode("126303")
    )
    """
    Least Mean Square (LMS) deconvolution
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    LeastMeanSquare_LMS_Deconvolution = DICOMControlledTerminologyDefinitionsCode(
        "126310"
    )
    """
    Singular Value Decomposition (SVD) deconvolution
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SingularValueDecomposition_SVD_Deconvolution = (
        DICOMControlledTerminologyDefinitionsCode("126311")
    )
    """
    Ktrans, the volume transfer constant of a tracer diffusion kinetic model,
    specifically the volume transfer constant between blood plasma and
    extravascular extracellular space (EES) See Tofts et al, "Estimating Kinetic
    Parameters From Dynamic Contrast-Enhanced T1-Weighted MRI of a Diffusable
    Tracer: Standardized Quantities and Symbols", Journal of Magnetic Resonance
    Imaging, vol. 10, pp. 223-232, 1999
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Ktrans = DICOMControlledTerminologyDefinitionsCode("126312")
    """
    kep, the rate constant between extravascular extracellular space (EES) and
    blood plasma See Tofts et al, "Estimating Kinetic Parameters From Dynamic
    Contrast-Enhanced T1-Weighted MRI of a Diffusable Tracer: Standardized
    Quantities and Symbols", Journal of Magnetic Resonance Imaging, vol. 10, pp.
    223-232, 1999
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Kep = DICOMControlledTerminologyDefinitionsCode("126313")
    """
    ve, the fractional (not absolute) volume of extravascular extracellular space
    (EES) per unit volume of tissue See Tofts et al, "Estimating Kinetic
    Parameters From Dynamic Contrast-Enhanced T1-Weighted MRI of a Diffusable
    Tracer: Standardized Quantities and Symbols", Journal of Magnetic Resonance
    Imaging, vol. 10, pp. 223-232, 1999
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Ve = DICOMControlledTerminologyDefinitionsCode("126314")
    """
    The intial area under the contrast agent concentration-time curve
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IAUC = DICOMControlledTerminologyDefinitionsCode("126320")
    """
    The intial area under the contrast agent concentration-time curve at 60
    seconds after the onset time
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IAUC60 = DICOMControlledTerminologyDefinitionsCode("126321")
    """
    The intial area under the contrast agent concentration-time curve at 90
    seconds after the onset time
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IAUC90 = DICOMControlledTerminologyDefinitionsCode("126322")
    """
    τm. The mean intracellular water lifetime (τi). Used in the Shutter-Speed
    Model (SSM) of tracer kinetics
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Tau_m = DICOMControlledTerminologyDefinitionsCode("126330")
    """
    vp. The fractional (not absolute) blood plasma volume per unit volume of
    tissue. See Tofts et al, "Estimating Kinetic Parameters From Dynamic Contrast-
    Enhanced T1-Weighted MRI of a Diffusable Tracer: Standardized Quantities and
    Symbols", Journal of Magnetic Resonance Imaging, vol. 10, pp. 223-232, 1999
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Vp = DICOMControlledTerminologyDefinitionsCode("126331")
    """
    A tracer diffusion kinetic model in which the permeability is assumed to be
    isodirectional. See P. Tofts, "Modeling tracer kinetics in dynamic Gd-DTPA MR
    imaging", Journal of Magnetic Resonance Imaging, vol. 7, pp. 91-101, 1997
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StandardToftsModel = DICOMControlledTerminologyDefinitionsCode("126340")
    """
    A tracer diffusion kinetic model in which the permeability is not assumed to
    be isodirectional, and which includes the contribution of tracer in the blood
    plasma to the total tissue concentration. See P. Tofts, "Modeling tracer
    kinetics in dynamic Gd-DTPA MR imaging", Journal of Magnetic Resonance
    Imaging, vol. 7, pp. 91-101, 1997
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ExtendedToftsModel = DICOMControlledTerminologyDefinitionsCode("126341")
    """
    A semiquantitative analysis of the contrast-enhancement concentration versus
    time curve that avoids the use of a pharmacokinetic model; e.g. integration to
    compute the initial area under the curve
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Model_freeConcentration_timeQuantitification = (
        DICOMControlledTerminologyDefinitionsCode("126342")
    )
    """
    A tracer diffusion kinetic model that accounts for the tumor leakage profile
    during the first pass of contrast. See Li, Ka-Loh, Xiao Ping Zhu, John
    Waterton, and Alan Jackson. "Improved 3D Quantitative Mapping of Blood Volume
    and Endothelial Permeability in Brain Tumors." Journal of Magnetic Resonance
    Imaging 12, no. 2 (2000): 347-357. doi:10.1002/1522-2586(200008)12:2<347::AID-
    JMRI19>3.0.CO;2-7
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FirstPassLeakageProfile_FPLP_ = DICOMControlledTerminologyDefinitionsCode("126343")
    """
    A tracer diffusion kinetic model that does not assume that intercompartmental
    water molecule exchange is infinitely fast. See Li, Xin, Wei Huang, Thomas E.
    Yankeelov, Alina Tudorica, William D. Rooney, and Charles S. Springer.
    "Shutter-Speed Analysis of Contrast Reagent Bolus-Tracking Data: Preliminary
    Observations in Benign and Malignant Breast Disease." Magnetic Resonance in
    Medicine 53, no. 3 (2005): 724-29. doi:10.1002/mrm.20405
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Shutter_SpeedModel_SSM_ = DICOMControlledTerminologyDefinitionsCode("126344")
    """
    T1 measurement by Multiple Flip Angles (MFA) (variable saturation) method
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    T1ByMultipleFlipAngles = DICOMControlledTerminologyDefinitionsCode("126350")
    """
    T1 measurement by Inversion Recovery (IR) method
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    T1ByInversionRecovery = DICOMControlledTerminologyDefinitionsCode("126351")
    """
    Calculation was performed using a fixed value of T1 rather than a measured
    value. The value could be encoded as the value of (126353, DCM, "T1 Used For
    Calculation")
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    T1ByFixedValue = DICOMControlledTerminologyDefinitionsCode("126352")
    """
    The fixed value of T1 used for a calculation
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    T1UsedForCalculation = DICOMControlledTerminologyDefinitionsCode("126353")
    """
    No Arterial Input Function was used
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AIFIgnored = DICOMControlledTerminologyDefinitionsCode("126360")
    """
    A population-averaged Arterial Input Function
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PopulationAveragedAIF = DICOMControlledTerminologyDefinitionsCode("126361")
    """
    An Arterial Input Function computed from a user-defined Region of Interest
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    User_definedAIFROI = DICOMControlledTerminologyDefinitionsCode("126362")
    """
    An Arterial Input Function computed from an automatically detected Region of
    Interest
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    AutomaticallyDetectedAIFROI = DICOMControlledTerminologyDefinitionsCode("126363")
    """
    A data-driven blind source separation (BSS) algorithm that estimates AIF from
    individuals without any presumed AIF model and initialization. See Lin, Yu-
    Chun, Tsung-Han Chan, Chong-Yung Chi, Shu-Hang Ng, Hao-Li Liu, Kuo-Chen Wei,
    Yau-Yau Wai, Chun-Chieh Wang, and Jiun-Jie Wang. "Blind Estimation of the
    Arterial Input Function in Dynamic Contrast-Enhanced MRI Using Purity
    Maximization." Magnetic Resonance in Medicine 68, no. 5 (November 1, 2012):
    1439-49. doi:10.1002/mrm.24144
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BlindEstimationOfAIF = DICOMControlledTerminologyDefinitionsCode("126364")
    """
    The time at which the concentration-time curve achieves its peak for the first
    time. Used as a concept name for a value or as a method; e.g. used as a method
    of calculation for BAT. See Shpilfoygel Med Phys 2008. doi: 10.1118/1.1288669
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TimeOfPeakConcentration = DICOMControlledTerminologyDefinitionsCode("126370")
    """
    The nominal time at which arrival of a contrast bolus is detected, which is
    used as a reference point for subsequent calculations. Used as a concept name
    for a value or as a method. No specific computational method is implied by
    this general definition. Abbreviated BAT
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    BolusArrivalTime = DICOMControlledTerminologyDefinitionsCode("126371")
    """
    The time at which the concentration-time curve achieves half of its peak
    density for the first time. Used as a concept name for a value or as a method;
    e.g. used as a method of calculation for BAT. See Shpilfoygel Med Phys 2008.
    doi: 10.1118/1.1288669
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TimeOfLeadingHalf_PeakConcentration = DICOMControlledTerminologyDefinitionsCode(
        "126372"
    )
    """
    A method of determining BAT that involves computing the temporal derivative of
    the concentration-time curve and selecting the time when the temporal
    derivative exceeds a specified threshold. See Shpilfoygel Med Phys 2008. doi:
    10.1118/1.1288669
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TemporalDerivativeExceedsThreshold = DICOMControlledTerminologyDefinitionsCode(
        "126373"
    )
    """
    A threshold applied to the temporal derivative of the concentration-time
    curve; e.g. used to establish BAT. See Shpilfoygel Med Phys 2008. doi:
    10.1118/1.1288669
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TemporalDerivativeThreshold = DICOMControlledTerminologyDefinitionsCode("126374")
    """
    The maximum rate of signal intensity change within a measured region of a
    time-activity curve. See Boonsirikamchai, Piyaporn, Harmeet Kaur, Deborah A.
    Kuban, Edward Jackson, Ping Hou, and Haesun Choi. "Use of Maximum Slope Images
    Generated From Dynamic Contrast-Enhanced MRI to Detect Locally Recurrent
    Prostate Carcinoma After Prostatectomy: A Practical Approach." American
    Journal of Roentgenology 198, no. 3 (March 1, 2012): W228-W236.
    doi:10.2214/AJR.10.6387
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MaximumSlope = DICOMControlledTerminologyDefinitionsCode("126375")
    """
    The maximum degree of signal intensity change within a measured region of a
    time-activity curve. See Boonsirikamchai, Piyaporn, Harmeet Kaur, Deborah A.
    Kuban, Edward Jackson, Ping Hou, and Haesun Choi. "Use of Maximum Slope Images
    Generated From Dynamic Contrast-Enhanced MRI to Detect Locally Recurrent
    Prostate Carcinoma After Prostatectomy: A Practical Approach." American
    Journal of Roentgenology 198, no. 3 (March 1, 2012): W228-W236.
    doi:10.2214/AJR.10.6387
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MaximumDifference = DICOMControlledTerminologyDefinitionsCode("126376")
    """
    Tracer concentration in tissue; e.g. in a DCE-MR experiment, the concentration
    of contrast agent in mmol/l
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    TracerConcentration = DICOMControlledTerminologyDefinitionsCode("126377")
    """
    The degree to which a paramagnetic contrast agent can enhance the proton
    longitudinal relaxation rate constant (R1, 1/T1), normalized to the
    concentration of the contrast agent. Also referred to as r1. Typically
    expressed in units of l/mmol/s
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ContrastLongitudinalRelaxivity = DICOMControlledTerminologyDefinitionsCode("126380")
    """
    The flow rate of blood perfusing a region as volume per mass per unit of time
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RegionalBloodFlow = DICOMControlledTerminologyDefinitionsCode("126390")
    """
    The volume of blood perfusing a region as volume per mass
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    RegionalBloodVolume = DICOMControlledTerminologyDefinitionsCode("126391")
    """
    The percent of the oxygen removed from the blood by tissue during its passage
    through the capillary network. For example, as measured by blood oxygenation
    level dependent (BOLD) MR. See He, Xiang, and Dmitriy A. Yablonskiy.
    "Quantitative BOLD: Mapping of Human Cerebral Deoxygenated Blood Volume and
    Oxygen Extraction Fraction: Default State." Magnetic Resonance in Medicine 57,
    no. 1 (2007): 115-26
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    OxygenExtractionFraction = DICOMControlledTerminologyDefinitionsCode("126392")
    """
    The longitiudinal relaxation rate constant. The inverse of longitudinal
    relaxation time, i.e., R1 = 1/T1
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    R1 = DICOMControlledTerminologyDefinitionsCode("126393")
    """
    The transverse relaxation rate constant. The inverse of transverse relaxation
    time, i.e., R2 = 1/T2
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    R2 = DICOMControlledTerminologyDefinitionsCode("126394")
    """
    A ratio of locally measured radioactivity concentration versus the injected
    radioactivity distributed evenly throughout the whole body. This general
    concept encompasses all specific methods of calculating the whole body volume
    of distribution, such as using body weight, lean body mass, body surface area,
    etc.
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    StandardizedUptakeValue = DICOMControlledTerminologyDefinitionsCode("126400")
    """
    Standardized Uptake Value calculated using body weight. The patient size
    correction factor for males and females is body weight. Defined in Sugawara et
    al. Reevaluation of the Standardized Uptake Value for FDG: Variations with
    Body Weight and Methods for Correction.Radiology, 1999 at
    http://radiology.rsna.org/content/213/2/521
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SUVbw = DICOMControlledTerminologyDefinitionsCode("126401")
    """
    Standardized Uptake Value calculated using lean body mass. The patient size
    correction factor for males is 1.10 * weight - 120 * (weight/height) ^2, and
    for females is 1.07 * weight - 148 * (weight/height) ^2. Defined in Sugawara
    et al. Reevaluation of the Standardized Uptake Value for FDG: Variations with
    Body Weight and Methods for Correction.Radiology, 1999 at
    http://radiology.rsna.org/content/213/2/521
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SUVlbm = DICOMControlledTerminologyDefinitionsCode("126402")
    """
    Standardized Uptake Value calculated using body surface area. The patient size
    correction factor for males and females is weight^ 0.425 * height^0.725 *
    0.007184. Defined in Sugawara et al. Reevaluation of the Standardized Uptake
    Value for FDG: Variations with Body Weight and Methods for
    Correction.Radiology, 1999 at http://radiology.rsna.org/content/213/2/521
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SUVbsa = DICOMControlledTerminologyDefinitionsCode("126403")
    """
    Standardized Uptake Value calculated using ideal body weight. The patient size
    correction factor for males is 48.0 + 1.06 * (height - 152) and for females is
    45.5 + 0.91 * (height - 152). Defined in Sugawara et al. Reevaluation of the
    Standardized Uptake Value for FDG: Variations with Body Weight and Methods for
    Correction.Radiology, 1999 at http://radiology.rsna.org/content/213/2/521
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SUVibw = DICOMControlledTerminologyDefinitionsCode("126404")
    """
    Method of calculating Standardized Uptake Value using body weight. The patient
    size correction factor for males and females is body weight. Defined in
    Sugawara et al. Reevaluation of the Standardized Uptake Value for FDG:
    Variations with Body Weight and Methods for Correction.Radiology, 1999 at
    http://radiology.rsna.org/content/213/2/521
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SUVBodyWeightCalculationMethod = DICOMControlledTerminologyDefinitionsCode("126410")
    """
    Method of calculating Standardized Uptake Value using lean body mass. The
    patient size correction factor for males is 1.10 * weight - 120 *
    (weight/height) ^2, and for females is 1.07 * weight - 148 * (weight/height)
    ^2. Defined in Sugawara et al. Reevaluation of the Standardized Uptake Value
    for FDG: Variations with Body Weight and Methods for Correction.Radiology,
    1999 at http://radiology.rsna.org/content/213/2/521
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SUVLeanBodyMassCalculationMethod = DICOMControlledTerminologyDefinitionsCode(
        "126411"
    )
    """
    Method of calculating Standardized Uptake Value using body surface area. The
    patient size correction factor for males and females is weight^ 0.425 *
    height^0.725 * 0.007184. Defined in Sugawara et al. Reevaluation of the
    Standardized Uptake Value for FDG: Variations with Body Weight and Methods for
    Correction.Radiology, 1999 at http://radiology.rsna.org/content/213/2/521
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SUVBodySurfaceAreaCalculationMethod = DICOMControlledTerminologyDefinitionsCode(
        "126412"
    )
    """
    Method of calculating Standardized Uptake Value using ideal body weight. The
    patient size correction factor for males is 48.0 + 1.06 * (height - 152) and
    for females is 45.5 + 0.91 * (height - 152). Defined in Sugawara et al.
    Reevaluation of the Standardized Uptake Value for FDG: Variations with Body
    Weight and Methods for Correction.Radiology, 1999 at
    http://radiology.rsna.org/content/213/2/521
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    SUVIdealBodyWeightCalculationMethod = DICOMControlledTerminologyDefinitionsCode(
        "126413"
    )
    """
    A beta-amyloid PET radiotracer that is an analog of thioflavin T
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    PittsburghCompoundBC_11_ = DICOMControlledTerminologyDefinitionsCode("126500")
    """
    A beta-amyloid PET radiotracer
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FlorbetabenF_18_ = DICOMControlledTerminologyDefinitionsCode("126501")
    """
    A PHF-tau PET radiotracer
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    T807F_18_ = DICOMControlledTerminologyDefinitionsCode("126502")
    """
    A nicotinic α4β2 receptor (nAChR) PET radiotracer
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FlubatineF_18_ = DICOMControlledTerminologyDefinitionsCode("126503")
    """
    A Cu 64 Monoclonal Antibody (mAb) PET Radiotracer
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MonoclonalAntibody_mAb_64_Cu = DICOMControlledTerminologyDefinitionsCode("126510")
    """
    A Zr 89 Monoclonal Antibody (mAb) PET Radiotracer
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    MonoclonalAntibody_mAb_89_Zr = DICOMControlledTerminologyDefinitionsCode("126511")
    """
    A Zr 89 Trastuzumab PET Radiotracer
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Trastuzumab_89_Zr = DICOMControlledTerminologyDefinitionsCode("126512")
    """
    A Zr 89 Cetuximab PET Radiotracer
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Cetuximab_89_Zr = DICOMControlledTerminologyDefinitionsCode("126513")
    """
    A Zr 89 J591 PET Radiotracer
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    J591_89_Zr = DICOMControlledTerminologyDefinitionsCode("126514")
    """
    A Zr 89 cU36 PET Radiotracer
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CU36_89_Zr = DICOMControlledTerminologyDefinitionsCode("126515")
    """
    A Zr 89 Bevacizumab PET Radiotracer
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Bevacizumab_89_Zr = DICOMControlledTerminologyDefinitionsCode("126516")
    """
    A Zr 89 cG250-F(ab')(2) PET Radiotracer
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CG250_F_ab_2_89_Zr = DICOMControlledTerminologyDefinitionsCode("126517")
    """
    A Zr 89 R1507 PET Radiotracer
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    R1507_89_Zr = DICOMControlledTerminologyDefinitionsCode("126518")
    """
    A Zr 89 E4G10 PET Radiotracer
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    E4G10_89_Zr = DICOMControlledTerminologyDefinitionsCode("126519")
    """
    A Zr 89 Df-CD45 PET Radiotracer
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Df_CD45_89_Zr = DICOMControlledTerminologyDefinitionsCode("126520")
    """
    ^44^Scandium
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    _44_Scandium = DICOMControlledTerminologyDefinitionsCode("126600")
    """
    ^51^Manganese
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    _51_Manganese = DICOMControlledTerminologyDefinitionsCode("126601")
    """
    ^70^Arsenic
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    _70_Arsenic = DICOMControlledTerminologyDefinitionsCode("126602")
    """
    ^90^Niobium
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    _90_Niobium = DICOMControlledTerminologyDefinitionsCode("126603")
    """
    ^191m^Iridium
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    _191m_Iridium = DICOMControlledTerminologyDefinitionsCode("126604")
    """
    ^43^Scandium
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    _43_Scandium = DICOMControlledTerminologyDefinitionsCode("126605")
    """
    ^152^Terbium
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    _152_Terbium = DICOMControlledTerminologyDefinitionsCode("126606")
    """
    A Cu 60 ATSM PET radiotracer
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ATSMCu_60_ = DICOMControlledTerminologyDefinitionsCode("126700")
    """
    A Cu 61 ATSM PET radiotracer
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ATSMCu_61_ = DICOMControlledTerminologyDefinitionsCode("126701")
    """
    A Cu 62 ATSM PET radiotracer
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    ATSMCu_62_ = DICOMControlledTerminologyDefinitionsCode("126702")
    """
    A C 11 Choline PET radiotracer
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CholineC_11_ = DICOMControlledTerminologyDefinitionsCode("126703")
    """
    A C 11 Fallypride PET radiotracer
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FallyprideC_11_ = DICOMControlledTerminologyDefinitionsCode("126704")
    """
    An F 18 Fallypride PET radiotracer
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FallyprideF_18_ = DICOMControlledTerminologyDefinitionsCode("126705")
    """
    A C 11 FLB 457 PET radiotracer
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FLB457C_11_ = DICOMControlledTerminologyDefinitionsCode("126706")
    """
    An F 18 Fluorotriopride PET radiotracer
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FluorotrioprideF_18_ = DICOMControlledTerminologyDefinitionsCode("126707")
    """
    An F 18 Fluoromisonidazole PET radiotracer
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    Fluoromisonidazole_FMISO_F_18_ = DICOMControlledTerminologyDefinitionsCode("126708")
    """
    A C 11 Glutamine PET radiotracer
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    GlutamineC_11_ = DICOMControlledTerminologyDefinitionsCode("126709")
    """
    A C 14 Glutamine PET radiotracer
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    GlutamineC_14_ = DICOMControlledTerminologyDefinitionsCode("126710")
    """
    An F 18 Glutamine PET radiotracer
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    GlutamineF_18_ = DICOMControlledTerminologyDefinitionsCode("126711")
    """
    An F 18 Flubatine PET radiotracer
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    FlubatineF_18_ = DICOMControlledTerminologyDefinitionsCode("126712")
    """
    An F 18 2FA PET radiotracer
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    _2FAF_18_ = DICOMControlledTerminologyDefinitionsCode("126713")
    """
    An F 18 Nifene PET radiotracer
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    NifeneF_18_ = DICOMControlledTerminologyDefinitionsCode("126714")
    """
    An I 124 cancer targeted phospholipid ether PET radiotracer
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CLR1404I_124_ = DICOMControlledTerminologyDefinitionsCode("126715")
    """
    An I 131 cancer targeted phospholipid ether PET radiotracer
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    CLR1404I_131_ = DICOMControlledTerminologyDefinitionsCode("126716")
    """
    Patient Support Continuous Angle in IEC PATIENT SUPPORT Coordinate System [IEC
    61217]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IEC6127PatientSupportContinuousAngle = DICOMControlledTerminologyDefinitionsCode(
        "126801"
    )
    """
    Table Top Continuous Pitch Angle in the direction of the IEC TABLE TOP
    Coordinate System [IEC 61217]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IEC6127TableTopContinuousPitchAngle = DICOMControlledTerminologyDefinitionsCode(
        "126802"
    )
    """
    Table Top Continuous Roll Angle in the direction of the IEC TABLE TOP
    Coordinate System [IEC 61217]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IEC6127TableTopContinuousRollAngle = DICOMControlledTerminologyDefinitionsCode(
        "126803"
    )
    """
    Table Top Eccentric Axis Distance [IEC 61217]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IEC6127TableTopEccentricAxisDistance = DICOMControlledTerminologyDefinitionsCode(
        "126804"
    )
    """
    Table Top Continuous Eccentric Angle in the direction of the IEC TABLE TOP
    ECCENTRIC Coordinate System [IEC 61217]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IEC6127TableTopContinuousEccentricAngle = DICOMControlledTerminologyDefinitionsCode(
        "126805"
    )
    """
    Table Top Lateral Position IEC TABLE TOP Coordinate System [IEC 61217]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IEC6127TableTopLateralPosition = DICOMControlledTerminologyDefinitionsCode("126806")
    """
    Table Top Longitudinal Position IEC TABLE TOP Coordinate System [IEC 61217]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IEC6127TableTopLongitudinalPosition = DICOMControlledTerminologyDefinitionsCode(
        "126807"
    )
    """
    Table Top Vertical Position in IEC TABLE TOP Coordinate System [IEC 61217]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IEC6127TableTopVerticalPosition = DICOMControlledTerminologyDefinitionsCode(
        "126808"
    )
    """
    Gantry Continuous Roll Angle in degrees of the radiation source, i.e., the
    rotation about the Y-axis of the IEC GANTRY coordinate system [IEC 61217]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IEC6127GantryContinuousRollAngle = DICOMControlledTerminologyDefinitionsCode(
        "126809"
    )
    """
    Gantry Pitch Continuous Angle in degrees of the radiation source, i.e., the
    rotation about the X-axis of the IEC GANTRY coordinate system [IEC 61217]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IEC6127GantryContinuousPitchAngle = DICOMControlledTerminologyDefinitionsCode(
        "126810"
    )
    """
    Gantry Yaw Continuous Angle in degrees of the radiation source, i.e., about
    the Z-axis of the IEC GANTRY coordinate system [IEC 61217]
    From: http://dicom.nema.org/resources/ontology/DCM in valuesets.xml
    """
    IEC6127GantryContinuousYawAngle = DICOMControlledTerminologyDefinitionsCode(
        "126811"
    )
