from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class DocumentTypeValueSetCode(GenericTypeCode):
    """
    DocumentTypeValueSet
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
        This is the code specifying the precise type of document (e.g. Pulmonary
    History and  Physical, Discharge Summary, Ultrasound Report, etc.). The
    Document Type value set includes all LOINC  values listed in HITSP C80 Table
    2-144 Document Class Value Set Definition above used for Document Class,  and
    all LOINC values whose SCALE is DOC in the LOINC database.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://loinc.org
    """
    codeset: FhirUri = "http://loinc.org"


class DocumentTypeValueSetCodeValues:
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """

    AddendumDocument = DocumentTypeValueSetCode("55107-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ADHDActionPlan = DocumentTypeValueSetCode("74155-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AdministrativeNote = DocumentTypeValueSetCode("51851-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AdmissionEvaluationNote = DocumentTypeValueSetCode("67851-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NurseAdmissionEvaluationNote = DocumentTypeValueSetCode("34744-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SurgeryAdmissionEvaluationNote = DocumentTypeValueSetCode("34873-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    EmergencyMedicineEmergencyDepartmentAdmissionEvaluationNote = (
        DocumentTypeValueSetCode("68552-9")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HospitalAdmissionEvaluationNote = DocumentTypeValueSetCode("67852-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CardiologyHospitalAdmissionEvaluationNote = DocumentTypeValueSetCode("68471-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CardiologyMedicalStudentHospitalAdmissionEvaluationNote = DocumentTypeValueSetCode(
        "68483-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CriticalCareMedicineHospitalAdmissionEvaluationNote = DocumentTypeValueSetCode(
        "64058-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CriticalCareMedicineMedicalStudentHospitalAdmissionEvaluationNote = (
        DocumentTypeValueSetCode("64070-6")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GeneralMedicineHospitalAdmissionEvaluationNote = DocumentTypeValueSetCode("64053-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GeneralMedicineMedicalStudentHospitalAdmissionEvaluationNote = (
        DocumentTypeValueSetCode("64054-0")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GeneralMedicinePhysicianAttendingHospitalAdmissionEvaluationNote = (
        DocumentTypeValueSetCode("34862-3")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PulmonaryHospitalAdmissionEvaluationNote = DocumentTypeValueSetCode("64062-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PulmonaryMedicalStudentHospitalAdmissionEvaluationNote = DocumentTypeValueSetCode(
        "64078-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SurgeryMedicalStudentHospitalAdmissionEvaluationNote = DocumentTypeValueSetCode(
        "64066-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThoracicSurgeryHospitalAdmissionEvaluationNote = DocumentTypeValueSetCode("64060-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThoracicSurgeryMedicalStudentHospitalAdmissionEvaluationNote = (
        DocumentTypeValueSetCode("64074-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AdmissionHistoryAndPhysicalNote = DocumentTypeValueSetCode("51849-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GeneralMedicineAdmissionHistoryAndPhysicalNote = DocumentTypeValueSetCode("34763-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HospitalAdmissionHistoryAndPhysicalNote = DocumentTypeValueSetCode("47039-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CardiologyHospitalAdmissionHistoryAndPhysicalNote = DocumentTypeValueSetCode(
        "34094-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AdmissionRequestDocument = DocumentTypeValueSetCode("57830-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AllergiesAndAdverseReactionsDocument = DocumentTypeValueSetCode("48765-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AnaphylaxisActionPlan = DocumentTypeValueSetCode("74152-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PatientAnesthesiaConsent = DocumentTypeValueSetCode("61359-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AntepartumSummaryNote = DocumentTypeValueSetCode("57055-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AppointmentSummaryDocument = DocumentTypeValueSetCode("56446-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AssessmentNote = DocumentTypeValueSetCode("51848-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricsAssessmentNote = DocumentTypeValueSetCode("68814-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PastoralCareHospitalAssessmentNote = DocumentTypeValueSetCode("64064-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Assessment_PlanNote = DocumentTypeValueSetCode("51847-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AsthmaActionPlan = DocumentTypeValueSetCode("69981-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AutismActionPlan = DocumentTypeValueSetCode("74154-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BirthCertificateDocument = DocumentTypeValueSetCode("71230-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CancerEventReport = DocumentTypeValueSetCode("72134-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClinicalPresentationDocument = DocumentTypeValueSetCode("55108-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CommunicationOfCriticalResults_Description_Document = DocumentTypeValueSetCode(
        "73568-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ComplexMedicalConditionsActionPlan = DocumentTypeValueSetCode("74144-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ComplicationsDocument = DocumentTypeValueSetCode("55109-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ComprehensiveHistoryAndPhysicalNote = DocumentTypeValueSetCode("34095-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NursingFacilityComprehensiveHistoryAndPhysicalNote = DocumentTypeValueSetCode(
        "34096-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ComputerGeneratedRecommendationDocument = DocumentTypeValueSetCode("63485-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ConclusionsDocument = DocumentTypeValueSetCode("55110-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ConferenceNote = DocumentTypeValueSetCode("34098-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NursingFacilityConferenceNote = DocumentTypeValueSetCode("34097-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Consultation2ndOpinion = DocumentTypeValueSetCode("47040-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HospitalConsultation2ndOpinion = DocumentTypeValueSetCode("47041-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PatientConsent = DocumentTypeValueSetCode("59284-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ConsultNote = DocumentTypeValueSetCode("11488-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CardiologyConsultNote = DocumentTypeValueSetCode("34099-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    DentistryConsultNote = DocumentTypeValueSetCode("34756-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    DermatologyConsultNote = DocumentTypeValueSetCode("34758-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    DiabetologyConsultNote = DocumentTypeValueSetCode("34760-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    EndocrinologyConsultNote = DocumentTypeValueSetCode("34879-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GastroenterologyConsultNote = DocumentTypeValueSetCode("34761-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GeneralMedicineConsultNote = DocumentTypeValueSetCode("34764-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GeriatricMedicineConsultNote = DocumentTypeValueSetCode("34776-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hematology_MedicalOncologyConsultNote = DocumentTypeValueSetCode("34779-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InfectiousDiseaseConsultNote = DocumentTypeValueSetCode("34781-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InterventionalRadiologyConsultNote = DocumentTypeValueSetCode("72555-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KinesiotherapyConsultNote = DocumentTypeValueSetCode("34783-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MentalHealthConsultNote = DocumentTypeValueSetCode("34785-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NephrologyConsultNote = DocumentTypeValueSetCode("34795-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeurologicalSurgeryConsultNote = DocumentTypeValueSetCode("34798-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeurologyConsultNote = DocumentTypeValueSetCode("34797-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NutritionAndDieteticsConsultNote = DocumentTypeValueSetCode("34800-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ObstetricsAndGynecologyConsultNote = DocumentTypeValueSetCode("34777-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OccupationalMedicineConsultNote = DocumentTypeValueSetCode("34803-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OccupationalTherapyConsultNote = DocumentTypeValueSetCode("34855-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OncologyConsultNote = DocumentTypeValueSetCode("34805-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OphthalmologyConsultNote = DocumentTypeValueSetCode("34807-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OptometryConsultNote = DocumentTypeValueSetCode("34810-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OralAndMaxillofacialSurgeryConsultNote = DocumentTypeValueSetCode("34812-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OrthopaedicSurgeryConsultNote = DocumentTypeValueSetCode("34814-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OtolaryngologyConsultNote = DocumentTypeValueSetCode("34816-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PharmacyConsultNote = DocumentTypeValueSetCode("34820-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PhysicalMedicineAndRehabilitationConsultNote = DocumentTypeValueSetCode("34822-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PhysicalTherapyConsultNote = DocumentTypeValueSetCode("34824-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PlasticSurgeryConsultNote = DocumentTypeValueSetCode("34826-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PodiatryConsultNote = DocumentTypeValueSetCode("34828-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PsychiatryConsultNote = DocumentTypeValueSetCode("34788-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PsychologyConsultNote = DocumentTypeValueSetCode("34791-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PulmonaryConsultNote = DocumentTypeValueSetCode("34103-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RadiationOncologyConsultNote = DocumentTypeValueSetCode("34831-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RadiologyConsultNote = DocumentTypeValueSetCode("73575-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RecreationalTherapyConsultNote = DocumentTypeValueSetCode("34833-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RespiratoryTherapyConsultNote = DocumentTypeValueSetCode("34837-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RheumatologyConsultNote = DocumentTypeValueSetCode("34839-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SocialWorkConsultNote = DocumentTypeValueSetCode("34841-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Speech_languagePathology_AudiologyConsultNote = DocumentTypeValueSetCode("34845-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SurgeryConsultNote = DocumentTypeValueSetCode("34847-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThoracicSurgeryConsultNote = DocumentTypeValueSetCode("34849-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UrologyConsultNote = DocumentTypeValueSetCode("34851-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VascularSurgeryConsultNote = DocumentTypeValueSetCode("34853-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    EmergencyDepartmentConsultNote = DocumentTypeValueSetCode("51846-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HospitalConsultNote = DocumentTypeValueSetCode("34104-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AdolescentMedicineHospitalConsultNote = DocumentTypeValueSetCode("68619-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AllergyAndImmunologyHospitalConsultNote = DocumentTypeValueSetCode("68633-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AudiologyHospitalConsultNote = DocumentTypeValueSetCode("68639-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CardiologyMedicalStudentHospitalConsultNote = DocumentTypeValueSetCode("68486-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChildAndAdolescentPsychiatryHospitalConsultNote = DocumentTypeValueSetCode(
        "68648-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClinicalBiochemicalGeneticsHospitalConsultNote = DocumentTypeValueSetCode("68651-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClinicalGeneticsHospitalConsultNote = DocumentTypeValueSetCode("68661-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CriticalCareMedicineMedicalStudentHospitalConsultNote = DocumentTypeValueSetCode(
        "64072-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    DermatologyHospitalConsultNote = DocumentTypeValueSetCode("68551-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Developmental_behavioralPediatricsHospitalConsultNote = DocumentTypeValueSetCode(
        "68670-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GeneralMedicineMedicalStudentHospitalConsultNote = DocumentTypeValueSetCode(
        "64056-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Multi_specialtyProgramHospitalConsultNote = DocumentTypeValueSetCode("68681-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeonatalPerinatalMedicineHospitalConsultNote = DocumentTypeValueSetCode("68685-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeurologicalSurgeryHospitalConsultNote = DocumentTypeValueSetCode("68694-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeurologyWithSpecialQualificationsInChildNeurologyHospitalConsultNote = (
        DocumentTypeValueSetCode("68705-3")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ObstetricsAndGynecologyHospitalConsultNote = DocumentTypeValueSetCode("68566-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OccupationalTherapyHospitalConsultNote = DocumentTypeValueSetCode("68570-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OphthalmologyHospitalConsultNote = DocumentTypeValueSetCode("68575-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PainMedicineHospitalConsultNote = DocumentTypeValueSetCode("68716-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PastoralCareHospitalConsultNote = DocumentTypeValueSetCode("68469-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricCardiologyHospitalConsultNote = DocumentTypeValueSetCode("68727-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricDermatologyHospitalConsultNote = DocumentTypeValueSetCode("68892-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricEndocrinologyHospitalConsultNote = DocumentTypeValueSetCode("68897-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricGastroenterologyHospitalConsultNote = DocumentTypeValueSetCode("68746-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricHematology_oncologyHospitalConsultNote = DocumentTypeValueSetCode(
        "68757-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricInfectiousDiseasesHospitalConsultNote = DocumentTypeValueSetCode("68765-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricNephrologyHospitalConsultNote = DocumentTypeValueSetCode("68869-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricOtolaryngologyHospitalConsultNote = DocumentTypeValueSetCode("68874-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricPulmonologyHospitalConsultNote = DocumentTypeValueSetCode("68787-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricRheumatologyHospitalConsultNote = DocumentTypeValueSetCode("68879-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricSurgeryHospitalConsultNote = DocumentTypeValueSetCode("68802-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricTransplantHepatologyHospitalConsultNote = DocumentTypeValueSetCode(
        "68864-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricUrologyHospitalConsultNote = DocumentTypeValueSetCode("68812-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricsHospitalConsultNote = DocumentTypeValueSetCode("68821-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PharmacyHospitalConsultNote = DocumentTypeValueSetCode("68586-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PhysicalTherapyHospitalConsultNote = DocumentTypeValueSetCode("68590-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PlasticSurgeryHospitalConsultNote = DocumentTypeValueSetCode("68597-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PrimaryCareHospitalConsultNote = DocumentTypeValueSetCode("68837-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PsychiatryHospitalConsultNote = DocumentTypeValueSetCode("34102-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PulmonaryMedicalStudentHospitalConsultNote = DocumentTypeValueSetCode("64080-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Speech_languagePathologyHospitalConsultNote = DocumentTypeValueSetCode("68846-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SurgeryMedicalStudentHospitalConsultNote = DocumentTypeValueSetCode("64068-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThoracicSurgeryMedicalStudentHospitalConsultNote = DocumentTypeValueSetCode(
        "64076-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TransplantSurgeryHospitalConsultNote = DocumentTypeValueSetCode("68852-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    IntensiveCareUnitConsultNote = DocumentTypeValueSetCode("34100-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LongTermCareFacilityConsultNote = DocumentTypeValueSetCode("51854-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OutpatientConsultNote = DocumentTypeValueSetCode("51845-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AnesthesiologyOutpatientConsultNote = DocumentTypeValueSetCode("34749-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GeneralMedicineOutpatientConsultNote = DocumentTypeValueSetCode("34101-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CounselingNote = DocumentTypeValueSetCode("47042-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MentalHealthCounselingNote = DocumentTypeValueSetCode("34864-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PharmacyCounselingNote = DocumentTypeValueSetCode("34869-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PsychiatryCounselingNote = DocumentTypeValueSetCode("34865-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PsychologyCounselingNote = DocumentTypeValueSetCode("34866-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SocialWorkCounselingNote = DocumentTypeValueSetCode("34872-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CurrentImagingProcedureDescriptionsDocument = DocumentTypeValueSetCode("55111-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CysticFibrosisActionPlan = DocumentTypeValueSetCode("74148-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    DeathCertificate = DocumentTypeValueSetCode("64297-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    DemographicInformation_HistoryOfOccupationDocument = DocumentTypeValueSetCode(
        "74208-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    DetailsDocument = DocumentTypeValueSetCode("51899-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    DiabetesTypeIActionPlan = DocumentTypeValueSetCode("74150-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    DiabetesTypeIIActionPlan = DocumentTypeValueSetCode("74151-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    DiagnosticInterventionalStudyReportInterventionalRadiology = (
        DocumentTypeValueSetCode("47048-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    DiagnosticStudyNote = DocumentTypeValueSetCode("70004-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AdolescentMedicineDiagnosticStudyNote = DocumentTypeValueSetCode("68611-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AllergyAndImmunologyDiagnosticStudyNote = DocumentTypeValueSetCode("68625-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AudiologyDiagnosticStudyNote = DocumentTypeValueSetCode("68635-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChildAndAdolescentPsychiatryDiagnosticStudyNote = DocumentTypeValueSetCode(
        "68641-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClinicalGeneticsDiagnosticStudyNote = DocumentTypeValueSetCode("68652-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Multi_specialtyProgramDiagnosticStudyNote = DocumentTypeValueSetCode("68673-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeurologicalSurgeryDiagnosticStudyNote = DocumentTypeValueSetCode("68687-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeurologyDiagnosticStudyNote = DocumentTypeValueSetCode("68556-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeurologyWithSpecialQualificationsInChildNeurologyDiagnosticStudyNote = (
        DocumentTypeValueSetCode("68696-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ObstetricsAndGynecologyDiagnosticStudyNote = DocumentTypeValueSetCode("68557-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OrthopaedicSurgeryDiagnosticStudyNote = DocumentTypeValueSetCode("68577-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PainMedicineDiagnosticStudyNote = DocumentTypeValueSetCode("68708-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricCardiologyDiagnosticStudyNote = DocumentTypeValueSetCode("68718-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricHematology_oncologyDiagnosticStudyNote = DocumentTypeValueSetCode(
        "68748-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricNephrologyDiagnosticStudyNote = DocumentTypeValueSetCode("68767-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricPulmonologyDiagnosticStudyNote = DocumentTypeValueSetCode("68778-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricSurgeryDiagnosticStudyNote = DocumentTypeValueSetCode("68794-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricTransplantHepatologyDiagnosticStudyNote = DocumentTypeValueSetCode(
        "68855-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricUrologyDiagnosticStudyNote = DocumentTypeValueSetCode("68804-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RadiologyDiagnosticStudyNote = DocumentTypeValueSetCode("68604-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AudiologyHospitalDiagnosticStudyNote = DocumentTypeValueSetCode("68640-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeurologyWithSpecialQualificationsInChildNeurologyHospitalDiagnosticStudyNote = (
        DocumentTypeValueSetCode("68706-1")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricPulmonologyHospitalDiagnosticStudyNote = DocumentTypeValueSetCode(
        "68788-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricsHospitalDiagnosticStudyNote = DocumentTypeValueSetCode("68822-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    DischargeInstructions = DocumentTypeValueSetCode("74213-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    EmergencyDepartmentDischargeInstructions = DocumentTypeValueSetCode("60280-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HospitalDischargeInstructions = DocumentTypeValueSetCode("8653-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    DischargeSummary = DocumentTypeValueSetCode("18842-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AdolescentMedicineDischargeSummary = DocumentTypeValueSetCode("68612-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AllergyAndImmunologyDischargeSummary = DocumentTypeValueSetCode("68626-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChildAndAdolescentPsychiatryDischargeSummary = DocumentTypeValueSetCode("68642-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClinicalGeneticsDischargeSummary = DocumentTypeValueSetCode("68653-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Developmental_behavioralPediatricsDischargeSummary = DocumentTypeValueSetCode(
        "68663-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Multi_specialtyProgramDischargeSummary = DocumentTypeValueSetCode("68674-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeurologicalSurgeryDischargeSummary = DocumentTypeValueSetCode("68688-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeurologyWithSpecialQualificationsInChildNeurologyDischargeSummary = (
        DocumentTypeValueSetCode("68697-2")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NurseDischargeSummary = DocumentTypeValueSetCode("34745-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ObstetricsAndGynecologyDischargeSummary = DocumentTypeValueSetCode("68558-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OphthalmologyDischargeSummary = DocumentTypeValueSetCode("68572-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OrthopaedicSurgeryDischargeSummary = DocumentTypeValueSetCode("68578-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PainMedicineDischargeSummary = DocumentTypeValueSetCode("68709-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricCardiologyDischargeSummary = DocumentTypeValueSetCode("68719-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricEndocrinologyDischargeSummary = DocumentTypeValueSetCode("68733-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricGastroenterologyDischargeSummary = DocumentTypeValueSetCode("68738-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricHematology_oncologyDischargeSummary = DocumentTypeValueSetCode("68749-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricNephrologyDischargeSummary = DocumentTypeValueSetCode("68768-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricOtolaryngologyDischargeSummary = DocumentTypeValueSetCode("68773-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricPulmonologyDischargeSummary = DocumentTypeValueSetCode("68779-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricSurgeryDischargeSummary = DocumentTypeValueSetCode("68795-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricTransplantHepatologyDischargeSummary = DocumentTypeValueSetCode("68856-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricUrologyDischargeSummary = DocumentTypeValueSetCode("68805-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricsDischargeSummary = DocumentTypeValueSetCode("68815-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PlasticSurgeryDischargeSummary = DocumentTypeValueSetCode("68591-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PrimaryCareDischargeSummary = DocumentTypeValueSetCode("68831-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PsychiatryDischargeSummary = DocumentTypeValueSetCode("59259-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Speech_languagePathologyDischargeSummary = DocumentTypeValueSetCode("68841-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    EmergencyDepartmentDischargeSummary = DocumentTypeValueSetCode("59258-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HospitalDischargeSummary = DocumentTypeValueSetCode("34105-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricsHospitalDischargeSummary = DocumentTypeValueSetCode("68823-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PhysicianHospitalDischargeSummary = DocumentTypeValueSetCode("34106-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    DocumentSummary = DocumentTypeValueSetCode("55112-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    EducationNote = DocumentTypeValueSetCode("34895-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    DiabetologyEducationNote = DocumentTypeValueSetCode("34897-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GeriatricMedicineEducationNote = DocumentTypeValueSetCode("67854-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NurseHospitalEducationNote = DocumentTypeValueSetCode("68477-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RecreationalTherapyHospitalEducationNote = DocumentTypeValueSetCode("68605-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OutpatientEducationNote = DocumentTypeValueSetCode("67855-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GeriatricMedicineOutpatientEducationNote = DocumentTypeValueSetCode("34902-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Patient_sHomeEducationNote = DocumentTypeValueSetCode("34107-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    EvaluationAndManagementOfAnticoagulationNote = DocumentTypeValueSetCode("34856-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    EvaluationAndManagementOfHyperlipidemia = DocumentTypeValueSetCode("34859-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    EvaluationAndManagementOfHypertension = DocumentTypeValueSetCode("34860-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    EvaluationAndManagementOfSmokingCessation = DocumentTypeValueSetCode("70005-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HospitalEvaluationAndManagementOfSmokingCessation = DocumentTypeValueSetCode(
        "64142-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    EvaluationAndManagementOfSubstanceAbuseNote = DocumentTypeValueSetCode("34857-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    EvaluationOfMentalAndPhysicalIncapacityCertificateDocument = (
        DocumentTypeValueSetCode("72267-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FunctionalStatusAssessmentNote = DocumentTypeValueSetCode("47420-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GroupCounselingNote = DocumentTypeValueSetCode("47043-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MentalHealthGroupCounselingNote = DocumentTypeValueSetCode("34787-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PsychiatryGroupCounselingNote = DocumentTypeValueSetCode("34790-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PsychologyGroupCounselingNote = DocumentTypeValueSetCode("34793-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SocialWorkGroupCounselingNote = DocumentTypeValueSetCode("34843-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HospitalGroupCounselingNote = DocumentTypeValueSetCode("34114-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HealthInsuranceCard = DocumentTypeValueSetCode("64290-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HealthInsurance_relatedForm = DocumentTypeValueSetCode("64291-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HealthQualityMeasureDocument = DocumentTypeValueSetCode("57024-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HealthRecordCoverSheet = DocumentTypeValueSetCode("64289-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HealthcareAssociatedInfectionReportDocument = DocumentTypeValueSetCode("51897-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HealthcareCommunicationDocument = DocumentTypeValueSetCode("56444-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartDiseaseActionPlan = DocumentTypeValueSetCode("74146-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HistoryAndPhysicalNote = DocumentTypeValueSetCode("34117-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AdolescentMedicineHistoryAndPhysicalNote = DocumentTypeValueSetCode("68614-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AdvancedHeartFailureAndTransplantCardiologyHistoryAndPhysicalNote = (
        DocumentTypeValueSetCode("68622-0")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AllergyAndImmunologyHistoryAndPhysicalNote = DocumentTypeValueSetCode("68628-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AudiologyHistoryAndPhysicalNote = DocumentTypeValueSetCode("68637-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChildAndAdolescentPsychiatryHistoryAndPhysicalNote = DocumentTypeValueSetCode(
        "68644-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClinicalGeneticsHistoryAndPhysicalNote = DocumentTypeValueSetCode("68655-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Developmental_behavioralPediatricsHistoryAndPhysicalNote = DocumentTypeValueSetCode(
        "68665-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Multi_specialtyProgramHistoryAndPhysicalNote = DocumentTypeValueSetCode("68676-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeonatalPerinatalMedicineHistoryAndPhysicalNote = DocumentTypeValueSetCode(
        "68683-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeurologicalSurgeryHistoryAndPhysicalNote = DocumentTypeValueSetCode("68690-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeurologyWithSpecialQualificationsInChildNeurologyHistoryAndPhysicalNote = (
        DocumentTypeValueSetCode("68699-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ObstetricsAndGynecologyHistoryAndPhysicalNote = DocumentTypeValueSetCode("68560-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OphthalmologyHistoryAndPhysicalNote = DocumentTypeValueSetCode("68573-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OrthopaedicSurgeryHistoryAndPhysicalNote = DocumentTypeValueSetCode("68580-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PainMedicineHistoryAndPhysicalNote = DocumentTypeValueSetCode("68711-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricCardiologyHistoryAndPhysicalNote = DocumentTypeValueSetCode("68721-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricDermatologyHistoryAndPhysicalNote = DocumentTypeValueSetCode("68731-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricEndocrinologyHistoryAndPhysicalNote = DocumentTypeValueSetCode("68735-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricGastroenterologyHistoryAndPhysicalNote = DocumentTypeValueSetCode(
        "68740-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricHematology_oncologyHistoryAndPhysicalNote = DocumentTypeValueSetCode(
        "68751-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricInfectiousDiseasesHistoryAndPhysicalNote = DocumentTypeValueSetCode(
        "68760-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricNephrologyHistoryAndPhysicalNote = DocumentTypeValueSetCode("68770-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricOtolaryngologyHistoryAndPhysicalNote = DocumentTypeValueSetCode("68775-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricPulmonologyHistoryAndPhysicalNote = DocumentTypeValueSetCode("68781-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricRheumatologyHistoryAndPhysicalNote = DocumentTypeValueSetCode("68791-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricSurgeryHistoryAndPhysicalNote = DocumentTypeValueSetCode("68797-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricTransplantHepatologyHistoryAndPhysicalNote = DocumentTypeValueSetCode(
        "68858-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricUrologyHistoryAndPhysicalNote = DocumentTypeValueSetCode("68807-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricsHistoryAndPhysicalNote = DocumentTypeValueSetCode("68817-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PhysicianHistoryAndPhysicalNote = DocumentTypeValueSetCode("28626-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PlasticSurgeryHistoryAndPhysicalNote = DocumentTypeValueSetCode("68592-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PrimaryCareHistoryAndPhysicalNote = DocumentTypeValueSetCode("68833-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PsychiatryHistoryAndPhysicalNote = DocumentTypeValueSetCode("68599-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Speech_languagePathologyHistoryAndPhysicalNote = DocumentTypeValueSetCode("68843-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SurgeryHistoryAndPhysicalNote = DocumentTypeValueSetCode("34774-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TransplantSurgeryHistoryAndPhysicalNote = DocumentTypeValueSetCode("68849-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Provider_unspecifed_HistoryAndPhysicalNote = DocumentTypeValueSetCode("11492-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MedicalStudentHospitalHistoryAndPhysicalNote = DocumentTypeValueSetCode("34115-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricsHospitalHistoryAndPhysicalNote = DocumentTypeValueSetCode("68825-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NursingFacilityHistoryAndPhysicalNote = DocumentTypeValueSetCode("67856-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PhysicianNursingFacilityHistoryAndPhysicalNote = DocumentTypeValueSetCode("34116-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HIVSummaryRegistryReportDocument = DocumentTypeValueSetCode("74264-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InflammatoryBowelDiseaseActionPlan = DocumentTypeValueSetCode("74149-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Provider_unspecifiedInitialAssessment = DocumentTypeValueSetCode("28636-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChiropracticMedicineInitialAssessmentNote = DocumentTypeValueSetCode("28581-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hematology_MedicalOncologyInitialAssessmentNote = DocumentTypeValueSetCode(
        "68553-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Speech_languagePathologyInitialAssessmentNote = DocumentTypeValueSetCode("18740-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HospitalInitialAssessmentNote = DocumentTypeValueSetCode("47044-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CaseManagerHospitalInitialAssessmentNote = DocumentTypeValueSetCode("64065-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RespiratoryTherapyHospitalInitialAssessmentNote = DocumentTypeValueSetCode(
        "68470-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NursingFacilityInitialAssessmentNote = DocumentTypeValueSetCode("34119-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OutpatientInitialAssessmentNote = DocumentTypeValueSetCode("34120-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Patient_sHomeInitialAssessmentNote = DocumentTypeValueSetCode("34118-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InjuryEventSummaryDocument = DocumentTypeValueSetCode("74209-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InterRAIAcuteCare_AC_HospitalDocument = DocumentTypeValueSetCode("74188-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InterRAICommunityHealthAssessment_CHA_Document = DocumentTypeValueSetCode("74194-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InterRAICommunityHealthAssessment_AssistedLivingSupplement_CHA_AL_Document = (
        DocumentTypeValueSetCode("74191-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InterRAICommunityHealthAssessment_DeafblindSupplement_CHA_Db_Document = (
        DocumentTypeValueSetCode("74190-0")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InterRAICommunityHealthAssessment_FunctionalSupplement_CHA_FS_Document = (
        DocumentTypeValueSetCode("74193-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InterRAICommunityHealthAssessment_MentalHealthSupplement_CHA_MH_Document = (
        DocumentTypeValueSetCode("74192-6")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InterRAIContactAssessment_CA_Document = DocumentTypeValueSetCode("74197-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InterRAIEmergencyScreenerForPsychiatry_ESP_Document = DocumentTypeValueSetCode(
        "74187-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InterRAIHomeCare_HC_Document = DocumentTypeValueSetCode("74196-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InterRAILongTermCareFacility_LTCF_Document = DocumentTypeValueSetCode("74195-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InterRAIPalliativeCare_PC_Document = DocumentTypeValueSetCode("74189-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InterventionalProcedureNote = DocumentTypeValueSetCode("34121-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CardiologyInterventionalProcedureNote = DocumentTypeValueSetCode("34896-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GastroenterologyInterventionalProcedureNote = DocumentTypeValueSetCode("34899-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KeyImagesDocumentRadiology = DocumentTypeValueSetCode("55113-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LaborAndDeliveryAdmissionHistoryAndPhysicalNote = DocumentTypeValueSetCode(
        "57056-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LaborAndDeliverySummaryNote = DocumentTypeValueSetCode("57057-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LegalDocument = DocumentTypeValueSetCode("64299-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Letter = DocumentTypeValueSetCode("51852-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeonatalPerinatalMedicineLetter = DocumentTypeValueSetCode("68684-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricNephrologyLetter = DocumentTypeValueSetCode("68866-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PlasticSurgeryLetter = DocumentTypeValueSetCode("68593-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HospitalLetter = DocumentTypeValueSetCode("68609-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AdolescentMedicineHospitalLetter = DocumentTypeValueSetCode("68620-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AdvancedHeartFailureAndTransplantCardiologyHospitalLetter = (
        DocumentTypeValueSetCode("68624-6")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AllergyAndImmunologyHospitalLetter = DocumentTypeValueSetCode("68634-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChildAndAdolescentPsychiatryHospitalLetter = DocumentTypeValueSetCode("68649-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClinicalGeneticsHospitalLetter = DocumentTypeValueSetCode("68662-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Developmental_behavioralPediatricsHospitalLetter = DocumentTypeValueSetCode(
        "68671-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hematology_MedicalOncologyHospitalLetter = DocumentTypeValueSetCode("68555-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Multi_specialtyProgramHospitalLetter = DocumentTypeValueSetCode("68682-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeonatalPerinatalMedicineHospitalLetter = DocumentTypeValueSetCode("68686-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeurologicalSurgeryHospitalLetter = DocumentTypeValueSetCode("68695-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeurologyWithSpecialQualificationsInChildNeurologyHospitalLetter = (
        DocumentTypeValueSetCode("68707-9")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ObstetricsAndGynecologyHospitalLetter = DocumentTypeValueSetCode("68567-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OccupationalTherapyHospitalLetter = DocumentTypeValueSetCode("68571-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OphthalmologyHospitalLetter = DocumentTypeValueSetCode("68576-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OrthopaedicSurgeryHospitalLetter = DocumentTypeValueSetCode("68585-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PainMedicineHospitalLetter = DocumentTypeValueSetCode("68717-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricCardiologyHospitalLetter = DocumentTypeValueSetCode("68728-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricDermatologyHospitalLetter = DocumentTypeValueSetCode("68893-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricEndocrinologyHospitalLetter = DocumentTypeValueSetCode("68898-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricGastroenterologyHospitalLetter = DocumentTypeValueSetCode("68747-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricHematology_oncologyHospitalLetter = DocumentTypeValueSetCode("68758-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricInfectiousDiseasesHospitalLetter = DocumentTypeValueSetCode("68766-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricNephrologyHospitalLetter = DocumentTypeValueSetCode("68870-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricOtolaryngologyHospitalLetter = DocumentTypeValueSetCode("68875-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricPulmonologyHospitalLetter = DocumentTypeValueSetCode("68789-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricRheumatologyHospitalLetter = DocumentTypeValueSetCode("68880-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricSurgeryHospitalLetter = DocumentTypeValueSetCode("68803-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricTransplantHepatologyHospitalLetter = DocumentTypeValueSetCode("68865-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricUrologyHospitalLetter = DocumentTypeValueSetCode("68813-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricsHospitalLetter = DocumentTypeValueSetCode("68826-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PlasticSurgeryHospitalLetter = DocumentTypeValueSetCode("68598-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PrimaryCareHospitalLetter = DocumentTypeValueSetCode("68838-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Speech_languagePathologyHospitalLetter = DocumentTypeValueSetCode("68847-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TransplantSurgeryHospitalLetter = DocumentTypeValueSetCode("68853-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MaternalDischargeSummaryNote = DocumentTypeValueSetCode("57058-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MedicalHistoryScreeningForm = DocumentTypeValueSetCode("64285-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MedicationDispensed_briefDocument = DocumentTypeValueSetCode("60590-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MedicationDispensed_extendedDocument = DocumentTypeValueSetCode("60593-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MedicationManagementNote = DocumentTypeValueSetCode("70006-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PharmacyHospitalMedicationManagementNote = DocumentTypeValueSetCode("68587-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MedicationPharmaceuticalAdvice_briefDocument = DocumentTypeValueSetCode("61357-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MedicationPharmaceuticalAdvice_extendedDocument = DocumentTypeValueSetCode(
        "61356-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MedicationSummaryDocument = DocumentTypeValueSetCode("56445-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MultipleSclerosisActionPlan = DocumentTypeValueSetCode("74145-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MuscularDystrophyActionPlan = DocumentTypeValueSetCode("74147-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeonatalCareReport = DocumentTypeValueSetCode("59268-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Note = DocumentTypeValueSetCode("34109-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AdolescentMedicineNote = DocumentTypeValueSetCode("68615-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AdvancedHeartFailureAndTransplantCardiologyNote = DocumentTypeValueSetCode(
        "68621-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AllergyAndImmunologyNote = DocumentTypeValueSetCode("68629-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AnesthesiologyNote = DocumentTypeValueSetCode("34750-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AudiologyNote = DocumentTypeValueSetCode("68636-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CardiologyNote = DocumentTypeValueSetCode("34752-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChildAndAdolescentPsychiatryNote = DocumentTypeValueSetCode("68645-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClinicalBiochemicalGeneticsNote = DocumentTypeValueSetCode("68650-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClinicalGeneticsNote = DocumentTypeValueSetCode("68656-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CriticalCareMedicineNote = DocumentTypeValueSetCode("34754-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    DentistryNote = DocumentTypeValueSetCode("28618-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    DermatologyNote = DocumentTypeValueSetCode("34759-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Developmental_behavioralPediatricsNote = DocumentTypeValueSetCode("68666-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    DiabetologyNote = DocumentTypeValueSetCode("34861-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    EmergencyMedicineNote = DocumentTypeValueSetCode("34878-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    EndocrinologyNote = DocumentTypeValueSetCode("34898-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GastroenterologyNote = DocumentTypeValueSetCode("34762-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GeneralMedicineNote = DocumentTypeValueSetCode("34765-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GeneralMedicineMedicalStudentNote = DocumentTypeValueSetCode("34767-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GeneralMedicineNurseNote = DocumentTypeValueSetCode("34768-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GeneralMedicinePhysicianAttendingNote = DocumentTypeValueSetCode("34769-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hematology_MedicalOncologyNote = DocumentTypeValueSetCode("34780-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InfectiousDiseaseNote = DocumentTypeValueSetCode("34782-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InterdisciplinaryNote = DocumentTypeValueSetCode("34794-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KinesiotherapyNote = DocumentTypeValueSetCode("34784-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MentalHealthNote = DocumentTypeValueSetCode("34786-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Multi_specialtyProgramNote = DocumentTypeValueSetCode("68677-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NephrologyNote = DocumentTypeValueSetCode("34796-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeurologicalSurgeryNote = DocumentTypeValueSetCode("34799-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeurologyNote = DocumentTypeValueSetCode("34905-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeurologyWithSpecialQualificationsInChildNeurologyNote = DocumentTypeValueSetCode(
        "68700-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NurseNote = DocumentTypeValueSetCode("34746-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NutritionAndDieteticsNote = DocumentTypeValueSetCode("34801-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ObstetricsAndGynecologyNote = DocumentTypeValueSetCode("34778-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OccupationalMedicineNote = DocumentTypeValueSetCode("34802-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OccupationalTherapyNote = DocumentTypeValueSetCode("28578-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OncologyNote = DocumentTypeValueSetCode("34806-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OphthalmologyNote = DocumentTypeValueSetCode("34808-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OptometryNote = DocumentTypeValueSetCode("34811-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OralAndMaxillofacialSurgeryNote = DocumentTypeValueSetCode("34813-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OrthopaedicSurgeryNote = DocumentTypeValueSetCode("34815-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OtolaryngologyNote = DocumentTypeValueSetCode("34817-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PainMedicineNote = DocumentTypeValueSetCode("34858-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PastoralCareNote = DocumentTypeValueSetCode("34906-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PatientNote = DocumentTypeValueSetCode("51855-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricCardiologyNote = DocumentTypeValueSetCode("68722-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricDermatologyNote = DocumentTypeValueSetCode("68889-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricEndocrinologyNote = DocumentTypeValueSetCode("68894-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricGastroenterologyNote = DocumentTypeValueSetCode("68741-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricHematology_oncologyNote = DocumentTypeValueSetCode("68752-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricInfectiousDiseasesNote = DocumentTypeValueSetCode("68761-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricNephrologyNote = DocumentTypeValueSetCode("68867-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricOtolaryngologyNote = DocumentTypeValueSetCode("68871-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricPulmonologyNote = DocumentTypeValueSetCode("68782-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricRehabilitationMedicineNote = DocumentTypeValueSetCode("68854-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricRheumatologyNote = DocumentTypeValueSetCode("68876-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricSurgeryNote = DocumentTypeValueSetCode("68881-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricTransplantHepatologyNote = DocumentTypeValueSetCode("68859-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricUrologyNote = DocumentTypeValueSetCode("68882-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricsNote = DocumentTypeValueSetCode("68818-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PharmacyNote = DocumentTypeValueSetCode("34821-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PhysicalMedicineAndRehabilitationNote = DocumentTypeValueSetCode("34823-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PhysicalTherapyNote = DocumentTypeValueSetCode("28579-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PlasticSurgeryNote = DocumentTypeValueSetCode("34827-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PodiatryNote = DocumentTypeValueSetCode("34829-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PrimaryCareNote = DocumentTypeValueSetCode("68834-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PsychiatryNote = DocumentTypeValueSetCode("28628-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PsychologyNote = DocumentTypeValueSetCode("34792-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PulmonaryNote = DocumentTypeValueSetCode("34830-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RadiationOncologyNote = DocumentTypeValueSetCode("34832-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RecreationalTherapyNote = DocumentTypeValueSetCode("34834-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ResearchNote = DocumentTypeValueSetCode("68839-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RespiratoryTherapyNote = DocumentTypeValueSetCode("34838-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RheumatologyNote = DocumentTypeValueSetCode("34840-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SocialWorkNote = DocumentTypeValueSetCode("28653-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Speech_languagePathologyNote = DocumentTypeValueSetCode("28571-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Speech_languagePathology_AudiologyNote = DocumentTypeValueSetCode("34846-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SurgeryNote = DocumentTypeValueSetCode("34848-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SurgeryPhysicianAttendingNote = DocumentTypeValueSetCode("34773-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TransplantSurgeryNote = DocumentTypeValueSetCode("68848-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UrologyNote = DocumentTypeValueSetCode("34852-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    EmergencyDepartmentNote = DocumentTypeValueSetCode("34111-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NurseEmergencyDepartmentNote = DocumentTypeValueSetCode("57053-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HospitalNote = DocumentTypeValueSetCode("34112-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CriticalCareMedicinePhysicianAttendingHospitalNote = DocumentTypeValueSetCode(
        "64069-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricsHospitalNote = DocumentTypeValueSetCode("68827-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PulmonaryPhysicianAttendingHospitalNote = DocumentTypeValueSetCode("64077-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThoracicSurgeryPhysicianAttendingHospitalNote = DocumentTypeValueSetCode("64073-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NursingFacilityNote = DocumentTypeValueSetCode("34113-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OutpatientNote = DocumentTypeValueSetCode("34108-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CardiologyOutpatientNote = DocumentTypeValueSetCode("34753-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    DiabetologyOutpatientNote = DocumentTypeValueSetCode("34110-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GeneralMedicineOutpatientNote = DocumentTypeValueSetCode("34766-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PsychiatryOutpatientNote = DocumentTypeValueSetCode("68601-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThoracicSurgeryOutpatientNote = DocumentTypeValueSetCode("34850-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VascularSurgeryOutpatientNote = DocumentTypeValueSetCode("34854-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GeriatricMedicineSkilledNursingFacilityNote = DocumentTypeValueSetCode("68672-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TelephoneEncounterNote = DocumentTypeValueSetCode("34748-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NurseTelephoneEncounterNote = DocumentTypeValueSetCode("34139-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SocialWorkTelephoneEncounterNote = DocumentTypeValueSetCode("34844-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OccupationalSummaryNote = DocumentTypeValueSetCode("74166-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OncologyTreatmentPlanAndSummaryDocument = DocumentTypeValueSetCode("74156-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OrganDonationConsent = DocumentTypeValueSetCode("64300-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PatientSummaryDocument = DocumentTypeValueSetCode("60591-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PatientSummary_unexpectedContactDocument = DocumentTypeValueSetCode("60592-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PatientTransportationRequestDocument = DocumentTypeValueSetCode("57834-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PaymentSourcesDocument = DocumentTypeValueSetCode("48768-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PersonalHealthMonitoringReportDocument = DocumentTypeValueSetCode("53576-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PersonalHealthMonitoringReportAutomated = DocumentTypeValueSetCode("64296-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PhotographicImageUnspecifiedBodyRegionDocument = DocumentTypeValueSetCode("72170-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PlanOfCareNote = DocumentTypeValueSetCode("56447-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NursePlanOfCareNote = DocumentTypeValueSetCode("64295-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PopulationSummaryNote = DocumentTypeValueSetCode("51900-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PostoperativeEvaluationAndManagementNote = DocumentTypeValueSetCode("67860-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OphthalmologyPostoperativeEvaluationAndManagementNote = DocumentTypeValueSetCode(
        "67861-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SurgeryPostoperativeEvaluationAndManagementNote = DocumentTypeValueSetCode(
        "34875-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SurgeryNursePostoperativeEvaluationAndManagementNote = DocumentTypeValueSetCode(
        "34880-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HospitalPostoperativeEvaluationAndManagementNote = DocumentTypeValueSetCode(
        "68610-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SurgeryHospitalPostoperativeEvaluationAndManagementNote = DocumentTypeValueSetCode(
        "68606-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OphthalmologyOutpatientPostoperativeEvaluationAndManagementNote = (
        DocumentTypeValueSetCode("34867-2")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PowerOfAttorney = DocumentTypeValueSetCode("64298-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PrehospitalSummaryDocument = DocumentTypeValueSetCode("74207-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PreoperativeEvaluationAndManagementNote = DocumentTypeValueSetCode("67862-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AdolescentMedicinePreoperativeEvaluationAndManagementNote = (
        DocumentTypeValueSetCode("68616-2")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AdvancedHeartFailureAndTransplantCardiologyPreoperativeEvaluationAndManagementNote = DocumentTypeValueSetCode(
        "68623-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AnesthesiologyPreoperativeEvaluationAndManagementNote = DocumentTypeValueSetCode(
        "34751-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AudiologyPreoperativeEvaluationAndManagementNote = DocumentTypeValueSetCode(
        "68638-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClinicalGeneticsPreoperativeEvaluationAndManagementNote = DocumentTypeValueSetCode(
        "68657-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    DermatologyPreoperativeEvaluationAndManagementNote = DocumentTypeValueSetCode(
        "68550-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Multi_specialtyProgramPreoperativeEvaluationAndManagementNote = (
        DocumentTypeValueSetCode("68678-2")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeurologicalSurgeryPreoperativeEvaluationAndManagementNote = (
        DocumentTypeValueSetCode("68691-5")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeurologyWithSpecialQualificationsInChildNeurologyPreoperativeEvaluationAndManagementNote = DocumentTypeValueSetCode(
        "68701-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NursePreoperativeEvaluationAndManagementNote = DocumentTypeValueSetCode("34747-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ObstetricsAndGynecologyPreoperativeEvaluationAndManagementNote = (
        DocumentTypeValueSetCode("68562-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OphthalmologyPreoperativeEvaluationAndManagementNote = DocumentTypeValueSetCode(
        "34809-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OrthopaedicSurgeryPreoperativeEvaluationAndManagementNote = (
        DocumentTypeValueSetCode("68581-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PainMedicinePreoperativeEvaluationAndManagementNote = DocumentTypeValueSetCode(
        "68713-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricCardiologyPreoperativeEvaluationAndManagementNote = (
        DocumentTypeValueSetCode("68723-6")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricDermatologyPreoperativeEvaluationAndManagementNote = (
        DocumentTypeValueSetCode("68732-7")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricEndocrinologyPreoperativeEvaluationAndManagementNote = (
        DocumentTypeValueSetCode("68736-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricGastroenterologyPreoperativeEvaluationAndManagementNote = (
        DocumentTypeValueSetCode("68742-6")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricHematology_oncologyPreoperativeEvaluationAndManagementNote = (
        DocumentTypeValueSetCode("68753-3")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricInfectiousDiseasesPreoperativeEvaluationAndManagementNote = (
        DocumentTypeValueSetCode("68762-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricNephrologyPreoperativeEvaluationAndManagementNote = (
        DocumentTypeValueSetCode("68771-5")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricOtolaryngologyPreoperativeEvaluationAndManagementNote = (
        DocumentTypeValueSetCode("68776-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricPulmonologyPreoperativeEvaluationAndManagementNote = (
        DocumentTypeValueSetCode("68783-0")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricRheumatologyPreoperativeEvaluationAndManagementNote = (
        DocumentTypeValueSetCode("68792-1")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricSurgeryPreoperativeEvaluationAndManagementNote = DocumentTypeValueSetCode(
        "68798-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricTransplantHepatologyPreoperativeEvaluationAndManagementNote = (
        DocumentTypeValueSetCode("68860-6")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricUrologyPreoperativeEvaluationAndManagementNote = DocumentTypeValueSetCode(
        "68808-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricsPreoperativeEvaluationAndManagementNote = DocumentTypeValueSetCode(
        "68819-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PlasticSurgeryPreoperativeEvaluationAndManagementNote = DocumentTypeValueSetCode(
        "68594-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PrimaryCarePreoperativeEvaluationAndManagementNote = DocumentTypeValueSetCode(
        "68835-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Speech_languagePathologyPreoperativeEvaluationAndManagementNote = (
        DocumentTypeValueSetCode("68844-0")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SurgeryPreoperativeEvaluationAndManagementNote = DocumentTypeValueSetCode("34876-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SurgeryNursePreoperativeEvaluationAndManagementNote = DocumentTypeValueSetCode(
        "34881-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TransplantSurgeryPreoperativeEvaluationAndManagementNote = DocumentTypeValueSetCode(
        "68850-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AnesthesiologyHospitalPreoperativeEvaluationAndManagementNote = (
        DocumentTypeValueSetCode("34123-0")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricsHospitalPreoperativeEvaluationAndManagementNote = (
        DocumentTypeValueSetCode("68828-3")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PrescriptionForDiagnosticOrSpecialistCareDocument = DocumentTypeValueSetCode(
        "57832-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PrescriptionForEyewear = DocumentTypeValueSetCode("64288-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PrescriptionForMedicalEquipmentOrProductDocument = DocumentTypeValueSetCode(
        "57829-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PrescriptionForMedicationDocument = DocumentTypeValueSetCode("57833-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PrescriptionForRehabilitationDocument = DocumentTypeValueSetCode("57831-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PrescriptionListDocument = DocumentTypeValueSetCode("57828-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PrescriptionRequestPharmacyDocumentFromPharmacist = DocumentTypeValueSetCode(
        "73709-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PriorImagingProcedureDescriptionsDocument = DocumentTypeValueSetCode("55114-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PrivacyPolicyOrganizationDocument = DocumentTypeValueSetCode("57017-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PrivacyPolicyAcknowledgmentDocument = DocumentTypeValueSetCode("57016-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ProcedureConsent = DocumentTypeValueSetCode("64293-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AllergyAndImmunologyProcedureNote = DocumentTypeValueSetCode("68630-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClinicalGeneticsProcedureNote = DocumentTypeValueSetCode("68658-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Developmental_behavioralPediatricsProcedureNote = DocumentTypeValueSetCode(
        "68667-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeurologicalSurgeryProcedureNote = DocumentTypeValueSetCode("68692-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeurologyWithSpecialQualificationsInChildNeurologyProcedureNote = (
        DocumentTypeValueSetCode("68702-0")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ObstetricsAndGynecologyProcedureNote = DocumentTypeValueSetCode("68563-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PainMedicineProcedureNote = DocumentTypeValueSetCode("68714-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricCardiologyProcedureNote = DocumentTypeValueSetCode("68724-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricDermatologyProcedureNote = DocumentTypeValueSetCode("68890-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricEndocrinologyProcedureNote = DocumentTypeValueSetCode("68895-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricGastroenterologyProcedureNote = DocumentTypeValueSetCode("68743-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricHematology_oncologyProcedureNote = DocumentTypeValueSetCode("68754-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricNephrologyProcedureNote = DocumentTypeValueSetCode("68868-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricOtolaryngologyProcedureNote = DocumentTypeValueSetCode("68872-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricPulmonologyProcedureNote = DocumentTypeValueSetCode("68784-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricRheumatologyProcedureNote = DocumentTypeValueSetCode("68877-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricSurgeryProcedureNote = DocumentTypeValueSetCode("68799-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricTransplantHepatologyProcedureNote = DocumentTypeValueSetCode("68861-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricUrologyProcedureNote = DocumentTypeValueSetCode("68809-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricsProcedureNote = DocumentTypeValueSetCode("68820-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PrimaryCareProcedureNote = DocumentTypeValueSetCode("68836-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TransplantSurgeryProcedureNote = DocumentTypeValueSetCode("68851-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricCriticalCareMedicineHospitalProcedureNote = DocumentTypeValueSetCode(
        "68729-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricsHospitalProcedureNote = DocumentTypeValueSetCode("68829-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ProgressLetter = DocumentTypeValueSetCode("68607-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Provider_unspecifiedProgressNote = DocumentTypeValueSetCode("11506-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AdolescentMedicineProgressNote = DocumentTypeValueSetCode("68617-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AllergyAndImmunologyProgressNote = DocumentTypeValueSetCode("68631-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChildAndAdolescentPsychiatryProgressNote = DocumentTypeValueSetCode("68646-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChiropracticMedicineProgressNote = DocumentTypeValueSetCode("28580-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClinicalGeneticsProgressNote = DocumentTypeValueSetCode("68659-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    DentistryProgressNote = DocumentTypeValueSetCode("28617-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Developmental_behavioralPediatricsProgressNote = DocumentTypeValueSetCode("68668-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GeneralMedicineProgressNote = DocumentTypeValueSetCode("34900-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hematology_MedicalOncologyProgressNote = DocumentTypeValueSetCode("68554-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InterventionalRadiologyProgressNote = DocumentTypeValueSetCode("72556-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MentalHealthProgressNote = DocumentTypeValueSetCode("34904-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Multi_specialtyProgramProgressNote = DocumentTypeValueSetCode("68679-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeurologicalSurgeryProgressNote = DocumentTypeValueSetCode("68693-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeurologyWithSpecialQualificationsInChildNeurologyProgressNote = (
        DocumentTypeValueSetCode("68703-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NurseProgressNote = DocumentTypeValueSetCode("28623-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NursePractitionerProgressNote = DocumentTypeValueSetCode("28575-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ObstetricsAndGynecologyProgressNote = DocumentTypeValueSetCode("68564-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OccupationalTherapyProgressNote = DocumentTypeValueSetCode("11507-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OphthalmologyProgressNote = DocumentTypeValueSetCode("68574-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OrthopaedicSurgeryProgressNote = DocumentTypeValueSetCode("68582-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricCardiologyProgressNote = DocumentTypeValueSetCode("68725-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricDermatologyProgressNote = DocumentTypeValueSetCode("68891-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricEndocrinologyProgressNote = DocumentTypeValueSetCode("68896-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricGastroenterologyProgressNote = DocumentTypeValueSetCode("68744-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricHematology_oncologyProgressNote = DocumentTypeValueSetCode("68755-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricInfectiousDiseasesProgressNote = DocumentTypeValueSetCode("68763-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricOtolaryngologyProgressNote = DocumentTypeValueSetCode("68873-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricPulmonologyProgressNote = DocumentTypeValueSetCode("68785-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricRheumatologyProgressNote = DocumentTypeValueSetCode("68878-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricSurgeryProgressNote = DocumentTypeValueSetCode("68800-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricTransplantHepatologyProgressNote = DocumentTypeValueSetCode("68862-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricUrologyProgressNote = DocumentTypeValueSetCode("68810-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PhysicalTherapyProgressNote = DocumentTypeValueSetCode("11508-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PhysicianAttendingProgressNote = DocumentTypeValueSetCode("18733-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PhysicianConsultingProgressNote = DocumentTypeValueSetCode("28569-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PlasticSurgeryProgressNote = DocumentTypeValueSetCode("68595-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PodiatryProgressNote = DocumentTypeValueSetCode("11509-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PsychiatryProgressNote = DocumentTypeValueSetCode("28627-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PsychologyProgressNote = DocumentTypeValueSetCode("11510-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ResearchProgressNote = DocumentTypeValueSetCode("68840-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SocialWorkProgressNote = DocumentTypeValueSetCode("28656-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Speech_languagePathologyProgressNote = DocumentTypeValueSetCode("11512-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Provider_unspecifiedEDProgressNote = DocumentTypeValueSetCode("15507-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HospitalProgressNote = DocumentTypeValueSetCode("34130-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CardiologyHospitalProgressNote = DocumentTypeValueSetCode("68472-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CardiologyMedicalStudentHospitalProgressNote = DocumentTypeValueSetCode("68485-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CardiologyPhysicianAttendingHospitalProgressNote = DocumentTypeValueSetCode(
        "68484-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CriticalCareMedicineHospitalProgressNote = DocumentTypeValueSetCode("64059-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CriticalCareMedicineMedicalStudentHospitalProgressNote = DocumentTypeValueSetCode(
        "64071-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CriticalCareMedicinePhysicianAttendingHospitalProgressNote = (
        DocumentTypeValueSetCode("68473-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GeneralMedicineMedicalStudentHospitalProgressNote = DocumentTypeValueSetCode(
        "64055-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GeneralMedicinePhysicianAttendingHospitalProgressNote = DocumentTypeValueSetCode(
        "68475-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricsHospitalProgressNote = DocumentTypeValueSetCode("68830-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PulmonaryHospitalProgressNote = DocumentTypeValueSetCode("64063-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PulmonaryMedicalStudentHospitalProgressNote = DocumentTypeValueSetCode("64079-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PulmonaryPhysicianAttendingHospitalProgressNote = DocumentTypeValueSetCode(
        "68478-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RespiratoryTherapyHospitalProgressNote = DocumentTypeValueSetCode("68479-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SurgeryHospitalProgressNote = DocumentTypeValueSetCode("64057-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SurgeryMedicalStudentHospitalProgressNote = DocumentTypeValueSetCode("64067-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SurgeryPhysicianAttendingHospitalProgressNote = DocumentTypeValueSetCode("68480-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThoracicSurgeryHospitalProgressNote = DocumentTypeValueSetCode("64061-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThoracicSurgeryMedicalStudentHospitalProgressNote = DocumentTypeValueSetCode(
        "64075-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThoracicSurgeryPhysicianAttendingHospitalProgressNote = DocumentTypeValueSetCode(
        "68481-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TransplantSurgeryHospitalProgressNote = DocumentTypeValueSetCode("70238-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    IntensiveCareUnitProgressNote = DocumentTypeValueSetCode("34126-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OutpatientProgressNote = DocumentTypeValueSetCode("34131-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CardiologyOutpatientProgressNote = DocumentTypeValueSetCode("34124-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    DentistryOutpatientProgressNote = DocumentTypeValueSetCode("34128-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    DentistryHygienistOutpatientProgressNote = DocumentTypeValueSetCode("34127-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GeneralMedicineOutpatientProgressNote = DocumentTypeValueSetCode("34901-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PharmacyOutpatientProgressNote = DocumentTypeValueSetCode("34132-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Patient_sHomeProgressNote = DocumentTypeValueSetCode("34129-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CaseManagerPatient_sHomeProgressNote = DocumentTypeValueSetCode("34125-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    QuestionnaireFormDefinitionSectionDocument = DocumentTypeValueSetCode("74468-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    QuestionnaireResponseSectionDocument = DocumentTypeValueSetCode("74465-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RadiationExposureAndProtectionInformation_Description_DocumentDiagnosticImaging = (
        DocumentTypeValueSetCode("73569-6")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ReadinessForDutyLetter = DocumentTypeValueSetCode("64294-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ReadinessForDutyAssessment = DocumentTypeValueSetCode("64284-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ReferralNote = DocumentTypeValueSetCode("57133-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CardiologyReferralNote = DocumentTypeValueSetCode("57170-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CriticalCareMedicineReferralNote = DocumentTypeValueSetCode("57178-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    DentistryReferralNote = DocumentTypeValueSetCode("57134-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    DermatologyReferralNote = DocumentTypeValueSetCode("57135-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    DiabetologyReferralNote = DocumentTypeValueSetCode("57136-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    EndocrinologyReferralNote = DocumentTypeValueSetCode("57137-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ReferralNoteForensicMedicine = DocumentTypeValueSetCode("69438-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GastroenterologyReferralNote = DocumentTypeValueSetCode("57138-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GeneralMedicineReferralNote = DocumentTypeValueSetCode("57139-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GeriatricMedicineReferralNote = DocumentTypeValueSetCode("57171-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hematology_MedicalOncologyReferralNote = DocumentTypeValueSetCode("57172-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InfectiousDiseaseReferralNote = DocumentTypeValueSetCode("57141-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KinesiotherapyReferralNote = DocumentTypeValueSetCode("57142-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MentalHealthReferralNote = DocumentTypeValueSetCode("57143-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NephrologyReferralNote = DocumentTypeValueSetCode("57144-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeurologicalSurgeryReferralNote = DocumentTypeValueSetCode("57146-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeurologyReferralNote = DocumentTypeValueSetCode("57145-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NutritionAndDieteticsReferralNote = DocumentTypeValueSetCode("57173-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ObstetricsAndGynecologyReferralNote = DocumentTypeValueSetCode("57179-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OccupationalMedicineReferralNote = DocumentTypeValueSetCode("57147-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OccupationalTherapyReferralNote = DocumentTypeValueSetCode("57148-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OncologyReferralNote = DocumentTypeValueSetCode("57149-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OphthalmologyReferralNote = DocumentTypeValueSetCode("57150-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OptometryReferralNote = DocumentTypeValueSetCode("57151-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OralAndMaxillofacialSurgeryReferralNote = DocumentTypeValueSetCode("57174-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OrthopaedicSurgeryReferralNote = DocumentTypeValueSetCode("57175-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OtolaryngologyReferralNote = DocumentTypeValueSetCode("57176-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PharmacyReferralNote = DocumentTypeValueSetCode("57152-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PhysicalMedicineAndRehabilitationReferralNote = DocumentTypeValueSetCode("57153-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PhysicalTherapyReferralNote = DocumentTypeValueSetCode("57154-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PlasticSurgeryReferralNote = DocumentTypeValueSetCode("57155-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PodiatryReferralNote = DocumentTypeValueSetCode("57156-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PsychiatryReferralNote = DocumentTypeValueSetCode("57157-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PsychologyReferralNote = DocumentTypeValueSetCode("57158-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PulmonaryReferralNote = DocumentTypeValueSetCode("57177-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RadiationOncologyReferralNote = DocumentTypeValueSetCode("57159-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RecreationalTherapyReferralNote = DocumentTypeValueSetCode("57160-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RespiratoryTherapyReferralNote = DocumentTypeValueSetCode("57162-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RheumatologyReferralNote = DocumentTypeValueSetCode("57163-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SocialWorkReferralNote = DocumentTypeValueSetCode("57164-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Speech_languagePathologyReferralNote = DocumentTypeValueSetCode("57165-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SurgeryReferralNote = DocumentTypeValueSetCode("57166-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThoracicSurgeryReferralNote = DocumentTypeValueSetCode("57167-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UrologyReferralNote = DocumentTypeValueSetCode("57168-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VascularSurgeryReferralNote = DocumentTypeValueSetCode("57169-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ReleaseOfInformationConsent = DocumentTypeValueSetCode("64292-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RequestedImagingStudiesInformationDocument = DocumentTypeValueSetCode("55115-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RestraintNote = DocumentTypeValueSetCode("70007-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NurseHospitalRestraintNote = DocumentTypeValueSetCode("68476-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PhysicianHospitalRestraintNote = DocumentTypeValueSetCode("68474-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RiskAssessmentDocument = DocumentTypeValueSetCode("71482-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RiskFactorsDocument = DocumentTypeValueSetCode("51898-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SeizureDisorderActionPlan = DocumentTypeValueSetCode("74153-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    StressCardiacEchoStudyReportUS = DocumentTypeValueSetCode("59282-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    StudyReport = DocumentTypeValueSetCode("47045-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SummaryNote = DocumentTypeValueSetCode("68608-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NurseSummaryNote = DocumentTypeValueSetCode("61143-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RadiationOncologySummaryNote = DocumentTypeValueSetCode("68602-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RadiationOncologyHospitalSummaryNote = DocumentTypeValueSetCode("68603-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SummaryOfDeathNote = DocumentTypeValueSetCode("47046-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SummaryOfEpisodeNote = DocumentTypeValueSetCode("34133-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SummaryOfEpisodeNoteEmergencyDepartment_Hospital = DocumentTypeValueSetCode(
        "74211-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SummaryPurposeCCDDocument = DocumentTypeValueSetCode("48764-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SupervisoryNote = DocumentTypeValueSetCode("47047-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OutpatientSupervisoryNote = DocumentTypeValueSetCode("67865-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CardiologyPhysicianAttendingOutpatientSupervisoryNote = DocumentTypeValueSetCode(
        "34135-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GastroenterologyPhysicianAttendingOutpatientSupervisoryNote = (
        DocumentTypeValueSetCode("34136-2")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PhysicianAttendingOutpatientSupervisoryNote = DocumentTypeValueSetCode("34134-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PatientSurgicalOperationConsent = DocumentTypeValueSetCode("61358-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Provider_unspecifiedOperationNote = DocumentTypeValueSetCode("11504-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OrthopaedicSurgerySurgicalOperationNote = DocumentTypeValueSetCode("34868-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OtolaryngologySurgicalOperationNote = DocumentTypeValueSetCode("34818-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PlasticSurgerySurgicalOperationNote = DocumentTypeValueSetCode("34870-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PodiatryOperationNote = DocumentTypeValueSetCode("28624-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SurgerySurgicalOperationNote = DocumentTypeValueSetCode("34874-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UrologySurgicalOperationNote = DocumentTypeValueSetCode("34877-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OutpatientSurgicalOperationNote = DocumentTypeValueSetCode("34137-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TargetedHistoryAndPhysicalNote = DocumentTypeValueSetCode("34138-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Provider_unspecifiedTransferSummary = DocumentTypeValueSetCode("18761-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AdolescentMedicineTransferSummaryNote = DocumentTypeValueSetCode("68618-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AllergyAndImmunologyTransferSummaryNote = DocumentTypeValueSetCode("68632-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChildAndAdolescentPsychiatryTransferSummaryNote = DocumentTypeValueSetCode(
        "68647-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClinicalGeneticsTransferSummaryNote = DocumentTypeValueSetCode("68660-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CriticalCareMedicineTransferSummaryNote = DocumentTypeValueSetCode("34755-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Developmental_behavioralPediatricsTransferSummaryNote = DocumentTypeValueSetCode(
        "68669-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GeneralMedicineTransferSummaryNote = DocumentTypeValueSetCode("34770-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Multi_specialtyProgramTransferSummaryNote = DocumentTypeValueSetCode("68680-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeurologyWithSpecialQualificationsInChildNeurologyTransferSummaryNote = (
        DocumentTypeValueSetCode("68704-6")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ObstetricsAndGynecologyTransferSummaryNote = DocumentTypeValueSetCode("68565-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OccupationalTherapyTransferSummaryNote = DocumentTypeValueSetCode("68569-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OphthalmologyTransferSummaryNote = DocumentTypeValueSetCode("68887-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OrthopaedicSurgeryTransferSummaryNote = DocumentTypeValueSetCode("68583-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PainMedicineTransferSummaryNote = DocumentTypeValueSetCode("68715-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricCardiologyTransferSummaryNote = DocumentTypeValueSetCode("68726-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricEndocrinologyTransferSummaryNote = DocumentTypeValueSetCode("68737-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricGastroenterologyTransferSummaryNote = DocumentTypeValueSetCode("68745-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricHematology_oncologyTransferSummaryNote = DocumentTypeValueSetCode(
        "68756-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricInfectiousDiseasesTransferSummaryNote = DocumentTypeValueSetCode("68764-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricNephrologyTransferSummaryNote = DocumentTypeValueSetCode("68772-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricOtolaryngologyTransferSummaryNote = DocumentTypeValueSetCode("68777-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricPulmonologyTransferSummaryNote = DocumentTypeValueSetCode("68786-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricRheumatologyTransferSummaryNote = DocumentTypeValueSetCode("68793-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricSurgeryTransferSummaryNote = DocumentTypeValueSetCode("68801-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricTransplantHepatologyTransferSummaryNote = DocumentTypeValueSetCode(
        "68863-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricUrologyTransferSummaryNote = DocumentTypeValueSetCode("68811-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricsTransferSummaryNote = DocumentTypeValueSetCode("68883-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PlasticSurgeryTransferSummaryNote = DocumentTypeValueSetCode("68596-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NurseHospitalTransferSummaryNote = DocumentTypeValueSetCode("68482-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PediatricsHospitalTransferSummaryNote = DocumentTypeValueSetCode("68884-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TransthoracicCardiacEchoStudyReportUS = DocumentTypeValueSetCode("59281-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TraumaSummaryRegistryReportDocument = DocumentTypeValueSetCode("74198-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    EmergencyDepartmentTriageNote = DocumentTypeValueSetCode("54094-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NurseEmergencyDepartmentTriage_careNote = DocumentTypeValueSetCode("57054-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationAcromegaly = DocumentTypeValueSetCode(
        "38932-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationAidAndAttendance_housebound = (
        DocumentTypeValueSetCode("38933-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationArrhythmias = DocumentTypeValueSetCode(
        "38934-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationAudio = DocumentTypeValueSetCode(
        "38936-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationBonesFractures_boneDisease = (
        DocumentTypeValueSetCode("38937-9")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationBrain_spinalCord = (
        DocumentTypeValueSetCode("38938-7")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationChronicFatigueSyndrome = (
        DocumentTypeValueSetCode("38939-5")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationColdInjuryProtocol = (
        DocumentTypeValueSetCode("38940-3")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationCranialNerves = DocumentTypeValueSetCode(
        "38941-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationCushingsSyndrome = (
        DocumentTypeValueSetCode("38942-9")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationDental_oral = DocumentTypeValueSetCode(
        "38943-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationDiabetesMellitus = (
        DocumentTypeValueSetCode("38944-5")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationDisabilityInGulfWarVeterans = (
        DocumentTypeValueSetCode("38956-9")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationEarDisease = DocumentTypeValueSetCode(
        "38946-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationEpilepsy_narcolepsy = (
        DocumentTypeValueSetCode("38949-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationEsophagus_hiatalHernia = (
        DocumentTypeValueSetCode("38950-2")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationExtremityJoints = (
        DocumentTypeValueSetCode("38966-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationEye = DocumentTypeValueSetCode("38951-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationFeet = DocumentTypeValueSetCode("38952-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationFibromyalgia = DocumentTypeValueSetCode(
        "38953-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationGeneralMedical = DocumentTypeValueSetCode(
        "38954-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationGeneralMentalDisorders = (
        DocumentTypeValueSetCode("38969-2")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationGenitourinary = DocumentTypeValueSetCode(
        "38955-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationGynecologicalConditions_disordersOfTheBreast = DocumentTypeValueSetCode(
        "38957-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationHand_thumb_fingers = (
        DocumentTypeValueSetCode("38958-5")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationHeart = DocumentTypeValueSetCode(
        "38959-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationHemicDisorders = DocumentTypeValueSetCode(
        "38960-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationHIV_relatedIllness = (
        DocumentTypeValueSetCode("38961-9")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationHypertension = DocumentTypeValueSetCode(
        "38962-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationInfectious_immune_nutritionalDisabilities = DocumentTypeValueSetCode(
        "38963-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationInitialEvaluationPost_traumaticStressDisorder = DocumentTypeValueSetCode(
        "38964-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationLarge_smallIntestines = (
        DocumentTypeValueSetCode("38965-0")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationLiver_gallBladder_pancreas = (
        DocumentTypeValueSetCode("38967-6")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationLymphaticDisorders = (
        DocumentTypeValueSetCode("38968-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationMentalHealthEatingDisorders = (
        DocumentTypeValueSetCode("38947-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationMiscellaneousArteries_veins = (
        DocumentTypeValueSetCode("38935-3")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationMiscellaneousDigestiveConditions = (
        DocumentTypeValueSetCode("38945-2")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationMiscellaneousEndocrineDiseases = (
        DocumentTypeValueSetCode("38948-6")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationMiscellaneousNeurologicalDisorders = (
        DocumentTypeValueSetCode("38972-6")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationMiscellaneousRespiratoryDiseases = (
        DocumentTypeValueSetCode("38980-9")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationMouth_lips_tongue = (
        DocumentTypeValueSetCode("38970-0")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationMuscles = DocumentTypeValueSetCode(
        "38971-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationNose_sinus_larynx_pharynx = (
        DocumentTypeValueSetCode("38973-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationObstructive_restrictive_interstitialRespiratoryDiseases = DocumentTypeValueSetCode(
        "38979-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationPeripheralNerves = (
        DocumentTypeValueSetCode("38974-2")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationPrisonerOfWarProtocol = (
        DocumentTypeValueSetCode("38975-9")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationPulmonaryTuberculosis_mycobacterialDiseases = DocumentTypeValueSetCode(
        "38976-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationRectum_anus = DocumentTypeValueSetCode(
        "38977-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationResidualsOfAmputations = (
        DocumentTypeValueSetCode("38978-3")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationReviewEvaluationPost_traumaticStressDisorder = DocumentTypeValueSetCode(
        "38981-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationScars = DocumentTypeValueSetCode(
        "38982-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationSenseOfSmell_taste = (
        DocumentTypeValueSetCode("38983-3")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationSkinDiseasesOtherThanScars = (
        DocumentTypeValueSetCode("38984-1")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationSocial_industrialSurvey = (
        DocumentTypeValueSetCode("38985-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationSpine = DocumentTypeValueSetCode(
        "38986-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationStomach_duodenum_peritonealAdhesions = (
        DocumentTypeValueSetCode("38987-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VACompensationAndPension_CAndP_ExaminationThyroid_parathyroidDiseases = (
        DocumentTypeValueSetCode("38988-2")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    WellChildVisitNote = DocumentTypeValueSetCode("59283-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbortionConsent = DocumentTypeValueSetCode("52027-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AdministrationOfVasodilatorIntoCatheterOfVein = DocumentTypeValueSetCode("24754-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AdministrationOfVasodilatorIntoCatheterOfVein_Bilateral = DocumentTypeValueSetCode(
        "26376-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AdministrationOfVasodilatorIntoCatheterOfVein_Left = DocumentTypeValueSetCode(
        "26377-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AdministrationOfVasodilatorIntoCatheterOfVein_Right = DocumentTypeValueSetCode(
        "26378-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AdvancedBeneficiaryNotice = DocumentTypeValueSetCode("53243-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AnesthesiaRecords = DocumentTypeValueSetCode("11485-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PeripheralArteryFluoroscopicAngiogramAdditionalAngioplastyWContrastIA = (
        DocumentTypeValueSetCode("30649-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VeinFluoroscopicAngiogramAdditionalAngioplastyWContrastIV = (
        DocumentTypeValueSetCode("30641-5")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AVShuntFluoroscopicAngiogramAngioplastyWContrast = DocumentTypeValueSetCode(
        "36760-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityVesselFluoroscopicAngiogramAngioplastyWContrast = DocumentTypeValueSetCode(
        "36762-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionFluoroscopicAngiogramAngioplastyWContrast = (
        DocumentTypeValueSetCode("69067-7")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AortaFluoroscopicAngiogramAngioplastyWContrastIA = DocumentTypeValueSetCode(
        "24543-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrachiocephalicArteryFluoroscopicAngiogramAngioplastyWContrastIA = (
        DocumentTypeValueSetCode("24580-3")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrachiocephalicArtery_LeftFluoroscopicAngiogramAngioplastyWContrastIA = (
        DocumentTypeValueSetCode("26368-1")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrachiocephalicArtery_RightFluoroscopicAngiogramAngioplastyWContrastIA = (
        DocumentTypeValueSetCode("26369-9")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CarotidArteryExtracranialFluoroscopicAngiogramAngioplastyWContrastIA = (
        DocumentTypeValueSetCode("24614-0")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CarotidArteryIntracranialFluoroscopicAngiogramAngioplastyWContrastIA = (
        DocumentTypeValueSetCode("24615-7")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityArteryFluoroscopicAngiogramAngioplastyWContrastIA = (
        DocumentTypeValueSetCode("35881-2")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FemoralArteryFluoroscopicAngiogramAngioplastyWContrastIA = DocumentTypeValueSetCode(
        "24698-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FemoralArteryAndPoplitealArteryFluoroscopicAngiogramAngioplastyWContrastIA = (
        DocumentTypeValueSetCode("36763-1")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    IliacArteryFluoroscopicAngiogramAngioplastyWContrastIA = DocumentTypeValueSetCode(
        "24766-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    IliacArtery_BilateralFluoroscopicAngiogramAngioplastyWContrastIA = (
        DocumentTypeValueSetCode("26370-7")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    IliacArtery_LeftFluoroscopicAngiogramAngioplastyWContrastIA = (
        DocumentTypeValueSetCode("26371-5")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    IliacArtery_RightFluoroscopicAngiogramAngioplastyWContrastIA = (
        DocumentTypeValueSetCode("26372-3")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MesentericArteryFluoroscopicAngiogramAngioplastyWContrastIA = (
        DocumentTypeValueSetCode("24832-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PeripheralArteryFluoroscopicAngiogramAngioplastyWContrastIA = (
        DocumentTypeValueSetCode("30648-0")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RenalVesselFluoroscopicAngiogramAngioplastyWContrastIA = DocumentTypeValueSetCode(
        "25081-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TibialArteryFluoroscopicAngiogramAngioplastyWContrastIA = DocumentTypeValueSetCode(
        "25012-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TibialArtery_BilateralFluoroscopicAngiogramAngioplastyWContrastIA = (
        DocumentTypeValueSetCode("26373-1")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TibialArtery_LeftFluoroscopicAngiogramAngioplastyWContrastIA = (
        DocumentTypeValueSetCode("26374-9")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TibialArtery_RightFluoroscopicAngiogramAngioplastyWContrastIA = (
        DocumentTypeValueSetCode("26375-6")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TibioperonealArteriesFluoroscopicAngiogramAngioplastyWContrastIA = (
        DocumentTypeValueSetCode("43793-9")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TibioperonealArteries_BilateralFluoroscopicAngiogramAngioplastyWContrastIA = (
        DocumentTypeValueSetCode("43794-7")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TibioperonealArteries_LeftFluoroscopicAngiogramAngioplastyWContrastIA = (
        DocumentTypeValueSetCode("43795-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TibioperonealArteries_RightFluoroscopicAngiogramAngioplastyWContrastIA = (
        DocumentTypeValueSetCode("43792-1")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VesselFluoroscopicAngiogramAngioplastyWContrastIA = DocumentTypeValueSetCode(
        "25064-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VisceralArteryFluoroscopicAngiogramAngioplastyWContrastIA = (
        DocumentTypeValueSetCode("30836-1")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVeinFluoroscopicAngiogramAngioplastyWContrastIV = (
        DocumentTypeValueSetCode("37426-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VeinFluoroscopicAngiogramAngioplastyWContrastIV = DocumentTypeValueSetCode(
        "30640-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InferiorVenaCavaFluoroscopicAngiogramAngioplastyWContrastIV = (
        DocumentTypeValueSetCode("35882-0")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AppealDenialLetter = DocumentTypeValueSetCode("52032-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FemoralVesselAndPoplitealArteryFluoroscopicAngiogramAtherectomyWContrast = (
        DocumentTypeValueSetCode("36764-9")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    IliacArteryFluoroscopicAngiogramAtherectomyWContrast = DocumentTypeValueSetCode(
        "69135-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RenalVesselsFluoroscopicAngiogramAtherectomyWContrast = DocumentTypeValueSetCode(
        "69253-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VesselFluoroscopicAngiogramAtherectomyWContrast = DocumentTypeValueSetCode(
        "36765-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AortaFluoroscopicAngiogramAtherectomyWContrastIA = DocumentTypeValueSetCode(
        "35883-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CoronaryArteriesFluoroscopicAngiogramAtherectomyWContrastIA = (
        DocumentTypeValueSetCode("36766-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AVFistulaFluoroscopicAngiogramAtherectomyWContrastIV = DocumentTypeValueSetCode(
        "24568-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AudiologyStudy = DocumentTypeValueSetCode("28615-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AutomobileLiability = DocumentTypeValueSetCode("52065-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AutopsyReport = DocumentTypeValueSetCode("18743-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BiliaryDuctsFluoroscopyBalloonDilatationWContrast = DocumentTypeValueSetCode(
        "36761-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BloodBankConsult = DocumentTypeValueSetCode("33720-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BloodGlucoseMonitors = DocumentTypeValueSetCode("52041-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SkeletalSystemDXABoneDensity = DocumentTypeValueSetCode("38268-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SkeletalSystem_axialScanBoneDensity = DocumentTypeValueSetCode("43562-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SkeletalSystem_peripheralScanBoneDensity = DocumentTypeValueSetCode("43563-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BoneMarrowAspirationReport = DocumentTypeValueSetCode("48807-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionFluoroscopyCentralVeinCatheterPlacementCheck = (
        DocumentTypeValueSetCode("24631-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChargeTicketOrEncounterForm = DocumentTypeValueSetCode("53242-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChemotherapyEffectivenessPanel_Identifier_BloodOrTissue = DocumentTypeValueSetCode(
        "54095-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChemotherapyRecords = DocumentTypeValueSetCode("11486-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CMS_HistoryOfPresentIllnessPanel = DocumentTypeValueSetCode("71428-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CMS_PastFamily_SocialHistoryPanel = DocumentTypeValueSetCode("71421-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CMS_PhysicalExamPanel = DocumentTypeValueSetCode("71388-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CMS_ReviewOfSystemsPanel = DocumentTypeValueSetCode("71406-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionX_rayComparisonView = DocumentTypeValueSetCode("25062-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OutpatientConsultation2ndOpinion = DocumentTypeValueSetCode("24611-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PathologyConsultNote = DocumentTypeValueSetCode("60570-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PathologyConsultNote_synoptic = DocumentTypeValueSetCode("60571-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ContinuousPositiveAirwayPressure_CPAP_ = DocumentTypeValueSetCode("52042-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionCourtesyConsultation = DocumentTypeValueSetCode("25038-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CriticalCareRecords = DocumentTypeValueSetCode("29751-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CytologyReportOfBronchoalveolarLavageCytoStain = DocumentTypeValueSetCode("50007-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CytologyReportOfBodyFluidCytoStain = DocumentTypeValueSetCode("47523-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CytologyReportOfBreastDuctalLavageCytoStain = DocumentTypeValueSetCode("47530-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CytologyReportOfBreastFineNeedleAspirateCytoStain = DocumentTypeValueSetCode(
        "47521-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CytologyReportOfBronchialBrushCytoStain = DocumentTypeValueSetCode("50971-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CytologyReportOfCervicalOrVaginalSmearOrScrapingCytoStain = (
        DocumentTypeValueSetCode("47528-5")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CytologyReportOfCervicalOrVaginalSmearOrScrapingCytoStain_thinPrep = (
        DocumentTypeValueSetCode("47527-7")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CytologyReportOfNippleDischargeCytoStain = DocumentTypeValueSetCode("47522-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CytologyReportOfSputumCytoStain = DocumentTypeValueSetCode("47520-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CytologyReportOfThyroidFineNeedleAspirateCytoStain = DocumentTypeValueSetCode(
        "47524-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CytologyReportOfTissueOtherStain = DocumentTypeValueSetCode("47529-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CytologyReportOfTissueFineNeedleAspirateCytoStain = DocumentTypeValueSetCode(
        "33718-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CytologyReportOfUrineCytoStain = DocumentTypeValueSetCode("47525-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CytologyReportOfUnspecifiedSpecimenCytoStain = DocumentTypeValueSetCode("47526-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    DentalX_raysAndOtherImages_notDICOM_ = DocumentTypeValueSetCode("52040-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    DialysisRecords = DocumentTypeValueSetCode("29749-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NurseDischargeAssessment = DocumentTypeValueSetCode("28622-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    DischargeNote = DocumentTypeValueSetCode("28574-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    DentistDischargeSummary = DocumentTypeValueSetCode("29761-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PhysicianDischargeSummary = DocumentTypeValueSetCode("11490-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PhysicianAttendingDischargeSummary = DocumentTypeValueSetCode("28655-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    DriverLicenseImage = DocumentTypeValueSetCode("53245-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    EligibilityAcknowledgement = DocumentTypeValueSetCode("53247-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtracranialVesselsFluoroscopicAngiogramEmbolectomyWContrastIA = (
        DocumentTypeValueSetCode("24684-3")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PulmonaryArteryFluoroscopicAngiogramEmbolectomyWContrastIA = (
        DocumentTypeValueSetCode("24887-2")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VesselIntracranialFluoroscopicAngiogramEmbolectomyWContrastIV = (
        DocumentTypeValueSetCode("24553-0")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ArteryFluoroscopicAngiogramEmbolizationWContrastIA = DocumentTypeValueSetCode(
        "24554-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    EmployeeAssistanceProgram = DocumentTypeValueSetCode("52071-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    EMSPatientCareReport_Version3_1DocumentNEMSIS = DocumentTypeValueSetCode("67796-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    EnteralNutrition = DocumentTypeValueSetCode("52043-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SmallBowelCTViewsEnteroclysisWContrastPOViaDuodenalIntubation = (
        DocumentTypeValueSetCode("30600-1")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SmallBowelFluoroscopyViewsEnteroclysisWContrastPOViaDuodenalIntubation = (
        DocumentTypeValueSetCode("24923-5")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExplanationOfBenefits = DocumentTypeValueSetCode("52030-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExplanationOfBenefitsToSubscriber = DocumentTypeValueSetCode("52031-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExternalInfusionPump = DocumentTypeValueSetCode("52044-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    EyeUltrasoundStudy = DocumentTypeValueSetCode("29272-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FirstReportOfInjury = DocumentTypeValueSetCode("52064-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FullNewbornScreeningSummaryReportForDisplayOrPrinting = DocumentTypeValueSetCode(
        "57129-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GaitTrainers = DocumentTypeValueSetCode("52045-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GeneralCorrespondence = DocumentTypeValueSetCode("52033-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GeneticAnalysisSummaryReportInBloodOrTissueDocumentByMolecularGeneticsMethod = (
        DocumentTypeValueSetCode("51969-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForAblationOfTissueOfCeliacPlexus = DocumentTypeValueSetCode("46365-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForAblationOfTissueOfKidney = DocumentTypeValueSetCode("44228-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForAblationOfTissueOfKidney = DocumentTypeValueSetCode("44156-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForAblationOfTissueOfLiver = DocumentTypeValueSetCode("44101-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForAblationOfTissueOfLiver = DocumentTypeValueSetCode("44155-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForAblationOfTissueOfUnspecifiedBodyRegion = DocumentTypeValueSetCode(
        "58747-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForAblationOfTissueOfUnspecifiedBodyRegion = DocumentTypeValueSetCode(
        "58743-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForAbscessDrainageOfAbdomen = DocumentTypeValueSetCode("35884-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForAbscessDrainageOfAppendix = DocumentTypeValueSetCode("42280-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForAbscessDrainageOfAppendix = DocumentTypeValueSetCode("42705-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForAbscessDrainageOfChest = DocumentTypeValueSetCode("42281-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForAbscessDrainageOfKidney = DocumentTypeValueSetCode("42285-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForAbscessDrainageOfKidney = DocumentTypeValueSetCode("44167-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForAbscessDrainageOfLiver = DocumentTypeValueSetCode("42282-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForAbscessDrainageOfLiver = DocumentTypeValueSetCode("42133-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForAbscessDrainageOfLiver = DocumentTypeValueSetCode("39361-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForAbscessDrainageOfNeck = DocumentTypeValueSetCode("69120-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForAbscessDrainageOfPancreas = DocumentTypeValueSetCode(
        "69122-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForAbscessDrainageOfPelvis = DocumentTypeValueSetCode("42286-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForAbscessDrainageOfPelvis = DocumentTypeValueSetCode("44168-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForAbscessDrainageOfPeritonealSpace = DocumentTypeValueSetCode("44169-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForAbscessDrainageOfPleuralSpace = DocumentTypeValueSetCode("42284-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForAbscessDrainageOfPleuralSpace = DocumentTypeValueSetCode(
        "69123-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForAbscessDrainageOfSubphrenicSpace = DocumentTypeValueSetCode("43502-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForAbscessDrainageOfSubphrenicSpace = DocumentTypeValueSetCode("44166-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForAbscessDrainageOfUnspecifiedBodyRegion = DocumentTypeValueSetCode(
        "30578-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForAbscessDrainageOfUnspecifiedBodyRegion = DocumentTypeValueSetCode(
        "39451-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForAbscessDrainageOfUnspecifiedBodyRegion = (
        DocumentTypeValueSetCode("35885-3")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScanGuidanceForAbscessLocalizationLimited = DocumentTypeValueSetCode("39620-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScanGuidanceForAbscessLocalizationWholeBody = DocumentTypeValueSetCode("39623-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SPECTGuidanceForAbscessLocalizationWholeBody = DocumentTypeValueSetCode("39622-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SPECTGuidanceForAbscessLocalization = DocumentTypeValueSetCode("39621-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForAmbulatoryPhlebectomyOfExtremityVein_Left = DocumentTypeValueSetCode(
        "72533-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForAmbulatoryPhlebectomyOfExtremityVein_Right = DocumentTypeValueSetCode(
        "72532-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForAnestheticBlockInjectionOfCeliacPlexus = DocumentTypeValueSetCode(
        "24623-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForAnestheticBlockInjectionOfSpine = DocumentTypeValueSetCode("42688-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForAspirationOfBreast = DocumentTypeValueSetCode("35886-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MammogramGuidanceForAspirationOfBreast = DocumentTypeValueSetCode("24598-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForAspirationOfBreast = DocumentTypeValueSetCode("43756-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForAspirationOfBreast_Bilateral = DocumentTypeValueSetCode("69278-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForAspirationOfBreast_Left = DocumentTypeValueSetCode("69292-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForAspirationOfBreast_Right = DocumentTypeValueSetCode("69296-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForAspirationOfHip = DocumentTypeValueSetCode("35888-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForAspirationOfJointSpace = DocumentTypeValueSetCode("24771-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForAspirationOfKidney = DocumentTypeValueSetCode("48434-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForAspirationOfLiver = DocumentTypeValueSetCode("24811-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForAspirationOfLung = DocumentTypeValueSetCode("24822-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForAspirationOfLymphNode = DocumentTypeValueSetCode("69287-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForAspirationOfNeck = DocumentTypeValueSetCode("24837-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForAspirationOfOvary = DocumentTypeValueSetCode("39452-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForAspirationOfPancreas = DocumentTypeValueSetCode("24856-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForAspirationOfPelvis = DocumentTypeValueSetCode("24863-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForAspirationOfPericardialSpace = DocumentTypeValueSetCode("30703-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForAspirationOfPleuralSpace = DocumentTypeValueSetCode("37491-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForAspirationOfPleuralSpace = DocumentTypeValueSetCode("24662-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForAspirationOfPleuralSpace = DocumentTypeValueSetCode("37887-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForAspirationOfSpineLumbarSpace = DocumentTypeValueSetCode(
        "24973-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForAspirationOfThyroid = DocumentTypeValueSetCode("42134-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForAspirationOfUnspecifiedBodyRegion = DocumentTypeValueSetCode("25043-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForAspirationOfUnspecifiedBodyRegion = DocumentTypeValueSetCode("30878-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForAspirationAndPlacementOfDrainageTubeOfAbdomen = (
        DocumentTypeValueSetCode("36926-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForAspirationOfCystOfAbdomen = DocumentTypeValueSetCode("37210-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForAspirationOfCystOfBone = DocumentTypeValueSetCode("69306-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MammogramGuidanceForAspirationOfCystOfBreast = DocumentTypeValueSetCode("24594-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MRIGuidanceForAspirationOfCystOfBreast = DocumentTypeValueSetCode("69192-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForAspirationOfCystOfBreast = DocumentTypeValueSetCode("30653-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MammogramGuidanceForAspirationOfCystOfBreast_Bilateral = DocumentTypeValueSetCode(
        "26343-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForAspirationOfCystOfBreast_Bilateral = DocumentTypeValueSetCode(
        "38012-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MammogramGuidanceForAspirationOfCystOfBreast_Left = DocumentTypeValueSetCode(
        "26344-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForAspirationOfCystOfBreast_Left = DocumentTypeValueSetCode("42450-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MammogramGuidanceForAspirationOfCystOfBreast_Right = DocumentTypeValueSetCode(
        "26345-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForAspirationOfCystOfBreast_Right = DocumentTypeValueSetCode("42458-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForAspirationOfCystOfKidney = DocumentTypeValueSetCode("38126-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForAspirationOfCystOfOvary = DocumentTypeValueSetCode("69121-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForAspirationOfCystOfPancreas = DocumentTypeValueSetCode("38133-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForAspirationOfCystOfThyroid = DocumentTypeValueSetCode("42447-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForAspirationOfCystOfUnspecifiedBodyRegion = DocumentTypeValueSetCode(
        "35887-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForAspirationOfCystOfUnspecifiedBodyRegion = DocumentTypeValueSetCode(
        "30698-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForAspirationOfCystOfUnspecifiedBodyRegion = (
        DocumentTypeValueSetCode("24671-0")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForAspirationOrBiopsyOfUnspecifiedBodyRegion = DocumentTypeValueSetCode(
        "25042-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForAspirationOrBiopsyOfUnspecifiedBodyRegion_WContrastIV = (
        DocumentTypeValueSetCode("25041-5")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForAspirationOrInjectionOfCystOfUnspecifiedBodyRegion = (
        DocumentTypeValueSetCode("46281-2")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForAspirationOrInjectionOfCystOfUnspecifiedBodyRegion = (
        DocumentTypeValueSetCode("46282-0")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForFineNeedleAspirationOfAbdomen = DocumentTypeValueSetCode("30602-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForFineNeedleAspirationOfAbdomenRetroperitoneum = (
        DocumentTypeValueSetCode("44107-1")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForFineNeedleAspirationOfAdrenalGland = DocumentTypeValueSetCode(
        "44108-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MammogramGuidanceForFineNeedleAspirationOfBreast = DocumentTypeValueSetCode(
        "46387-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForFineNeedleAspirationOfBreast = DocumentTypeValueSetCode("44160-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MammogramGuidanceForFineNeedleAspirationOfBreast_Left = DocumentTypeValueSetCode(
        "46284-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForFineNeedleAspirationOfBreast_Left = DocumentTypeValueSetCode("38026-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MammogramGuidanceForFineNeedleAspirationOfBreast_Right = DocumentTypeValueSetCode(
        "46283-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForFineNeedleAspirationOfBreast_Right = DocumentTypeValueSetCode(
        "38033-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForFineNeedleAspirationOfDeepTissue = DocumentTypeValueSetCode("38135-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForFineNeedleAspirationOfDeepTissue = DocumentTypeValueSetCode(
        "44221-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForFineNeedleAspirationOfKidney = DocumentTypeValueSetCode("43757-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForFineNeedleAspirationOfKidney = DocumentTypeValueSetCode("44159-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForFineNeedleAspirationOfKidney = DocumentTypeValueSetCode(
        "44217-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForFineNeedleAspirationOfKidney_Bilateral = DocumentTypeValueSetCode(
        "30608-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForFineNeedleAspirationOfLiver = DocumentTypeValueSetCode("30603-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForFineNeedleAspirationOfLiver = DocumentTypeValueSetCode("44158-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForFineNeedleAspirationOfLiver = DocumentTypeValueSetCode(
        "44220-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForFineNeedleAspirationOfLung = DocumentTypeValueSetCode("30595-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForFineNeedleAspirationOfLymphNode = DocumentTypeValueSetCode("44103-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForFineNeedleAspirationOfLymphNode = DocumentTypeValueSetCode(
        "44219-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForFineNeedleAspirationOfMediastinum = DocumentTypeValueSetCode("44104-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForFineNeedleAspirationOfMuscle = DocumentTypeValueSetCode("44105-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForFineNeedleAspirationOfPancreas = DocumentTypeValueSetCode("30605-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForFineNeedleAspirationOfPancreas = DocumentTypeValueSetCode("44157-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForFineNeedleAspirationOfPancreas = DocumentTypeValueSetCode(
        "44218-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForFineNeedleAspirationOfPelvis = DocumentTypeValueSetCode("30606-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForFineNeedleAspirationOfProstate = DocumentTypeValueSetCode("44106-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForFineNeedleAspirationOfProstate = DocumentTypeValueSetCode("38017-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForFineNeedleAspirationOfSpleen = DocumentTypeValueSetCode("30610-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForFineNeedleAspirationOfSuperficialTissue = DocumentTypeValueSetCode(
        "38136-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForFineNeedleAspirationOfSuperficialTissue = (
        DocumentTypeValueSetCode("69124-6")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForFineNeedleAspirationOfThyroid = DocumentTypeValueSetCode("38019-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForFineNeedleAspirationOfThyroid = DocumentTypeValueSetCode(
        "44216-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForFineNeedleAspirationOfUnspecifiedBodyRegion = DocumentTypeValueSetCode(
        "30580-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForFineNeedleAspirationOfUnspecifiedBodyRegion = DocumentTypeValueSetCode(
        "38018-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForFineNeedleAspirationOfUnspecifiedBodyRegion = (
        DocumentTypeValueSetCode("44215-2")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopicAngiogramGuidanceForAtherectomyOfVein_WContrastIV = (
        DocumentTypeValueSetCode("24755-1")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopicAngiogramGuidanceForAtherectomyOfVein_Bilateral_WContrastIV = (
        DocumentTypeValueSetCode("26298-0")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopicAngiogramGuidanceForAtherectomyOfVein_Left_WContrastIV = (
        DocumentTypeValueSetCode("26299-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopicAngiogramGuidanceForAtherectomyOfVein_Right_WContrastIV = (
        DocumentTypeValueSetCode("26300-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForBiopsyOfAbdomen = DocumentTypeValueSetCode("30601-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForBiopsyOfAbdomen = DocumentTypeValueSetCode("37913-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForBiopsyOfAbdomen = DocumentTypeValueSetCode("35890-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForBiopsyOfAbdomenRetroperitoneum = DocumentTypeValueSetCode("44117-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForBiopsyOfAbdomenRetroperitoneum = DocumentTypeValueSetCode("44162-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForBiopsyOfAdrenalGland = DocumentTypeValueSetCode("36767-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForBiopsyOfBone = DocumentTypeValueSetCode("35891-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForBiopsyOfBone = DocumentTypeValueSetCode("69076-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForBiopsyOfBoneMarrow = DocumentTypeValueSetCode("37211-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForBiopsyOfBreast = DocumentTypeValueSetCode("35893-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MammogramGuidanceForBiopsyOfBreast = DocumentTypeValueSetCode("24602-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForBiopsyOfBreast = DocumentTypeValueSetCode("37914-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MammogramGuidanceForBiopsyOfBreast_Bilateral = DocumentTypeValueSetCode("26337-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MRIGuidanceForBiopsyOfBreast_Bilateral = DocumentTypeValueSetCode("69169-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForBiopsyOfBreast_Bilateral = DocumentTypeValueSetCode("37912-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MammogramGuidanceForBiopsyOfBreast_Left = DocumentTypeValueSetCode("26338-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MRIGuidanceForBiopsyOfBreast_Left = DocumentTypeValueSetCode("69203-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForBiopsyOfBreast_Left = DocumentTypeValueSetCode("42449-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MammogramGuidanceForBiopsyOfBreast_Right = DocumentTypeValueSetCode("26339-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MRIGuidanceForBiopsyOfBreast_Right = DocumentTypeValueSetCode("69213-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForBiopsyOfBreast_Right = DocumentTypeValueSetCode("42457-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForBiopsyOfChest = DocumentTypeValueSetCode("35895-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForBiopsyOfChest = DocumentTypeValueSetCode("37915-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForBiopsyOfChest = DocumentTypeValueSetCode("35894-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForBiopsyOfChest_pleura = DocumentTypeValueSetCode("37492-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForBiopsyOfChest_pleura = DocumentTypeValueSetCode("42333-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForBiopsyOfDeepBone = DocumentTypeValueSetCode("43567-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForBiopsyOfDeepBone = DocumentTypeValueSetCode("43565-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForBiopsyOfDeepMuscle = DocumentTypeValueSetCode("44109-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForBiopsyOfEndomyocardium = DocumentTypeValueSetCode("42463-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForBiopsyOfEpididymis = DocumentTypeValueSetCode("37212-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForBiopsyOfEpididymis = DocumentTypeValueSetCode("69387-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForBiopsyOfFacialBonesAndMaxilla = DocumentTypeValueSetCode("36927-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForBiopsyOfHead = DocumentTypeValueSetCode("35892-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForBiopsyOfHeart = DocumentTypeValueSetCode("42136-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForBiopsyOfKidney = DocumentTypeValueSetCode("42279-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForBiopsyOfKidney = DocumentTypeValueSetCode("24772-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForBiopsyOfKidney = DocumentTypeValueSetCode("35899-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForBiopsyOfKidneyTransplant = DocumentTypeValueSetCode("38766-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForBiopsyOfKidney_Bilateral = DocumentTypeValueSetCode("30607-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForBiopsyOfKidney_Bilateral = DocumentTypeValueSetCode("26340-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForBiopsyOfKidney_Left = DocumentTypeValueSetCode("26341-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForBiopsyOfKidney_Right = DocumentTypeValueSetCode("26342-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForBiopsyOfLiver = DocumentTypeValueSetCode("24812-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForBiopsyOfLiver = DocumentTypeValueSetCode("24816-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForBiopsyOfLiver = DocumentTypeValueSetCode("35900-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForBiopsyOfLiverTransplant = DocumentTypeValueSetCode("38765-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForBiopsyOfLowerExtremity = DocumentTypeValueSetCode("35896-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForBiopsyOfLung = DocumentTypeValueSetCode("24823-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForBiopsyOfLung = DocumentTypeValueSetCode("44161-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForBiopsyOfLung = DocumentTypeValueSetCode("30634-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForBiopsyOfLymphNode = DocumentTypeValueSetCode("35901-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForBiopsyOfLymphNode = DocumentTypeValueSetCode("39522-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForBiopsyOfMediastinum = DocumentTypeValueSetCode("37213-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForBiopsyOfMediastinum = DocumentTypeValueSetCode("42137-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForBiopsyOfMuscle = DocumentTypeValueSetCode("36768-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForBiopsyOfMuscle = DocumentTypeValueSetCode("37917-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForBiopsyOfNeck = DocumentTypeValueSetCode("24838-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForBiopsyOfNeck = DocumentTypeValueSetCode("37918-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForBiopsyOfPancreas = DocumentTypeValueSetCode("30604-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForBiopsyOfPancreas = DocumentTypeValueSetCode("37919-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForBiopsyOfPancreas = DocumentTypeValueSetCode("35902-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForBiopsyOfPelvis = DocumentTypeValueSetCode("24864-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForBiopsyOfPelvis = DocumentTypeValueSetCode("69074-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForBiopsyOfProstate = DocumentTypeValueSetCode("35903-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForBiopsyOfProstate = DocumentTypeValueSetCode("24883-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForBiopsyOfProstate = DocumentTypeValueSetCode("41802-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForBiopsyOfSalivaryGland = DocumentTypeValueSetCode("35898-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForBiopsyOfSalivaryGland = DocumentTypeValueSetCode("37920-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForBiopsyOfSalivaryGland = DocumentTypeValueSetCode("69075-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForBiopsyOfScrotumAndTesticle = DocumentTypeValueSetCode("38132-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForBiopsyOfSpinalCord = DocumentTypeValueSetCode("69396-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForBiopsyOfSpine = DocumentTypeValueSetCode("24986-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForBiopsyOfSpineCervical = DocumentTypeValueSetCode("35904-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForBiopsyOfSpineLumbar = DocumentTypeValueSetCode("35905-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForBiopsyOfSpineThoracic = DocumentTypeValueSetCode("35906-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForBiopsyOfSpleen = DocumentTypeValueSetCode("30609-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForBiopsyOfSpleen = DocumentTypeValueSetCode("35907-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForBiopsyOfSuperficialBone = DocumentTypeValueSetCode("42265-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForBiopsyOfSuperficialBone = DocumentTypeValueSetCode("42135-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForBiopsyOfSuperficialBone = DocumentTypeValueSetCode("38154-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForBiopsyOfSuperficialLymphNode = DocumentTypeValueSetCode("43797-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForBiopsyOfSuperficialMuscle = DocumentTypeValueSetCode("43564-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForBiopsyOfSuperficialTissue = DocumentTypeValueSetCode("37214-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForBiopsyOfThyroid = DocumentTypeValueSetCode("35908-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForBiopsyOfThyroid = DocumentTypeValueSetCode("25009-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForBiopsyOfUpperExtremity = DocumentTypeValueSetCode("35897-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForBiopsyOfUnspecifiedBodyRegion = DocumentTypeValueSetCode("25044-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForBiopsyOfUnspecifiedBodyRegion = DocumentTypeValueSetCode("25059-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForBiopsyOfUnspecifiedBodyRegion = DocumentTypeValueSetCode(
        "25069-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForBiopsyOfCystOfUnspecifiedBodyRegion = DocumentTypeValueSetCode(
        "24670-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForCoreNeedleBiopsyOfBreast = DocumentTypeValueSetCode("30651-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForCoreNeedleBiopsyOfLiver = DocumentTypeValueSetCode("24813-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForCoreNeedleBiopsyOfLymphNode = DocumentTypeValueSetCode("69279-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForCoreNeedleBiopsyOfThyroid = DocumentTypeValueSetCode("46285-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForCoreNeedleBiopsyOfUnspecifiedBodyRegion = DocumentTypeValueSetCode(
        "38024-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForCoreNeedleBiopsyOfUnspecifiedBodyRegion = (
        DocumentTypeValueSetCode("69073-5")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForExcisionalBiopsyOfBreast = DocumentTypeValueSetCode("42448-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForFineNeedleBiopsyOfBreast = DocumentTypeValueSetCode("30652-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForNeedleBiopsyOfAbdomen = DocumentTypeValueSetCode("42288-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForNeedleBiopsyOfAbdomen = DocumentTypeValueSetCode("69224-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForNeedleBiopsyOfAdrenalGland = DocumentTypeValueSetCode("46367-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForNeedleBiopsyOfBreast = DocumentTypeValueSetCode("46368-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MammogramGuidanceForNeedleBiopsyOfBreast = DocumentTypeValueSetCode("46286-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForNeedleBiopsyOfBreast = DocumentTypeValueSetCode("38028-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForNeedleBiopsyOfBreast = DocumentTypeValueSetCode("41803-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForNeedleBiopsyOfBreast_Left = DocumentTypeValueSetCode("43462-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MammogramGuidanceForNeedleBiopsyOfBreast_Right = DocumentTypeValueSetCode("43447-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForNeedleBiopsyOfBreast_Right = DocumentTypeValueSetCode("69290-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForNeedleBiopsyOfChest = DocumentTypeValueSetCode("38029-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForNeedleBiopsyOfChest = DocumentTypeValueSetCode("69225-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForNeedleBiopsyOfChest_pleura = DocumentTypeValueSetCode("69099-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForNeedleBiopsyOfChest_pleura = DocumentTypeValueSetCode("44171-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForNeedleBiopsyOfChest_pleura = DocumentTypeValueSetCode(
        "69127-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForNeedleBiopsyOfDeepBone = DocumentTypeValueSetCode("43568-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForNeedleBiopsyOfKidney = DocumentTypeValueSetCode("42289-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForNeedleBiopsyOfKidney_Bilateral = DocumentTypeValueSetCode("38027-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForNeedleBiopsyOfLiver = DocumentTypeValueSetCode("69097-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MRIGuidanceForNeedleBiopsyOfLiver = DocumentTypeValueSetCode("69197-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForNeedleBiopsyOfLiver = DocumentTypeValueSetCode("44170-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForNeedleBiopsyOfLiver = DocumentTypeValueSetCode("69125-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForNeedleBiopsyOfLymphNode = DocumentTypeValueSetCode("42267-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForNeedleBiopsyOfLymphNode = DocumentTypeValueSetCode("37916-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForNeedleBiopsyOfMuscle = DocumentTypeValueSetCode("69098-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MRIGuidanceForNeedleBiopsyOfMuscle = DocumentTypeValueSetCode("69198-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForNeedleBiopsyOfMuscle = DocumentTypeValueSetCode("69288-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForNeedleBiopsyOfMuscle = DocumentTypeValueSetCode("69226-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForNeedleBiopsyOfOvary = DocumentTypeValueSetCode("46369-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForNeedleBiopsyOfPancreas = DocumentTypeValueSetCode("42290-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MRIGuidanceForNeedleBiopsyOfPancreas = DocumentTypeValueSetCode("69199-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForNeedleBiopsyOfPancreas = DocumentTypeValueSetCode("69289-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForNeedleBiopsyOfPancreas = DocumentTypeValueSetCode("69126-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForNeedleBiopsyOfPelvis = DocumentTypeValueSetCode("46370-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MRIGuidanceForNeedleBiopsyOfPleura = DocumentTypeValueSetCode("69200-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForNeedleBiopsyOfPleura = DocumentTypeValueSetCode("69227-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForNeedleBiopsyOfProstate = DocumentTypeValueSetCode("46288-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForNeedleBiopsyOfProstate = DocumentTypeValueSetCode("69228-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForNeedleBiopsyOfSalivaryGland = DocumentTypeValueSetCode("69100-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MRIGuidanceForNeedleBiopsyOfSalivaryGland = DocumentTypeValueSetCode("69201-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForNeedleBiopsyOfSalivaryGland = DocumentTypeValueSetCode("69291-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForNeedleBiopsyOfSalivaryGland = DocumentTypeValueSetCode(
        "69128-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForNeedleBiopsyOfSoftBone = DocumentTypeValueSetCode("43571-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForNeedleBiopsyOfSpinalCord = DocumentTypeValueSetCode("69401-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForNeedleBiopsyOfSpleen = DocumentTypeValueSetCode("38030-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForNeedleBiopsyOfSuperficialBone = DocumentTypeValueSetCode("42266-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForNeedleBiopsyOfThyroid = DocumentTypeValueSetCode("69101-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MRIGuidanceForNeedleBiopsyOfThyroid = DocumentTypeValueSetCode("69202-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForNeedleBiopsyOfThyroid = DocumentTypeValueSetCode("38031-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForNeedleBiopsyOfThyroid = DocumentTypeValueSetCode("69129-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForNeedleBiopsyOfUnspecifiedBodyRegion = DocumentTypeValueSetCode(
        "46287-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForNeedleBiopsyOfUnspecifiedBodyRegion = DocumentTypeValueSetCode(
        "30700-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForNeedleBiopsyOfLiver_WContrastIV = DocumentTypeValueSetCode(
        "44225-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForTransjugularBiopsyOfLiver_WContrastIV = (
        DocumentTypeValueSetCode("24718-9")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForBiopsyOfChest_WAndWOContrastIV = DocumentTypeValueSetCode("35910-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForBiopsyOfUnspecifiedBodyRegion_WAndWOContrastIV = (
        DocumentTypeValueSetCode("46289-5")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForBiopsyOfChest_WContrastIV = DocumentTypeValueSetCode("35909-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForBiopsyOfPelvis_WContrastIV = DocumentTypeValueSetCode("69093-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForBiopsyOfUnspecifiedBodyRegion_WContrastIV = DocumentTypeValueSetCode(
        "42260-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SPECTGuidanceForBiopsyOfBone = DocumentTypeValueSetCode("46366-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SPECTGuidanceForBiopsyOfSuperficialBone = DocumentTypeValueSetCode("46384-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForBiopsyOfAbdomen_WOContrast = DocumentTypeValueSetCode("69083-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForBiopsyOfChest_WOContrast = DocumentTypeValueSetCode("35911-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForBiopsyOfLiver_WOContrast = DocumentTypeValueSetCode("69092-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForBiopsyOfPelvis_WOContrast = DocumentTypeValueSetCode("69094-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForBiopsyOfUnspecifiedBodyRegion_WOContrast = DocumentTypeValueSetCode(
        "46290-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForBronchoscopyOfChest = DocumentTypeValueSetCode("35889-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForCatheterizationOfFallopianTube_Left_Transcervical = (
        DocumentTypeValueSetCode("64998-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForCatheterizationOfFallopianTube_right_Transcervical = (
        DocumentTypeValueSetCode("64999-6")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForCatheterizationOfFallopianTubes_Transcervical = (
        DocumentTypeValueSetCode("30818-9")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForCatheterizationOfBiliaryDuctsAndPancreaticDuct_WContrastRetrograde = DocumentTypeValueSetCode(
        "30892-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopicAngiogramGuidanceForChangeOfCentralCatheterInCentralVein_WContrastIV = (
        DocumentTypeValueSetCode("24624-9")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopicAngiogramGuidanceForChangeOfCentralCatheterInCentralVein_Bilateral_WContrastIV = DocumentTypeValueSetCode(
        "26331-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopicAngiogramGuidanceForChangeOfCentralCatheterInCentralVein_Left_WContrastIV = DocumentTypeValueSetCode(
        "26332-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopicAngiogramGuidanceForChangeOfCentralCatheterInCentralVein_Right_WContrastIV = DocumentTypeValueSetCode(
        "26333-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForChangeOfDialysisCatheterInUnspecifiedBodyRegion_WContrastIV = DocumentTypeValueSetCode(
        "43558-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForChangeOfNephrostomyTubeInKidney = DocumentTypeValueSetCode("36769-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForChangeOfPercutaneousNephrostomyTubeInKidney_Bilateral_WContrast = DocumentTypeValueSetCode(
        "24781-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    X_rayGuidanceForChangeOfPercutaneousTubeInUnspecifiedBodyRegion_WContrast = (
        DocumentTypeValueSetCode("46371-1")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForChangeOfTubeInSinusTract_WContrast = DocumentTypeValueSetCode(
        "30646-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForChorionicVillusSampling = DocumentTypeValueSetCode("69400-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForCordocentesis = DocumentTypeValueSetCode("69391-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForCSFAspirationOfSpine = DocumentTypeValueSetCode("38127-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForCSFAspirationOfSpineCervical = DocumentTypeValueSetCode("70915-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForCSFAspirationOfSpineLumbar = DocumentTypeValueSetCode("70916-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForCSFAspirationOfSpineThoracic = DocumentTypeValueSetCode("70917-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForDilationOfEsophagus = DocumentTypeValueSetCode("24680-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForDrainageOfAbdomen = DocumentTypeValueSetCode("35913-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForDrainageOfAbdomenRetroperitoneum = DocumentTypeValueSetCode("42287-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForDrainageOfAbdomenRetroperitoneum = DocumentTypeValueSetCode("41809-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForDrainageOfAnus = DocumentTypeValueSetCode("35914-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForDrainageOfAppendix = DocumentTypeValueSetCode("35915-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForDrainageOfBiliaryDuctsAndGallbladder = DocumentTypeValueSetCode(
        "36770-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForDrainageOfChest = DocumentTypeValueSetCode("35916-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForDrainageOfChest = DocumentTypeValueSetCode("69078-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForDrainageOfExtremity = DocumentTypeValueSetCode("24692-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForDrainageOfExtremity_Bilateral = DocumentTypeValueSetCode("26325-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForDrainageOfExtremity_Left = DocumentTypeValueSetCode("26326-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForDrainageOfExtremity_Right = DocumentTypeValueSetCode("26327-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForDrainageOfGallbladder = DocumentTypeValueSetCode("35917-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForDrainageOfHip = DocumentTypeValueSetCode("69133-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForDrainageOfKidney = DocumentTypeValueSetCode("35918-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForDrainageOfKidney = DocumentTypeValueSetCode("24896-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForDrainageOfKidney_Bilateral = DocumentTypeValueSetCode("26328-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForDrainageOfKidney_Left = DocumentTypeValueSetCode("26329-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForDrainageOfKidney_Right = DocumentTypeValueSetCode("26330-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForDrainageOfLiver = DocumentTypeValueSetCode("35919-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForDrainageOfLymphNode = DocumentTypeValueSetCode("35920-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForDrainageOfPancreas = DocumentTypeValueSetCode("42283-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForDrainageOfPancreas = DocumentTypeValueSetCode("44172-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForDrainageOfPelvis = DocumentTypeValueSetCode("35921-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForDrainageOfPelvis = DocumentTypeValueSetCode("24868-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForDrainageOfPharynx = DocumentTypeValueSetCode("41800-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForDrainageOfProstate = DocumentTypeValueSetCode("41798-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForDrainageOfUnspecifiedBodyRegion = DocumentTypeValueSetCode("35922-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForDrainageOfUnspecifiedBodyRegion = DocumentTypeValueSetCode("30699-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForDrainageOfUnspecifiedBodyRegion = DocumentTypeValueSetCode(
        "43537-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForDrainageOfCystOfKidney = DocumentTypeValueSetCode("42478-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForDrainageOfUnspecifiedBodyRegion_WAndWOContrastIV = (
        DocumentTypeValueSetCode("46291-1")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForDrainageOfChest_WContrastIV = DocumentTypeValueSetCode("35923-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForDrainageOfUnspecifiedBodyRegion_WContrastIV = DocumentTypeValueSetCode(
        "46292-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForDrainageOfChest_WOContrast = DocumentTypeValueSetCode("35924-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForDrainageOfUnspecifiedBodyRegion_WOContrast = DocumentTypeValueSetCode(
        "46293-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForEndoscopyOfStomach = DocumentTypeValueSetCode("35925-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForEndoscopyOfBiliaryDuctsAndPancreaticDuct_1_5HoursPostContrastRetrograde = DocumentTypeValueSetCode(
        "43478-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForEndoscopyOfBiliaryDuctsAndPancreaticDuct_15MinutesPostContrastRetrograde = DocumentTypeValueSetCode(
        "43474-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForEndoscopyOfBiliaryDuctsAndPancreaticDuct_1HourPostContrastRetrograde = DocumentTypeValueSetCode(
        "43477-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForEndoscopyOfBiliaryDuctsAndPancreaticDuct_2HoursPostContrastRetrograde = DocumentTypeValueSetCode(
        "43473-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForEndoscopyOfBiliaryDuctsAndPancreaticDuct_30MinutesPostContrastRetrograde = DocumentTypeValueSetCode(
        "43475-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForEndoscopyOfBiliaryDuctsAndPancreaticDuct_45MinutesPostContrastRetrograde = DocumentTypeValueSetCode(
        "43476-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenMRCPWithAndWithoutContrastIV = DocumentTypeValueSetCode("72248-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForEndoscopyOfBiliaryDucts_WContrastRetrograde = (
        DocumentTypeValueSetCode("44214-5")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForEndoscopyOfBiliaryDuctsAndPancreaticDuct_WContrastRetrograde = DocumentTypeValueSetCode(
        "30815-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForEndoscopyOfPancreaticDuct_WContrastRetrograde = (
        DocumentTypeValueSetCode("44213-7")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenMRCPWOContrast = DocumentTypeValueSetCode("58740-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForFacetJointDenervationOfSpineCervical = (
        DocumentTypeValueSetCode("72541-6")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForFacetJointDenervationOfSpineLumbar = DocumentTypeValueSetCode(
        "72542-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForFacetJointDenervationOfSpine = DocumentTypeValueSetCode(
        "72540-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForGastrostomyOfStomach = DocumentTypeValueSetCode("35926-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForInjectionOfHip = DocumentTypeValueSetCode("30638-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForInjectionOfJointSpace = DocumentTypeValueSetCode("24769-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForInjectionOfMammaryArtery_internal_Left = (
        DocumentTypeValueSetCode("42334-3")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForInjectionOfPleuralSpace = DocumentTypeValueSetCode("42706-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForInjectionOfSacroiliacJoint = DocumentTypeValueSetCode("24901-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForInjectionOfSacroiliacJoint = DocumentTypeValueSetCode(
        "35927-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForInjectionOfSacroiliacJoint_Bilateral = DocumentTypeValueSetCode(
        "26319-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForInjectionOfSacroiliacJoint_Left = DocumentTypeValueSetCode("26320-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForInjectionOfSacroiliacJoint_Right = DocumentTypeValueSetCode("26321-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForInjectionOfSalivaryGland_Bilateral = DocumentTypeValueSetCode(
        "48435-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForInjectionOfSinuses = DocumentTypeValueSetCode("46392-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForInjectionOfSpine = DocumentTypeValueSetCode("37427-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForInjectionOfSpineFacetJoint = DocumentTypeValueSetCode("30579-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForInjectionOfSpineFacetJoint = DocumentTypeValueSetCode(
        "24931-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForInjectionOfSpineFacetJoint_Bilateral = (
        DocumentTypeValueSetCode("26322-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForInjectionOfSpineFacetJoint_Left = DocumentTypeValueSetCode(
        "26323-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForInjectionOfSpineFacetJoint_Right = DocumentTypeValueSetCode(
        "26324-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForInjectionOfSpineCervical = DocumentTypeValueSetCode("70918-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForInjectionOfSpineCervicalFacetJoint = DocumentTypeValueSetCode(
        "30812-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForInjectionOfSpine_disc_cervical = DocumentTypeValueSetCode("37493-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForInjectionOfSpineLumbar = DocumentTypeValueSetCode("70919-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForInjectionOfSpineLumbarFacetJoint = DocumentTypeValueSetCode(
        "30817-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForInjectionOfSpineThoracic = DocumentTypeValueSetCode("70920-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForInjectionOfSpineThoracicFacetJoint = DocumentTypeValueSetCode(
        "30814-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForInjectionOfThyroid = DocumentTypeValueSetCode("30702-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForInjectionOfJoint = DocumentTypeValueSetCode("72530-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForInjectionOfJoint = DocumentTypeValueSetCode("36771-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForInjectionOfTendon = DocumentTypeValueSetCode("37494-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForInjectionOfSclerosingAgentOfExtremityVein_Bilateral = (
        DocumentTypeValueSetCode("72537-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForInjectionOfSclerosingAgentOfExtremityVein_Left = (
        DocumentTypeValueSetCode("72645-5")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForInjectionOfSclerosingAgentOfExtremityVein_Right = (
        DocumentTypeValueSetCode("72644-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForInjectionOfSclerosingAgentOfExtremityVeins_Bilateral = (
        DocumentTypeValueSetCode("72536-6")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForInjectionOfSclerosingAgentOfExtremityVeins_Left = (
        DocumentTypeValueSetCode("72643-0")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForInjectionOfSclerosingAgentOfExtremityVeins_Right = (
        DocumentTypeValueSetCode("72642-2")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForIntercostalNerveDevervationOfSpineThoracic = (
        DocumentTypeValueSetCode("72543-2")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForKyphoplastyOfSpineLumbar = DocumentTypeValueSetCode("72552-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForKyphoplastyOfSpineThoracic = DocumentTypeValueSetCode(
        "72553-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForLaserAblationOfVein_s_OfExtremityVein_Left = DocumentTypeValueSetCode(
        "72535-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForLaserAblationOfVein_s_OfExtremityVein_Right = DocumentTypeValueSetCode(
        "72534-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MammogramGuidanceForLocalizationOfBreast = DocumentTypeValueSetCode("48735-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForLocalizationOfBreast_Bilateral = DocumentTypeValueSetCode("43759-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForLocalizationOfBreast_Left = DocumentTypeValueSetCode("35928-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MammogramGuidanceForLocalizationOfBreast_Left = DocumentTypeValueSetCode("42296-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForLocalizationOfBreast_Left = DocumentTypeValueSetCode("43758-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForLocalizationOfBreast_Right = DocumentTypeValueSetCode("35929-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MammogramGuidanceForLocalizationOfBreast_Right = DocumentTypeValueSetCode("42297-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForLocalizationOfBreast_Right = DocumentTypeValueSetCode("43760-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForLocalizationOfForeignBodyOfEye = DocumentTypeValueSetCode("37608-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForLocalizationOfPlacentaOfUterus = DocumentTypeValueSetCode("42701-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScanGuidanceForLocalizationOfTumorLimited = DocumentTypeValueSetCode("39760-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SPECTGuidanceForLocalizationOfTumorLimited = DocumentTypeValueSetCode("39759-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScanGuidanceForLocalizationOfTumorLimited_WTc_99mSestamibiIV = (
        DocumentTypeValueSetCode("39761-2")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScanGuidanceForLocalizationOfTumorMultipleAreas = DocumentTypeValueSetCode(
        "39953-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScanGuidanceForLocalizationOfTumor = DocumentTypeValueSetCode("39763-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SPECTGuidanceForLocalizationOfTumor = DocumentTypeValueSetCode("39762-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScanGuidanceForLocalizationOfTumorOfBreast = DocumentTypeValueSetCode("39758-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForNeedleLocalizationOfBreast = DocumentTypeValueSetCode("44110-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForNeedleLocalizationOfBreast = DocumentTypeValueSetCode("24600-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MammogramGuidanceForNeedleLocalizationOfBreast_Bilateral = DocumentTypeValueSetCode(
        "69068-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForNeedleLocalizationOfBreast_Bilateral = DocumentTypeValueSetCode(
        "26313-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForNeedleLocalizationOfBreast_Left = DocumentTypeValueSetCode("26314-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForNeedleLocalizationOfBreast_Right = DocumentTypeValueSetCode("26318-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForNeedleLocalizationOfChest = DocumentTypeValueSetCode("37921-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForNeedleLocalizationOfSpineCervical = DocumentTypeValueSetCode("42021-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForNeedleLocalizationOfSpineLumbar = DocumentTypeValueSetCode("42020-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForNeedleLocalizationOfUnspecifiedBodyRegion = DocumentTypeValueSetCode(
        "39026-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MRIGuidanceForNeedleLocalizationOfUnspecifiedBodyRegion = DocumentTypeValueSetCode(
        "39028-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForNeedleLocalizationOfUnspecifiedBodyRegion = DocumentTypeValueSetCode(
        "38032-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForNeedleLocalizationOfUnspecifiedBodyRegion = (
        DocumentTypeValueSetCode("39027-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MammogramGuidanceForNeedleLocalizationOfMassOfBreast = DocumentTypeValueSetCode(
        "24595-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MammogramGuidanceForNeedleLocalizationOfMassOfBreast_Bilateral = (
        DocumentTypeValueSetCode("26315-2")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MammogramGuidanceForNeedleLocalizationOfMassOfBreast_Left = (
        DocumentTypeValueSetCode("26316-0")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MammogramGuidanceForNeedleLocalizationOfMassOfBreast_Right = (
        DocumentTypeValueSetCode("26317-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForNeedleLocalizationOfBreast_WAndWOContrastIV = DocumentTypeValueSetCode(
        "44118-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForNerveBlockOfAbdomen = DocumentTypeValueSetCode("35930-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForNerveBlockOfPelvis = DocumentTypeValueSetCode("35931-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForNerveBlockOfSpineCervical = DocumentTypeValueSetCode("70921-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForNerveBlockOfSpineLumbar = DocumentTypeValueSetCode("35932-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForNerveBlockOfSpineThoracic = DocumentTypeValueSetCode("70922-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForPercutaneousBiopsyOfAbdomen = DocumentTypeValueSetCode(
        "69240-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForPercutaneousBiopsyOfMuscle = DocumentTypeValueSetCode("42139-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MammogramGuidanceForCoreNeedlePercutaneousBiopsyOfBreast = DocumentTypeValueSetCode(
        "24609-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MammogramGuidanceForCoreNeedlePercutaneousBiopsyOfBreast_Bilateral = (
        DocumentTypeValueSetCode("26334-3")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MammogramGuidanceForCoreNeedlePercutaneousBiopsyOfBreast_Left = (
        DocumentTypeValueSetCode("26335-0")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForCoreNeedlePercutaneousBiopsyOfBreast_Left = DocumentTypeValueSetCode(
        "38023-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MammogramGuidanceForCoreNeedlePercutaneousBiopsyOfBreast_Right = (
        DocumentTypeValueSetCode("26336-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForCoreNeedlePercutaneousBiopsyOfBreast_Right = DocumentTypeValueSetCode(
        "38025-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MammogramGuidanceForPercutaneousNeedleBiopsyOfBreast = DocumentTypeValueSetCode(
        "44121-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForPercutaneousNeedleBiopsyOfKidney = DocumentTypeValueSetCode(
        "69245-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForPercutaneousNeedleBiopsyOfLiver = DocumentTypeValueSetCode(
        "69246-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForPercutaneousNeedleBiopsyOfLung = DocumentTypeValueSetCode(
        "44204-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForPercutaneousNeedleBiopsyOfSalivaryGland = (
        DocumentTypeValueSetCode("69247-5")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForPercutaneousDrainageOfBiliaryDucts = DocumentTypeValueSetCode(
        "46372-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForPercutaneousDrainageOfCavity = DocumentTypeValueSetCode("62494-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForPercutaneousDrainageOfCavity = DocumentTypeValueSetCode(
        "24621-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForPercutaneousDrainageOfAbscessOfAbdomen = (
        DocumentTypeValueSetCode("69241-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForPercutaneousDrainageOfAbscessOfAppendix = (
        DocumentTypeValueSetCode("69242-6")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForPercutaneousDrainageOfAbscessOfBreast = (
        DocumentTypeValueSetCode("42422-6")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForPercutaneousDrainageOfAbscessOfCavity = DocumentTypeValueSetCode(
        "43444-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForPercutaneousDrainageOfAbscessOfChest = (
        DocumentTypeValueSetCode("42423-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForPercutaneousDrainageOfAbscessOfLung = (
        DocumentTypeValueSetCode("69243-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForPercutaneousDrainageOfAbscessOfOvary = (
        DocumentTypeValueSetCode("44223-6")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForPercutaneousDrainageOfAbscessOfPelvis = (
        DocumentTypeValueSetCode("69244-2")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForPercutaneousDrainageOfAbscessOfUnspecifiedBodyRegion = (
        DocumentTypeValueSetCode("42421-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForPercutaneousVertebroplastyOfSpine = DocumentTypeValueSetCode("35933-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForPercutaneousVertebroplastyOfSpine = DocumentTypeValueSetCode(
        "35936-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForPercutaneousVertebroplastyOfSpineCervical = (
        DocumentTypeValueSetCode("70923-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForPercutaneousVertebroplastyOfSpineLumbar = DocumentTypeValueSetCode(
        "35934-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForPercutaneousVertebroplastyOfSpineLumbar = (
        DocumentTypeValueSetCode("70924-6")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForPercutaneousVertebroplastyOfSpineThoracic = DocumentTypeValueSetCode(
        "35935-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForPercutaneousVertebroplastyOfSpineThoracic = (
        DocumentTypeValueSetCode("70925-3")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForPeripheralNerveDenervationOfUnspecifiedBodyRegion = (
        DocumentTypeValueSetCode("72539-0")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForPlacementOfCatheterInCentralVein = DocumentTypeValueSetCode("30643-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForPlacementOfCatheterInUnspecifiedBodyRegion = (
        DocumentTypeValueSetCode("35912-5")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopicAngiogramGuidanceForPlacementOfCatheterForAdminstrationOfThrombolyticInVessel = DocumentTypeValueSetCode(
        "25028-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopicAngiogramGuidanceForPlacementOfCatheterForVasoconstrictorInfusionInVessels = DocumentTypeValueSetCode(
        "25029-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopicAngiogramGuidanceForPlacementOfCatheterInArteryInCentralCardiovascularArtery = DocumentTypeValueSetCode(
        "24613-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForPlacementOfCatheterInCentralVein_Tunneled = DocumentTypeValueSetCode(
        "30644-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopicAngiogramGuidanceForPlacementOfCatheterInHepaticArtery_WContrastIA = (
        DocumentTypeValueSetCode("25077-9")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopicAngiogramGuidanceForPlacementOfCatheterInCentralVein_WContrastIV = (
        DocumentTypeValueSetCode("24625-6")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopicAngiogramGuidanceForPlacementOfCatheterInCentralVein_Bilateral_WContrastIV = DocumentTypeValueSetCode(
        "26310-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopicAngiogramGuidanceForPlacementOfCatheterInCentralVein_Left_WContrastIV = DocumentTypeValueSetCode(
        "26311-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopicAngiogramGuidanceForPlacementOfCatheterInCentralVein_Right_WContrastIV = DocumentTypeValueSetCode(
        "26312-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopicAngiogramGuidanceForPlacementOfCatheterInPortalVein_WContrastIV = (
        DocumentTypeValueSetCode("41801-2")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForPlacementOfDecompressionTubeInGastrointestine = (
        DocumentTypeValueSetCode("24716-3")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopicAngiogramGuidanceForPlacementOfIlio_iliacTubeEndoprosthesisInIliacArtery_Left_WContrastIA = DocumentTypeValueSetCode(
        "62491-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopicAngiogramGuidanceForPlacementOfIlio_iliacTubeEndoprosthesisInIliacArtery_Right_WContrastIA = DocumentTypeValueSetCode(
        "62492-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GuidanceForPlacementOfInfusionPortInUnspecifiedBodyRegion = (
        DocumentTypeValueSetCode("25072-0")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopicAngiogramGuidanceForPlacementOfIntraperitonealCatheterInAbdomen = (
        DocumentTypeValueSetCode("62450-2")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopicAngiogramGuidanceForPlacementOfIVCFilterInInferiorVenaCava_WContrastIV = DocumentTypeValueSetCode(
        "25026-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GuidanceForPlacementOfLargeBoreCatheterIntoVesselInCentralVein = (
        DocumentTypeValueSetCode("25027-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GuidanceForPlacementOfLargeBoreCatheterIntoVesselInCentralVein_Bilateral = (
        DocumentTypeValueSetCode("26307-9")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GuidanceForPlacementOfLargeBoreCatheterIntoVesselInCentralVein_Left = (
        DocumentTypeValueSetCode("26308-7")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GuidanceForPlacementOfLargeBoreCatheterIntoVesselInCentralVein_Right = (
        DocumentTypeValueSetCode("26309-5")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopicAngiogramGuidanceForPlacementOfLongtermPeripheralCatheterInCentralVein = DocumentTypeValueSetCode(
        "25024-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopicAngiogramGuidanceForPlacementOfLongtermPeripheralCatheterInCentralVein_Bilateral = DocumentTypeValueSetCode(
        "26304-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopicAngiogramGuidanceForPlacementOfLongtermPeripheralCatheterInCentralVein_Left = DocumentTypeValueSetCode(
        "26305-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopicAngiogramGuidanceForPlacementOfLongtermPeripheralCatheterInCentralVein_Right = DocumentTypeValueSetCode(
        "26306-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForPlacementOfNeedleInUnspecifiedBodyRegion = DocumentTypeValueSetCode(
        "64993-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForPlacementOfNeedleWireInBreast = DocumentTypeValueSetCode("42456-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForPlacementOfNephrostomyTubeInKidney = DocumentTypeValueSetCode(
        "36772-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForPlacementOfPercutaneousNephrostomyInKidney_Bilateral_WContrastViaTube = DocumentTypeValueSetCode(
        "24779-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForPlacementOfPercutaneousNephroureteralStentInKidney_Bilateral = DocumentTypeValueSetCode(
        "24782-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForPlacementOfRadiationTherapyFieldsInUnspecifiedBodyRegion = (
        DocumentTypeValueSetCode("35937-2")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForPlacementOfRadiationTherapyFieldsInUnspecifiedBodyRegion = (
        DocumentTypeValueSetCode("43487-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopicAngiogramGuidanceForPlacementOfStentInArtery_Left = (
        DocumentTypeValueSetCode("65797-3")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopicAngiogramGuidanceForPlacementOfStentInArtery_Right = (
        DocumentTypeValueSetCode("65798-1")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopicAngiogramGuidanceForPlacementOfStentInIliacArtery = (
        DocumentTypeValueSetCode("69134-5")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForPlacementOfStentInIntrahepaticPortalSystem = (
        DocumentTypeValueSetCode("25078-7")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopicAngiogramGuidanceForPlacementOfStentInVein = DocumentTypeValueSetCode(
        "24756-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopicAngiogramGuidanceForPlacementOfStentInVein_Bilateral = (
        DocumentTypeValueSetCode("26301-2")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopicAngiogramGuidanceForPlacementOfStentInVein_Left = (
        DocumentTypeValueSetCode("26302-0")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopicAngiogramGuidanceForPlacementOfStentInVein_Right = (
        DocumentTypeValueSetCode("26303-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopicAngiogramGuidanceForPlacementOfStentInArtery = DocumentTypeValueSetCode(
        "24555-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopicAngiogramGuidanceForPlacementOfTransjugularIntrahepaticPortosystemicShuntInPortalVeinAndHepaticVein = DocumentTypeValueSetCode(
        "51391-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForPlacementOfTubeInChest = DocumentTypeValueSetCode("35938-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForPlacementOfTubeInChest = DocumentTypeValueSetCode("42140-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForPlacementOfTubeInChest = DocumentTypeValueSetCode("39362-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForPlacementOfTubeInGastrointestine = DocumentTypeValueSetCode(
        "30637-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForPlacementOfTubeInLiver = DocumentTypeValueSetCode("41799-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForPlacementOfTubeInStomach = DocumentTypeValueSetCode("24995-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForPlacementOfTubeInUnspecifiedBodyRegion = (
        DocumentTypeValueSetCode("44224-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SPECTGuidanceForPlacementOfTubeInChest = DocumentTypeValueSetCode("46373-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForProcedureOfJointSpace = DocumentTypeValueSetCode("44102-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForProcedureOfJointSpace = DocumentTypeValueSetCode("44222-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForProcedureOfUnspecifiedBodyRegion = DocumentTypeValueSetCode(
        "30629-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForRadiationTreatmentOfUnspecifiedBodyRegion_WContrastIV = (
        DocumentTypeValueSetCode("30581-3")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MRIGuidanceForRadiationTreatmentOfUnspecifiedBodyRegion_WContrastIV = (
        DocumentTypeValueSetCode("30664-7")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForRadiationTreatmentOfUnspecifiedBodyRegion_WOContrast = (
        DocumentTypeValueSetCode("30582-1")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MRIGuidanceForRadiationTreatmentOfUnspecifiedBodyRegion_WOContrast = (
        DocumentTypeValueSetCode("30665-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForRadiosurgeryOfUnspecifiedBodyRegion = DocumentTypeValueSetCode(
        "25053-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForRadiosurgeryOfUnspecifiedBodyRegion_WContrastIV = (
        DocumentTypeValueSetCode("25054-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForRemovalOfAmnioticFluidFromUterus = DocumentTypeValueSetCode("24537-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForRemovalOfCatheterFromCentralVein_Tunneled = DocumentTypeValueSetCode(
        "42141-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForRemovalOfCatheterFromCentralVein_Tunneled = (
        DocumentTypeValueSetCode("72549-9")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopicAngiogramGuidanceForRemovalOfCatheterFromCentralVein_WContrastIV = (
        DocumentTypeValueSetCode("72548-1")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForRemovalOfCVADeviceObstructionFromCentralVein = (
        DocumentTypeValueSetCode("72547-3")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForRemovalOfCVALumenObstructionFromCentralVein = (
        DocumentTypeValueSetCode("72546-5")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForRemovalOfFluidFromAbdomen = DocumentTypeValueSetCode("41810-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForRemovalOfFluidFromAbdomen = DocumentTypeValueSetCode("24559-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForRemovalOfFluidFromChest = DocumentTypeValueSetCode("38142-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForRemovalOfForeignBodyFromUnspecifiedBodyRegion = (
        DocumentTypeValueSetCode("30628-2")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopicAngiogramGuidanceForRemovalOfLongtermPeripheralCatheterFromCentralVein = DocumentTypeValueSetCode(
        "72538-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForRemovalOfPercutaneousNephrostomyTubeFromKidney_Bilateral_WContrast = DocumentTypeValueSetCode(
        "72544-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForRepairOfPseudoaneurysm_AVFistula = DocumentTypeValueSetCode("24885-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForRepairOfCVACatheterWithPortOrPumpOfCentralVein = (
        DocumentTypeValueSetCode("72550-7")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForRepairOfCVACatheterWithoutPortOrPumpOfCentralVein = (
        DocumentTypeValueSetCode("72551-5")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForReplacementOfPercutaneousCholecystostomyInAbdomen = (
        DocumentTypeValueSetCode("42017-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForReplacementOfPercutaneousDrainageTubeInAbdomen = (
        DocumentTypeValueSetCode("52790-3")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForReplacementOfPercutaneousDrainageTubeInBiliaryDuctsAndGallbladder = DocumentTypeValueSetCode(
        "72545-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidanceForReplacementOfPercutaneousDrainageTubeInPelvis = (
        DocumentTypeValueSetCode("52791-1")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForReplacementOfPercutaneousDrainageTubeInStomach = (
        DocumentTypeValueSetCode("46294-5")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForReplacementOfPercutaneousGastrostomyInStomach = (
        DocumentTypeValueSetCode("24996-1")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopicAngiogramGuidanceForRepositionOfCatheterInCentralVein_WContrastIV = (
        DocumentTypeValueSetCode("24626-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopicAngiogramGuidanceForRepositionOfCatheterInCentralVein_Bilateral_WContrastIV = DocumentTypeValueSetCode(
        "26295-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopicAngiogramGuidanceForRepositionOfCatheterInCentralVein_Left_WContrastIV = DocumentTypeValueSetCode(
        "26296-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopicAngiogramGuidanceForRepositionOfCatheterInCentralVein_Right_WContrastIV = DocumentTypeValueSetCode(
        "26297-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MammogramGuidanceForSentinelLymphNodeInjectionOfBreast = DocumentTypeValueSetCode(
        "48740-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MammogramGuidanceForSentinelLymphNodeInjectionOfBreast_Left = (
        DocumentTypeValueSetCode("48736-3")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MammogramGuidanceForSentinelLymphNodeInjectionOfBreast_Right = (
        DocumentTypeValueSetCode("48739-7")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForStoneRemovalOfBiliaryDuctCommon_WContrastIntraBiliaryDuct = (
        DocumentTypeValueSetCode("24570-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopicAngiogramGuidanceForThrombectomyOfVein_WContrastIV = (
        DocumentTypeValueSetCode("43763-2")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopicAngiogramGuidanceForThrombectomyOfVein_Bilateral_WContrastIV = (
        DocumentTypeValueSetCode("43761-6")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopicAngiogramGuidanceForThrombectomyOfVein_Left_WContrastIV = (
        DocumentTypeValueSetCode("43762-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopicAngiogramGuidanceForThrombectomyOfVein_Right_WContrastIV = (
        DocumentTypeValueSetCode("43764-0")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopyGuidanceForTriggerPointInjectionOfMuscle = DocumentTypeValueSetCode(
        "72554-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FluoroscopicAngiogramGuidanceForVascularAccessOfVessel = DocumentTypeValueSetCode(
        "39138-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USGuidanceForVascularAccessOfUnspecifiedBodyRegion = DocumentTypeValueSetCode(
        "39139-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MRIGuidance_stereotacticForBiopsyOfBrain = DocumentTypeValueSetCode("36936-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MammogramGuidance_stereotacticForBiopsyOfBreast = DocumentTypeValueSetCode(
        "24603-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MammogramGuidance_stereotacticForBiopsyOfBreast_Bilateral = (
        DocumentTypeValueSetCode("26292-3")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MammogramGuidance_stereotacticForBiopsyOfBreast_Left = DocumentTypeValueSetCode(
        "26293-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MammogramGuidance_stereotacticForBiopsyOfBreast_Right = DocumentTypeValueSetCode(
        "26294-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidance_stereotacticForBiopsyOfHead = DocumentTypeValueSetCode("36928-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MammogramGuidance_stereotacticForCoreNeedleBiopsyOfBreast = (
        DocumentTypeValueSetCode("46296-0")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MammogramGuidance_stereotacticForCoreNeedleBiopsyOfBreast_Left = (
        DocumentTypeValueSetCode("46295-2")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MammogramGuidance_stereotacticForCoreNeedleBiopsyOfBreast_Right = (
        DocumentTypeValueSetCode("42433-3")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MammogramGuidance_stereotacticForNeedleBiopsyOfBreast = DocumentTypeValueSetCode(
        "69160-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidance_stereotacticForBiopsyOfHead_WContrastIV = DocumentTypeValueSetCode(
        "24585-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTGuidance_stereotacticForBiopsyOfHead_WOContrast = DocumentTypeValueSetCode(
        "36929-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MRIGuidance_stereotacticForLocalizationInBrain_WAndWOContrastIV = (
        DocumentTypeValueSetCode("44122-0")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MRIGuidance_stereotacticForLocalizationInBrain_WContrastIV = (
        DocumentTypeValueSetCode("30656-3")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MRIGuidance_stereotacticForLocalizationInBrain_WOContrast = (
        DocumentTypeValueSetCode("30800-7")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeterophoriaStudy = DocumentTypeValueSetCode("28632-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HistoryOfMedicalDeviceUse = DocumentTypeValueSetCode("46264-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HistoryOfProceduresDocument = DocumentTypeValueSetCode("47519-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HIVTreatmentFormDocument = DocumentTypeValueSetCode("47245-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HomeHealthClaims = DocumentTypeValueSetCode("52035-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HomeHealthPriorAuthorization = DocumentTypeValueSetCode("52036-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HospitalBeds = DocumentTypeValueSetCode("52046-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HospitalConsultationsDocument = DocumentTypeValueSetCode("18841-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HysterectomyConsent = DocumentTypeValueSetCode("52028-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestFluoroscopyImageIntensifierDuringSurgery = DocumentTypeValueSetCode("24655-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ImmunosuppressiveDrugs = DocumentTypeValueSetCode("52047-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InhalationChallengeTestReportDocument_WMethacholineInhaled = (
        DocumentTypeValueSetCode("65806-2")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OccupationalTherapyInitialAssessmentNoteAtFirstEncounter = DocumentTypeValueSetCode(
        "11500-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PhysicalTherapyInitialAssessmentNoteAtFirstEncounter = DocumentTypeValueSetCode(
        "11495-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PhysicianInitialAssessmentNoteAtFirstEncounter = DocumentTypeValueSetCode("11494-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PodiatryInitialAssessmentNoteAtFirstEncounter = DocumentTypeValueSetCode("11496-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PsychologyInitialAssessmentNoteAtFirstEncounter = DocumentTypeValueSetCode(
        "11497-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SocialWorkInitialAssessmentNoteAtFirstEncounter = DocumentTypeValueSetCode(
        "11498-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    DentistInitialAssessmentNote = DocumentTypeValueSetCode("28572-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NursePractitionerInitialAssessmentNote = DocumentTypeValueSetCode("28621-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NurseInitialAssessmentNote = DocumentTypeValueSetCode("29753-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OccupationalTherapyInitialAssessmentNote = DocumentTypeValueSetCode("18734-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PhysicalTherapyInitialAssessmentNote = DocumentTypeValueSetCode("18735-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PhysicianInitialAssessmentNote = DocumentTypeValueSetCode("18736-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PhysicianAttendingInitialAssessmentNote = DocumentTypeValueSetCode("28654-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PhysicianConsultingInitialAssessmentNote = DocumentTypeValueSetCode("18763-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PodiatryInitialAssessmentNote = DocumentTypeValueSetCode("18737-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PsychiatryInitialAssessmentNote = DocumentTypeValueSetCode("28635-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PsychologyInitialAssessmentNote = DocumentTypeValueSetCode("18738-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SocialWorkInitialAssessmentNote = DocumentTypeValueSetCode("18739-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    IntracardiacAblationStudy = DocumentTypeValueSetCode("46214-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LaborAndDeliveryRecords = DocumentTypeValueSetCode("15508-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LaboratoryReport = DocumentTypeValueSetCode("11502-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    IlealConduitX_rayLoopogram = DocumentTypeValueSetCode("24717-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LymphedemaPumps = DocumentTypeValueSetCode("52048-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ManualWheelchair = DocumentTypeValueSetCode("52049-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MeasureDocument = DocumentTypeValueSetCode("55186-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MeasureSetDocument = DocumentTypeValueSetCode("55185-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MedicalRecords = DocumentTypeValueSetCode("11503-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MemberIDCardCopy = DocumentTypeValueSetCode("52037-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    DiaphragmUSMotion = DocumentTypeValueSetCode("24672-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    DiaphragmFluoroscopyMotion = DocumentTypeValueSetCode("30632-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MotorizedWheelchair = DocumentTypeValueSetCode("52050-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FetalMRI = DocumentTypeValueSetCode("35990-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenCT = DocumentTypeValueSetCode("41806-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenMRI = DocumentTypeValueSetCode("24556-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenUS = DocumentTypeValueSetCode("24558-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenX_rayTomograph = DocumentTypeValueSetCode("30762-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenRetroperitoneumCT = DocumentTypeValueSetCode("24566-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenRetroperitoneumUS = DocumentTypeValueSetCode("24531-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenRUQUS = DocumentTypeValueSetCode("24532-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenAndPelvisCT = DocumentTypeValueSetCode("44115-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdominalVeinsMRIAngiogram = DocumentTypeValueSetCode("36781-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdominalVeinsAndIVCMRIAngiogram = DocumentTypeValueSetCode("30864-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdominalVesselsMRIAngiogram = DocumentTypeValueSetCode("36791-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdominalVesselsUS_doppler = DocumentTypeValueSetCode("24534-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdominalWallUS = DocumentTypeValueSetCode("39494-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AdrenalGlandCT = DocumentTypeValueSetCode("36930-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AdrenalGlandMRI = DocumentTypeValueSetCode("36931-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AdrenalGlandUS = DocumentTypeValueSetCode("69277-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AdrenalVesselsMRIAngiogram = DocumentTypeValueSetCode("36792-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AnkleCT = DocumentTypeValueSetCode("35940-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AnkleMRI = DocumentTypeValueSetCode("24538-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AnkleX_rayTomograph = DocumentTypeValueSetCode("35939-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_BilateralCT = DocumentTypeValueSetCode("35941-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_BilateralMRI = DocumentTypeValueSetCode("26208-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_LeftCT = DocumentTypeValueSetCode("35942-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_LeftMRI = DocumentTypeValueSetCode("26209-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_LeftX_rayTomograph = DocumentTypeValueSetCode("35943-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_RightCT = DocumentTypeValueSetCode("35944-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_RightMRI = DocumentTypeValueSetCode("26210-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_RightX_rayTomograph = DocumentTypeValueSetCode("37674-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AnkleAndFootMRI = DocumentTypeValueSetCode("37222-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AnusUS = DocumentTypeValueSetCode("24542-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AortaCT = DocumentTypeValueSetCode("35945-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AortaMRI = DocumentTypeValueSetCode("35947-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AortaMRIAngiogram = DocumentTypeValueSetCode("35946-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AortaUS = DocumentTypeValueSetCode("24547-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AortaUS_doppler = DocumentTypeValueSetCode("46388-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AortaAbdominalCT = DocumentTypeValueSetCode("35948-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AortaAbdominalMRI = DocumentTypeValueSetCode("35949-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AortaAbdominalUS = DocumentTypeValueSetCode("69276-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Aorta_endograftCT = DocumentTypeValueSetCode("37216-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AortaThoracicCT = DocumentTypeValueSetCode("24544-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AortaThoracicMRI = DocumentTypeValueSetCode("35950-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AortaThoracicMRIAngiogram = DocumentTypeValueSetCode("24660-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdominalAortaAndArteriesMRIAngiogram = DocumentTypeValueSetCode("30863-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AorticArchMRIAngiogram = DocumentTypeValueSetCode("35951-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AorticArchAndNeckVesselsMRIAngiogram = DocumentTypeValueSetCode("30861-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AppendixCT = DocumentTypeValueSetCode("35952-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AppendixUS = DocumentTypeValueSetCode("24548-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AVFistulaUS = DocumentTypeValueSetCode("39040-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Axilla_LeftMRI = DocumentTypeValueSetCode("43508-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Axilla_LeftUS = DocumentTypeValueSetCode("72529-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Axilla_RightMRI = DocumentTypeValueSetCode("43510-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Axilla_RightUS = DocumentTypeValueSetCode("72528-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BiliaryDuctsMRI = DocumentTypeValueSetCode("37219-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BiliaryDuctsAndGallbladderUS = DocumentTypeValueSetCode("38021-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BiliaryDuctsAndPancreaticDuctMRI = DocumentTypeValueSetCode("37220-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrachiocephalicArteryUS_doppler = DocumentTypeValueSetCode("39039-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainMRI = DocumentTypeValueSetCode("24590-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainFunctionalMRI = DocumentTypeValueSetCode("58748-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainPET = DocumentTypeValueSetCode("44138-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainStemAndNerves_cranialMRI = DocumentTypeValueSetCode("37217-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Brain_temporalMRI = DocumentTypeValueSetCode("37218-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainAndInternalAuditoryCanalMRI = DocumentTypeValueSetCode("43772-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainAndPituitaryAndSellaTurcicaMRI = DocumentTypeValueSetCode("42385-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastMRI = DocumentTypeValueSetCode("30794-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastUS = DocumentTypeValueSetCode("24601-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastImplant_BilateralMRI = DocumentTypeValueSetCode("69165-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastImplant_LeftMRI = DocumentTypeValueSetCode("38057-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastImplant_RightMRI = DocumentTypeValueSetCode("38058-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastSpecimenUS = DocumentTypeValueSetCode("24596-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastVesselsUS_doppler = DocumentTypeValueSetCode("69397-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_BilateralMRI = DocumentTypeValueSetCode("30795-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_BilateralUS = DocumentTypeValueSetCode("26214-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_LeftMRI = DocumentTypeValueSetCode("35954-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_LeftUS = DocumentTypeValueSetCode("26215-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_RightMRI = DocumentTypeValueSetCode("35955-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_RightUS = DocumentTypeValueSetCode("26216-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_UnilateralMRI = DocumentTypeValueSetCode("46299-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CalcaneusCT = DocumentTypeValueSetCode("36010-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CalcaneusX_rayTomograph = DocumentTypeValueSetCode("36011-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CarotidArteryUS = DocumentTypeValueSetCode("24616-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CarotidArteryUS_doppler = DocumentTypeValueSetCode("42146-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CarotidArtery_BilateralUS = DocumentTypeValueSetCode("26217-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CarotidArtery_BilateralUS_doppler = DocumentTypeValueSetCode("43765-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CarotidArtery_LeftUS = DocumentTypeValueSetCode("26218-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CarotidArtery_LeftUS_doppler = DocumentTypeValueSetCode("39427-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CarotidArtery_RightUS = DocumentTypeValueSetCode("26219-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CarotidArtery_RightUS_doppler = DocumentTypeValueSetCode("39437-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CarotidArtery_UnilateralUS = DocumentTypeValueSetCode("43552-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CarotidVesselMRIAngiogram = DocumentTypeValueSetCode("36793-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CarotidVesselsAndNeckVesselsMRIAngiogram = DocumentTypeValueSetCode("30859-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CeliacVesselsAndSuperiorMesentericVesselsMRIAngiogram = DocumentTypeValueSetCode(
        "30865-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CerebralArteryUS = DocumentTypeValueSetCode("46374-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestCT = DocumentTypeValueSetCode("24627-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestMRI = DocumentTypeValueSetCode("24629-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestUS = DocumentTypeValueSetCode("24630-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayTomograph = DocumentTypeValueSetCode("24657-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestVesselsMRIAngiogram = DocumentTypeValueSetCode("30862-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestWallUS = DocumentTypeValueSetCode("38016-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CircleOfWillisMRIAngiogram = DocumentTypeValueSetCode("37235-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClavicleCT = DocumentTypeValueSetCode("35960-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClavicleMRI = DocumentTypeValueSetCode("35961-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClavicleX_rayTomograph = DocumentTypeValueSetCode("35959-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ColonCT = DocumentTypeValueSetCode("44120-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CoronaryArteriesCTFast = DocumentTypeValueSetCode("24757-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ElbowCT = DocumentTypeValueSetCode("35962-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ElbowMRI = DocumentTypeValueSetCode("24674-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ElbowX_rayTomograph = DocumentTypeValueSetCode("35963-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_BilateralCT = DocumentTypeValueSetCode("35965-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_BilateralMRI = DocumentTypeValueSetCode("26220-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_BilateralX_rayTomograph = DocumentTypeValueSetCode("35964-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_LeftCT = DocumentTypeValueSetCode("35966-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_LeftMRI = DocumentTypeValueSetCode("26221-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_LeftX_rayTomograph = DocumentTypeValueSetCode("35967-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_RightCT = DocumentTypeValueSetCode("35968-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_RightMRI = DocumentTypeValueSetCode("26222-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_RightX_rayTomograph = DocumentTypeValueSetCode("37688-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    EsophagusCT = DocumentTypeValueSetCode("35969-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    EsophagusPET = DocumentTypeValueSetCode("57823-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityCT = DocumentTypeValueSetCode("24690-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityMRI = DocumentTypeValueSetCode("69193-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityUS = DocumentTypeValueSetCode("24693-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityX_rayTomograph = DocumentTypeValueSetCode("35970-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityArteryUS_doppler = DocumentTypeValueSetCode("39042-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityArtery_BilateralUS_doppler = DocumentTypeValueSetCode("39031-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityArtery_LeftUS = DocumentTypeValueSetCode("69293-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityArtery_LeftUS_doppler = DocumentTypeValueSetCode("39428-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityArtery_RightUS = DocumentTypeValueSetCode("69297-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityArtery_RightUS_doppler = DocumentTypeValueSetCode("39439-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityVeinUS_doppler = DocumentTypeValueSetCode("39449-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityVein_BilateralUS_doppler = DocumentTypeValueSetCode("39418-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityVein_LeftUS = DocumentTypeValueSetCode("42145-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityVein_LeftUS_doppler = DocumentTypeValueSetCode("39429-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityVein_RightUS = DocumentTypeValueSetCode("42144-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityVein_RightUS_doppler = DocumentTypeValueSetCode("39440-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityVeinsMRIAngiogram = DocumentTypeValueSetCode("30876-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityVeins_BilateralUS_doppler = DocumentTypeValueSetCode("69283-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityVeins_LeftUS = DocumentTypeValueSetCode("41835-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityVeins_RightUS = DocumentTypeValueSetCode("41816-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityVesselsMRIAngiogram = DocumentTypeValueSetCode("36794-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityVesselsUS_doppler = DocumentTypeValueSetCode("43771-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityVessels_BilateralUS_doppler = DocumentTypeValueSetCode("39495-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityVesselsLeftUS_doppler = DocumentTypeValueSetCode("69398-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityVessels_RightUS_doppler = DocumentTypeValueSetCode("39503-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Extremity_BilateralCT = DocumentTypeValueSetCode("26224-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Extremity_BilateralUS = DocumentTypeValueSetCode("26223-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Extremity_LeftCT = DocumentTypeValueSetCode("26226-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Extremity_LeftUS = DocumentTypeValueSetCode("26225-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Extremity_RightCT = DocumentTypeValueSetCode("26231-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Extremity_RightUS = DocumentTypeValueSetCode("26230-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Eye_Orbit_BilateralUS = DocumentTypeValueSetCode("24853-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FaceMRI = DocumentTypeValueSetCode("35953-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FacialBonesAndMaxillaCT = DocumentTypeValueSetCode("41808-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FacialBonesAndSinusesCT = DocumentTypeValueSetCode("24696-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FemoralArteryAndPoplitealArteryUS = DocumentTypeValueSetCode("69389-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FemoralVeinAndPoplitealVeinUS = DocumentTypeValueSetCode("69399-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FemoralVesselsMRIAngiogram = DocumentTypeValueSetCode("30871-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FemoralVesselsUS = DocumentTypeValueSetCode("38134-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FemoralVessels_BilateralUS = DocumentTypeValueSetCode("38128-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FemoralVessels_LeftUS_doppler = DocumentTypeValueSetCode("39498-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FemoralVessels_RightUS_doppler = DocumentTypeValueSetCode("39504-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FemurCT = DocumentTypeValueSetCode("35984-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FemurX_rayTomograph = DocumentTypeValueSetCode("35985-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Femur_BilateralX_rayTomograph = DocumentTypeValueSetCode("35986-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Femur_LeftCT = DocumentTypeValueSetCode("35987-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Femur_LeftUS = DocumentTypeValueSetCode("38037-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Femur_LeftX_rayTomograph = DocumentTypeValueSetCode("35988-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Femur_RightCT = DocumentTypeValueSetCode("35989-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Femur_RightUS = DocumentTypeValueSetCode("38048-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Femur_RightX_rayTomograph = DocumentTypeValueSetCode("38768-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FingerMRI = DocumentTypeValueSetCode("24705-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Finger_BilateralMRI = DocumentTypeValueSetCode("26238-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Finger_LeftMRI = DocumentTypeValueSetCode("26239-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Finger_RightMRI = DocumentTypeValueSetCode("26240-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FistulaCT = DocumentTypeValueSetCode("37221-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FootCT = DocumentTypeValueSetCode("35991-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FootMRI = DocumentTypeValueSetCode("24707-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FootX_rayTomograph = DocumentTypeValueSetCode("35992-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FootVesselsMRIAngiogram = DocumentTypeValueSetCode("30872-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FootVesselsUS_doppler = DocumentTypeValueSetCode("46362-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_BilateralCT = DocumentTypeValueSetCode("35993-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_BilateralMRI = DocumentTypeValueSetCode("26241-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_LeftCT = DocumentTypeValueSetCode("35994-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_LeftMRI = DocumentTypeValueSetCode("26242-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_LeftX_rayTomograph = DocumentTypeValueSetCode("35995-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_RightCT = DocumentTypeValueSetCode("35996-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_RightMRI = DocumentTypeValueSetCode("26243-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_RightX_rayTomograph = DocumentTypeValueSetCode("37706-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ForearmCT = DocumentTypeValueSetCode("35997-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ForearmMRI = DocumentTypeValueSetCode("24710-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ForearmVesselsMRIAngiogram = DocumentTypeValueSetCode("30873-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Forearm_BilateralCT = DocumentTypeValueSetCode("35998-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Forearm_BilateralMRI = DocumentTypeValueSetCode("26244-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Forearm_LeftCT = DocumentTypeValueSetCode("35999-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Forearm_LeftMRI = DocumentTypeValueSetCode("26245-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Forearm_RightCT = DocumentTypeValueSetCode("36000-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Forearm_RightMRI = DocumentTypeValueSetCode("26246-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GallbladderUS = DocumentTypeValueSetCode("24711-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GallbladderX_rayTomograph = DocumentTypeValueSetCode("36001-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GastrointestineUS = DocumentTypeValueSetCode("39415-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GenitourinarySystemUS = DocumentTypeValueSetCode("39416-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GreatVesselMRI = DocumentTypeValueSetCode("37236-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GroinUS = DocumentTypeValueSetCode("24719-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HandCT = DocumentTypeValueSetCode("36002-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HandMRI = DocumentTypeValueSetCode("24720-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HandX_rayTomograph = DocumentTypeValueSetCode("36003-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HandVesselsUS_doppler = DocumentTypeValueSetCode("46382-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_BilateralCT = DocumentTypeValueSetCode("36004-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_BilateralMRI = DocumentTypeValueSetCode("26247-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_LeftCT = DocumentTypeValueSetCode("36005-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_LeftMRI = DocumentTypeValueSetCode("26248-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_LeftX_rayTomograph = DocumentTypeValueSetCode("36006-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_RightCT = DocumentTypeValueSetCode("36007-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_RightMRI = DocumentTypeValueSetCode("26249-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_RightX_rayTomograph = DocumentTypeValueSetCode("37717-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadCT = DocumentTypeValueSetCode("24725-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadCTCine = DocumentTypeValueSetCode("24728-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadUS = DocumentTypeValueSetCode("24731-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadToThighPET = DocumentTypeValueSetCode("58741-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadVeinsMRIAngiogram = DocumentTypeValueSetCode("30858-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadVesselsMRIAngiogram = DocumentTypeValueSetCode("30856-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadVesselsUS_doppler = DocumentTypeValueSetCode("24733-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadVesselsAndNeckVesselsMRIAngiogram = DocumentTypeValueSetCode("42304-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadVesselsAndNeckVesselsUS_doppler = DocumentTypeValueSetCode("30880-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadCisternMRI = DocumentTypeValueSetCode("30655-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadSagittalSinusMRI = DocumentTypeValueSetCode("24746-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadAndNeckPET = DocumentTypeValueSetCode("58742-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadAndNeckUS = DocumentTypeValueSetCode("44164-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartCT = DocumentTypeValueSetCode("58744-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartMRI = DocumentTypeValueSetCode("24748-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartMRIAngiogram = DocumentTypeValueSetCode("36009-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartPET = DocumentTypeValueSetCode("44137-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartUS = DocumentTypeValueSetCode("42148-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HipCT = DocumentTypeValueSetCode("36014-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HipMRI = DocumentTypeValueSetCode("36013-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HipUS = DocumentTypeValueSetCode("24760-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HipX_rayTomograph = DocumentTypeValueSetCode("36012-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_BilateralCT = DocumentTypeValueSetCode("36016-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_BilateralMRI = DocumentTypeValueSetCode("36017-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_BilateralUS = DocumentTypeValueSetCode("26250-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_BilateralX_rayTomograph = DocumentTypeValueSetCode("36015-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_LeftCT = DocumentTypeValueSetCode("36018-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_LeftMRI = DocumentTypeValueSetCode("36020-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_LeftUS = DocumentTypeValueSetCode("26251-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_LeftX_rayTomograph = DocumentTypeValueSetCode("36019-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_RightCT = DocumentTypeValueSetCode("36021-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_RightMRI = DocumentTypeValueSetCode("36022-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_RightUS = DocumentTypeValueSetCode("26252-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_RightX_rayTomograph = DocumentTypeValueSetCode("37735-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HipAndThighUS = DocumentTypeValueSetCode("43566-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HumerusX_rayTomograph = DocumentTypeValueSetCode("36024-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    IliacArteryUS_doppler = DocumentTypeValueSetCode("39425-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    IliacGraftUS_doppler = DocumentTypeValueSetCode("42147-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    IliacVesselsUS_doppler = DocumentTypeValueSetCode("39497-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    IliacVessels_BilateralUS = DocumentTypeValueSetCode("38129-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    IliacVessels_LeftUS = DocumentTypeValueSetCode("38137-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    IliacVessels_RightUS = DocumentTypeValueSetCode("38141-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InternalAuditoryCanalCT = DocumentTypeValueSetCode("35958-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InternalAuditoryCanalMRI = DocumentTypeValueSetCode("35956-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InternalAuditoryCanalX_rayTomograph = DocumentTypeValueSetCode("24767-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InternalAuditoryCanal_BilateralX_rayTomograph = DocumentTypeValueSetCode("26253-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InternalAuditoryCanal_LeftCT = DocumentTypeValueSetCode("35957-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InternalAuditoryCanal_LeftX_rayTomograph = DocumentTypeValueSetCode("26254-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InternalAuditoryCanal_RightCT = DocumentTypeValueSetCode("38767-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InternalAuditoryCanal_RightX_rayTomograph = DocumentTypeValueSetCode("26255-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InternalAuditoryCanalAndPosteriorFossaMRI = DocumentTypeValueSetCode("24735-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KidneyMRI = DocumentTypeValueSetCode("36033-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KidneyUS = DocumentTypeValueSetCode("38036-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KidneyX_rayTomograph = DocumentTypeValueSetCode("36032-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KidneyTransplantUS = DocumentTypeValueSetCode("39032-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KidneyVesselsTransplantUS_doppler = DocumentTypeValueSetCode("42477-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_BilateralCT = DocumentTypeValueSetCode("43767-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_BilateralMRI = DocumentTypeValueSetCode("36034-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_BilateralUS = DocumentTypeValueSetCode("43774-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_BilateralX_rayTomograph = DocumentTypeValueSetCode("24789-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KidneyBilateralAndBladderUS = DocumentTypeValueSetCode("69402-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_LeftMRI = DocumentTypeValueSetCode("36035-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_LeftUS = DocumentTypeValueSetCode("38038-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_RightCT = DocumentTypeValueSetCode("69113-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_RightMRI = DocumentTypeValueSetCode("36036-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_RightUS = DocumentTypeValueSetCode("38049-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeCT = DocumentTypeValueSetCode("36037-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeMRI = DocumentTypeValueSetCode("24802-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeX_rayTomograph = DocumentTypeValueSetCode("36038-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeVesselsMRIAngiogram = DocumentTypeValueSetCode("36799-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeVessels_LeftMRIAngiogram = DocumentTypeValueSetCode("36800-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeVessels_RightMRIAngiogram = DocumentTypeValueSetCode("36801-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralCT = DocumentTypeValueSetCode("36040-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralMRI = DocumentTypeValueSetCode("26256-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralX_rayTomograph = DocumentTypeValueSetCode("36039-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftCT = DocumentTypeValueSetCode("36041-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftMRI = DocumentTypeValueSetCode("26257-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_rayTomograph = DocumentTypeValueSetCode("36042-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightCT = DocumentTypeValueSetCode("36043-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightMRI = DocumentTypeValueSetCode("26258-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_rayTomograph = DocumentTypeValueSetCode("37760-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LarynxMRI = DocumentTypeValueSetCode("36045-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LarynxX_rayTomograph = DocumentTypeValueSetCode("36044-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LiverCT = DocumentTypeValueSetCode("24814-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LiverMRI = DocumentTypeValueSetCode("36046-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LiverUS = DocumentTypeValueSetCode("28614-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LiverTransplantUS = DocumentTypeValueSetCode("39454-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LiverAndDiaphragmUS = DocumentTypeValueSetCode("24818-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityCT = DocumentTypeValueSetCode("35971-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityMRI = DocumentTypeValueSetCode("30692-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityUS = DocumentTypeValueSetCode("30709-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityX_rayTomograph = DocumentTypeValueSetCode("35972-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityArteryUS = DocumentTypeValueSetCode("48693-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityArteryUS_doppler = DocumentTypeValueSetCode("39434-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityArtery_BilateralUS = DocumentTypeValueSetCode("38130-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityArtery_BilateralUS_doppler = DocumentTypeValueSetCode("39421-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityArtery_LeftUS = DocumentTypeValueSetCode("41834-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityArtery_LeftUS_doppler = DocumentTypeValueSetCode("39499-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityArtery_RightUS = DocumentTypeValueSetCode("41815-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityArtery_RightUS_doppler = DocumentTypeValueSetCode("39505-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVeinUS = DocumentTypeValueSetCode("46363-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVeinUS_doppler = DocumentTypeValueSetCode("30881-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVein_BilateralUS = DocumentTypeValueSetCode("46364-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVein_BilateralUS_doppler = DocumentTypeValueSetCode("39420-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVein_LeftUS = DocumentTypeValueSetCode("48692-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVein_LeftUS_doppler = DocumentTypeValueSetCode("39432-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVein_RightUS = DocumentTypeValueSetCode("48691-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVein_RightUS_doppler = DocumentTypeValueSetCode("39443-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVeinsMRIAngiogram = DocumentTypeValueSetCode("36079-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVeins_BilateralUS = DocumentTypeValueSetCode("69385-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVeins_LeftMRIAngiogram = DocumentTypeValueSetCode("36784-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVeins_LeftUS = DocumentTypeValueSetCode("69392-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVeins_RightMRIAngiogram = DocumentTypeValueSetCode("36785-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVesselGraft_LeftUS_doppler = DocumentTypeValueSetCode("42461-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVesselGraft_RightUS_doppler = DocumentTypeValueSetCode("42462-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVesselsMRIAngiogram = DocumentTypeValueSetCode("30874-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVesselsUS_doppler = DocumentTypeValueSetCode("44174-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVessels_BilateralMRIAngiogram = DocumentTypeValueSetCode("35974-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVessels_BilateralUS_doppler = DocumentTypeValueSetCode("39422-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVessels_LeftMRIAngiogram = DocumentTypeValueSetCode("36795-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVessels_LeftUS_doppler = DocumentTypeValueSetCode("39431-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVessels_RightMRIAngiogram = DocumentTypeValueSetCode("36796-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVessels_RightUS_doppler = DocumentTypeValueSetCode("39442-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremity_BilateralCT = DocumentTypeValueSetCode("35973-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremity_BilateralMRI = DocumentTypeValueSetCode("35975-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremity_BilateralUS = DocumentTypeValueSetCode("38013-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityJointMRI = DocumentTypeValueSetCode("24687-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityJoint_BilateralMRI = DocumentTypeValueSetCode("26227-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityJoint_LeftMRI = DocumentTypeValueSetCode("26228-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityJoint_RightMRI = DocumentTypeValueSetCode("26229-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremity_LeftCT = DocumentTypeValueSetCode("35976-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremity_LeftMRI = DocumentTypeValueSetCode("35978-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremity_LeftUS = DocumentTypeValueSetCode("38040-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremity_LeftX_rayTomograph = DocumentTypeValueSetCode("35977-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremity_RightCT = DocumentTypeValueSetCode("35979-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremity_RightMRI = DocumentTypeValueSetCode("35980-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremity_RightUS = DocumentTypeValueSetCode("38051-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremity_RightX_rayTomograph = DocumentTypeValueSetCode("37766-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerLegCT = DocumentTypeValueSetCode("36074-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerLegMRI = DocumentTypeValueSetCode("24821-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerLegVessels_LeftMRIAngiogram = DocumentTypeValueSetCode("43513-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerLegVessels_RightMRIAngiogram = DocumentTypeValueSetCode("43556-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerLeg_BilateralMRI = DocumentTypeValueSetCode("42696-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerLeg_LeftMRI = DocumentTypeValueSetCode("36075-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerLeg_RightMRI = DocumentTypeValueSetCode("36076-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LumbarPlexusMRI = DocumentTypeValueSetCode("30866-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LungPET = DocumentTypeValueSetCode("57822-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MandibleCT = DocumentTypeValueSetCode("36047-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MandibleX_rayTomograph = DocumentTypeValueSetCode("36048-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MastoidUS = DocumentTypeValueSetCode("38043-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MastoidX_rayTomograph = DocumentTypeValueSetCode("36776-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Mastoid_BilateralCT = DocumentTypeValueSetCode("46298-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MaxillaCT = DocumentTypeValueSetCode("36050-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MaxillaAndMandibleCT = DocumentTypeValueSetCode("36049-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MediastinumMRI = DocumentTypeValueSetCode("37234-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MediastinumUS = DocumentTypeValueSetCode("38044-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MediastinumX_rayTomograph = DocumentTypeValueSetCode("37233-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MesentericArteryUS = DocumentTypeValueSetCode("69394-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NasalBonesMRI = DocumentTypeValueSetCode("69211-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NasalBonesX_rayTomograph = DocumentTypeValueSetCode("37606-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NasopharynxMRI = DocumentTypeValueSetCode("30860-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NasopharynxAndNeckCT = DocumentTypeValueSetCode("24835-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeckCT = DocumentTypeValueSetCode("36051-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeckMRI = DocumentTypeValueSetCode("24839-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeckUS = DocumentTypeValueSetCode("24842-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeckVeinsMRIAngiogram = DocumentTypeValueSetCode("36788-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeckVesselsMRIAngiogram = DocumentTypeValueSetCode("36085-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeckVesselsUS_doppler = DocumentTypeValueSetCode("44175-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NervesCranialMRI = DocumentTypeValueSetCode("30857-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OrbitCT = DocumentTypeValueSetCode("41807-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OrbitMRI = DocumentTypeValueSetCode("36777-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OrbitVesselsMRIAngiogram = DocumentTypeValueSetCode("36802-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Orbit_BilateralCT = DocumentTypeValueSetCode("24848-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Orbit_BilateralX_rayTomograph = DocumentTypeValueSetCode("37611-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Orbit_LeftMRI = DocumentTypeValueSetCode("38836-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Orbit_RightMRI = DocumentTypeValueSetCode("36778-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OrbitAndFaceMRI = DocumentTypeValueSetCode("42303-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OrbitAndFaceAndNeckMRI = DocumentTypeValueSetCode("43530-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OropharynxMRI = DocumentTypeValueSetCode("43455-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OvarianVesselsUS_doppler = DocumentTypeValueSetCode("39502-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OvaryMRI = DocumentTypeValueSetCode("36779-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OvaryUS = DocumentTypeValueSetCode("69390-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ovary_BilateralMRI = DocumentTypeValueSetCode("43506-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PancreasCT = DocumentTypeValueSetCode("24857-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PancreasMRI = DocumentTypeValueSetCode("36052-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PancreasUS = DocumentTypeValueSetCode("24859-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PancreasTransplantUS = DocumentTypeValueSetCode("39509-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ParathyroidMRI = DocumentTypeValueSetCode("36053-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ParathyroidUS = DocumentTypeValueSetCode("38045-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ParotidGlandCT = DocumentTypeValueSetCode("37223-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ParotidGlandMRI = DocumentTypeValueSetCode("37224-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ParotidGlandUS = DocumentTypeValueSetCode("38138-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisCT = DocumentTypeValueSetCode("24865-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisMRI = DocumentTypeValueSetCode("24867-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisUS = DocumentTypeValueSetCode("24869-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisX_rayTomograph = DocumentTypeValueSetCode("37632-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisVeinsMRIAngiogram = DocumentTypeValueSetCode("36789-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisVesselsMRIAngiogram = DocumentTypeValueSetCode("30867-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisVesselsUS_doppler = DocumentTypeValueSetCode("24870-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisAndHipMRI = DocumentTypeValueSetCode("24872-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisAndHip_BilateralMRI = DocumentTypeValueSetCode("26259-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisAndHip_LeftMRI = DocumentTypeValueSetCode("26260-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisAndHip_RightMRI = DocumentTypeValueSetCode("26261-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PenisUS = DocumentTypeValueSetCode("38140-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PenisVesselsUS = DocumentTypeValueSetCode("38139-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PetrousBoneCT = DocumentTypeValueSetCode("24877-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PituitaryAndSellaTurcicaCT = DocumentTypeValueSetCode("36932-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PituitaryAndSellaTurcicaMRI = DocumentTypeValueSetCode("24880-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PoplitealSpaceUS = DocumentTypeValueSetCode("24881-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PoplitealSpace_BilateralUS = DocumentTypeValueSetCode("26262-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PoplitealSpace_LeftUS = DocumentTypeValueSetCode("26263-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PoplitealSpace_RightUS = DocumentTypeValueSetCode("26264-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PortalVeinMRIAngiogram = DocumentTypeValueSetCode("36077-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PortalVeinAndHepaticVeinUS_doppler = DocumentTypeValueSetCode("69284-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PosteriorFossaCT = DocumentTypeValueSetCode("36055-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PosteriorFossaMRI = DocumentTypeValueSetCode("36056-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ProstateCT = DocumentTypeValueSetCode("36057-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ProstateMRI = DocumentTypeValueSetCode("30675-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ProstateUS = DocumentTypeValueSetCode("24884-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PulmonarySystemCT = DocumentTypeValueSetCode("43445-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PulmonarySystemMRI = DocumentTypeValueSetCode("43454-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PulmonaryVesselsMRIAngiogram = DocumentTypeValueSetCode("36803-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RectumUS = DocumentTypeValueSetCode("24892-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RenalArteryUS = DocumentTypeValueSetCode("69294-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RenalArteryUS_doppler = DocumentTypeValueSetCode("39435-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RenalVeinMRIAngiogram = DocumentTypeValueSetCode("36078-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RenalVesselsMRIAngiogram = DocumentTypeValueSetCode("30868-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RenalVesselsUS = DocumentTypeValueSetCode("69295-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RenalVesselsUS_doppler = DocumentTypeValueSetCode("39426-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RenalVessels_BilateralMRIAngiogram = DocumentTypeValueSetCode("36804-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RenalVessels_BilateralUS_doppler = DocumentTypeValueSetCode("39419-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SacroiliacJointCT = DocumentTypeValueSetCode("30619-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SacroiliacJointMRI = DocumentTypeValueSetCode("36031-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SacrumCT = DocumentTypeValueSetCode("36058-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SacrumMRI = DocumentTypeValueSetCode("36059-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SacrumUS = DocumentTypeValueSetCode("38053-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SacrumX_rayTomograph = DocumentTypeValueSetCode("37653-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SacrumAndCoccyxCT = DocumentTypeValueSetCode("69116-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SacrumAndCoccyxMRI = DocumentTypeValueSetCode("36060-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SalivaryGlandMRI = DocumentTypeValueSetCode("36933-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SalivaryGlandUS = DocumentTypeValueSetCode("69298-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScapulaCT = DocumentTypeValueSetCode("69117-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScapulaMRI = DocumentTypeValueSetCode("36061-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScrotumAndTesticleMRI = DocumentTypeValueSetCode("36073-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScrotumAndTesticleUS = DocumentTypeValueSetCode("25002-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScrotumAndTesticleUS_doppler = DocumentTypeValueSetCode("48742-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScrotumAndTesticle_BilateralUS = DocumentTypeValueSetCode("26271-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScrotumAndTesticle_LeftUS = DocumentTypeValueSetCode("26272-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScrotumAndTesticle_RightUS = DocumentTypeValueSetCode("26273-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SellaTurcicaX_rayTomograph = DocumentTypeValueSetCode("42437-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ShoulderCT = DocumentTypeValueSetCode("36062-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ShoulderMRI = DocumentTypeValueSetCode("24905-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ShoulderUS = DocumentTypeValueSetCode("24907-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ShoulderX_rayTomograph = DocumentTypeValueSetCode("37850-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ShoulderVesselsMRIAngiogram = DocumentTypeValueSetCode("36805-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ShoulderVessels_LeftMRIAngiogram = DocumentTypeValueSetCode("36806-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ShoulderVessels_RightMRIAngiogram = DocumentTypeValueSetCode("36807-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_BilateralCT = DocumentTypeValueSetCode("36063-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_BilateralMRI = DocumentTypeValueSetCode("26266-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_BilateralUS = DocumentTypeValueSetCode("26265-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftCT = DocumentTypeValueSetCode("36064-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftMRI = DocumentTypeValueSetCode("26268-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftUS = DocumentTypeValueSetCode("26267-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_rayTomograph = DocumentTypeValueSetCode("36065-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightCT = DocumentTypeValueSetCode("36066-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightMRI = DocumentTypeValueSetCode("26270-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightUS = DocumentTypeValueSetCode("26269-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightX_rayTomograph = DocumentTypeValueSetCode("37811-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SinusesCT = DocumentTypeValueSetCode("30588-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SinusesMRI = DocumentTypeValueSetCode("24914-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SinusesX_rayTomograph = DocumentTypeValueSetCode("37866-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SkullX_rayTomograph = DocumentTypeValueSetCode("37874-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Skull_baseCT = DocumentTypeValueSetCode("37495-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCT = DocumentTypeValueSetCode("28566-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineMRI = DocumentTypeValueSetCode("36067-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineUS = DocumentTypeValueSetCode("24926-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineVesselsMRIAngiogram = DocumentTypeValueSetCode("37497-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalCT = DocumentTypeValueSetCode("24932-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalMRI = DocumentTypeValueSetCode("24935-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalUS = DocumentTypeValueSetCode("70926-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalX_rayTomograph = DocumentTypeValueSetCode("36068-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalAndSpineThoracicMRI = DocumentTypeValueSetCode("43457-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalAndThoracicAndLumbarMRI = DocumentTypeValueSetCode("42698-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarCT = DocumentTypeValueSetCode("24963-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarMRI = DocumentTypeValueSetCode("24968-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarUS = DocumentTypeValueSetCode("69393-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_rayTomograph = DocumentTypeValueSetCode("36069-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbosacralJunctionCT = DocumentTypeValueSetCode("37232-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicCT = DocumentTypeValueSetCode("24978-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicMRI = DocumentTypeValueSetCode("24980-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicUS = DocumentTypeValueSetCode("70927-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicX_rayTomograph = DocumentTypeValueSetCode("37911-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThoracicSpineVesselsMRIAngiogram = DocumentTypeValueSetCode("49565-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpleenCT = DocumentTypeValueSetCode("24988-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpleenMRI = DocumentTypeValueSetCode("36070-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpleenUS = DocumentTypeValueSetCode("24990-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SternoclavicularJointCT = DocumentTypeValueSetCode("37225-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SternumCT = DocumentTypeValueSetCode("36071-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SternumMRI = DocumentTypeValueSetCode("36072-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SternumX_rayTomograph = DocumentTypeValueSetCode("37885-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SubclavianArteryMRIAngiogram = DocumentTypeValueSetCode("36782-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SubclavianVessels_BilateralUS = DocumentTypeValueSetCode("38131-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SuperiorMesentericVesselsMRIAngiogram = DocumentTypeValueSetCode("46359-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SuperiorMesentericVesselsUS_doppler = DocumentTypeValueSetCode("44235-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SurgicalSpecimenUS = DocumentTypeValueSetCode("42468-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TalusCT = DocumentTypeValueSetCode("38059-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporalBoneCT = DocumentTypeValueSetCode("36773-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporomandibularJointCT = DocumentTypeValueSetCode("37226-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporomandibularJointMRI = DocumentTypeValueSetCode("24999-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporomandibularJointX_rayTomograph = DocumentTypeValueSetCode("30719-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporomandibularJoint_BilateralMRI = DocumentTypeValueSetCode("37228-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporomandibularJoint_BilateralX_rayTomograph = DocumentTypeValueSetCode("37227-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporomandibularJoint_LeftMRI = DocumentTypeValueSetCode("37230-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporomandibularJoint_LeftX_rayTomograph = DocumentTypeValueSetCode("37229-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporomandibularJoint_RightMRI = DocumentTypeValueSetCode("37231-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporomandibularJoint_RightX_rayTomograph = DocumentTypeValueSetCode("37819-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TesticleVesselsUS_doppler = DocumentTypeValueSetCode("39446-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThighMRI = DocumentTypeValueSetCode("24702-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Thigh_BilateralMRI = DocumentTypeValueSetCode("26235-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Thigh_LeftMRI = DocumentTypeValueSetCode("26236-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Thigh_RightMRI = DocumentTypeValueSetCode("26237-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThoracicOutletCT = DocumentTypeValueSetCode("36054-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThoracicOutletMRI = DocumentTypeValueSetCode("24582-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThoracicOutletUS = DocumentTypeValueSetCode("44163-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThoracicOutlet_BilateralMRI = DocumentTypeValueSetCode("26211-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThoracicOutlet_LeftMRI = DocumentTypeValueSetCode("26212-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThoracicOutlet_RightMRI = DocumentTypeValueSetCode("26213-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThymusGlandMRI = DocumentTypeValueSetCode("43507-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThyroidMRI = DocumentTypeValueSetCode("42300-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThyroidUS = DocumentTypeValueSetCode("25010-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TibiaAndFibulaX_rayTomograph = DocumentTypeValueSetCode("37898-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TibioperonealVesselsMRIAngiogram = DocumentTypeValueSetCode("30888-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ToeMRI = DocumentTypeValueSetCode("36780-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UmbilicalArteryUS_doppler = DocumentTypeValueSetCode("69285-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UmbilicalVesselsUS_doppler = DocumentTypeValueSetCode("39508-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperArmCT = DocumentTypeValueSetCode("36023-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperArmMRI = DocumentTypeValueSetCode("36025-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperArm_BilateralCT = DocumentTypeValueSetCode("36026-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperArm_BilateralMRI = DocumentTypeValueSetCode("69180-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperArm_LeftCT = DocumentTypeValueSetCode("36027-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperArm_LeftMRI = DocumentTypeValueSetCode("36028-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperArm_RightCT = DocumentTypeValueSetCode("36029-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperArm_RightMRI = DocumentTypeValueSetCode("36030-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityCT = DocumentTypeValueSetCode("35981-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityMRI = DocumentTypeValueSetCode("24688-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityUS = DocumentTypeValueSetCode("30710-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityX_rayTomograph = DocumentTypeValueSetCode("37923-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityArteryUS = DocumentTypeValueSetCode("48448-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityArteryUS_doppler = DocumentTypeValueSetCode("39447-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityArtery_BilateralUS = DocumentTypeValueSetCode("38014-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityArtery_BilateralUS_doppler = DocumentTypeValueSetCode("39423-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityArtery_LeftUS = DocumentTypeValueSetCode("41833-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityArtery_LeftUS_doppler = DocumentTypeValueSetCode("39500-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityArtery_RightUS = DocumentTypeValueSetCode("41814-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityArtery_RightUS_doppler = DocumentTypeValueSetCode("39506-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityVeinUS_doppler = DocumentTypeValueSetCode("30882-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityVein_BilateralUS = DocumentTypeValueSetCode("48690-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityVein_BilateralUS_doppler = DocumentTypeValueSetCode("39496-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityVein_LeftUS = DocumentTypeValueSetCode("48689-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityVein_LeftUS_doppler = DocumentTypeValueSetCode("39501-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityVein_RightUS = DocumentTypeValueSetCode("48688-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityVein_RightUS_doppler = DocumentTypeValueSetCode("39507-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityVeinsMRIAngiogram = DocumentTypeValueSetCode("36080-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityVeinsUS = DocumentTypeValueSetCode("69395-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityVeins_LeftMRIAngiogram = DocumentTypeValueSetCode("36786-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityVeins_RightMRIAngiogram = DocumentTypeValueSetCode("36787-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityVesselGraftUS_doppler = DocumentTypeValueSetCode("46385-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityVesselGraft_BilateralUS_doppler = DocumentTypeValueSetCode("44236-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityVesselGraft_LeftUS_doppler = DocumentTypeValueSetCode("42475-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityVesselGraft_RightUS_doppler = DocumentTypeValueSetCode("42476-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityVesselsMRIAngiogram = DocumentTypeValueSetCode("36084-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityVesselsUS_doppler = DocumentTypeValueSetCode("39448-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityVessels_BilateralUS_doppler = DocumentTypeValueSetCode("46379-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityVessels_LeftMRIAngiogram = DocumentTypeValueSetCode("36797-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityVessels_LeftUS_doppler = DocumentTypeValueSetCode("39433-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityVessels_RightMRIAngiogram = DocumentTypeValueSetCode("36798-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityVessels_RightUS_doppler = DocumentTypeValueSetCode("39444-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremity_BilateralMRI = DocumentTypeValueSetCode("26232-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremity_jointMRI = DocumentTypeValueSetCode("30875-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityJoint_LeftMRI = DocumentTypeValueSetCode("36774-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityJoint_RightMRI = DocumentTypeValueSetCode("36775-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremity_LeftCT = DocumentTypeValueSetCode("35982-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremity_LeftMRI = DocumentTypeValueSetCode("26233-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremity_LeftUS = DocumentTypeValueSetCode("38041-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremity_RightCT = DocumentTypeValueSetCode("35983-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremity_RightMRI = DocumentTypeValueSetCode("26234-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremity_RightUS = DocumentTypeValueSetCode("38052-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UrinaryBladderUS = DocumentTypeValueSetCode("25019-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UterusMRI = DocumentTypeValueSetCode("42301-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UterusAndFallopianTubesUS = DocumentTypeValueSetCode("30705-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VeinUS = DocumentTypeValueSetCode("39036-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VeinUS_doppler = DocumentTypeValueSetCode("39525-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Vein_BilateralUS = DocumentTypeValueSetCode("39030-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VeinsMRIAngiogram = DocumentTypeValueSetCode("36783-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VenaCavaMRI = DocumentTypeValueSetCode("69222-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VenaCavaMRIAngiogram = DocumentTypeValueSetCode("36081-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InferiorVenaCavaMRI = DocumentTypeValueSetCode("36083-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InferiorVenaCavaMRIAngiogram = DocumentTypeValueSetCode("36082-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VenaCava_inferiorAndLowerExtremityVeinsMRIAngiogram = DocumentTypeValueSetCode(
        "36790-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VesselsUS_doppler = DocumentTypeValueSetCode("39445-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VisceralArteryUS = DocumentTypeValueSetCode("38054-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    WristCT = DocumentTypeValueSetCode("37428-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    WristMRI = DocumentTypeValueSetCode("25033-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    WristUS = DocumentTypeValueSetCode("25036-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    WristX_rayTomograph = DocumentTypeValueSetCode("37932-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_BilateralCT = DocumentTypeValueSetCode("37430-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_BilateralMRI = DocumentTypeValueSetCode("26277-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_BilateralUS = DocumentTypeValueSetCode("26278-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_BilateralX_rayTomograph = DocumentTypeValueSetCode("37429-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_LeftCT = DocumentTypeValueSetCode("37431-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_LeftMRI = DocumentTypeValueSetCode("26279-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_LeftUS = DocumentTypeValueSetCode("26280-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_LeftX_rayTomograph = DocumentTypeValueSetCode("37432-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_LeftAndHand_LeftMRI = DocumentTypeValueSetCode("69209-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_RightCT = DocumentTypeValueSetCode("37433-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_RightMRI = DocumentTypeValueSetCode("26281-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_RightUS = DocumentTypeValueSetCode("26282-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_RightX_rayTomograph = DocumentTypeValueSetCode("37644-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_RightAndHand_RightMRI = DocumentTypeValueSetCode("69219-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    WristAndHandMRI = DocumentTypeValueSetCode("36008-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionCT = DocumentTypeValueSetCode("25045-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionCT3D = DocumentTypeValueSetCode("25040-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionMRI = DocumentTypeValueSetCode("25056-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionPET = DocumentTypeValueSetCode("44136-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionUS = DocumentTypeValueSetCode("25061-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionX_rayTomograph = DocumentTypeValueSetCode("25071-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ArteryUS = DocumentTypeValueSetCode("46375-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ArteryUS_doppler = DocumentTypeValueSetCode("39523-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BonesCT = DocumentTypeValueSetCode("44229-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    JointMRI = DocumentTypeValueSetCode("28576-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TendonUS = DocumentTypeValueSetCode("39453-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FacialBonesAndMaxillaCTAnd3DReconstruction = DocumentTypeValueSetCode("36957-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadCTAnd3DReconstruction = DocumentTypeValueSetCode("37294-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionCTAnd3DReconstruction = DocumentTypeValueSetCode("41804-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionMRIAnd3DReconstruction = DocumentTypeValueSetCode("39043-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionUSAnd3DReconstruction = DocumentTypeValueSetCode("44165-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CoronaryArteriesCTAngiogramAnd3DReconstructionWContrastIV = (
        DocumentTypeValueSetCode("58745-1")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LeftAtriumAndPulmonaryVeinsCTAngiogramAnd3DReconstructionWContrastIV = (
        DocumentTypeValueSetCode("59255-0")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadCTAnd3DReconstructionWOContrast = DocumentTypeValueSetCode("69082-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FemurAndHipCTAndAnteversionMeasurement = DocumentTypeValueSetCode("37295-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityArteries_BilateralUS_dopplerMultisectionAndPhysiologicArteryStudy = (
        DocumentTypeValueSetCode("72830-3")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityArteries_BilateralUS_dopplerMultisectionAndPhysiologicArteryStudyAtRestAndWithExercise = DocumentTypeValueSetCode(
        "72832-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BoneSPECT1Phase = DocumentTypeValueSetCode("39879-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BoneSPECT3PhaseWholeBody = DocumentTypeValueSetCode("39881-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_BilateralX_rayTomograph3ViewsWContrastIV = DocumentTypeValueSetCode(
        "30760-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionMRIAdditionalSequence = DocumentTypeValueSetCode("25055-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicX_rayTomographAP = DocumentTypeValueSetCode("39408-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartSPECTBloodPoolAtRestAndWRadionuclideIV = DocumentTypeValueSetCode("39862-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LiverSPECTBloodPool = DocumentTypeValueSetCode("47378-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporomandibularJointMRICine = DocumentTypeValueSetCode("37435-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UrinaryBladderAndUrethraMRICine = DocumentTypeValueSetCode("42693-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartMRICineForBloodFlowVelocityMapping = DocumentTypeValueSetCode("39140-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartMRICineForBloodFlowVelocityMappingWContrastIV = DocumentTypeValueSetCode(
        "44126-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainMRICineForCSFFlow = DocumentTypeValueSetCode("42386-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionMRICineForCSFFlow = DocumentTypeValueSetCode("42387-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartMRICineForFunction = DocumentTypeValueSetCode("37434-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SinusesCTCoronal = DocumentTypeValueSetCode("46300-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_BilateralFFDMammogram_tomosynthesisDiagnostic = DocumentTypeValueSetCode(
        "72139-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_LeftFFDMammogram_tomosynthesisDiagnostic = DocumentTypeValueSetCode(
        "72138-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_RightFFDMammogram_tomosynthesisDiagnostic = DocumentTypeValueSetCode(
        "72137-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainMRIDiffusionWeighted = DocumentTypeValueSetCode("37436-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_LeftMRIDynamicWContrastIV = DocumentTypeValueSetCode("43555-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_RightMRIDynamicWContrastIV = DocumentTypeValueSetCode("43449-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastMRIDynamicWContrastIV = DocumentTypeValueSetCode("37437-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_BilateralMRIDynamicWContrastIV = DocumentTypeValueSetCode("36114-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_LeftMRIDynamicWContrastIV = DocumentTypeValueSetCode("43450-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_RightMRIDynamicWContrastIV = DocumentTypeValueSetCode("43451-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadCTDynamicWContrastIV = DocumentTypeValueSetCode("46394-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftMRIDynamicWContrastIV = DocumentTypeValueSetCode("43452-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightMRIDynamicWContrastIV = DocumentTypeValueSetCode("43453-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PituitaryAndSellaTurcicaCTDynamicWContrastIV = DocumentTypeValueSetCode("37438-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionCTDynamicWContrastIV = DocumentTypeValueSetCode("43527-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainSPECTFlow = DocumentTypeValueSetCode("39637-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LiverSPECTFlow = DocumentTypeValueSetCode("43655-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LiverAndSpleenSPECTFlow = DocumentTypeValueSetCode("43652-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScrotumAndTesticleSPECTFlow = DocumentTypeValueSetCode("69235-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpleenSPECTFlow = DocumentTypeValueSetCode("43670-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThyroidSPECTFlow = DocumentTypeValueSetCode("43673-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RenalVesselsSPECTFlowWTc_99mGlucoheptonateIV = DocumentTypeValueSetCode("43662-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SPECTForAbscessWGA_67IV = DocumentTypeValueSetCode("39684-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SPECTForAbscess = DocumentTypeValueSetCode("39811-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BoneMarrowMRIForBloodFlow = DocumentTypeValueSetCode("39141-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartSPECTForInfarct = DocumentTypeValueSetCode("39656-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartSPECTForInfarctWTc_99mPYPIV = DocumentTypeValueSetCode("39654-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartSPECTForInfarctWTc_99mSestamibiIV = DocumentTypeValueSetCode("39655-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SPECTForInfectionWGA_67IV = DocumentTypeValueSetCode("39675-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    USPelvisAndFetusForPregnancy = DocumentTypeValueSetCode("11525-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestVesselsCTMultisectionForPulmonaryEmbolus = DocumentTypeValueSetCode("72251-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PylorusUSForPyloricStenosis = DocumentTypeValueSetCode("24889-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartCTForScoring = DocumentTypeValueSetCode("36934-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartCTForScoringWContrastIV = DocumentTypeValueSetCode("36935-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTForTumorWholeBody = DocumentTypeValueSetCode("43446-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SPECTForTumorWholeBody = DocumentTypeValueSetCode("69237-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SPECTForTumorWGA_67IV = DocumentTypeValueSetCode("39678-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SPECTForTumorWTc_99mSestamibiIV = DocumentTypeValueSetCode("39748-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SPECTForTumorWTl_201IV = DocumentTypeValueSetCode("42292-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartSPECTGatedAndEjectionFractionAtRestAndWStressAndWRadionuclideIV = (
        DocumentTypeValueSetCode("46395-0")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartSPECTGatedAndEjectionFraction = DocumentTypeValueSetCode("39913-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartSPECTGatedAndWallMotion = DocumentTypeValueSetCode("39918-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartSPECTGatedAtRestAndWTc_99mSestamibiIV = DocumentTypeValueSetCode("46396-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartSPECTGated = DocumentTypeValueSetCode("39916-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartSPECTGatedWStressAndWRadionuclideIV = DocumentTypeValueSetCode("39930-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestCTHighResolution = DocumentTypeValueSetCode("37439-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestCTHighResolutionWContrastIV = DocumentTypeValueSetCode("37440-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestCTHighResolutionWOContrast = DocumentTypeValueSetCode("37441-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicX_rayTomographLateral = DocumentTypeValueSetCode("39409-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenCTLimited = DocumentTypeValueSetCode("36086-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenUSLimited = DocumentTypeValueSetCode("30704-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenRetroperitoneumUSLimited = DocumentTypeValueSetCode("38047-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdominalVesselsUS_dopplerLimited = DocumentTypeValueSetCode("43572-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AortaUSLimited = DocumentTypeValueSetCode("38011-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BladderUSLimited = DocumentTypeValueSetCode("69280-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastUSLimited = DocumentTypeValueSetCode("24599-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_BilateralUSLimited = DocumentTypeValueSetCode("26286-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_LeftUSLimited = DocumentTypeValueSetCode("26288-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_RightUSLimited = DocumentTypeValueSetCode("26290-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CarotidArteryUSLimited = DocumentTypeValueSetCode("38015-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CarotidArtery_LeftUSLimited = DocumentTypeValueSetCode("42149-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CarotidArtery_RightUSLimited = DocumentTypeValueSetCode("42151-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestCTLimited = DocumentTypeValueSetCode("36089-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestUSLimited = DocumentTypeValueSetCode("69281-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityCTLimited = DocumentTypeValueSetCode("36090-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityUSLimited = DocumentTypeValueSetCode("39526-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityVein_BilateralUS_dopplerLimited = DocumentTypeValueSetCode("46301-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityVesselsUS_dopplerLimited = DocumentTypeValueSetCode("39424-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Extremity_LeftUSLimited = DocumentTypeValueSetCode("62451-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Extremity_RightUSLimited = DocumentTypeValueSetCode("62452-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    EyeUSLimited = DocumentTypeValueSetCode("69286-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FacialBonesAndMaxillaCTLimited = DocumentTypeValueSetCode("36937-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GallbladderUSLimited = DocumentTypeValueSetCode("38020-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadCTLimited = DocumentTypeValueSetCode("36087-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadUSLimited = DocumentTypeValueSetCode("38034-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadVesselsMRIAngiogramLimited = DocumentTypeValueSetCode("36808-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadVesselsUS_dopplerLimited = DocumentTypeValueSetCode("39044-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartMRILimited = DocumentTypeValueSetCode("36091-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartUSLimited = DocumentTypeValueSetCode("42707-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HipCTLimited = DocumentTypeValueSetCode("36092-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    IliacArteryUS_dopplerLimited = DocumentTypeValueSetCode("43776-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    IliacGraftUS_dopplerLimited = DocumentTypeValueSetCode("42150-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InternalAuditoryCanalMRILimited = DocumentTypeValueSetCode("36088-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KidneyUSLimited = DocumentTypeValueSetCode("38035-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KidneyTransplantUSLimited = DocumentTypeValueSetCode("69300-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityArteryUSLimited = DocumentTypeValueSetCode("41812-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityArteryUS_dopplerLimited = DocumentTypeValueSetCode("38042-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVessels_LeftUS_dopplerLimited = DocumentTypeValueSetCode("39430-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVessels_RightUS_dopplerLimited = DocumentTypeValueSetCode("39441-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityJointMRILimited = DocumentTypeValueSetCode("36093-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremity_LeftUSLimited = DocumentTypeValueSetCode("38039-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremity_RightUSLimited = DocumentTypeValueSetCode("38050-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MandibleCTLimited = DocumentTypeValueSetCode("44116-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeckMRILimited = DocumentTypeValueSetCode("48461-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisMRILimited = DocumentTypeValueSetCode("69212-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisUSLimited = DocumentTypeValueSetCode("38046-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisVesselsUS_dopplerLimited = DocumentTypeValueSetCode("42152-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PeripheralArteryUSLimited = DocumentTypeValueSetCode("44173-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RenalVesselsUS_dopplerLimited = DocumentTypeValueSetCode("39436-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScrotumAndTesticleUSLimited = DocumentTypeValueSetCode("69299-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SinusesCTLimited = DocumentTypeValueSetCode("24913-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityArteryUSLimited = DocumentTypeValueSetCode("41813-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityArteryUS_dopplerLimited = DocumentTypeValueSetCode("38143-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityArtery_BilateralUS_dopplerLimited = DocumentTypeValueSetCode(
        "46302-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityVesselGraft_BilateralUS_dopplerLimited = DocumentTypeValueSetCode(
        "44237-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityVesselsUS_dopplerLimited = DocumentTypeValueSetCode("46303-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremity_jointMRILimited = DocumentTypeValueSetCode("36094-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VeinUSLimited = DocumentTypeValueSetCode("39045-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VeinUS_dopplerLimited = DocumentTypeValueSetCode("39524-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionCTLimited = DocumentTypeValueSetCode("25039-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionMRILimited = DocumentTypeValueSetCode("48460-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionUS_dopplerLimited = DocumentTypeValueSetCode("69282-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityArteries_BilateralUS_dopplerMultisectionLimitedAndPhysiologicArteryStudy = DocumentTypeValueSetCode(
        "72831-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartMRILimitedCineForFunction = DocumentTypeValueSetCode("44127-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisCTLimitedPelvimetryWOContrast = DocumentTypeValueSetCode("39046-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenCTLimitedWAndWOContrastIV = DocumentTypeValueSetCode("36102-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenCTLimitedWContrastIV = DocumentTypeValueSetCode("36095-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainMRILimitedWContrastIV = DocumentTypeValueSetCode("36096-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestCTLimitedWContrastIV = DocumentTypeValueSetCode("69096-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisCTLimitedWContrastIV = DocumentTypeValueSetCode("36098-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalCTLimitedWContrastIV = DocumentTypeValueSetCode("36099-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarMRILimitedWContrastIV = DocumentTypeValueSetCode("36100-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicMRILimitedWContrastIV = DocumentTypeValueSetCode("36101-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityCTLimitedWContrastIV = DocumentTypeValueSetCode("36097-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SPECTLimitedWGA_67IV = DocumentTypeValueSetCode("39681-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BoneSPECTLimited = DocumentTypeValueSetCode("39813-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BoneMarrowSPECTLimited = DocumentTypeValueSetCode("39821-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenCTLimitedWOContrast = DocumentTypeValueSetCode("36103-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainMRILimitedWOContrast = DocumentTypeValueSetCode("36105-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestCTLimitedWOContrast = DocumentTypeValueSetCode("47366-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FacialBonesAndMaxillaCTLimitedWOContrast = DocumentTypeValueSetCode("36938-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadCTLimitedWOContrast = DocumentTypeValueSetCode("36104-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityCTLimitedWOContrast = DocumentTypeValueSetCode("36106-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityJoint_LeftMRILimitedWOContrast = DocumentTypeValueSetCode("36107-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityJoint_RightMRILimitedWOContrast = DocumentTypeValueSetCode("38769-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisCTLimitedWOContrast = DocumentTypeValueSetCode("36108-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SinusesCTLimitedWOContrast = DocumentTypeValueSetCode("46304-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalCTLimitedWOContrast = DocumentTypeValueSetCode("36109-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarCTLimitedWOContrast = DocumentTypeValueSetCode("36110-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarMRILimitedWOContrast = DocumentTypeValueSetCode("36111-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicMRILimitedWOContrast = DocumentTypeValueSetCode("36112-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BoneSPECTMultipleAreas = DocumentTypeValueSetCode("39905-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BoneMarrowSPECTMultipleAreas = DocumentTypeValueSetCode("39906-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionUSOfForeignBody = DocumentTypeValueSetCode("39527-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartSPECTPerfusionAndWallMotionAtRestAndWStressAndWTl_201IVAndWTc_99mSestamibiIV = DocumentTypeValueSetCode(
        "49569-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartSPECTPerfusionQualitativeAtRestAndWRadionuclideIV = DocumentTypeValueSetCode(
        "43659-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartSPECTPerfusionAtRestAndWAdenosineAndWTl_201IV = DocumentTypeValueSetCode(
        "39725-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartSPECTPerfusionAtRestAndWRadionuclideIV = DocumentTypeValueSetCode("39718-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartSPECTPerfusionAtRestAndWStressAndWRadionuclideIV = DocumentTypeValueSetCode(
        "39724-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartSPECTPerfusionAtRestAndWStressAndWTl_201IV = DocumentTypeValueSetCode(
        "39723-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartSPECTPerfusionAtRestAndWStressAndWTl_201IVAndWTc_99mSestamibiIV = (
        DocumentTypeValueSetCode("49568-9")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartSPECTPerfusionAtRestAndWTl_201IV = DocumentTypeValueSetCode("39729-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartSPECTPerfusionWAdenosineAndWRadionuclideIV = DocumentTypeValueSetCode(
        "39700-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartSPECTPerfusionWAdenosineAndWTc_99mSestamibiIV = DocumentTypeValueSetCode(
        "49567-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadCTPerfusionWContrastIV = DocumentTypeValueSetCode("39142-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartSPECTPerfusion = DocumentTypeValueSetCode("39712-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartSPECTPerfusionWStressAndWRadionuclideIV = DocumentTypeValueSetCode("39734-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartSPECTPerfusionWStressAndWTc_99mSestamibiIV = DocumentTypeValueSetCode(
        "39736-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartSPECTPerfusionWTc_99mSestamibiIV = DocumentTypeValueSetCode("39710-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartSPECTPerfusionWTl_201IV = DocumentTypeValueSetCode("39711-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Spine_lumbosacral_Cervical_ThoracicMRISagittal = DocumentTypeValueSetCode("38060-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionCTSagittalAndCoronal = DocumentTypeValueSetCode("25052-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionCT3DSagittalAndCoronalDisarticulation = (
        DocumentTypeValueSetCode("25050-6")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastUSScreening = DocumentTypeValueSetCode("42132-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_BilateralFFDMammogram_tomosynthesisScreening = DocumentTypeValueSetCode(
        "72142-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_LeftFFDMammogram_tomosynthesisScreening = DocumentTypeValueSetCode("72141-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_RightFFDMammogram_tomosynthesisScreening = DocumentTypeValueSetCode(
        "72140-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainMRISpectroscopy = DocumentTypeValueSetCode("37442-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionMRISpectroscopy = DocumentTypeValueSetCode("37443-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCTStereotactic = DocumentTypeValueSetCode("36939-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalCTStereotactic = DocumentTypeValueSetCode("70929-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarCTStereotactic = DocumentTypeValueSetCode("70928-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicCTStereotactic = DocumentTypeValueSetCode("70930-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionCTStereotactic = DocumentTypeValueSetCode("36940-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisUSTransabdominalAndTransvaginal = DocumentTypeValueSetCode("42455-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisUSTransvaginal = DocumentTypeValueSetCode("24677-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TransvaginalMRI = DocumentTypeValueSetCode("42390-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LungSPECTVentilationAndPerfusionWRadionuclideInhaledAndWRadionuclideIV = (
        DocumentTypeValueSetCode("39838-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LungSPECTVentilationWRadionuclideAerosolInhaled = DocumentTypeValueSetCode(
        "39898-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartSPECTWallMotion = DocumentTypeValueSetCode("39872-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTWholeBody = DocumentTypeValueSetCode("46305-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MRIWholeBody = DocumentTypeValueSetCode("46358-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PETWholeBody = DocumentTypeValueSetCode("44139-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CTWholeBodyWContrastIV = DocumentTypeValueSetCode("46306-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SPECTWholeBodyWGA_67IV = DocumentTypeValueSetCode("39680-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BoneSPECTWholeBody = DocumentTypeValueSetCode("39816-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BoneMarrowSPECTWholeBody = DocumentTypeValueSetCode("39825-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SPECTWholeBodyWTc_99mArcitumomabIV = DocumentTypeValueSetCode("41837-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartSPECTAtRestAndWRadionuclideIV = DocumentTypeValueSetCode("39658-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartSPECTAtRestAndWStressAndWTc_99mSestamibiIV = DocumentTypeValueSetCode(
        "39662-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartSPECTAtRestAndWTc_99mSestamibiIV = DocumentTypeValueSetCode("49566-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HipUSDevelopmentalJointAssessment = DocumentTypeValueSetCode("30711-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadUSDuringSurgery = DocumentTypeValueSetCode("24732-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LiverUSDuringSurgery = DocumentTypeValueSetCode("30706-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionUSDuringSurgery = DocumentTypeValueSetCode("30701-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UrinaryBladderUSPostVoid = DocumentTypeValueSetCode("69388-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AortaCTWAndWOContrast = DocumentTypeValueSetCode("69086-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PulmonaryVesselsCTAngiogramWAndWOContrast = DocumentTypeValueSetCode("69108-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RenalVesselsCTAngiogramWAndWOContrast = DocumentTypeValueSetCode("69085-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_LeftMRIWAndWOContrastIntraarticular = DocumentTypeValueSetCode("69207-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_RightMRIWAndWOContrastIntraarticular = DocumentTypeValueSetCode("69217-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftMRIWAndWOContrastIntraarticular = DocumentTypeValueSetCode("69208-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightMRIWAndWOContrastIntraarticular = DocumentTypeValueSetCode("69218-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCTWAndWOContrastIT = DocumentTypeValueSetCode("48442-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalMRIWAndWOContrastIT = DocumentTypeValueSetCode("48450-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarCTWAndWOContrastIT = DocumentTypeValueSetCode("44114-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarMRIWAndWOContrastIT = DocumentTypeValueSetCode("48452-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicCTWAndWOContrastIT = DocumentTypeValueSetCode("44113-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicMRIWAndWOContrastIT = DocumentTypeValueSetCode("48441-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenCTWAndWOContrastIV = DocumentTypeValueSetCode("36267-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenMRIWAndWOContrastIV = DocumentTypeValueSetCode("24557-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenRetroperitoneumCTWAndWOContrastIV = DocumentTypeValueSetCode("48743-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenAndPelvisCTWAndWOContrastIV = DocumentTypeValueSetCode("42274-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdominalVeinsMRIAngiogramWAndWOContrastIV = DocumentTypeValueSetCode("36846-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdominalVesselsCTAngiogramWAndWOContrastIV = DocumentTypeValueSetCode("30805-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdominalVesselsMRIAngiogramWAndWOContrastIV = DocumentTypeValueSetCode("36855-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AdrenalGlandCTWAndWOContrastIV = DocumentTypeValueSetCode("36950-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AdrenalGlandMRIWAndWOContrastIV = DocumentTypeValueSetCode("36951-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AnkleCTWAndWOContrastIV = DocumentTypeValueSetCode("36268-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AnkleMRIWAndWOContrastIV = DocumentTypeValueSetCode("24539-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_BilateralMRIWAndWOContrastIV = DocumentTypeValueSetCode("26187-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_LeftCTWAndWOContrastIV = DocumentTypeValueSetCode("36269-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_LeftMRIWAndWOContrastIV = DocumentTypeValueSetCode("26188-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_RightCTWAndWOContrastIV = DocumentTypeValueSetCode("36270-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_RightMRIWAndWOContrastIV = DocumentTypeValueSetCode("26189-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AortaMRIAngiogramWAndWOContrastIV = DocumentTypeValueSetCode("44131-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AortaAbdominalCTWAndWOContrastIV = DocumentTypeValueSetCode("36271-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AortaAbdominalMRIWAndWOContrastIV = DocumentTypeValueSetCode("36273-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AortaAbdominalMRIAngiogramWAndWOContrastIV = DocumentTypeValueSetCode("36272-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AortaThoracicMRIAngiogramWAndWOContrastIV = DocumentTypeValueSetCode("36274-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AortaAndFemoralArtery_BilateralCTAngiogramWAndWOContrastIV = (
        DocumentTypeValueSetCode("30806-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AorticArchMRIAngiogramWAndWOContrastIV = DocumentTypeValueSetCode("46360-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Axilla_LeftMRIWAndWOContrastIV = DocumentTypeValueSetCode("43509-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Axilla_RightMRIWAndWOContrastIV = DocumentTypeValueSetCode("43511-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BiliaryDuctsAndPancreaticDuctMRIWAndWOContrastIV = DocumentTypeValueSetCode(
        "36944-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainMRIWAndWOContrastIV = DocumentTypeValueSetCode("24587-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Brain_temporalMRIWAndWOContrastIV = DocumentTypeValueSetCode("48694-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainAndInternalAuditoryCanalMRIWAndWOContrastIV = DocumentTypeValueSetCode(
        "43769-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainAndPituitaryAndSellaTurcicaMRIWAndWOContrastIV = DocumentTypeValueSetCode(
        "42392-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastMRIWAndWOContrastIV = DocumentTypeValueSetCode("36276-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastImplantMRIWAndWOContrastIV = DocumentTypeValueSetCode("69189-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastImplant_BilateralMRIWAndWOContrastIV = DocumentTypeValueSetCode("69166-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastImplant_LeftMRIWAndWOContrastIV = DocumentTypeValueSetCode("38870-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastImplant_RightMRIWAndWOContrastIV = DocumentTypeValueSetCode("38062-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_BilateralMRIWAndWOContrastIV = DocumentTypeValueSetCode("36277-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_LeftMRIWAndWOContrastIV = DocumentTypeValueSetCode("36278-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_RightMRIWAndWOContrastIV = DocumentTypeValueSetCode("36279-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_UnilateralMRIWAndWOContrastIV = DocumentTypeValueSetCode("43528-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CalcaneusCTWAndWOContrastIV = DocumentTypeValueSetCode("36358-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Calcaneus_LeftCTWAndWOContrastIV = DocumentTypeValueSetCode("36280-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Calcaneus_RightCTWAndWOContrastIV = DocumentTypeValueSetCode("36281-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CarotidVesselMRIAngiogramWAndWOContrastIV = DocumentTypeValueSetCode("36856-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestCTWAndWOContrastIV = DocumentTypeValueSetCode("30598-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestMRIWAndWOContrastIV = DocumentTypeValueSetCode("36283-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestVeinsMRIAngiogramWAndWOContrastIV = DocumentTypeValueSetCode("36848-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestVesselsCTAngiogramWAndWOContrastIV = DocumentTypeValueSetCode("30804-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestVesselsMRIAngiogramWAndWOContrastIV = DocumentTypeValueSetCode("36420-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestAndAbdomenCTWAndWOContrastIV = DocumentTypeValueSetCode("42277-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestAndAbdomenMRIWAndWOContrastIV = DocumentTypeValueSetCode("36284-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestAndAbdomenAndPelvisCTWAndWOContrastIV = DocumentTypeValueSetCode("72252-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CircleOfWillisMRIAngiogramWAndWOContrastIV = DocumentTypeValueSetCode("69161-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClavicleMRIWAndWOContrastIV = DocumentTypeValueSetCode("42299-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Clavicle_LeftMRIWAndWOContrastIV = DocumentTypeValueSetCode("48455-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Clavicle_RightMRIWAndWOContrastIV = DocumentTypeValueSetCode("48454-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ElbowCTWAndWOContrastIV = DocumentTypeValueSetCode("36285-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ElbowMRIWAndWOContrastIV = DocumentTypeValueSetCode("24675-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_BilateralMRIWAndWOContrastIV = DocumentTypeValueSetCode("26193-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_LeftCTWAndWOContrastIV = DocumentTypeValueSetCode("36286-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_LeftMRIWAndWOContrastIV = DocumentTypeValueSetCode("26194-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_RightCTWAndWOContrastIV = DocumentTypeValueSetCode("36287-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_RightMRIWAndWOContrastIV = DocumentTypeValueSetCode("26195-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityCTWAndWOContrastIV = DocumentTypeValueSetCode("42268-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FaceMRIWAndWOContrastIV = DocumentTypeValueSetCode("24694-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FacialBonesAndMaxillaCTWAndWOContrastIV = DocumentTypeValueSetCode("30803-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FemurCTWAndWOContrastIV = DocumentTypeValueSetCode("36338-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Femur_LeftCTWAndWOContrastIV = DocumentTypeValueSetCode("36339-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Femur_RightCTWAndWOContrastIV = DocumentTypeValueSetCode("36340-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FingerMRIWAndWOContrastIV = DocumentTypeValueSetCode("69194-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Finger_LeftMRIWAndWOContrastIV = DocumentTypeValueSetCode("69204-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Finger_RightMRIWAndWOContrastIV = DocumentTypeValueSetCode("69214-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FootCTWAndWOContrastIV = DocumentTypeValueSetCode("36341-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FootMRIWAndWOContrastIV = DocumentTypeValueSetCode("30682-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_BilateralMRIWAndWOContrastIV = DocumentTypeValueSetCode("36342-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_LeftCTWAndWOContrastIV = DocumentTypeValueSetCode("36343-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_LeftMRIWAndWOContrastIV = DocumentTypeValueSetCode("36344-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_RightCTWAndWOContrastIV = DocumentTypeValueSetCode("36345-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_RightMRIWAndWOContrastIV = DocumentTypeValueSetCode("36346-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ForearmCTWAndWOContrastIV = DocumentTypeValueSetCode("36347-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ForearmMRIWAndWOContrastIV = DocumentTypeValueSetCode("30684-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Forearm_BilateralMRIWAndWOContrastIV = DocumentTypeValueSetCode("69174-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Forearm_LeftCTWAndWOContrastIV = DocumentTypeValueSetCode("36348-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Forearm_LeftMRIWAndWOContrastIV = DocumentTypeValueSetCode("36349-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Forearm_RightCTWAndWOContrastIV = DocumentTypeValueSetCode("36350-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Forearm_RightMRIWAndWOContrastIV = DocumentTypeValueSetCode("36351-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HandCTWAndWOContrastIV = DocumentTypeValueSetCode("36352-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HandMRIWAndWOContrastIV = DocumentTypeValueSetCode("30686-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_BilateralMRIWAndWOContrastIV = DocumentTypeValueSetCode("69177-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_LeftCTWAndWOContrastIV = DocumentTypeValueSetCode("36353-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_LeftMRIWAndWOContrastIV = DocumentTypeValueSetCode("36354-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_RightCTWAndWOContrastIV = DocumentTypeValueSetCode("36355-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_RightMRIWAndWOContrastIV = DocumentTypeValueSetCode("36356-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadCTWAndWOContrastIV = DocumentTypeValueSetCode("24726-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadCTCineWAndWOContrastIV = DocumentTypeValueSetCode("24729-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadVeinsMRIAngiogramWAndWOContrastIV = DocumentTypeValueSetCode("36847-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadVesselsCTAngiogramWAndWOContrastIV = DocumentTypeValueSetCode("30593-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadVesselsMRIAngiogramWAndWOContrastIV = DocumentTypeValueSetCode("36857-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartMRIWAndWOContrastIV = DocumentTypeValueSetCode("36357-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HipCTWAndWOContrastIV = DocumentTypeValueSetCode("36359-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HipMRIWAndWOContrastIV = DocumentTypeValueSetCode("30688-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_BilateralCTWAndWOContrastIV = DocumentTypeValueSetCode("36360-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_BilateralMRIWAndWOContrastIV = DocumentTypeValueSetCode("36361-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_LeftCTWAndWOContrastIV = DocumentTypeValueSetCode("36362-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_LeftMRIWAndWOContrastIV = DocumentTypeValueSetCode("36363-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_RightCTWAndWOContrastIV = DocumentTypeValueSetCode("36364-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_RightMRIWAndWOContrastIV = DocumentTypeValueSetCode("36365-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InternalAuditoryCanalCTWAndWOContrastIV = DocumentTypeValueSetCode("36282-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InternalAuditoryCanalMRIWAndWOContrastIV = DocumentTypeValueSetCode("30659-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InternalAuditoryCanalAndPosteriorFossaMRIWAndWOContrastIV = (
        DocumentTypeValueSetCode("24740-3")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KidneyCTWAndWOContrastIV = DocumentTypeValueSetCode("43768-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KidneyMRIWAndWOContrastIV = DocumentTypeValueSetCode("43775-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_BilateralCTWAndWOContrastIV = DocumentTypeValueSetCode("36377-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_BilateralMRIWAndWOContrastIV = DocumentTypeValueSetCode("36378-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_BilateralX_rayTomographWAndWOContrastIV = DocumentTypeValueSetCode("24784-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeCTWAndWOContrastIV = DocumentTypeValueSetCode("36379-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeMRIWAndWOContrastIV = DocumentTypeValueSetCode("24803-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeVessels_LeftMRIAngiogramWAndWOContrastIV = DocumentTypeValueSetCode("38837-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeVessels_RightMRIAngiogramWAndWOContrastIV = DocumentTypeValueSetCode("36862-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralMRIWAndWOContrastIV = DocumentTypeValueSetCode("26199-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftCTWAndWOContrastIV = DocumentTypeValueSetCode("36380-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftMRIWAndWOContrastIV = DocumentTypeValueSetCode("26200-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightCTWAndWOContrastIV = DocumentTypeValueSetCode("36381-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightMRIWAndWOContrastIV = DocumentTypeValueSetCode("26201-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LarynxMRIWAndWOContrastIV = DocumentTypeValueSetCode("36382-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LiverCTWAndWOContrastIV = DocumentTypeValueSetCode("30612-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LiverMRIWAndWOContrastIV = DocumentTypeValueSetCode("30670-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityCTWAndWOContrastIV = DocumentTypeValueSetCode("36288-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityMRIWAndWOContrastIV = DocumentTypeValueSetCode("39291-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVeinsMRIAngiogramWAndWOContrastIV = DocumentTypeValueSetCode(
        "36416-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVeins_LeftMRIAngiogramWAndWOContrastIV = DocumentTypeValueSetCode(
        "36849-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVeins_RightMRIAngiogramWAndWOContrastIV = DocumentTypeValueSetCode(
        "36850-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVesselsCTAngiogramWAndWOContrastIV = DocumentTypeValueSetCode(
        "30807-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVesselsMRIAngiogramWAndWOContrastIV = DocumentTypeValueSetCode(
        "44128-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVessels_LeftCTAngiogramWAndWOContrastIV = DocumentTypeValueSetCode(
        "46308-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVessels_LeftMRIAngiogramWAndWOContrastIV = DocumentTypeValueSetCode(
        "36858-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVessels_RightCTAngiogramWAndWOContrastIV = DocumentTypeValueSetCode(
        "46307-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVessels_RightMRIAngiogramWAndWOContrastIV = DocumentTypeValueSetCode(
        "36859-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremity_BilateralMRIWAndWOContrastIV = DocumentTypeValueSetCode("36289-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityJointMRIWAndWOContrastIV = DocumentTypeValueSetCode("36371-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityJoint_LeftMRIWAndWOContrastIV = DocumentTypeValueSetCode("36372-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityJoint_RightMRIWAndWOContrastIV = DocumentTypeValueSetCode("36373-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremity_LeftCTWAndWOContrastIV = DocumentTypeValueSetCode("36290-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremity_LeftMRIWAndWOContrastIV = DocumentTypeValueSetCode("36291-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremity_RightCTWAndWOContrastIV = DocumentTypeValueSetCode("36292-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremity_RightMRIWAndWOContrastIV = DocumentTypeValueSetCode("36333-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerLegCTWAndWOContrastIV = DocumentTypeValueSetCode("36408-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerLegMRIWAndWOContrastIV = DocumentTypeValueSetCode("30870-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerLeg_BilateralMRIWAndWOContrastIV = DocumentTypeValueSetCode("42697-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerLeg_LeftCTWAndWOContrastIV = DocumentTypeValueSetCode("36409-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerLeg_LeftMRIWAndWOContrastIV = DocumentTypeValueSetCode("36410-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerLeg_RightCTWAndWOContrastIV = DocumentTypeValueSetCode("36411-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerLeg_RightMRIWAndWOContrastIV = DocumentTypeValueSetCode("36412-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MandibleCTWAndWOContrastIV = DocumentTypeValueSetCode("36383-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MediastinumMRIWAndWOContrastIV = DocumentTypeValueSetCode("37272-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NasopharynxCTWAndWOContrastIV = DocumentTypeValueSetCode("48443-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NasopharynxMRIWAndWOContrastIV = DocumentTypeValueSetCode("36384-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeckCTWAndWOContrastIV = DocumentTypeValueSetCode("30586-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeckMRIWAndWOContrastIV = DocumentTypeValueSetCode("24840-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeckVeinsMRIAngiogramWAndWOContrastIV = DocumentTypeValueSetCode("36853-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeckVesselsCTAngiogramWAndWOContrastIV = DocumentTypeValueSetCode("30594-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeckVesselsMRIAngiogramWAndWOContrastIV = DocumentTypeValueSetCode("36423-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OrbitCTWAndWOContrastIV = DocumentTypeValueSetCode("48451-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OrbitMRIWAndWOContrastIV = DocumentTypeValueSetCode("36842-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OrbitVesselsMRIAngiogramWAndWOContrastIV = DocumentTypeValueSetCode("43458-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Orbit_BilateralCTWAndWOContrastIV = DocumentTypeValueSetCode("24849-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Orbit_BilateralMRIWAndWOContrastIV = DocumentTypeValueSetCode("24851-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Orbit_LeftMRIWAndWOContrastIV = DocumentTypeValueSetCode("36843-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Orbit_RightMRIWAndWOContrastIV = DocumentTypeValueSetCode("36844-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OrbitAndFaceMRIWAndWOContrastIV = DocumentTypeValueSetCode("39029-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OrbitAndFaceAndNeckMRIWAndWOContrastIV = DocumentTypeValueSetCode("46310-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OvaryMRIWAndWOContrastIV = DocumentTypeValueSetCode("36845-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PancreasCTWAndWOContrastIV = DocumentTypeValueSetCode("30614-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PancreasMRIWAndWOContrastIV = DocumentTypeValueSetCode("36385-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ParotidGlandCTWAndWOContrastIV = DocumentTypeValueSetCode("46311-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ParotidGlandMRIWAndWOContrastIV = DocumentTypeValueSetCode("37265-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisCTWAndWOContrastIV = DocumentTypeValueSetCode("30616-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisMRIWAndWOContrastIV = DocumentTypeValueSetCode("30674-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisVeinsMRIAngiogramWAndWOContrastIV = DocumentTypeValueSetCode("36854-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisVesselsCTAngiogramWAndWOContrastIV = DocumentTypeValueSetCode("30623-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisVesselsMRIAngiogramWAndWOContrastIV = DocumentTypeValueSetCode("36863-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisAndHipMRIWAndWOContrastIV = DocumentTypeValueSetCode("30672-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PetrousBoneCTWAndWOContrastIV = DocumentTypeValueSetCode("36835-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PituitaryAndSellaTurcicaCTWAndWOContrastIV = DocumentTypeValueSetCode("24904-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PituitaryAndSellaTurcicaMRIWAndWOContrastIV = DocumentTypeValueSetCode("24879-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PortalVeinMRIAngiogramWAndWOContrastIV = DocumentTypeValueSetCode("36414-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PosteriorFossaCTWAndWOContrastIV = DocumentTypeValueSetCode("36387-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PosteriorFossaMRIWAndWOContrastIV = DocumentTypeValueSetCode("36388-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ProstateMRIWAndWOContrastIV = DocumentTypeValueSetCode("36389-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RenalArteryMRIAngiogramWAndWOContrastIV = DocumentTypeValueSetCode("36275-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RenalVeinMRIAngiogramWAndWOContrastIV = DocumentTypeValueSetCode("36415-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RenalVesselsMRIAngiogramWAndWOContrastIV = DocumentTypeValueSetCode("44134-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SacroiliacJointCTWAndWOContrastIV = DocumentTypeValueSetCode("36375-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SacroiliacJointMRIWAndWOContrastIV = DocumentTypeValueSetCode("36376-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SacrumCTWAndWOContrastIV = DocumentTypeValueSetCode("36390-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SacrumMRIWAndWOContrastIV = DocumentTypeValueSetCode("36391-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SacrumAndCoccyxMRIWAndWOContrastIV = DocumentTypeValueSetCode("36392-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Scapula_LeftMRIWAndWOContrastIV = DocumentTypeValueSetCode("36393-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Scapula_RightMRIWAndWOContrastIV = DocumentTypeValueSetCode("36394-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScrotumAndTesticleMRIWAndWOContrastIV = DocumentTypeValueSetCode("36406-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ShoulderCTWAndWOContrastIV = DocumentTypeValueSetCode("36395-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ShoulderMRIWAndWOContrastIV = DocumentTypeValueSetCode("24906-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ShoulderVessels_LeftMRIAngiogramWAndWOContrastIV = DocumentTypeValueSetCode(
        "36864-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ShoulderVessels_RightMRIAngiogramWAndWOContrastIV = DocumentTypeValueSetCode(
        "36865-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_BilateralMRIWAndWOContrastIV = DocumentTypeValueSetCode("26202-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftCTWAndWOContrastIV = DocumentTypeValueSetCode("36396-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftMRIWAndWOContrastIV = DocumentTypeValueSetCode("26203-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightCTWAndWOContrastIV = DocumentTypeValueSetCode("36397-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightMRIWAndWOContrastIV = DocumentTypeValueSetCode("26204-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SinusesCTWAndWOContrastIV = DocumentTypeValueSetCode("36398-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SinusesMRIWAndWOContrastIV = DocumentTypeValueSetCode("30663-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Skull_baseCTWAndWOContrastIV = DocumentTypeValueSetCode("44111-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Skull_baseMRIWAndWOContrastIV = DocumentTypeValueSetCode("69220-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpinalVeinMRIAngiogramWAndWOContrastIV = DocumentTypeValueSetCode("37277-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCTWAndWOContrastIV = DocumentTypeValueSetCode("36399-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineMRIWAndWOContrastIV = DocumentTypeValueSetCode("36400-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineVesselsMRIAngiogramWAndWOContrastIV = DocumentTypeValueSetCode("37505-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalCTWAndWOContrastIV = DocumentTypeValueSetCode("36401-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalMRIWAndWOContrastIV = DocumentTypeValueSetCode("24937-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CervicalSpineVesselsMRIAngiogramWAndWOContrastIV = DocumentTypeValueSetCode(
        "37506-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalAndSpineThoracicMRIWAndWOContrastIV = DocumentTypeValueSetCode(
        "43456-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalAndThoracicAndLumbarMRIWAndWOContrastIV = DocumentTypeValueSetCode(
        "30855-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarCTWAndWOContrastIV = DocumentTypeValueSetCode("36402-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarMRIWAndWOContrastIV = DocumentTypeValueSetCode("24967-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LumbarSpineVesselsMRIAngiogramWAndWOContrastIV = DocumentTypeValueSetCode("37507-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicCTWAndWOContrastIV = DocumentTypeValueSetCode("36403-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicMRIWAndWOContrastIV = DocumentTypeValueSetCode("24981-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThoracicSpineVesselsMRIAngiogramWAndWOContrastIV = DocumentTypeValueSetCode(
        "37508-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpleenCTWAndWOContrastIV = DocumentTypeValueSetCode("24989-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpleenMRIWAndWOContrastIV = DocumentTypeValueSetCode("36404-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SternoclavicularJointCTWAndWOContrastIV = DocumentTypeValueSetCode("37266-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SternumCTWAndWOContrastIV = DocumentTypeValueSetCode("36405-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SuperiorMesentericVesselsMRIAngiogramWAndWOContrastIV = DocumentTypeValueSetCode(
        "44231-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporalBoneCTWAndWOContrastIV = DocumentTypeValueSetCode("36837-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporomandibularJointCTWAndWOContrastIV = DocumentTypeValueSetCode("37267-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporomandibularJointMRIWAndWOContrastIV = DocumentTypeValueSetCode("37268-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporomandibularJoint_BilateralMRIWAndWOContrastIV = DocumentTypeValueSetCode(
        "37269-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporomandibularJoint_LeftMRIWAndWOContrastIV = DocumentTypeValueSetCode("37270-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporomandibularJoint_RightMRIWAndWOContrastIV = DocumentTypeValueSetCode(
        "37271-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThighMRIWAndWOContrastIV = DocumentTypeValueSetCode("24703-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Thigh_BilateralMRIWAndWOContrastIV = DocumentTypeValueSetCode("26196-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Thigh_LeftMRIWAndWOContrastIV = DocumentTypeValueSetCode("26197-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Thigh_RightMRIWAndWOContrastIV = DocumentTypeValueSetCode("26198-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThoracicOutletMRIWAndWOContrastIV = DocumentTypeValueSetCode("24583-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThoracicOutlet_BilateralMRIWAndWOContrastIV = DocumentTypeValueSetCode("26190-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThoracicOutlet_LeftMRIWAndWOContrastIV = DocumentTypeValueSetCode("26191-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThoracicOutlet_RightMRIWAndWOContrastIV = DocumentTypeValueSetCode("26192-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThyroidMRIWAndWOContrastIV = DocumentTypeValueSetCode("36407-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Toes_LeftMRIWAndWOContrastIV = DocumentTypeValueSetCode("72241-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Toes_RightMRIWAndWOContrastIV = DocumentTypeValueSetCode("72238-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperArmCTWAndWOContrastIV = DocumentTypeValueSetCode("36366-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperArmMRIWAndWOContrastIV = DocumentTypeValueSetCode("30690-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperArm_BilateralMRIWAndWOContrastIV = DocumentTypeValueSetCode("69181-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperArm_LeftCTWAndWOContrastIV = DocumentTypeValueSetCode("36367-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperArm_LeftMRIWAndWOContrastIV = DocumentTypeValueSetCode("36368-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperArm_RightCTWAndWOContrastIV = DocumentTypeValueSetCode("36369-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperArm_RightMRIWAndWOContrastIV = DocumentTypeValueSetCode("36370-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityCTWAndWOContrastIV = DocumentTypeValueSetCode("36334-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityMRIWAndWOContrastIV = DocumentTypeValueSetCode("39034-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityVeinsMRIAngiogramWAndWOContrastIV = DocumentTypeValueSetCode(
        "36417-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityVeins_LeftMRIAngiogramWAndWOContrastIV = DocumentTypeValueSetCode(
        "36851-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityVeins_RightMRIAngiogramWAndWOContrastIV = DocumentTypeValueSetCode(
        "36852-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityVesselsCTAngiogramWAndWOContrastIV = DocumentTypeValueSetCode(
        "36421-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityVesselsMRIAngiogramWAndWOContrastIV = DocumentTypeValueSetCode(
        "36422-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityVessels_LeftCTAngiogramWAndWOContrastIV = DocumentTypeValueSetCode(
        "46312-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityVessels_LeftMRIAngiogramWAndWOContrastIV = DocumentTypeValueSetCode(
        "36860-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityVessels_RightCTAngiogramWAndWOContrastIV = DocumentTypeValueSetCode(
        "46309-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityVessels_RightMRIAngiogramWAndWOContrastIV = DocumentTypeValueSetCode(
        "36861-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremity_BilateralMRIWAndWOContrastIV = DocumentTypeValueSetCode("69186-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremity_jointMRIWAndWOContrastIV = DocumentTypeValueSetCode("36374-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityJoint_LeftMRIWAndWOContrastIV = DocumentTypeValueSetCode("36840-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityJoint_RightMRIWAndWOContrastIV = DocumentTypeValueSetCode("36841-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremity_LeftCTWAndWOContrastIV = DocumentTypeValueSetCode("36335-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremity_LeftMRIWAndWOContrastIV = DocumentTypeValueSetCode("38831-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremity_RightCTWAndWOContrastIV = DocumentTypeValueSetCode("36336-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremity_RightMRIWAndWOContrastIV = DocumentTypeValueSetCode("36337-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UterusMRIWAndWOContrastIV = DocumentTypeValueSetCode("36413-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InferiorVenaCavaMRIWAndWOContrastIV = DocumentTypeValueSetCode("36418-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SuperiorVenaCavaMRIWAndWOContrastIV = DocumentTypeValueSetCode("36419-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    WristCTWAndWOContrastIV = DocumentTypeValueSetCode("37457-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    WristMRIWAndWOContrastIV = DocumentTypeValueSetCode("25035-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_BilateralMRIWAndWOContrastIV = DocumentTypeValueSetCode("26205-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_LeftCTWAndWOContrastIV = DocumentTypeValueSetCode("37458-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_LeftMRIWAndWOContrastIV = DocumentTypeValueSetCode("26206-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_RightCTWAndWOContrastIV = DocumentTypeValueSetCode("38802-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_RightMRIWAndWOContrastIV = DocumentTypeValueSetCode("26207-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionMRIWAndWOContrastIV = DocumentTypeValueSetCode("42298-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainMRIWAndWOContrastIVAndWAnesthesia = DocumentTypeValueSetCode("24588-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisMRIWAndWOContrastIVAndWEndorectalCoil = DocumentTypeValueSetCode("72244-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LiverMRIWAndWOFerumoxidesIV = DocumentTypeValueSetCode("43448-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenCTWAndWOReducedContrastVolumeIV = DocumentTypeValueSetCode("46318-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestCTWAndWOReducedContrastVolumeIV = DocumentTypeValueSetCode("46317-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FacialBonesAndMaxillaCTWAndWOReducedContrastVolumeIV = DocumentTypeValueSetCode(
        "46315-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadCTWAndWOReducedContrastVolumeIV = DocumentTypeValueSetCode("46316-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InternalAuditoryCanalCTWAndWOReducedContrastVolumeIV = DocumentTypeValueSetCode(
        "46314-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisCTWAndWOReducedContrastVolumeIV = DocumentTypeValueSetCode("46313-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RectumAndColonCT3DWAirContrastPR = DocumentTypeValueSetCode("60515-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainMRIWAnesthesia = DocumentTypeValueSetCode("24586-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalMRIWAnesthesia = DocumentTypeValueSetCode("24936-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarMRIWAnesthesia = DocumentTypeValueSetCode("24977-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionCTWAnesthesia = DocumentTypeValueSetCode("25046-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GallbladderUSWCholecystokinin = DocumentTypeValueSetCode("38022-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionCTWConsciousSedation = DocumentTypeValueSetCode("25047-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionMRIWConsciousSedation = DocumentTypeValueSetCode("25057-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenCTWContrast = DocumentTypeValueSetCode("30599-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenRetroperitoneumCTWContrast = DocumentTypeValueSetCode("24567-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionUSWContrast = DocumentTypeValueSetCode("38055-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HepaticArteryCTAngiogramWContrastIA = DocumentTypeValueSetCode("36809-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PulmonaryArtery_BilateralMRIAngiogramWContrastIA = DocumentTypeValueSetCode(
        "69162-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UrinaryBladderAndUrethraSPECTWContrastIntraBladderDuringVoiding = (
        DocumentTypeValueSetCode("69238-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastDuctUSWContrastIntraDuct = DocumentTypeValueSetCode("30853-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SalivaryGlandCTWContrastIntraSalivaryDuct = DocumentTypeValueSetCode("36941-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SinusTractCTWContrastIntraSinusTract = DocumentTypeValueSetCode("37237-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AnkleMRIWContrastIntraarticular = DocumentTypeValueSetCode("36115-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_LeftCTWContrastIntraarticular = DocumentTypeValueSetCode("69102-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_LeftMRIWContrastIntraarticular = DocumentTypeValueSetCode("36116-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_RightCTWContrastIntraarticular = DocumentTypeValueSetCode("69109-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_RightMRIWContrastIntraarticular = DocumentTypeValueSetCode("36117-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ElbowMRIWContrastIntraarticular = DocumentTypeValueSetCode("46319-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_LeftCTWContrastIntraarticular = DocumentTypeValueSetCode("69103-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_LeftMRIWContrastIntraarticular = DocumentTypeValueSetCode("36118-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_RightCTWContrastIntraarticular = DocumentTypeValueSetCode("69110-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_RightMRIWContrastIntraarticular = DocumentTypeValueSetCode("36119-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HipMRIWContrastIntraarticular = DocumentTypeValueSetCode("36120-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_LeftCTWContrastIntraarticular = DocumentTypeValueSetCode("69105-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_LeftMRIWContrastIntraarticular = DocumentTypeValueSetCode("36121-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_RightCTWContrastIntraarticular = DocumentTypeValueSetCode("69112-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_RightMRIWContrastIntraarticular = DocumentTypeValueSetCode("36122-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeCTWContrastIntraarticular = DocumentTypeValueSetCode("36124-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeMRIWContrastIntraarticular = DocumentTypeValueSetCode("36125-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftCTWContrastIntraarticular = DocumentTypeValueSetCode("69106-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftMRIWContrastIntraarticular = DocumentTypeValueSetCode("36126-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightCTWContrastIntraarticular = DocumentTypeValueSetCode("69114-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightMRIWContrastIntraarticular = DocumentTypeValueSetCode("36127-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityJointCTWContrastIntraarticular = DocumentTypeValueSetCode("37238-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityJointMRIWContrastIntraarticular = DocumentTypeValueSetCode("69210-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SacroiliacJointCTWContrastIntraarticular = DocumentTypeValueSetCode("36123-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ShoulderCTWContrastIntraarticular = DocumentTypeValueSetCode("36128-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ShoulderMRIWContrastIntraarticular = DocumentTypeValueSetCode("36129-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftCTWContrastIntraarticular = DocumentTypeValueSetCode("38828-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftMRIWContrastIntraarticular = DocumentTypeValueSetCode("36130-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightCTWContrastIntraarticular = DocumentTypeValueSetCode("36131-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightMRIWContrastIntraarticular = DocumentTypeValueSetCode("36132-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperJointCTWContrastIntraarticular = DocumentTypeValueSetCode("36810-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    WristMRIWContrastIntraarticular = DocumentTypeValueSetCode("37444-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_LeftCTWContrastIntraarticular = DocumentTypeValueSetCode("69107-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_LeftMRIWContrastIntraarticular = DocumentTypeValueSetCode("37445-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_RightCTWContrastIntraarticular = DocumentTypeValueSetCode("69115-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_RightMRIWContrastIntraarticular = DocumentTypeValueSetCode("37446-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    JointCTWContrastIntraarticular = DocumentTypeValueSetCode("36811-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    JointMRIWContrastIntraarticular = DocumentTypeValueSetCode("36812-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCTWContrastIntradisc = DocumentTypeValueSetCode("39322-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalCTWContrastIntradisc = DocumentTypeValueSetCode("37496-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarCTWContrastIntradisc = DocumentTypeValueSetCode("37509-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicCTWContrastIntradisc = DocumentTypeValueSetCode("70931-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadCisternCTWContrastIT = DocumentTypeValueSetCode("24734-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCTWContrastIT = DocumentTypeValueSetCode("47985-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalCTWContrastIT = DocumentTypeValueSetCode("24934-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalMRIWContrastIT = DocumentTypeValueSetCode("48447-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarCTWContrastIT = DocumentTypeValueSetCode("24965-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarMRIWContrastIT = DocumentTypeValueSetCode("48436-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicCTWContrastIT = DocumentTypeValueSetCode("30596-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicMRIWContrastIT = DocumentTypeValueSetCode("48439-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenMRIWContrastIV = DocumentTypeValueSetCode("36134-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenAndPelvisCTWContrastIV = DocumentTypeValueSetCode("36813-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdominalVesselsCTAngiogramWContrastIV = DocumentTypeValueSetCode("36828-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdominalVesselsMRIAngiogramWContrastIV = DocumentTypeValueSetCode("24533-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdominalVesselsAndPelvisVesselsCTAngiogramWContrastIV = DocumentTypeValueSetCode(
        "69908-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AdrenalGlandCTWContrastIV = DocumentTypeValueSetCode("36943-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AdrenalGlandMRIWContrastIV = DocumentTypeValueSetCode("44124-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AnkleCTWContrastIV = DocumentTypeValueSetCode("36135-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AnkleMRIWContrastIV = DocumentTypeValueSetCode("36136-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_BilateralMRIWContrastIV = DocumentTypeValueSetCode("69163-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_LeftCTWContrastIV = DocumentTypeValueSetCode("36137-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_LeftMRIWContrastIV = DocumentTypeValueSetCode("36138-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_RightCTWContrastIV = DocumentTypeValueSetCode("36139-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_RightMRIWContrastIV = DocumentTypeValueSetCode("36140-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AortaCTWContrastIV = DocumentTypeValueSetCode("36142-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AortaCTAngiogramWContrastIV = DocumentTypeValueSetCode("36141-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AortaAbdominalCTWContrastIV = DocumentTypeValueSetCode("36143-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AortaThoracicCTWContrastIV = DocumentTypeValueSetCode("24545-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AortaAndFemoralArtery_BilateralCTAngiogramWContrastIV = DocumentTypeValueSetCode(
        "72255-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AortaAndLowerExtremityVesselsCTAngiogramWContrastIV = DocumentTypeValueSetCode(
        "43503-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AorticArchCTAngiogramWContrastIV = DocumentTypeValueSetCode("36144-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AorticStentCTAngiogramWContrastIV = DocumentTypeValueSetCode("37499-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AppendixCTWContrastIV = DocumentTypeValueSetCode("36145-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Axilla_LeftMRIWContrastIV = DocumentTypeValueSetCode("43504-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Axilla_RightMRIWContrastIV = DocumentTypeValueSetCode("43505-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BiliaryDuctsAndPancreaticDuctMRIWContrastIV = DocumentTypeValueSetCode("44125-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BladderCTWContrastIV = DocumentTypeValueSetCode("69095-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainMRIWContrastIV = DocumentTypeValueSetCode("24589-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Brain_temporalMRIWContrastIV = DocumentTypeValueSetCode("48444-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainAndInternalAuditoryCanalMRIWContrastIV = DocumentTypeValueSetCode("37239-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainAndLarynxMRIWContrastIV = DocumentTypeValueSetCode("37215-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainAndPituitaryAndSellaTurcicaMRIWContrastIV = DocumentTypeValueSetCode("42391-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastMRIWContrastIV = DocumentTypeValueSetCode("36149-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastImplantMRIWContrastIV = DocumentTypeValueSetCode("69190-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastImplant_BilateralMRIWContrastIV = DocumentTypeValueSetCode("69167-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_BilateralMRIWContrastIV = DocumentTypeValueSetCode("36150-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_LeftMRIWContrastIV = DocumentTypeValueSetCode("36151-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_RightMRIWContrastIV = DocumentTypeValueSetCode("36152-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_UnilateralMRIWContrastIV = DocumentTypeValueSetCode("46323-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CalcaneusCTWContrastIV = DocumentTypeValueSetCode("36198-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Calcaneus_LeftCTWContrastIV = DocumentTypeValueSetCode("36153-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Calcaneus_RightCTWContrastIV = DocumentTypeValueSetCode("36154-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CarotidArteryCTAngiogramWContrastIV = DocumentTypeValueSetCode("36146-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CarotidVesselMRIAngiogramWContrastIV = DocumentTypeValueSetCode("36829-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestCTWContrastIV = DocumentTypeValueSetCode("24628-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestMRIWContrastIV = DocumentTypeValueSetCode("36156-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestVesselsCTAngiogramWContrastIV = DocumentTypeValueSetCode("36266-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestVesselsMRIAngiogramWContrastIV = DocumentTypeValueSetCode("24659-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestAndAbdomenCTWContrastIV = DocumentTypeValueSetCode("42275-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestAndAbdomenMRIWContrastIV = DocumentTypeValueSetCode("36942-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestAndAbdomenAndPelvisCTWContrastIV = DocumentTypeValueSetCode("72254-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CircleOfWillisMRIAngiogramWContrastIV = DocumentTypeValueSetCode("37254-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClavicleMRIWContrastIV = DocumentTypeValueSetCode("42694-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Clavicle_LeftMRIWContrastIV = DocumentTypeValueSetCode("48457-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Clavicle_RightMRIWContrastIV = DocumentTypeValueSetCode("48456-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ElbowCTWContrastIV = DocumentTypeValueSetCode("36157-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ElbowMRIWContrastIV = DocumentTypeValueSetCode("36158-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_BilateralMRIWContrastIV = DocumentTypeValueSetCode("69170-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_LeftCTWContrastIV = DocumentTypeValueSetCode("36159-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_LeftMRIWContrastIV = DocumentTypeValueSetCode("36160-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_RightCTWContrastIV = DocumentTypeValueSetCode("36161-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_RightMRIWContrastIV = DocumentTypeValueSetCode("36162-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityCTWContrastIV = DocumentTypeValueSetCode("24691-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Extremity_BilateralCTWContrastIV = DocumentTypeValueSetCode("26184-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Extremity_LeftCTWContrastIV = DocumentTypeValueSetCode("26185-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Extremity_RightCTWContrastIV = DocumentTypeValueSetCode("26186-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FaceMRIWContrastIV = DocumentTypeValueSetCode("36148-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FacialBonesAndMaxillaCTWContrastIV = DocumentTypeValueSetCode("30801-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FacialBonesAndSinusesCTWContrastIV = DocumentTypeValueSetCode("24697-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FemurCTWContrastIV = DocumentTypeValueSetCode("36172-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Femur_BilateralMRIWContrastIV = DocumentTypeValueSetCode("69172-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Femur_LeftCTWContrastIV = DocumentTypeValueSetCode("36174-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Femur_RightCTWContrastIV = DocumentTypeValueSetCode("36176-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FingerMRIWContrastIV = DocumentTypeValueSetCode("69195-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Finger_LeftMRIWContrastIV = DocumentTypeValueSetCode("69205-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Finger_RightMRIWContrastIV = DocumentTypeValueSetCode("69215-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FootCTWContrastIV = DocumentTypeValueSetCode("36178-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FootMRIWContrastIV = DocumentTypeValueSetCode("36179-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_BilateralMRIWContrastIV = DocumentTypeValueSetCode("36180-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_LeftCTWContrastIV = DocumentTypeValueSetCode("36181-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_LeftMRIWContrastIV = DocumentTypeValueSetCode("36182-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_RightCTWContrastIV = DocumentTypeValueSetCode("36183-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_RightMRIWContrastIV = DocumentTypeValueSetCode("36184-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ForearmCTWContrastIV = DocumentTypeValueSetCode("36185-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ForearmMRIWContrastIV = DocumentTypeValueSetCode("36186-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Forearm_BilateralMRIWContrastIV = DocumentTypeValueSetCode("69175-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Forearm_LeftCTWContrastIV = DocumentTypeValueSetCode("36187-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Forearm_LeftMRIWContrastIV = DocumentTypeValueSetCode("36188-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Forearm_RightCTWContrastIV = DocumentTypeValueSetCode("36189-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Forearm_RightMRIWContrastIV = DocumentTypeValueSetCode("36190-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HandCTWContrastIV = DocumentTypeValueSetCode("36191-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HandMRIWContrastIV = DocumentTypeValueSetCode("36192-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_BilateralMRIWContrastIV = DocumentTypeValueSetCode("69178-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_LeftCTWContrastIV = DocumentTypeValueSetCode("36193-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_LeftMRIWContrastIV = DocumentTypeValueSetCode("36194-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_RightCTWContrastIV = DocumentTypeValueSetCode("36195-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_RightMRIWContrastIV = DocumentTypeValueSetCode("36196-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadCTWContrastIV = DocumentTypeValueSetCode("24727-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadArteriesCTAngiogramWContrastIV = DocumentTypeValueSetCode("36814-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadVeinsMRIAngiogramWContrastIV = DocumentTypeValueSetCode("36826-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadVesselsCTAngiogramWContrastIV = DocumentTypeValueSetCode("36830-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadVesselsMRIAngiogramWContrastIV = DocumentTypeValueSetCode("24593-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadVesselsAndNeckVesselsCTAngiogramWContrastIV = DocumentTypeValueSetCode(
        "37498-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadSagittalSinusMRIAngiogramWContrastIV = DocumentTypeValueSetCode("24747-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartMRIWContrastIV = DocumentTypeValueSetCode("36197-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HipCTWContrastIV = DocumentTypeValueSetCode("36200-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HipMRIWContrastIV = DocumentTypeValueSetCode("36199-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_BilateralCTWContrastIV = DocumentTypeValueSetCode("36201-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_BilateralMRIWContrastIV = DocumentTypeValueSetCode("36202-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_LeftCTWContrastIV = DocumentTypeValueSetCode("36203-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_LeftMRIWContrastIV = DocumentTypeValueSetCode("36204-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_RightCTWContrastIV = DocumentTypeValueSetCode("36205-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_RightMRIWContrastIV = DocumentTypeValueSetCode("36206-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InternalAuditoryCanalCTWContrastIV = DocumentTypeValueSetCode("30583-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InternalAuditoryCanalMRIWContrastIV = DocumentTypeValueSetCode("36155-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KidneyCTWContrastIV = DocumentTypeValueSetCode("46322-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KidneyMRIWContrastIV = DocumentTypeValueSetCode("36113-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_BilateralCTWContrastIV = DocumentTypeValueSetCode("43766-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_BilateralMRIWContrastIV = DocumentTypeValueSetCode("36219-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_BilateralX_rayTomographWContrastIV = DocumentTypeValueSetCode("24790-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_LeftMRIWContrastIV = DocumentTypeValueSetCode("36220-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_RightMRIWContrastIV = DocumentTypeValueSetCode("36221-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeCTWContrastIV = DocumentTypeValueSetCode("36222-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeMRIWContrastIV = DocumentTypeValueSetCode("36223-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralCTWContrastIV = DocumentTypeValueSetCode("69088-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralMRIWContrastIV = DocumentTypeValueSetCode("36224-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftCTWContrastIV = DocumentTypeValueSetCode("36225-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftMRIWContrastIV = DocumentTypeValueSetCode("36226-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightCTWContrastIV = DocumentTypeValueSetCode("36227-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightMRIWContrastIV = DocumentTypeValueSetCode("36228-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LarynxCTWContrastIV = DocumentTypeValueSetCode("36229-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LarynxMRIWContrastIV = DocumentTypeValueSetCode("36230-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LiverCTWContrastIV = DocumentTypeValueSetCode("24815-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LiverMRIWContrastIV = DocumentTypeValueSetCode("36231-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityCTWContrastIV = DocumentTypeValueSetCode("30624-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityMRIWContrastIV = DocumentTypeValueSetCode("39293-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVeins_LeftCTWContrastIV = DocumentTypeValueSetCode("36824-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVeins_RightCTWContrastIV = DocumentTypeValueSetCode("36825-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVesselsCTAngiogramWContrastIV = DocumentTypeValueSetCode("36831-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVesselsMRIAngiogramWContrastIV = DocumentTypeValueSetCode("46324-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVessels_BilateralMRIAngiogramWContrastIV = DocumentTypeValueSetCode(
        "44135-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremity_BilateralCTWContrastIV = DocumentTypeValueSetCode("50755-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremity_BilateralMRIWContrastIV = DocumentTypeValueSetCode("36163-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityJointMRIWContrastIV = DocumentTypeValueSetCode("36213-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityJoint_LeftMRIWContrastIV = DocumentTypeValueSetCode("36214-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityJoint_RightMRIWContrastIV = DocumentTypeValueSetCode("36215-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremity_LeftCTWContrastIV = DocumentTypeValueSetCode("36164-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremity_LeftMRIWContrastIV = DocumentTypeValueSetCode("36165-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremity_RightCTWContrastIV = DocumentTypeValueSetCode("36166-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremity_RightMRIWContrastIV = DocumentTypeValueSetCode("36167-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerLegCTWContrastIV = DocumentTypeValueSetCode("36258-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerLegMRIWContrastIV = DocumentTypeValueSetCode("36259-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerLegVesselsMRIAngiogramWContrastIV = DocumentTypeValueSetCode("24820-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerLegVessels_BilateralMRIAngiogramWContrastIV = DocumentTypeValueSetCode(
        "43512-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerLeg_BilateralMRIWContrastIV = DocumentTypeValueSetCode("42695-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerLeg_LeftCTWContrastIV = DocumentTypeValueSetCode("36260-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerLeg_LeftMRIWContrastIV = DocumentTypeValueSetCode("36261-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerLeg_RightCTWContrastIV = DocumentTypeValueSetCode("36262-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerLeg_RightMRIWContrastIV = DocumentTypeValueSetCode("36263-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MandibleCTWContrastIV = DocumentTypeValueSetCode("36232-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NasopharynxCTWContrastIV = DocumentTypeValueSetCode("48446-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NasopharynxMRIWContrastIV = DocumentTypeValueSetCode("36233-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NasopharynxAndNeckCTWContrastIV = DocumentTypeValueSetCode("24836-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeckCTWContrastIV = DocumentTypeValueSetCode("36235-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeckMRIWContrastIV = DocumentTypeValueSetCode("24841-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeckVeinsMRIAngiogramWContrastIV = DocumentTypeValueSetCode("36827-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeckVesselsCTAngiogramWContrastIV = DocumentTypeValueSetCode("36234-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeckVesselsMRIAngiogramWContrastIV = DocumentTypeValueSetCode("24844-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OrbitCTWContrastIV = DocumentTypeValueSetCode("48449-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OrbitMRIWContrastIV = DocumentTypeValueSetCode("36820-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OrbitVesselsMRIAngiogramWContrastIV = DocumentTypeValueSetCode("36832-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Orbit_BilateralCTWContrastIV = DocumentTypeValueSetCode("24850-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Orbit_BilateralMRIWContrastIV = DocumentTypeValueSetCode("24852-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Orbit_LeftMRIWContrastIV = DocumentTypeValueSetCode("36821-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Orbit_RightMRIWContrastIV = DocumentTypeValueSetCode("36822-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OrbitAndFaceCTWContrastIV = DocumentTypeValueSetCode("46320-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OrbitAndFaceMRIWContrastIV = DocumentTypeValueSetCode("39038-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OrbitAndFaceAndNeckMRIWContrastIV = DocumentTypeValueSetCode("46321-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OvaryMRIWContrastIV = DocumentTypeValueSetCode("36823-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PancreasCTWContrastIV = DocumentTypeValueSetCode("24858-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PancreasMRIWContrastIV = DocumentTypeValueSetCode("36236-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ParotidGlandCTWContrastIV = DocumentTypeValueSetCode("37240-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ParotidGlandMRIWContrastIV = DocumentTypeValueSetCode("37241-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisCTWContrastIV = DocumentTypeValueSetCode("24866-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisMRIWContrastIV = DocumentTypeValueSetCode("36237-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisVesselsCTAngiogramWContrastIV = DocumentTypeValueSetCode("42294-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisVesselsMRIAngiogramWContrastIV = DocumentTypeValueSetCode("24873-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PetrousBoneCTWContrastIV = DocumentTypeValueSetCode("24878-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PituitaryAndSellaTurcicaCTWContrastIV = DocumentTypeValueSetCode("30590-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PituitaryAndSellaTurcicaMRIWContrastIV = DocumentTypeValueSetCode("36238-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PosteriorFossaCTWContrastIV = DocumentTypeValueSetCode("36242-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PosteriorFossaMRIWContrastIV = DocumentTypeValueSetCode("36243-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ProstateMRIWContrastIV = DocumentTypeValueSetCode("36244-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PulmonaryArteryCTAngiogramWContrastIV = DocumentTypeValueSetCode("36147-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RenalVesselsCTAngiogramWContrastIV = DocumentTypeValueSetCode("36833-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RenalVesselsMRIAngiogramWContrastIV = DocumentTypeValueSetCode("30887-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SacroiliacJointCTWContrastIV = DocumentTypeValueSetCode("36217-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SacroiliacJointMRIWContrastIV = DocumentTypeValueSetCode("36218-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SacrumCTWContrastIV = DocumentTypeValueSetCode("36245-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SacrumMRIWContrastIV = DocumentTypeValueSetCode("36246-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SacrumAndCoccyxMRIWContrastIV = DocumentTypeValueSetCode("36247-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Scapula_LeftMRIWContrastIV = DocumentTypeValueSetCode("36248-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Scapula_RightMRIWContrastIV = DocumentTypeValueSetCode("36249-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScrotumAndTesticleMRIWContrastIV = DocumentTypeValueSetCode("69221-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ShoulderCTWContrastIV = DocumentTypeValueSetCode("36250-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ShoulderMRIWContrastIV = DocumentTypeValueSetCode("36251-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_BilateralMRIWContrastIV = DocumentTypeValueSetCode("69184-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftCTWContrastIV = DocumentTypeValueSetCode("36252-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftMRIWContrastIV = DocumentTypeValueSetCode("38830-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightCTWContrastIV = DocumentTypeValueSetCode("36253-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightMRIWContrastIV = DocumentTypeValueSetCode("36254-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SinusesCTWContrastIV = DocumentTypeValueSetCode("36255-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SinusesMRIWContrastIV = DocumentTypeValueSetCode("24915-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Skull_baseMRIWContrastIV = DocumentTypeValueSetCode("48440-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SoftTissueMRIWContrastIV = DocumentTypeValueSetCode("37253-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCTWContrastIV = DocumentTypeValueSetCode("24987-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineMRIWContrastIV = DocumentTypeValueSetCode("36256-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineVesselsMRIAngiogramWContrastIV = DocumentTypeValueSetCode("37500-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalCTWContrastIV = DocumentTypeValueSetCode("24933-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalMRIWContrastIV = DocumentTypeValueSetCode("24938-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CervicalSpineVesselsMRIAngiogramWContrastIV = DocumentTypeValueSetCode("37501-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalAndSpineThoracicAndSpineLumbarAndSacrumMRIWContrastIV = (
        DocumentTypeValueSetCode("38061-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarCTWContrastIV = DocumentTypeValueSetCode("24964-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarMRIWContrastIV = DocumentTypeValueSetCode("30678-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LumbarSpineVesselsMRIAngiogramWContrastIV = DocumentTypeValueSetCode("37502-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicCTWContrastIV = DocumentTypeValueSetCode("24979-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicMRIWContrastIV = DocumentTypeValueSetCode("24982-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThoracicSpineVesselsMRIAngiogramWContrastIV = DocumentTypeValueSetCode("37503-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpleenCTWContrastIV = DocumentTypeValueSetCode("30622-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SternoclavicularJointCTWContrastIV = DocumentTypeValueSetCode("37242-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SternumCTWContrastIV = DocumentTypeValueSetCode("36257-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporalBoneCTWContrastIV = DocumentTypeValueSetCode("36815-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporalBone_LeftCTWContrastIV = DocumentTypeValueSetCode("38835-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporalBone_RightCTWContrastIV = DocumentTypeValueSetCode("36816-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporomandibularJointCTWContrastIV = DocumentTypeValueSetCode("37243-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporomandibularJointMRIWContrastIV = DocumentTypeValueSetCode("37244-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporomandibularJoint_BilateralMRIWContrastIV = DocumentTypeValueSetCode("37245-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporomandibularJoint_LeftCTWContrastIV = DocumentTypeValueSetCode("37246-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporomandibularJoint_LeftMRIWContrastIV = DocumentTypeValueSetCode("37247-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporomandibularJoint_RightCTWContrastIV = DocumentTypeValueSetCode("37248-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporomandibularJoint_RightMRIWContrastIV = DocumentTypeValueSetCode("37249-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThighMRIWContrastIV = DocumentTypeValueSetCode("36173-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThighVesselsMRIAngiogramWContrastIV = DocumentTypeValueSetCode("25003-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Thigh_LeftMRIWContrastIV = DocumentTypeValueSetCode("36175-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Thigh_RightMRIWContrastIV = DocumentTypeValueSetCode("36177-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThoracicOutletMRIWContrastIV = DocumentTypeValueSetCode("36239-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThoracicOutletVesselsMRIAngiogramWContrastIV = DocumentTypeValueSetCode("24584-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThoracicOutletVessels_BilateralMRIAngiogramWContrastIV = DocumentTypeValueSetCode(
        "26181-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThoracicOutletVessels_LeftMRIAngiogramWContrastIV = DocumentTypeValueSetCode(
        "26182-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThoracicOutletVessels_RightMRIAngiogramWContrastIV = DocumentTypeValueSetCode(
        "26183-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThoracicOutlet_LeftMRIWContrastIV = DocumentTypeValueSetCode("36240-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThoracicOutlet_RightMRIWContrastIV = DocumentTypeValueSetCode("36241-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Toes_LeftMRIWContrastIV = DocumentTypeValueSetCode("72243-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Toes_RightMRIWContrastIV = DocumentTypeValueSetCode("72240-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperArmCTWContrastIV = DocumentTypeValueSetCode("36207-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperArmMRIWContrastIV = DocumentTypeValueSetCode("36208-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperArm_BilateralMRIWContrastIV = DocumentTypeValueSetCode("69182-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperArm_LeftCTWContrastIV = DocumentTypeValueSetCode("36209-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperArm_LeftMRIWContrastIV = DocumentTypeValueSetCode("36210-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperArm_RightCTWContrastIV = DocumentTypeValueSetCode("36211-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperArm_RightMRIWContrastIV = DocumentTypeValueSetCode("36212-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityCTWContrastIV = DocumentTypeValueSetCode("30626-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityMRIWContrastIV = DocumentTypeValueSetCode("39037-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityVesselsCTAngiogramWContrastIV = DocumentTypeValueSetCode("42295-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityVesselsMRIAngiogramWContrastIV = DocumentTypeValueSetCode("24549-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremity_BilateralCTWContrastIV = DocumentTypeValueSetCode("36168-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremity_BilateralMRIWContrastIV = DocumentTypeValueSetCode("69187-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremity_jointMRIWContrastIV = DocumentTypeValueSetCode("36216-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityJoint_BilateralMRIWContrastIV = DocumentTypeValueSetCode("36817-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityJoint_LeftMRIWContrastIV = DocumentTypeValueSetCode("36818-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityJoint_RightMRIWContrastIV = DocumentTypeValueSetCode("36819-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremity_LeftCTWContrastIV = DocumentTypeValueSetCode("36169-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremity_LeftMRIWContrastIV = DocumentTypeValueSetCode("38829-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremity_RightCTWContrastIV = DocumentTypeValueSetCode("36170-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremity_RightMRIWContrastIV = DocumentTypeValueSetCode("36171-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UterusCTWContrastIV = DocumentTypeValueSetCode("36264-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UterusMRIWContrastIV = DocumentTypeValueSetCode("36265-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VesselCTAngiogramWContrastIV = DocumentTypeValueSetCode("36834-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    WristCTWContrastIV = DocumentTypeValueSetCode("37447-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    WristMRIWContrastIV = DocumentTypeValueSetCode("37448-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_BilateralCTWContrastIV = DocumentTypeValueSetCode("69091-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_BilateralMRIWContrastIV = DocumentTypeValueSetCode("37449-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_LeftCTWContrastIV = DocumentTypeValueSetCode("37450-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_LeftMRIWContrastIV = DocumentTypeValueSetCode("37451-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_RightCTWContrastIV = DocumentTypeValueSetCode("37452-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_RightMRIWContrastIV = DocumentTypeValueSetCode("37453-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionCTWContrastIV = DocumentTypeValueSetCode("24753-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionMRIWContrastIV = DocumentTypeValueSetCode("49507-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionMRIAngiogramWContrastIV = DocumentTypeValueSetCode("25058-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RectumAndColonCT3DWContrastIVAndWAirContrastPR = DocumentTypeValueSetCode("72531-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GastrointestineUSWContrastPO = DocumentTypeValueSetCode("39450-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenAndPelvisMRIWContrastPOAndWAndWOContrastIV = DocumentTypeValueSetCode(
        "72246-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenAndPelvisCTWContrastPOAndWContrastIV = DocumentTypeValueSetCode("72250-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenAndPelvisMRIWContrastPOAndWOContrastIV = DocumentTypeValueSetCode("72247-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisMRIWContrastPRAtRestAndMaxmalSphincterContractionDuringStrainingAndDefecation = DocumentTypeValueSetCode(
        "72245-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartSPECTWDipyridamoleAndWRadionuclideIV = DocumentTypeValueSetCode("39648-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartSPECTWDipyridamoleAndWTc_99mSestamibiIV = DocumentTypeValueSetCode("44154-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisMRIWEndorectalCoil = DocumentTypeValueSetCode("42389-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ProstateMRIWEndorectalCoil = DocumentTypeValueSetCode("42388-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalMRIWFlexionAndWExtension = DocumentTypeValueSetCode("42270-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SPECTWGA_67IV = DocumentTypeValueSetCode("39682-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainSPECTWI_123IV = DocumentTypeValueSetCode("39638-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThyroidSPECTWI_131IV = DocumentTypeValueSetCode("39755-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SPECTWI_131MIBGIV = DocumentTypeValueSetCode("39839-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SPECTWIn_111SatumomabIV = DocumentTypeValueSetCode("39844-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ProstateSPECTWIn_111SatumomabIV = DocumentTypeValueSetCode("41838-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BoneSPECTWIn_111TaggedWBCIV = DocumentTypeValueSetCode("41772-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SPECT = DocumentTypeValueSetCode("46297-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BoneMarrowSPECT = DocumentTypeValueSetCode("39823-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BonesSPECT = DocumentTypeValueSetCode("24578-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainSPECT = DocumentTypeValueSetCode("39632-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastSPECT = DocumentTypeValueSetCode("39644-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GastrointestineSPECT = DocumentTypeValueSetCode("39770-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartSPECT = DocumentTypeValueSetCode("39649-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KidneySPECT = DocumentTypeValueSetCode("42310-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_BilateralSPECT = DocumentTypeValueSetCode("39852-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LiverSPECT = DocumentTypeValueSetCode("39692-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LiverAndSpleenSPECT = DocumentTypeValueSetCode("39876-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MeckelsDiverticulumSPECT = DocumentTypeValueSetCode("39628-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ParathyroidSPECT = DocumentTypeValueSetCode("39740-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionSPECT = DocumentTypeValueSetCode("43526-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    JointSPECT = DocumentTypeValueSetCode("39938-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenCTWReducedContrastVolumeIV = DocumentTypeValueSetCode("46330-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestCTWReducedContrastVolumeIV = DocumentTypeValueSetCode("46327-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FacialBonesAndMaxillaCTWReducedContrastVolumeIV = DocumentTypeValueSetCode(
        "46326-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadCTWReducedContrastVolumeIV = DocumentTypeValueSetCode("46328-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InternalAuditoryCanalCTWReducedContrastVolumeIV = DocumentTypeValueSetCode(
        "46325-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisCTWReducedContrastVolumeIV = DocumentTypeValueSetCode("46329-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UterusAndFallopianTubesUSWSalineIntrauterine = DocumentTypeValueSetCode("42143-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartMRIWStress = DocumentTypeValueSetCode("58750-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartMRIWStressAndWAndWOContrastIV = DocumentTypeValueSetCode("58749-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartSPECTWStressAndWRadionuclideIV = DocumentTypeValueSetCode("39668-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainSPECTWTc_99mBicisateIV = DocumentTypeValueSetCode("44152-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ProstateSPECTWTc_99mCapromabPendatideIV = DocumentTypeValueSetCode("39743-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainSPECTWTc_99mDTPAIV = DocumentTypeValueSetCode("39640-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainSPECTWTc_99mGlucoheptonateIV = DocumentTypeValueSetCode("39641-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KidneySPECTWTc_99mGlucoheptonateIV = DocumentTypeValueSetCode("44153-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainSPECTWTc_99mHMPAOIV = DocumentTypeValueSetCode("39631-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LiverSPECTWTc_99mIV = DocumentTypeValueSetCode("24817-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_BilateralSPECTWTc_99mMertiatideIV = DocumentTypeValueSetCode("39851-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LiverSPECTWTc_99mSCIV = DocumentTypeValueSetCode("69229-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartSPECTWTc_99mSestamibiIV = DocumentTypeValueSetCode("44151-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LiverSPECTWTc_99mTaggedRBCIV = DocumentTypeValueSetCode("39691-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpleenSPECTWTc_99mTaggedRBCIV = DocumentTypeValueSetCode("69234-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartSPECTWTc_99mTetrofosminIV = DocumentTypeValueSetCode("39647-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainSPECTWTl_201IV = DocumentTypeValueSetCode("39639-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainCTWXe_133Inhaled = DocumentTypeValueSetCode("42377-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LiverCTWXe_133Inhaled = DocumentTypeValueSetCode("46393-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PulmonarySystemCTWXe_133Inhaled = DocumentTypeValueSetCode("42394-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenCTWOContrast = DocumentTypeValueSetCode("36424-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenMRIWOContrast = DocumentTypeValueSetCode("30668-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenRetroperitoneumCTWOContrast = DocumentTypeValueSetCode("42291-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenAndPelvisCTWOContrast = DocumentTypeValueSetCode("36952-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdominalVesselsMRIAngiogramWOContrast = DocumentTypeValueSetCode("36878-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AcromioclavicularJointMRIWOContrast = DocumentTypeValueSetCode("36496-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AdrenalGlandCTWOContrast = DocumentTypeValueSetCode("36953-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AdrenalGlandMRIWOContrast = DocumentTypeValueSetCode("36954-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AnkleCTWOContrast = DocumentTypeValueSetCode("36425-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AnkleMRIWOContrast = DocumentTypeValueSetCode("30680-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AnkleVesselsMRIAngiogramWOContrast = DocumentTypeValueSetCode("36879-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_BilateralCTWOContrast = DocumentTypeValueSetCode("69087-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_BilateralMRIWOContrast = DocumentTypeValueSetCode("69164-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_LeftCTWOContrast = DocumentTypeValueSetCode("36426-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_LeftMRIWOContrast = DocumentTypeValueSetCode("36427-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_RightCTWOContrast = DocumentTypeValueSetCode("36428-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_RightMRIWOContrast = DocumentTypeValueSetCode("36429-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AortaCTWOContrast = DocumentTypeValueSetCode("36430-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AortaMRIAngiogramWOContrast = DocumentTypeValueSetCode("44132-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AortaAbdominalCTWOContrast = DocumentTypeValueSetCode("36431-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AortaAbdominalMRIAngiogramWOContrast = DocumentTypeValueSetCode("36432-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AortaThoracicCTAngiogramWOContrast = DocumentTypeValueSetCode("69119-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AortaThoracicMRIAngiogramWOContrast = DocumentTypeValueSetCode("36433-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AorticArchMRIAngiogramWOContrast = DocumentTypeValueSetCode("44130-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AppendixCTWOContrast = DocumentTypeValueSetCode("36434-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BiliaryDuctsAndPancreaticDuctMRIWOContrast = DocumentTypeValueSetCode("44123-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainMRIWOContrast = DocumentTypeValueSetCode("30657-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Brain_temporalMRIWOContrast = DocumentTypeValueSetCode("48453-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainAndInternalAuditoryCanalMRIWOContrast = DocumentTypeValueSetCode("37278-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainAndLarynxMRIWOContrast = DocumentTypeValueSetCode("37279-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainAndPituitaryAndSellaTurcicaMRIWOContrast = DocumentTypeValueSetCode("42393-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastMRIWOContrast = DocumentTypeValueSetCode("36436-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastImplantMRIWOContrast = DocumentTypeValueSetCode("69191-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastImplant_BilateralMRIWOContrast = DocumentTypeValueSetCode("69168-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastImplant_LeftMRIWOContrast = DocumentTypeValueSetCode("38064-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastImplant_RightMRIWOContrast = DocumentTypeValueSetCode("38817-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_BilateralCTWOContrast = DocumentTypeValueSetCode("44119-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_BilateralMRIWOContrast = DocumentTypeValueSetCode("36437-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_LeftMRIWOContrast = DocumentTypeValueSetCode("36438-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_RightMRIWOContrast = DocumentTypeValueSetCode("36439-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_UnilateralMRIWOContrast = DocumentTypeValueSetCode("46333-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CalcaneusCTWOContrast = DocumentTypeValueSetCode("36483-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Calcaneus_LeftCTWOContrast = DocumentTypeValueSetCode("36440-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Calcaneus_RightCTWOContrast = DocumentTypeValueSetCode("36441-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CarotidVesselMRIAngiogramWOContrast = DocumentTypeValueSetCode("36880-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestCTWOContrast = DocumentTypeValueSetCode("29252-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestMRIWOContrast = DocumentTypeValueSetCode("36442-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestVesselsCTAngiogramWOContrast = DocumentTypeValueSetCode("69084-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestVesselsMRIAngiogramWOContrast = DocumentTypeValueSetCode("36547-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestAndAbdomenCTWOContrast = DocumentTypeValueSetCode("42276-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestAndAbdomenAndPelvisCTWOContrast = DocumentTypeValueSetCode("72253-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClavicleMRIWOContrast = DocumentTypeValueSetCode("42302-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Clavicle_LeftMRIWOContrast = DocumentTypeValueSetCode("48459-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Clavicle_RightMRIWOContrast = DocumentTypeValueSetCode("48458-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ElbowCTWOContrast = DocumentTypeValueSetCode("36443-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ElbowMRIWOContrast = DocumentTypeValueSetCode("30796-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_BilateralCTWOContrast = DocumentTypeValueSetCode("36444-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_BilateralMRIWOContrast = DocumentTypeValueSetCode("69171-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_LeftCTWOContrast = DocumentTypeValueSetCode("36445-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_LeftMRIWOContrast = DocumentTypeValueSetCode("36446-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_RightCTWOContrast = DocumentTypeValueSetCode("36447-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_RightMRIWOContrast = DocumentTypeValueSetCode("36448-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityCTWOContrast = DocumentTypeValueSetCode("42278-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Extremity_LeftCTWOContrast = DocumentTypeValueSetCode("69104-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Extremity_RightCTWOContrast = DocumentTypeValueSetCode("69111-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FaceMRIWOContrast = DocumentTypeValueSetCode("36435-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FacialBonesAndMaxillaCTWOContrast = DocumentTypeValueSetCode("30802-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FacialBonesAndSinusesCTWOContrast = DocumentTypeValueSetCode("72249-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FemurCTWOContrast = DocumentTypeValueSetCode("36460-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Femur_BilateralMRIWOContrast = DocumentTypeValueSetCode("69173-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Femur_LeftCTWOContrast = DocumentTypeValueSetCode("36462-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Femur_RightCTWOContrast = DocumentTypeValueSetCode("36464-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FingerMRIWOContrast = DocumentTypeValueSetCode("69196-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Finger_LeftMRIWOContrast = DocumentTypeValueSetCode("69206-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Finger_RightMRIWOContrast = DocumentTypeValueSetCode("69216-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FootCTWOContrast = DocumentTypeValueSetCode("36466-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FootMRIWOContrast = DocumentTypeValueSetCode("30681-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_BilateralMRIWOContrast = DocumentTypeValueSetCode("36467-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_LeftCTWOContrast = DocumentTypeValueSetCode("36468-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_LeftMRIWOContrast = DocumentTypeValueSetCode("36469-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_RightCTWOContrast = DocumentTypeValueSetCode("36470-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_RightMRIWOContrast = DocumentTypeValueSetCode("36471-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ForearmCTWOContrast = DocumentTypeValueSetCode("36472-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ForearmMRIWOContrast = DocumentTypeValueSetCode("30683-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Forearm_BilateralMRIWOContrast = DocumentTypeValueSetCode("69176-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Forearm_LeftCTWOContrast = DocumentTypeValueSetCode("36473-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Forearm_LeftMRIWOContrast = DocumentTypeValueSetCode("36474-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Forearm_RightCTWOContrast = DocumentTypeValueSetCode("36475-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Forearm_RightMRIWOContrast = DocumentTypeValueSetCode("36476-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HandCTWOContrast = DocumentTypeValueSetCode("36477-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HandMRIWOContrast = DocumentTypeValueSetCode("30685-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_BilateralMRIWOContrast = DocumentTypeValueSetCode("69179-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_LeftCTWOContrast = DocumentTypeValueSetCode("36478-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_LeftMRIWOContrast = DocumentTypeValueSetCode("36479-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_RightCTWOContrast = DocumentTypeValueSetCode("36480-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_RightMRIWOContrast = DocumentTypeValueSetCode("36481-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadCTWOContrast = DocumentTypeValueSetCode("30799-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadVeinsMRIAngiogramWOContrast = DocumentTypeValueSetCode("36876-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadVesselsCTAngiogramWOContrast = DocumentTypeValueSetCode("42293-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadVesselsMRIAngiogramWOContrast = DocumentTypeValueSetCode("36881-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartMRIWOContrast = DocumentTypeValueSetCode("36482-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HipCTWOContrast = DocumentTypeValueSetCode("36484-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HipMRIWOContrast = DocumentTypeValueSetCode("30687-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_BilateralCTWOContrast = DocumentTypeValueSetCode("36485-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_BilateralMRIWOContrast = DocumentTypeValueSetCode("36486-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_LeftCTWOContrast = DocumentTypeValueSetCode("36487-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_LeftMRIWOContrast = DocumentTypeValueSetCode("36488-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_RightCTWOContrast = DocumentTypeValueSetCode("36489-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_RightMRIWOContrast = DocumentTypeValueSetCode("36490-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InternalAuditoryCanalCTWOContrast = DocumentTypeValueSetCode("30584-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InternalAuditoryCanalMRIWOContrast = DocumentTypeValueSetCode("30658-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KidneyCTWOContrast = DocumentTypeValueSetCode("43770-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KidneyMRIWOContrast = DocumentTypeValueSetCode("43773-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_BilateralCTWOContrast = DocumentTypeValueSetCode("36503-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_BilateralMRIWOContrast = DocumentTypeValueSetCode("36504-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_BilateralX_rayTomographWOContrast = DocumentTypeValueSetCode("39359-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeCTWOContrast = DocumentTypeValueSetCode("36505-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeMRIWOContrast = DocumentTypeValueSetCode("30691-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralCTWOContrast = DocumentTypeValueSetCode("69089-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralMRIWOContrast = DocumentTypeValueSetCode("36506-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftCTWOContrast = DocumentTypeValueSetCode("36507-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftMRIWOContrast = DocumentTypeValueSetCode("36508-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightCTWOContrast = DocumentTypeValueSetCode("36509-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightMRIWOContrast = DocumentTypeValueSetCode("36510-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LarynxCTWOContrast = DocumentTypeValueSetCode("36511-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LarynxMRIWOContrast = DocumentTypeValueSetCode("48445-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LiverCTWOContrast = DocumentTypeValueSetCode("30611-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LiverMRIWOContrast = DocumentTypeValueSetCode("30669-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityCTWOContrast = DocumentTypeValueSetCode("30625-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityMRIWOContrast = DocumentTypeValueSetCode("39292-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVesselsMRIAngiogramWOContrast = DocumentTypeValueSetCode("44129-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVessels_BilateralMRIAngiogramWOContrast = DocumentTypeValueSetCode(
        "36450-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVessels_LeftMRIAngiogramWOContrast = DocumentTypeValueSetCode(
        "36882-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVessels_RightMRIAngiogramWOContrast = DocumentTypeValueSetCode(
        "38773-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremity_BilateralCTWOContrast = DocumentTypeValueSetCode("36449-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremity_BilateralMRIWOContrast = DocumentTypeValueSetCode("36451-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityJointMRIWOContrast = DocumentTypeValueSetCode("36497-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityJoint_LeftMRIWOContrast = DocumentTypeValueSetCode("36498-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityJoint_RightMRIWOContrast = DocumentTypeValueSetCode("36499-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremity_LeftCTWOContrast = DocumentTypeValueSetCode("36452-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremity_LeftMRIWOContrast = DocumentTypeValueSetCode("36453-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremity_RightCTWOContrast = DocumentTypeValueSetCode("36454-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremity_RightMRIWOContrast = DocumentTypeValueSetCode("36455-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerLegCTWOContrast = DocumentTypeValueSetCode("36537-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerLegMRIWOContrast = DocumentTypeValueSetCode("30869-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerLeg_BilateralMRIWOContrast = DocumentTypeValueSetCode("69185-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerLeg_LeftCTWOContrast = DocumentTypeValueSetCode("36538-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerLeg_LeftMRIWOContrast = DocumentTypeValueSetCode("36539-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerLeg_RightCTWOContrast = DocumentTypeValueSetCode("36540-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerLeg_RightMRIWOContrast = DocumentTypeValueSetCode("36541-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MandibleCTWOContrast = DocumentTypeValueSetCode("36512-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NasopharynxMRIWOContrast = DocumentTypeValueSetCode("36513-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NasopharynxAndNeckCTWOContrast = DocumentTypeValueSetCode("30585-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeckCTWOContrast = DocumentTypeValueSetCode("36514-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeckMRIWOContrast = DocumentTypeValueSetCode("30660-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeckVeinsMRIAngiogramWOContrast = DocumentTypeValueSetCode("36877-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeckVesselsMRIAngiogramWOContrast = DocumentTypeValueSetCode("36549-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OrbitCTWOContrast = DocumentTypeValueSetCode("46331-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OrbitMRIWOContrast = DocumentTypeValueSetCode("36872-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Orbit_BilateralCTWOContrast = DocumentTypeValueSetCode("30587-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Orbit_BilateralMRIWOContrast = DocumentTypeValueSetCode("30661-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Orbit_LeftMRIWOContrast = DocumentTypeValueSetCode("36873-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Orbit_RightMRIWOContrast = DocumentTypeValueSetCode("36874-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OrbitAndFaceMRIWOContrast = DocumentTypeValueSetCode("36956-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OrbitAndFaceAndNeckMRIWOContrast = DocumentTypeValueSetCode("46332-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OvaryMRIWOContrast = DocumentTypeValueSetCode("36875-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PancreasCTWOContrast = DocumentTypeValueSetCode("30613-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PancreasMRIWOContrast = DocumentTypeValueSetCode("36515-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ParotidGlandCTWOContrast = DocumentTypeValueSetCode("37280-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ParotidGlandMRIWOContrast = DocumentTypeValueSetCode("37281-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisCTWOContrast = DocumentTypeValueSetCode("30615-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisMRIWOContrast = DocumentTypeValueSetCode("30673-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisVesselsMRIAngiogramWOContrast = DocumentTypeValueSetCode("36883-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisAndHipMRIWOContrast = DocumentTypeValueSetCode("30671-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PetrousBoneCTWOContrast = DocumentTypeValueSetCode("30589-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PituitaryAndSellaTurcicaCTWOContrast = DocumentTypeValueSetCode("30591-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PituitaryAndSellaTurcicaMRIWOContrast = DocumentTypeValueSetCode("30666-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PortalVeinMRIAngiogramWOContrast = DocumentTypeValueSetCode("36543-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PosteriorFossaCTWOContrast = DocumentTypeValueSetCode("36517-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PosteriorFossaMRIWOContrast = DocumentTypeValueSetCode("36518-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ProstateMRIWOContrast = DocumentTypeValueSetCode("36519-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RenalVeinMRIAngiogramWOContrast = DocumentTypeValueSetCode("36544-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RenalVesselsMRIAngiogramWOContrast = DocumentTypeValueSetCode("44133-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SacroiliacJointCTWOContrast = DocumentTypeValueSetCode("36501-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SacroiliacJointMRIWOContrast = DocumentTypeValueSetCode("36502-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SacrumCTWOContrast = DocumentTypeValueSetCode("36520-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SacrumMRIWOContrast = DocumentTypeValueSetCode("36521-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SacrumAndCoccyxMRIWOContrast = DocumentTypeValueSetCode("36522-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScapulaCTWOContrast = DocumentTypeValueSetCode("69118-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Scapula_LeftMRIWOContrast = DocumentTypeValueSetCode("36523-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Scapula_RightMRIWOContrast = DocumentTypeValueSetCode("38770-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScrotumAndTesticleMRIWOContrast = DocumentTypeValueSetCode("36535-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ShoulderCTWOContrast = DocumentTypeValueSetCode("36524-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ShoulderMRIWOContrast = DocumentTypeValueSetCode("30693-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_BilateralCTWOContrast = DocumentTypeValueSetCode("69090-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_BilateralMRIWOContrast = DocumentTypeValueSetCode("36525-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftCTWOContrast = DocumentTypeValueSetCode("36526-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftMRIWOContrast = DocumentTypeValueSetCode("38834-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightCTWOContrast = DocumentTypeValueSetCode("36527-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightMRIWOContrast = DocumentTypeValueSetCode("36528-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SinusesCTWOContrast = DocumentTypeValueSetCode("36529-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SinusesMRIWOContrast = DocumentTypeValueSetCode("30662-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Skull_baseCTWOContrast = DocumentTypeValueSetCode("44112-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Skull_baseMRIWOContrast = DocumentTypeValueSetCode("48687-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SoftTissueMRIWOContrast = DocumentTypeValueSetCode("37293-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCTWOContrast = DocumentTypeValueSetCode("36530-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineMRIWOContrast = DocumentTypeValueSetCode("36531-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineVesselsMRIAngiogramWOContrast = DocumentTypeValueSetCode("37510-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalCTWOContrast = DocumentTypeValueSetCode("30592-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalMRIWOContrast = DocumentTypeValueSetCode("30667-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CervicalSpineVesselsMRIAngiogramWOContrast = DocumentTypeValueSetCode("37511-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalAndThoracicAndLumbarMRIWOContrast = DocumentTypeValueSetCode("30854-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarCTWOContrast = DocumentTypeValueSetCode("30620-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarMRIWOContrast = DocumentTypeValueSetCode("30679-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LumbarSpineVesselsMRIAngiogramWOContrast = DocumentTypeValueSetCode("37994-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbosacralJunctionCTWOContrast = DocumentTypeValueSetCode("37288-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicCTWOContrast = DocumentTypeValueSetCode("30597-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicMRIWOContrast = DocumentTypeValueSetCode("36532-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThoracicSpineVesselsMRIAngiogramWOContrast = DocumentTypeValueSetCode("37512-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpleenCTWOContrast = DocumentTypeValueSetCode("30621-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpleenMRIWOContrast = DocumentTypeValueSetCode("36533-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SternoclavicularJointCTWOContrast = DocumentTypeValueSetCode("37282-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SternumCTWOContrast = DocumentTypeValueSetCode("36534-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SuperiorMesentericVesselsMRIAngiogramWOContrast = DocumentTypeValueSetCode(
        "44230-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporalBoneCTWOContrast = DocumentTypeValueSetCode("36866-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporalBone_LeftCTWOContrast = DocumentTypeValueSetCode("36867-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporalBone_RightCTWOContrast = DocumentTypeValueSetCode("36868-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporomandibularJointCTWOContrast = DocumentTypeValueSetCode("37283-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporomandibularJointMRIWOContrast = DocumentTypeValueSetCode("37284-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporomandibularJoint_BilateralMRIWOContrast = DocumentTypeValueSetCode("37285-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporomandibularJoint_LeftMRIWOContrast = DocumentTypeValueSetCode("37286-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporomandibularJoint_RightMRIWOContrast = DocumentTypeValueSetCode("37287-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThighMRIWOContrast = DocumentTypeValueSetCode("36461-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThighVessels_LeftMRIAngiogramWOContrast = DocumentTypeValueSetCode("43514-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThighVessels_RightMRIAngiogramWOContrast = DocumentTypeValueSetCode("43515-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Thigh_LeftMRIWOContrast = DocumentTypeValueSetCode("36463-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Thigh_RightMRIWOContrast = DocumentTypeValueSetCode("36465-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThoracicOutletMRIWOContrast = DocumentTypeValueSetCode("30654-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThoracicOutlet_LeftMRIWOContrast = DocumentTypeValueSetCode("38833-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThoracicOutlet_RightMRIWOContrast = DocumentTypeValueSetCode("36516-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThyroidCTWOContrast = DocumentTypeValueSetCode("36955-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThyroidMRIWOContrast = DocumentTypeValueSetCode("36536-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Toes_LeftMRIWOContrast = DocumentTypeValueSetCode("72242-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Toes_RightMRIWOContrast = DocumentTypeValueSetCode("72239-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperArmCTWOContrast = DocumentTypeValueSetCode("36491-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperArmMRIWOContrast = DocumentTypeValueSetCode("30689-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperArm_BilateralMRIWOContrast = DocumentTypeValueSetCode("69183-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperArm_LeftCTWOContrast = DocumentTypeValueSetCode("36492-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperArm_LeftMRIWOContrast = DocumentTypeValueSetCode("36493-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperArm_RightCTWOContrast = DocumentTypeValueSetCode("36494-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperArm_RightMRIWOContrast = DocumentTypeValueSetCode("36495-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityCTWOContrast = DocumentTypeValueSetCode("30627-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityMRIWOContrast = DocumentTypeValueSetCode("39033-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityVesselsMRIAngiogramWOContrast = DocumentTypeValueSetCode("36548-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremity_BilateralCTWOContrast = DocumentTypeValueSetCode("36456-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremity_BilateralMRIWOContrast = DocumentTypeValueSetCode("69188-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremity_jointMRIWOContrast = DocumentTypeValueSetCode("36500-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityJoint_LeftMRIWOContrast = DocumentTypeValueSetCode("36869-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityJoint_RightMRIWOContrast = DocumentTypeValueSetCode("36870-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremity_LeftCTWOContrast = DocumentTypeValueSetCode("36457-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremity_LeftMRIWOContrast = DocumentTypeValueSetCode("38832-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremity_RightCTWOContrast = DocumentTypeValueSetCode("36458-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremity_RightMRIWOContrast = DocumentTypeValueSetCode("36459-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UterusMRIWOContrast = DocumentTypeValueSetCode("36542-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InferiorVenaCavaMRIWOContrast = DocumentTypeValueSetCode("36545-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SuperiorVenaCavaMRIWOContrast = DocumentTypeValueSetCode("36546-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    WristCTWOContrast = DocumentTypeValueSetCode("37459-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    WristMRIWOContrast = DocumentTypeValueSetCode("37460-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    WristVessels_LeftMRIAngiogramWOContrast = DocumentTypeValueSetCode("43516-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    WristVessels_RightMRIAngiogramWOContrast = DocumentTypeValueSetCode("43517-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_BilateralCTWOContrast = DocumentTypeValueSetCode("37461-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_BilateralMRIWOContrast = DocumentTypeValueSetCode("37462-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_LeftCTWOContrast = DocumentTypeValueSetCode("37463-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_LeftMRIWOContrast = DocumentTypeValueSetCode("37464-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_RightCTWOContrast = DocumentTypeValueSetCode("37465-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_RightMRIWOContrast = DocumentTypeValueSetCode("37466-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionCTWOContrast = DocumentTypeValueSetCode("43525-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionMRIWOContrast = DocumentTypeValueSetCode("69223-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    JointMRIWOContrast = DocumentTypeValueSetCode("36871-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_BilateralX_rayTomographWOContrastAnd10MPostContrastIV = (
        DocumentTypeValueSetCode("24787-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HipUSWODevelopmentalJointAssessment = DocumentTypeValueSetCode("30712-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionCTMultisectionalSagittal = DocumentTypeValueSetCode("25051-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeonatalIntensiveCareRecords = DocumentTypeValueSetCode("29750-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionUSNoCharge = DocumentTypeValueSetCode("25060-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Non_emergencyTransportation = DocumentTypeValueSetCode("52072-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Non_medicalServices = DocumentTypeValueSetCode("53246-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CaseManagerNote = DocumentTypeValueSetCode("46210-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PathologyEvaluationAndManagementNote = DocumentTypeValueSetCode("34819-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    WoundCareManagementNote = DocumentTypeValueSetCode("46215-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PhysicianEmergencyDepartmentNote = DocumentTypeValueSetCode("28568-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NurseNotes = DocumentTypeValueSetCode("11536-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NoticeOfDischargeMedicareAppealRights_NODMAR_Form = DocumentTypeValueSetCode(
        "52066-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NoticeOfPrivacyPracticesReceipt = DocumentTypeValueSetCode("53244-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NurseryRecords = DocumentTypeValueSetCode("11543-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NursingNotes = DocumentTypeValueSetCode("46208-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Orthotics_Prosthetics = DocumentTypeValueSetCode("52051-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OsteogenesisStimulators = DocumentTypeValueSetCode("52052-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Oxygen = DocumentTypeValueSetCode("52053-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Parenteral = DocumentTypeValueSetCode("52054-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PastFilingLimitJustification = DocumentTypeValueSetCode("52067-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CatheterFluoroscopyPatencyCheckWContrastViaCatheter = DocumentTypeValueSetCode(
        "24620-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BoneMarrowPathologyBiopsyReport = DocumentTypeValueSetCode("33721-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PathologyProcedureNote = DocumentTypeValueSetCode("34122-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PatientDataDocument = DocumentTypeValueSetCode("55188-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PatientSafetyReportEventDocument = DocumentTypeValueSetCode("55750-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PayerLetter = DocumentTypeValueSetCode("52034-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PoplitealArteryFluoroscopicAngiogramPercutaneousTransluminalAngioplastyOfVesselWContrastIA = DocumentTypeValueSetCode(
        "24882-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PulmonaryArteryFluoroscopicAngiogramPercutaneousTransluminalAngioplastyOfVesselWContrastIA = DocumentTypeValueSetCode(
        "69252-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RenalArteryFluoroscopicAngiogramPercutaneousTransluminalAngioplastyOfVesselWContrastIA = DocumentTypeValueSetCode(
        "69248-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VeinFluoroscopicAngiogramPercutaneousTransluminalAngioplastyOfVesselWContrastIA = (
        DocumentTypeValueSetCode("42018-2")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityVeinFluoroscopicAngiogramPercutaneousTransluminalAngioplastyOfVesselWContrastIV = DocumentTypeValueSetCode(
        "69301-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PerimetryStudy = DocumentTypeValueSetCode("28629-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PeriodontalServiceAttachment = DocumentTypeValueSetCode("74030-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PerioperativeRecords = DocumentTypeValueSetCode("29752-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PeripheralVesselUS_dopplerPeripheralPlane = DocumentTypeValueSetCode("24875-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PharmacogeneticAnalysisReportInBloodOrTissueDocumentByMolecularGeneticsMethod = (
        DocumentTypeValueSetCode("51965-2")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PhysicalFindingsOfHeadAndEarsAndEyesAndNoseAndThroat = DocumentTypeValueSetCode(
        "51850-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PlacementCheckOfGastrostomyTubeWContrastViaGITube = DocumentTypeValueSetCode(
        "24998-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PowerOperatedVehicles = DocumentTypeValueSetCode("52055-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PrescriptionForDurableMedicalEquipment_DME_ = DocumentTypeValueSetCode("52063-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CardiacStressStudyProcedure = DocumentTypeValueSetCode("18836-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Provider_unspecifiedProcedureNote = DocumentTypeValueSetCode("28570-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    DentistProcedureNote = DocumentTypeValueSetCode("28577-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PhysicianProcedureNote = DocumentTypeValueSetCode("11505-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PodiatryProcedureNote = DocumentTypeValueSetCode("28625-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PropertyAndCasualtyStateMandatedForms = DocumentTypeValueSetCode("52068-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ProviderOrders = DocumentTypeValueSetCode("46209-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PublicHealthCaseReportDocument = DocumentTypeValueSetCode("55751-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PurchaseInvoice = DocumentTypeValueSetCode("52075-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    QualityReportingDocumentArchitectureCalculatedSummaryReportPopulationDocument = (
        DocumentTypeValueSetCode("55184-6")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    QualityReportingDocumentArchitectureIncidenceReportDocument = (
        DocumentTypeValueSetCode("55182-0")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    QualityReportingDocumentArchitecturePatientListReportPopulationDocument = (
        DocumentTypeValueSetCode("55183-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Recommendation_interpretation_Document = DocumentTypeValueSetCode("62385-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChiropracticRecordsTotalEncounter = DocumentTypeValueSetCode("11514-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OccupationalTherapyRecordsTotalEncounter = DocumentTypeValueSetCode("11521-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PhysicalTherapyRecordsTotalEncounter = DocumentTypeValueSetCode("11515-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PhysicianRecordsTotalEncounter = DocumentTypeValueSetCode("11516-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PodiatryRecordsTotalEncounter = DocumentTypeValueSetCode("11517-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PsychologyRecordsTotalEncounter = DocumentTypeValueSetCode("11518-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SocialServiceRecordsTotalEncounter = DocumentTypeValueSetCode("11519-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpeechTherapyRecordsTotalEncounter = DocumentTypeValueSetCode("11520-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ColonFluoroscopyReductionWViewsWBariumContrastPR = DocumentTypeValueSetCode(
        "44226-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ColonFluoroscopyReductionWViewsWContrastPR = DocumentTypeValueSetCode("30636-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AlcoholAnd_orSubstanceAbuseServiceAttachment = DocumentTypeValueSetCode("18823-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CardiacServiceAttachment = DocumentTypeValueSetCode("18824-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MedicalSocialServicesAttachment = DocumentTypeValueSetCode("18825-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OccupationalTherapyServiceAttachment = DocumentTypeValueSetCode("18826-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PhysicalTherapyServiceAttachment = DocumentTypeValueSetCode("19002-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PsychiatricServiceAttachment = DocumentTypeValueSetCode("18594-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PulmonaryTherapyServiceAttachment = DocumentTypeValueSetCode("52184-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RespiratoryTherapyServiceAttachment = DocumentTypeValueSetCode("19003-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SkilledNursingServiceAttachment = DocumentTypeValueSetCode("19004-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpeechTherapyServiceAttachment = DocumentTypeValueSetCode("29206-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VesselFluoroscopicAngiogramRemovalOfForeignBodyFromVascularSpace = (
        DocumentTypeValueSetCode("25073-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RepairOfDurableMedicalEquipment = DocumentTypeValueSetCode("52056-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperGITractReplacementOfPercutaneousGastrojejunostomy = DocumentTypeValueSetCode(
        "25015-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ReportAddendum_synopticDocument = DocumentTypeValueSetCode("60569-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ReportingParametersDocument = DocumentTypeValueSetCode("55187-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SeatLiftMechanism = DocumentTypeValueSetCode("52057-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SeatingSystems = DocumentTypeValueSetCode("52058-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SkilledNursingFacility_SNF_Record = DocumentTypeValueSetCode("52039-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpeechGeneratingDevice = DocumentTypeValueSetCode("52059-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Standers_standingFrames = DocumentTypeValueSetCode("52060-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SterilizationConsent = DocumentTypeValueSetCode("52029-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CytogeneticsStudy = DocumentTypeValueSetCode("55228-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExerciseStressTestStudy = DocumentTypeValueSetCode("18752-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NerveConductionStudy = DocumentTypeValueSetCode("29755-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PathologyStudy = DocumentTypeValueSetCode("11526-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Polysomnography_sleep_Study = DocumentTypeValueSetCode("28633-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PsychiatryStudy = DocumentTypeValueSetCode("11527-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PulmonaryFunctionReport = DocumentTypeValueSetCode("58477-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SurgicalPathologyStudy = DocumentTypeValueSetCode("11529-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ImmunophenotypingStudy = DocumentTypeValueSetCode("55230-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    EEGStudy = DocumentTypeValueSetCode("11523-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MRIBrainStudy = DocumentTypeValueSetCode("11541-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ColposcopyStudy = DocumentTypeValueSetCode("29757-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CytologyCervicalOrVaginalSmearOrScrapingStudy = DocumentTypeValueSetCode("33717-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CardiacCatheterizationStudy = DocumentTypeValueSetCode("18745-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    EKGStudy = DocumentTypeValueSetCode("11524-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ElectrophysiologyStudy = DocumentTypeValueSetCode("18750-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HolterMonitorStudy = DocumentTypeValueSetCode("18754-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ColonoscopyStudy = DocumentTypeValueSetCode("18746-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FlexibleSigmoidoscopyStudy = DocumentTypeValueSetCode("18753-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PeritoneoscopyStudy = DocumentTypeValueSetCode("29756-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BronchoscopyStudy = DocumentTypeValueSetCode("18744-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpirometryStudy = DocumentTypeValueSetCode("18759-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    StudyReportSkeletalSystemDXA = DocumentTypeValueSetCode("38269-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MRISpineStudy = DocumentTypeValueSetCode("18756-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThyroidScanStudyReport = DocumentTypeValueSetCode("17787-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ImmuneStainStudy = DocumentTypeValueSetCode("55229-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    EndoscopyStudy = DocumentTypeValueSetCode("18751-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ArthroscopyStudy = DocumentTypeValueSetCode("18742-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Non_gynecologicalCytologyMethodStudy = DocumentTypeValueSetCode("33716-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    DiagnosticImagingStudy = DocumentTypeValueSetCode("18748-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ElectromyogramStudy = DocumentTypeValueSetCode("18749-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FlowCytometryStudy = DocumentTypeValueSetCode("33719-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NystagmogramStudy = DocumentTypeValueSetCode("29754-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SubscriberInformationIncludingRetroactiveAndPresumptiveEligibility = (
        DocumentTypeValueSetCode("52038-7")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SupportSurfaces = DocumentTypeValueSetCode("52061-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    DentistOperationNote = DocumentTypeValueSetCode("28583-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Physician_OperationNote = DocumentTypeValueSetCode("28573-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SynopticReport = DocumentTypeValueSetCode("60568-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TaxIDNumber_IRSFormW9 = DocumentTypeValueSetCode("52069-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemperatureCharts = DocumentTypeValueSetCode("11534-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TiltTableStudy = DocumentTypeValueSetCode("46213-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TonometryStudy = DocumentTypeValueSetCode("28630-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TranscutaneousElectricalNeuralStimulation_TENS_ = DocumentTypeValueSetCode(
        "52062-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NurseTransferNote = DocumentTypeValueSetCode("28651-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PhysicianTransferNote = DocumentTypeValueSetCode("28616-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    U_S_StandardCertificateOfDeath_2003Revision = DocumentTypeValueSetCode("69409-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_BilateralFluoroscopyUrodynamics = DocumentTypeValueSetCode("24783-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionFluoroscopy15Minutes = DocumentTypeValueSetCode("25065-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionFluoroscopy1Hour = DocumentTypeValueSetCode("25068-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionFluoroscopy2Hour = DocumentTypeValueSetCode("43471-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionFluoroscopy30Minutes = DocumentTypeValueSetCode("25066-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionFluoroscopy45Minutes = DocumentTypeValueSetCode("25067-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionFluoroscopy90Minutes = DocumentTypeValueSetCode("43472-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionFluoroscopyGreaterThan1Hour = DocumentTypeValueSetCode(
        "42702-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionFluoroscopyLessThan1Hour = DocumentTypeValueSetCode("42703-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenX_raySingleView = DocumentTypeValueSetCode("36550-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AnkleX_raySingleView = DocumentTypeValueSetCode("36551-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_LeftX_raySingleView = DocumentTypeValueSetCode("69307-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_RightX_raySingleView = DocumentTypeValueSetCode("69314-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_BilateralMammogramSingleView = DocumentTypeValueSetCode("46335-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_LeftMammogramSingleView = DocumentTypeValueSetCode("46336-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_RightMammogramSingleView = DocumentTypeValueSetCode("46337-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_UnilateralMammogramSingleView = DocumentTypeValueSetCode("46338-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CalcaneusX_raySingleView = DocumentTypeValueSetCode("36564-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Calcaneus_LeftX_raySingleView = DocumentTypeValueSetCode("69311-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Calcaneus_RightX_raySingleView = DocumentTypeValueSetCode("69319-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_raySingleView = DocumentTypeValueSetCode("36554-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestAndAbdomenX_raySingleView = DocumentTypeValueSetCode("42699-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClavicleX_raySingleView = DocumentTypeValueSetCode("36555-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ElbowX_raySingleView = DocumentTypeValueSetCode("36556-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_LeftX_raySingleView = DocumentTypeValueSetCode("69308-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_RightX_raySingleView = DocumentTypeValueSetCode("69315-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityX_raySingleView = DocumentTypeValueSetCode("42153-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FemurX_raySingleView = DocumentTypeValueSetCode("36559-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Femur_LeftX_raySingleView = DocumentTypeValueSetCode("36560-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Femur_RightX_raySingleView = DocumentTypeValueSetCode("37689-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FootX_raySingleView = DocumentTypeValueSetCode("36561-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_LeftX_raySingleView = DocumentTypeValueSetCode("69309-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_RightX_raySingleView = DocumentTypeValueSetCode("69316-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HandX_raySingleView = DocumentTypeValueSetCode("36563-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_LeftX_raySingleView = DocumentTypeValueSetCode("69310-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_RightX_raySingleView = DocumentTypeValueSetCode("69318-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HipX_raySingleView = DocumentTypeValueSetCode("24761-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_BilateralX_raySingleView = DocumentTypeValueSetCode("26400-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_LeftX_raySingleView = DocumentTypeValueSetCode("26401-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_RightX_raySingleView = DocumentTypeValueSetCode("26402-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HumerusX_raySingleView = DocumentTypeValueSetCode("36565-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Humerus_LeftX_raySingleView = DocumentTypeValueSetCode("69312-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Humerus_RightX_raySingleView = DocumentTypeValueSetCode("69320-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralX_raySingleView = DocumentTypeValueSetCode("36566-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_raySingleView = DocumentTypeValueSetCode("36567-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_raySingleView = DocumentTypeValueSetCode("37741-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremity_BilateralX_raySingleView = DocumentTypeValueSetCode("36557-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremity_LeftX_raySingleView = DocumentTypeValueSetCode("36558-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremity_RightX_raySingleView = DocumentTypeValueSetCode("37764-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PatellaX_raySingleView = DocumentTypeValueSetCode("37614-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Patella_LeftX_raySingleView = DocumentTypeValueSetCode("69152-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Patella_RightX_raySingleView = DocumentTypeValueSetCode("69260-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisX_raySingleView = DocumentTypeValueSetCode("37616-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Radius_RightAndUlna_RightX_raySingleView = DocumentTypeValueSetCode("69317-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ribs_LeftX_raySingleView = DocumentTypeValueSetCode("42313-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ribs_RightX_raySingleView = DocumentTypeValueSetCode("42314-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScapulaX_raySingleView = DocumentTypeValueSetCode("37654-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ShoulderX_raySingleView = DocumentTypeValueSetCode("30748-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_BilateralX_raySingleView = DocumentTypeValueSetCode("36568-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_raySingleView = DocumentTypeValueSetCode("36569-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightX_raySingleView = DocumentTypeValueSetCode("37792-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SinusesX_raySingleView = DocumentTypeValueSetCode("37851-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SkullX_raySingleView = DocumentTypeValueSetCode("24917-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Skull_baseX_raySingleView = DocumentTypeValueSetCode("48695-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineX_raySingleView = DocumentTypeValueSetCode("37875-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalX_raySingleView = DocumentTypeValueSetCode("24940-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_raySingleView = DocumentTypeValueSetCode("30773-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicX_raySingleView = DocumentTypeValueSetCode("37904-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicAndLumbarX_raySingleView = DocumentTypeValueSetCode("38121-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Tibia_LeftAndFibula_LeftX_raySingleView = DocumentTypeValueSetCode("69313-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Tibia_RightAndFibula_RightX_raySingleView = DocumentTypeValueSetCode("69321-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TibiaAndFibulaX_raySingleView = DocumentTypeValueSetCode("37894-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    WristX_raySingleView = DocumentTypeValueSetCode("37924-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_BilateralX_raySingleView = DocumentTypeValueSetCode("42419-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_LeftX_raySingleView = DocumentTypeValueSetCode("36570-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_RightX_raySingleView = DocumentTypeValueSetCode("37825-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionFluoroscopySingleView = DocumentTypeValueSetCode("30642-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    JointX_raySingleView = DocumentTypeValueSetCode("30787-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HipX_raySingleViewPortable = DocumentTypeValueSetCode("44176-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisX_raySingleViewPortable = DocumentTypeValueSetCode("41775-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ShoulderX_raySingleViewPortable = DocumentTypeValueSetCode("30749-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SkullX_raySingleViewPortable = DocumentTypeValueSetCode("30722-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalX_raySingleViewPortable = DocumentTypeValueSetCode("30724-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_raySingleViewPortable = DocumentTypeValueSetCode("30774-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicX_raySingleViewPortable = DocumentTypeValueSetCode("70932-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VesselFluoroscopicAngiogramSingleViewWContrastIA = DocumentTypeValueSetCode(
        "25063-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastDuctMammogramSingleViewWContrastIntraDuct = DocumentTypeValueSetCode(
        "69268-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastDuct_LeftMammogramSingleViewWContrastIntraDuct = DocumentTypeValueSetCode(
        "49510-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastDuct_RightMammogramSingleViewWContrastIntraDuct = DocumentTypeValueSetCode(
        "49509-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GastrointestineUpperFluoroscopySingleViewWContrastPO = DocumentTypeValueSetCode(
        "24715-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Tibia_BilateralX_ray10DegreeCaudalAngle = DocumentTypeValueSetCode("37513-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Tibia_LeftX_ray10DegreeCaudalAngle = DocumentTypeValueSetCode("37514-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Tibia_RightX_ray10DegreeCaudalAngle = DocumentTypeValueSetCode("38806-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AcromioclavicularJointX_ray10DegreeCephalicAngle = DocumentTypeValueSetCode(
        "37467-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_BilateralX_ray30DegreeCaudalAngle = DocumentTypeValueSetCode("37468-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_ray30DegreeStanding = DocumentTypeValueSetCode("42431-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClavicleX_ray45DegreeCephalicAngle = DocumentTypeValueSetCode("69079-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Clavicle_BilateralX_ray45DegreeCephalicAngle = DocumentTypeValueSetCode("37469-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Clavicle_LeftX_ray45DegreeCephalicAngle = DocumentTypeValueSetCode("37470-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Clavicle_RightX_ray45DegreeCephalicAngle = DocumentTypeValueSetCode("38803-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenX_rayAPSingleView = DocumentTypeValueSetCode("24799-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AcromioclavicularJoint_LeftX_rayAPSingleView = DocumentTypeValueSetCode("36583-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AcromioclavicularJoint_RightX_rayAPSingleView = DocumentTypeValueSetCode("37662-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AnkleX_rayAPSingleView = DocumentTypeValueSetCode("36571-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayAPSingleView = DocumentTypeValueSetCode("36572-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClavicleX_rayAPSingleView = DocumentTypeValueSetCode("36573-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FemurX_rayAPSingleView = DocumentTypeValueSetCode("36575-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FingerFifthX_rayAPSingleView = DocumentTypeValueSetCode("36576-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FingerFourthX_rayAPSingleView = DocumentTypeValueSetCode("36577-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FingerThirdX_rayAPSingleView = DocumentTypeValueSetCode("36578-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FootX_rayAPSingleView = DocumentTypeValueSetCode("36579-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_BilateralX_rayAPSingleView = DocumentTypeValueSetCode("36580-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HipX_rayAPSingleView = DocumentTypeValueSetCode("36581-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_LeftX_rayAPSingleView = DocumentTypeValueSetCode("36582-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_RightX_rayAPSingleView = DocumentTypeValueSetCode("37726-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeX_rayAPSingleView = DocumentTypeValueSetCode("36584-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralX_rayAPSingleView = DocumentTypeValueSetCode("36585-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_rayAPSingleView = DocumentTypeValueSetCode("48462-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_rayAPSingleView = DocumentTypeValueSetCode("48463-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityX_rayAPSingleView = DocumentTypeValueSetCode("36574-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeckX_rayAPSingleView = DocumentTypeValueSetCode("42439-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisX_rayAPSingleView = DocumentTypeValueSetCode("37622-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RibsX_rayAPSingleView = DocumentTypeValueSetCode("39050-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ribs_BilateralX_rayAPSingleView = DocumentTypeValueSetCode("36958-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ribs_LeftX_rayAPSingleView = DocumentTypeValueSetCode("36959-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ribs_RightX_rayAPSingleView = DocumentTypeValueSetCode("37783-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScapulaX_rayAPSingleView = DocumentTypeValueSetCode("39048-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ShoulderX_rayAPSingleView = DocumentTypeValueSetCode("37842-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_BilateralX_rayAPSingleView = DocumentTypeValueSetCode("36586-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_rayAPSingleView = DocumentTypeValueSetCode("36587-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightX_rayAPSingleView = DocumentTypeValueSetCode("37798-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SkullX_rayAPSingleView = DocumentTypeValueSetCode("69269-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineX_rayAPSingleView = DocumentTypeValueSetCode("37877-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalX_rayAPSingleView = DocumentTypeValueSetCode("30725-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalOdontoidAndCervicalAxisX_rayAPSingleView = DocumentTypeValueSetCode(
        "24948-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_rayAPSingleView = DocumentTypeValueSetCode("30777-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicX_rayAPSingleView = DocumentTypeValueSetCode("30752-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicAndLumbarX_rayAPSingleView = DocumentTypeValueSetCode("39049-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SternoclavicularJointX_rayAPSingleView = DocumentTypeValueSetCode("37880-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThumbX_rayAPSingleView = DocumentTypeValueSetCode("37890-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TibiaAndFibulaX_rayAPSingleView = DocumentTypeValueSetCode("37897-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ShoulderX_rayAP_WInternalRotationAndWExternalRotation_ = DocumentTypeValueSetCode(
        "39402-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisX_rayAP20DegreeCephalicAngle = DocumentTypeValueSetCode("37634-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayAPLateral_decubitus = DocumentTypeValueSetCode("30734-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayAPLateral_decubitusPortable = DocumentTypeValueSetCode("30735-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenX_rayAPLeftLateral_decubitus = DocumentTypeValueSetCode("24561-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayAPLeftLateral_decubitus = DocumentTypeValueSetCode("24637-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenX_rayAPLeftLateral_decubitusPortable = DocumentTypeValueSetCode("24560-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayAPLeftLateral_decubitusPortable = DocumentTypeValueSetCode("24636-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenX_rayAPPortableSingleView = DocumentTypeValueSetCode("36588-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayAPPortableSingleView = DocumentTypeValueSetCode("36589-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalX_rayAPPortableSingleView = DocumentTypeValueSetCode("30727-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalOdontoidAndCervicalAxisX_rayAPPortableSingleView = (
        DocumentTypeValueSetCode("30729-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicX_rayAPPortableSingleView = DocumentTypeValueSetCode("30755-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenX_rayAPRightLateral_decubitus = DocumentTypeValueSetCode("24563-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayAPRightLateral_decubitus = DocumentTypeValueSetCode("43466-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayAPRightLateral_decubitusPortable = DocumentTypeValueSetCode("24652-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayAPSupinePortable = DocumentTypeValueSetCode("43778-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenX_rayAPUprightPortable = DocumentTypeValueSetCode("24564-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayAPUprightPortable = DocumentTypeValueSetCode("36960-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeX_rayAPSingleViewStanding = DocumentTypeValueSetCode("24807-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralX_rayAPSingleViewStanding = DocumentTypeValueSetCode("26358-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_rayAPSingleViewStanding = DocumentTypeValueSetCode("26359-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_rayAPSingleViewStanding = DocumentTypeValueSetCode("26360-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremity_BilateralX_rayAPSingleViewStanding = DocumentTypeValueSetCode(
        "44177-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremity_LeftX_rayAPSingleViewStanding = DocumentTypeValueSetCode("38849-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremity_RightX_rayAPSingleViewStanding = DocumentTypeValueSetCode("37733-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisX_rayAPSingleViewStanding = DocumentTypeValueSetCode("42420-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_rayAPSingleViewWLeftBending = DocumentTypeValueSetCode("42378-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicX_rayAPSingleViewWLeftBending = DocumentTypeValueSetCode("39410-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_rayAPSingleViewWRightBending = DocumentTypeValueSetCode("42379-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicX_rayAPSingleViewWRightBending = DocumentTypeValueSetCode("39411-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HandX_rayArthritis = DocumentTypeValueSetCode("24723-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_BilateralX_rayArthritis = DocumentTypeValueSetCode("26355-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_LeftX_rayArthritis = DocumentTypeValueSetCode("26356-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_RightX_rayArthritis = DocumentTypeValueSetCode("26357-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FootSesamoidBones_BilateralX_rayAxial = DocumentTypeValueSetCode("42395-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FootSesamoidBones_LeftX_rayAxial = DocumentTypeValueSetCode("42396-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastMammogramAxillary = DocumentTypeValueSetCode("36962-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ShoulderX_rayAxillary = DocumentTypeValueSetCode("37849-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_BilateralX_rayAxillary = DocumentTypeValueSetCode("36963-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_rayAxillary = DocumentTypeValueSetCode("36964-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightX_rayAxillary = DocumentTypeValueSetCode("37800-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HandX_rayBallCatcher = DocumentTypeValueSetCode("36965-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_BilateralX_rayBora = DocumentTypeValueSetCode("37471-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_LeftX_rayBora = DocumentTypeValueSetCode("37472-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_RightX_rayBora = DocumentTypeValueSetCode("38804-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_BilateralX_rayBrewerton = DocumentTypeValueSetCode("36966-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_LeftX_rayBrewerton = DocumentTypeValueSetCode("36967-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_RightX_rayBrewerton = DocumentTypeValueSetCode("38775-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    WristX_rayBrewerton = DocumentTypeValueSetCode("37928-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SinusesX_rayCaldwell = DocumentTypeValueSetCode("37857-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HipX_rayDaneliusMiller = DocumentTypeValueSetCode("69132-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_LeftX_rayDaneliusMiller = DocumentTypeValueSetCode("69141-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_RightX_rayDaneliusMiller = DocumentTypeValueSetCode("39514-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisX_rayFerguson = DocumentTypeValueSetCode("37625-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SacroiliacJointX_rayFerguson = DocumentTypeValueSetCode("37650-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_BilateralFluoroscopyViewForCystExamination = DocumentTypeValueSetCode(
        "65799-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_LeftFluoroscopyViewForCystExamination = DocumentTypeValueSetCode("65800-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_RightFluoroscopyViewForCystExamination = DocumentTypeValueSetCode("65801-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenAndFetusX_rayViewForFetalAge = DocumentTypeValueSetCode("37297-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GastrointestinalSystemAndRespiratorySystemX_rayForForeignBody = (
        DocumentTypeValueSetCode("39149-0")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HipX_rayFriedman = DocumentTypeValueSetCode("36973-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ShoulderX_rayGarth = DocumentTypeValueSetCode("37843-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_rayGarth = DocumentTypeValueSetCode("36974-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightX_rayGarth = DocumentTypeValueSetCode("37801-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ShoulderX_rayGrashey = DocumentTypeValueSetCode("37844-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_BilateralX_rayGrashey = DocumentTypeValueSetCode("37035-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_rayGrashey = DocumentTypeValueSetCode("37473-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightX_rayGrashey = DocumentTypeValueSetCode("38805-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Calcaneus_BilateralX_rayHarris = DocumentTypeValueSetCode("36975-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Calcaneus_LeftX_rayHarris = DocumentTypeValueSetCode("36977-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Calcaneus_RightX_rayHarris = DocumentTypeValueSetCode("38776-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FootX_rayHarris = DocumentTypeValueSetCode("36976-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeX_rayHolmblad = DocumentTypeValueSetCode("36978-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisX_rayInlet = DocumentTypeValueSetCode("37628-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ElbowX_rayJones = DocumentTypeValueSetCode("36979-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_LeftX_rayJones = DocumentTypeValueSetCode("36980-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_RightX_rayJones = DocumentTypeValueSetCode("38777-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HipX_rayJudet = DocumentTypeValueSetCode("36981-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_BilateralX_rayJudet = DocumentTypeValueSetCode("36982-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_LeftX_rayJudet = DocumentTypeValueSetCode("36983-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_RightX_rayJudet = DocumentTypeValueSetCode("37732-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayLeftAnteriorOblique = DocumentTypeValueSetCode("36620-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenX_rayLateral = DocumentTypeValueSetCode("36591-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AnkleX_rayLateral = DocumentTypeValueSetCode("36592-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayLateral = DocumentTypeValueSetCode("39051-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FemurX_rayLateral = DocumentTypeValueSetCode("36593-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FingerFifthX_rayLateral = DocumentTypeValueSetCode("36594-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FingerFourthX_rayLateral = DocumentTypeValueSetCode("36595-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FingerSecondX_rayLateral = DocumentTypeValueSetCode("36596-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FingerThirdX_rayLateral = DocumentTypeValueSetCode("36597-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_LeftX_rayLateral = DocumentTypeValueSetCode("36598-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_RightX_rayLateral = DocumentTypeValueSetCode("37703-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HandX_rayLateral = DocumentTypeValueSetCode("36599-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_BilateralX_rayLateral = DocumentTypeValueSetCode("36600-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_LeftX_rayLateral = DocumentTypeValueSetCode("36601-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_RightX_rayLateral = DocumentTypeValueSetCode("37712-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HipX_rayLateral = DocumentTypeValueSetCode("36602-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_LeftX_rayLateral = DocumentTypeValueSetCode("36603-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_RightX_rayLateral = DocumentTypeValueSetCode("37730-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeX_rayLateral = DocumentTypeValueSetCode("36604-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralX_rayLateral = DocumentTypeValueSetCode("36605-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_rayLateral = DocumentTypeValueSetCode("36606-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_rayLateral = DocumentTypeValueSetCode("37751-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeckX_rayLateral = DocumentTypeValueSetCode("24843-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisX_rayLateral = DocumentTypeValueSetCode("37629-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RibsX_rayLateral = DocumentTypeValueSetCode("39053-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ribs_LeftX_rayLateral = DocumentTypeValueSetCode("38857-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ribs_RightX_rayLateral = DocumentTypeValueSetCode("37784-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SinusesX_rayLateral = DocumentTypeValueSetCode("37858-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SkullX_rayLateral = DocumentTypeValueSetCode("24920-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineX_rayLateral = DocumentTypeValueSetCode("39052-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalX_rayLateral = DocumentTypeValueSetCode("24943-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_rayLateral = DocumentTypeValueSetCode("24969-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicX_rayLateral = DocumentTypeValueSetCode("30756-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThumbX_rayLateral = DocumentTypeValueSetCode("37891-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TibiaAndFibulaX_rayLateral = DocumentTypeValueSetCode("37893-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    WristX_rayLateral = DocumentTypeValueSetCode("37930-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenX_rayLateralCrosstable = DocumentTypeValueSetCode("36984-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HipX_rayLateralCrosstable = DocumentTypeValueSetCode("36985-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_BilateralX_rayLateralCrosstable = DocumentTypeValueSetCode("36986-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_LeftX_rayLateralCrosstable = DocumentTypeValueSetCode("36987-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_RightX_rayLateralCrosstable = DocumentTypeValueSetCode("37727-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeX_rayLateralCrosstable = DocumentTypeValueSetCode("36988-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SkullX_rayLateralCrosstable = DocumentTypeValueSetCode("37872-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineX_rayLateralCrosstable = DocumentTypeValueSetCode("37878-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalX_rayLateralCrosstable = DocumentTypeValueSetCode("36989-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_rayLateralCrosstable = DocumentTypeValueSetCode("36990-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicX_rayLateralCrosstable = DocumentTypeValueSetCode("37903-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalX_rayLateralCrosstablePortable = DocumentTypeValueSetCode("36991-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_rayLateralCrosstablePortable = DocumentTypeValueSetCode("36992-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HipX_rayLateralFrog = DocumentTypeValueSetCode("30786-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_BilateralX_rayLateralFrog = DocumentTypeValueSetCode("36993-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_LeftX_rayLateralFrog = DocumentTypeValueSetCode("36994-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_RightX_rayLateralFrog = DocumentTypeValueSetCode("37729-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisX_rayLateralFrog = DocumentTypeValueSetCode("37626-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralX_rayLateralHyperextension = DocumentTypeValueSetCode("36999-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_rayLateralHyperextension = DocumentTypeValueSetCode("37000-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_rayLateralHyperextension = DocumentTypeValueSetCode("37750-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicX_rayLateralHyperextension = DocumentTypeValueSetCode("37909-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeckX_rayLateralPortable = DocumentTypeValueSetCode("41774-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicX_rayLateralPortable = DocumentTypeValueSetCode("30757-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbosacralJunctionX_rayLateralSpot = DocumentTypeValueSetCode("37515-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbosacralJunctionX_rayLateralSpotStanding = DocumentTypeValueSetCode(
        "37516-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_LeftX_rayLateralDuringSurgery = DocumentTypeValueSetCode("38066-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_RightX_rayLateralDuringSurgery = DocumentTypeValueSetCode("38819-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FootX_rayLateralStanding = DocumentTypeValueSetCode("37001-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_rayLateralStanding = DocumentTypeValueSetCode("37002-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_rayLateralStanding = DocumentTypeValueSetCode("37754-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineX_rayLateralStanding = DocumentTypeValueSetCode("42442-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_rayLateralStanding = DocumentTypeValueSetCode("37003-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicX_rayLateralStanding = DocumentTypeValueSetCode("37910-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalX_rayLateralWExtension = DocumentTypeValueSetCode("36997-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_LeftX_rayLateralWExtension = DocumentTypeValueSetCode("36971-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_RightX_rayLateralWExtension = DocumentTypeValueSetCode("37833-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalX_rayLateralWFlexion = DocumentTypeValueSetCode("36998-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_LeftX_rayLateralWFlexion = DocumentTypeValueSetCode("36972-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_RightX_rayLateralWFlexion = DocumentTypeValueSetCode("37834-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeX_rayLaurin = DocumentTypeValueSetCode("37004-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenX_rayLeftLateral = DocumentTypeValueSetCode("36995-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayLeftLateral = DocumentTypeValueSetCode("30737-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayLeftLateralPortable = DocumentTypeValueSetCode("30738-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayLeftLateralUpright = DocumentTypeValueSetCode("24639-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayLeftLateralUprightPortable = DocumentTypeValueSetCode("24638-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayLeftOblique = DocumentTypeValueSetCode("37008-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_rayLeftOblique = DocumentTypeValueSetCode("37009-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayLeftObliquePortable = DocumentTypeValueSetCode("24641-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayLordotic = DocumentTypeValueSetCode("24640-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenX_rayLeftPosteriorOblique = DocumentTypeValueSetCode("38069-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_LeftMammogramMagnification = DocumentTypeValueSetCode("37005-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_RightMammogramMagnification = DocumentTypeValueSetCode("37773-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeckX_rayMagnification = DocumentTypeValueSetCode("42441-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeX_rayMerchants = DocumentTypeValueSetCode("24801-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralX_rayMerchants = DocumentTypeValueSetCode("26283-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_rayMerchants = DocumentTypeValueSetCode("26284-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_rayMerchants = DocumentTypeValueSetCode("26285-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_BilateralMammogramMLO = DocumentTypeValueSetCode("37006-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AnkleX_rayMortise = DocumentTypeValueSetCode("37007-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_LeftX_rayMortiseWManualStress = DocumentTypeValueSetCode("37475-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_RightX_rayMortiseWManualStress = DocumentTypeValueSetCode("37671-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_BilateralMammogramNippleProfile = DocumentTypeValueSetCode("38067-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenX_rayObliqueSingleView = DocumentTypeValueSetCode("36607-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FemurX_rayObliqueSingleView = DocumentTypeValueSetCode("36609-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FingerFifthX_rayObliqueSingleView = DocumentTypeValueSetCode("36610-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FingerFourthX_rayObliqueSingleView = DocumentTypeValueSetCode("36611-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FingerSecondX_rayObliqueSingleView = DocumentTypeValueSetCode("36612-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FingerThirdX_rayObliqueSingleView = DocumentTypeValueSetCode("36613-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FootX_rayObliqueSingleView = DocumentTypeValueSetCode("36614-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_LeftX_rayObliqueSingleView = DocumentTypeValueSetCode("36615-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_RightX_rayObliqueSingleView = DocumentTypeValueSetCode("37704-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HandX_rayObliqueSingleView = DocumentTypeValueSetCode("36616-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HipX_rayObliqueSingleView = DocumentTypeValueSetCode("36617-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_BilateralX_rayObliqueSingleView = DocumentTypeValueSetCode("36618-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineX_rayObliqueSingleView = DocumentTypeValueSetCode("42689-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_rayObliqueSingleView = DocumentTypeValueSetCode("30778-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicX_rayObliqueSingleView = DocumentTypeValueSetCode("30758-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThumbX_rayObliqueSingleView = DocumentTypeValueSetCode("37892-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_rayObliqueViewAnd_viewsWRightBendingAndWLeftBending_ = (
        DocumentTypeValueSetCode("44178-2")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_LeftX_rayObliqueCrosstable = DocumentTypeValueSetCode("37545-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_RightX_rayObliqueCrosstable = DocumentTypeValueSetCode("37728-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicX_rayObliquePortable = DocumentTypeValueSetCode("30759-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisX_rayOutlet = DocumentTypeValueSetCode("37631-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ShoulderX_rayOutlet = DocumentTypeValueSetCode("37845-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_BilateralX_rayOutlet = DocumentTypeValueSetCode("37012-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_rayOutlet = DocumentTypeValueSetCode("37013-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightX_rayOutlet = DocumentTypeValueSetCode("37802-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HandX_rayPA = DocumentTypeValueSetCode("36621-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_BilateralX_rayPA = DocumentTypeValueSetCode("36622-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_LeftX_rayPA = DocumentTypeValueSetCode("36623-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_RightX_rayPA = DocumentTypeValueSetCode("37714-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SkullX_rayPA = DocumentTypeValueSetCode("69270-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    WristX_rayPA = DocumentTypeValueSetCode("37931-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_BilateralX_rayPA = DocumentTypeValueSetCode("36624-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenX_rayPAProne = DocumentTypeValueSetCode("37015-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayPAUpright = DocumentTypeValueSetCode("24648-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_rayPAStanding = DocumentTypeValueSetCode("37014-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_rayPAStanding = DocumentTypeValueSetCode("37755-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeX_rayPAStandingAndW45DegreeFlexion = DocumentTypeValueSetCode("37477-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeX_rayPAW45DegreeFlexion = DocumentTypeValueSetCode("37476-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_LeftX_rayPAWClenchedFist = DocumentTypeValueSetCode("39324-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_RightX_rayPAWClenchedFist = DocumentTypeValueSetCode("69263-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MandibleX_rayPanorex = DocumentTypeValueSetCode("24828-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisX_rayPelvimetry = DocumentTypeValueSetCode("24871-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ElbowX_rayRadialHeadCapitellar = DocumentTypeValueSetCode("37998-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_BilateralX_rayRadialHeadCapitellar = DocumentTypeValueSetCode("37999-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_LeftX_rayRadialHeadCapitellar = DocumentTypeValueSetCode("38000-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_RightX_rayRadialHeadCapitellar = DocumentTypeValueSetCode("38006-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayRightAnteriorOblique = DocumentTypeValueSetCode("38068-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenX_rayRightLateral = DocumentTypeValueSetCode("36996-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayRightOblique = DocumentTypeValueSetCode("37010-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_rayRightOblique = DocumentTypeValueSetCode("37011-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeX_rayRosenbergStanding = DocumentTypeValueSetCode("37018-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralX_rayRosenbergStanding = DocumentTypeValueSetCode("37020-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_rayRosenbergStanding = DocumentTypeValueSetCode("37019-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_rayRosenbergStanding = DocumentTypeValueSetCode("37752-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenX_rayRightPosteriorOblique = DocumentTypeValueSetCode("39323-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FemoralArteryFluoroscopicAngiogramRunoffWAndWOContrastIA = DocumentTypeValueSetCode(
        "49511-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FemoralArteryFluoroscopicAngiogramRunoffWContrastIA = DocumentTypeValueSetCode(
        "24699-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FemoralArtery_BilateralFluoroscopicAngiogramRunoffWContrastIA = (
        DocumentTypeValueSetCode("26178-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FemoralArtery_LeftFluoroscopicAngiogramRunoffWContrastIA = DocumentTypeValueSetCode(
        "26179-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FemoralArtery_RightFluoroscopicAngiogramRunoffWContrastIA = (
        DocumentTypeValueSetCode("26180-0")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    WristX_rayScaphoidSingleView = DocumentTypeValueSetCode("42812-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_BilateralX_rayScaphoidSingleView = DocumentTypeValueSetCode("42813-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_LeftX_rayScaphoidSingleView = DocumentTypeValueSetCode("42814-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_RightX_rayScaphoidSingleView = DocumentTypeValueSetCode("42811-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicAndLumbarX_rayScoliosisSingleView = DocumentTypeValueSetCode("44206-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicAndLumbarX_rayScoliosisAP = DocumentTypeValueSetCode("30714-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicAndLumbarX_rayScoliosisAPSitting = DocumentTypeValueSetCode("42426-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicAndLumbarX_rayScoliosisAPStanding = DocumentTypeValueSetCode("37659-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicAndLumbarX_rayScoliosisAPStandingAndInBrace = DocumentTypeValueSetCode(
        "42428-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicAndLumbarX_rayScoliosisAPStandingAndWRightBending = (
        DocumentTypeValueSetCode("42429-1")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicAndLumbarX_rayScoliosisLateralSitting = DocumentTypeValueSetCode(
        "42427-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicAndLumbarX_rayScoliosisLateralStanding = DocumentTypeValueSetCode(
        "37660-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SternoclavicularJointX_raySerendipity = DocumentTypeValueSetCode("37846-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SternoclavicularJoint_BilateralX_raySerendipity = DocumentTypeValueSetCode(
        "37298-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SternoclavicularJoint_LeftX_raySerendipity = DocumentTypeValueSetCode("37299-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SternoclavicularJoint_RightX_raySerendipity = DocumentTypeValueSetCode("37808-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThyroidScanSpot = DocumentTypeValueSetCode("43671-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisX_rayStereo = DocumentTypeValueSetCode("42471-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SkullX_rayStereo = DocumentTypeValueSetCode("42474-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ShoulderX_rayStrykerNotch = DocumentTypeValueSetCode("39516-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_BilateralX_rayStrykerNotch = DocumentTypeValueSetCode("37024-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_rayStrykerNotch = DocumentTypeValueSetCode("37025-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightX_rayStrykerNotch = DocumentTypeValueSetCode("37791-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ShoulderX_rayStrykerNotchAndWestPoint = DocumentTypeValueSetCode("39517-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SinusesX_raySubmentovertex = DocumentTypeValueSetCode("37861-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SkullX_raySubmentovertex = DocumentTypeValueSetCode("37026-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeX_raySunrise = DocumentTypeValueSetCode("43780-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralX_raySunrise = DocumentTypeValueSetCode("37027-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_raySunrise = DocumentTypeValueSetCode("43779-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_raySunrise = DocumentTypeValueSetCode("69256-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PatellaX_raySunrise = DocumentTypeValueSetCode("69239-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Patella_BilateralX_raySunrise = DocumentTypeValueSetCode("69069-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralX_raySunriseAnd_viewsStanding_ = DocumentTypeValueSetCode("69064-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_raySunriseAnd_viewsStanding_ = DocumentTypeValueSetCode("69149-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_raySunriseAnd_viewsStanding_ = DocumentTypeValueSetCode("42432-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalX_raySwimmers = DocumentTypeValueSetCode("24944-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastMammogramTangential = DocumentTypeValueSetCode("37028-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_BilateralMammogramTangential = DocumentTypeValueSetCode("37029-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_LeftMammogramTangential = DocumentTypeValueSetCode("37030-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_RightMammogramTangential = DocumentTypeValueSetCode("37770-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SkullX_rayTowne = DocumentTypeValueSetCode("37870-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ColonFluoroscopyTransitPostSolidContrast = DocumentTypeValueSetCode("24668-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HumerusX_rayTransthoracic = DocumentTypeValueSetCode("37031-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Humerus_BilateralX_rayTransthoracic = DocumentTypeValueSetCode("37032-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Humerus_LeftX_rayTransthoracic = DocumentTypeValueSetCode("37033-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Humerus_RightX_rayTransthoracic = DocumentTypeValueSetCode("38007-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_rayTransthoracic = DocumentTypeValueSetCode("37034-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightX_rayTransthoracic = DocumentTypeValueSetCode("38779-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbosacralJunctionX_rayTrueAP = DocumentTypeValueSetCode("37300-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastMammogramTrueLateral = DocumentTypeValueSetCode("37037-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_BilateralMammogramTrueLateral = DocumentTypeValueSetCode("37038-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_LeftMammogramTrueLateral = DocumentTypeValueSetCode("38855-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_RightMammogramTrueLateral = DocumentTypeValueSetCode("37771-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HipX_rayTrueLateral = DocumentTypeValueSetCode("37039-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_LeftX_rayTrueLateral = DocumentTypeValueSetCode("37040-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_RightX_rayTrueLateral = DocumentTypeValueSetCode("38772-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeX_rayTunnel = DocumentTypeValueSetCode("30790-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralX_rayTunnel = DocumentTypeValueSetCode("37041-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_rayTunnel = DocumentTypeValueSetCode("37042-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_rayTunnel = DocumentTypeValueSetCode("37761-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_LeftX_rayTunnel_carpal = DocumentTypeValueSetCode("38842-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_RightX_rayTunnel_carpal = DocumentTypeValueSetCode("37677-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_rayTunnelStanding = DocumentTypeValueSetCode("37043-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_rayTunnelStanding = DocumentTypeValueSetCode("37756-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_LeftX_rayUlnarDeviation = DocumentTypeValueSetCode("37044-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_RightX_rayUlnarDeviation = DocumentTypeValueSetCode("37645-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_BilateralX_rayUlnarVariance = DocumentTypeValueSetCode("37045-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenX_rayUpright = DocumentTypeValueSetCode("37046-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_BilateralX_rayVelpeauAxillary = DocumentTypeValueSetCode("37047-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_rayVelpeauAxillary = DocumentTypeValueSetCode("37048-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightX_rayVelpeauAxillary = DocumentTypeValueSetCode("38780-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HipX_rayVonRossen = DocumentTypeValueSetCode("37049-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Orbit_BilateralX_rayWaters = DocumentTypeValueSetCode("37613-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SinusesX_rayWaters = DocumentTypeValueSetCode("37863-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SkullX_rayWaters = DocumentTypeValueSetCode("24921-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SinusesX_rayWatersStereo = DocumentTypeValueSetCode("42473-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SinusesX_rayWatersUpright = DocumentTypeValueSetCode("38117-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ShoulderX_rayWestPoint = DocumentTypeValueSetCode("30751-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_BilateralX_rayWestPoint = DocumentTypeValueSetCode("37050-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_rayWestPoint = DocumentTypeValueSetCode("37051-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightX_rayWestPoint = DocumentTypeValueSetCode("37809-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastMammogramXCCL = DocumentTypeValueSetCode("42680-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_BilateralMammogramXCCL = DocumentTypeValueSetCode("37052-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_LeftMammogramXCCL = DocumentTypeValueSetCode("37053-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_RightMammogramXCCL = DocumentTypeValueSetCode("37772-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScapulaX_rayY = DocumentTypeValueSetCode("37656-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Scapula_BilateralX_rayY = DocumentTypeValueSetCode("37055-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Scapula_LeftX_rayY = DocumentTypeValueSetCode("37054-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Scapula_RightX_rayY = DocumentTypeValueSetCode("37790-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ShoulderX_rayY = DocumentTypeValueSetCode("37847-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_rayY = DocumentTypeValueSetCode("38858-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightX_rayY = DocumentTypeValueSetCode("37805-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AcromioclavicularJointX_rayZanca = DocumentTypeValueSetCode("37848-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AcromioclavicularJoint_BilateralX_rayZanca = DocumentTypeValueSetCode("37056-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AcromioclavicularJoint_LeftX_rayZanca = DocumentTypeValueSetCode("37057-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AcromioclavicularJoint_RightX_rayZanca = DocumentTypeValueSetCode("37810-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenX_rayDuringSurgery = DocumentTypeValueSetCode("41793-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayDuringSurgery = DocumentTypeValueSetCode("41790-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestFluoroscopyDuringSurgery = DocumentTypeValueSetCode("24656-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HipFluoroscopyDuringSurgery = DocumentTypeValueSetCode("39047-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_LeftX_rayDuringSurgery = DocumentTypeValueSetCode("38065-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_RightX_rayDuringSurgery = DocumentTypeValueSetCode("38818-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HumerusX_rayDuringSurgery = DocumentTypeValueSetCode("42008-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RectumFluoroscopyPostContrastPRDuringDefecation = DocumentTypeValueSetCode(
        "24893-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Calcaneus_BilateralX_rayStanding = DocumentTypeValueSetCode("37058-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_BilateralX_rayStanding = DocumentTypeValueSetCode("37059-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_LeftX_rayStanding = DocumentTypeValueSetCode("37207-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_RightX_rayStanding = DocumentTypeValueSetCode("37731-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremity_BilateralX_rayStanding = DocumentTypeValueSetCode("44205-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremity_LeftX_rayStanding = DocumentTypeValueSetCode("38850-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremity_RightX_rayStanding = DocumentTypeValueSetCode("37734-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisX_rayStanding = DocumentTypeValueSetCode("37633-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GastrointestineUpperFluoroscopyWAirContrastPO = DocumentTypeValueSetCode("39144-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperGastrointestineAndSmallBowelFluoroscopyWAirContrastPO = (
        DocumentTypeValueSetCode("41795-6")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    WristX_rayWClenchedFist = DocumentTypeValueSetCode("69302-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_BilateralX_rayWClenchedFist = DocumentTypeValueSetCode("36968-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VesselFluoroscopicAngiogramWContrast = DocumentTypeValueSetCode("30639-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GastrointestineUpperAndGallbladderFluoroscopyWContrastPO = DocumentTypeValueSetCode(
        "42470-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperGastrointestineAndSmallBowelFluoroscopyWContrastPO = DocumentTypeValueSetCode(
        "30809-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GastrointestineUpperAndSmallBowelAndGallbladderFluoroscopyWContrastPO = (
        DocumentTypeValueSetCode("42469-7")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayWExpiration = DocumentTypeValueSetCode("38001-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayWInspiration = DocumentTypeValueSetCode("38002-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FetalX_ray = DocumentTypeValueSetCode("37060-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenX_ray = DocumentTypeValueSetCode("37636-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenFluoroscopy = DocumentTypeValueSetCode("46341-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AcetabulumX_ray = DocumentTypeValueSetCode("24535-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Acetabulum_BilateralX_ray = DocumentTypeValueSetCode("26133-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Acetabulum_LeftX_ray = DocumentTypeValueSetCode("26134-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Acetabulum_RightX_ray = DocumentTypeValueSetCode("26135-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AcromioclavicularJointX_ray = DocumentTypeValueSetCode("24536-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AcromioclavicularJoint_BilateralX_ray = DocumentTypeValueSetCode("26136-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AcromioclavicularJoint_LeftX_ray = DocumentTypeValueSetCode("26137-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AcromioclavicularJoint_RightX_ray = DocumentTypeValueSetCode("26138-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AnkleX_ray = DocumentTypeValueSetCode("24541-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_BilateralX_ray = DocumentTypeValueSetCode("26097-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_LeftX_ray = DocumentTypeValueSetCode("26098-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_LeftAndFoot_leftX_ray = DocumentTypeValueSetCode("51395-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_RightX_ray = DocumentTypeValueSetCode("26099-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_RightAndFoot_RightX_ray = DocumentTypeValueSetCode("51394-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastMammogram = DocumentTypeValueSetCode("36625-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastFFDMammogram = DocumentTypeValueSetCode("46342-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastImplantMammogram = DocumentTypeValueSetCode("38070-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastImplant_BilateralMammogram = DocumentTypeValueSetCode("38071-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastImplant_LeftMammogram = DocumentTypeValueSetCode("38072-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastImplant_RightMammogram = DocumentTypeValueSetCode("38820-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastImplant_UnilateralMammogram = DocumentTypeValueSetCode("46380-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastSpecimenMammogram = DocumentTypeValueSetCode("24597-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastSpecimen_BilateralMammogram = DocumentTypeValueSetCode("38079-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastSpecimen_LeftMammogram = DocumentTypeValueSetCode("38080-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastSpecimen_RightMammogram = DocumentTypeValueSetCode("38821-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_BilateralMammogram = DocumentTypeValueSetCode("36626-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_LeftMammogram = DocumentTypeValueSetCode("36627-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_RightMammogram = DocumentTypeValueSetCode("37774-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_UnilateralMammogram = DocumentTypeValueSetCode("46339-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CalcaneusX_ray = DocumentTypeValueSetCode("24612-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Calcaneus_BilateralX_ray = DocumentTypeValueSetCode("26100-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Calcaneus_LeftX_ray = DocumentTypeValueSetCode("26101-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Calcaneus_RightX_ray = DocumentTypeValueSetCode("26102-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_ray = DocumentTypeValueSetCode("30745-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestFluoroscopy = DocumentTypeValueSetCode("30631-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestAndAbdomenX_ray = DocumentTypeValueSetCode("42269-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClavicleX_ray = DocumentTypeValueSetCode("24664-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Clavicle_BilateralX_ray = DocumentTypeValueSetCode("26106-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Clavicle_LeftX_ray = DocumentTypeValueSetCode("26107-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Clavicle_RightX_ray = DocumentTypeValueSetCode("26108-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CoccyxX_ray = DocumentTypeValueSetCode("30883-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ElbowX_ray = DocumentTypeValueSetCode("24676-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_BilateralX_ray = DocumentTypeValueSetCode("26109-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_LeftX_ray = DocumentTypeValueSetCode("26110-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_RightX_ray = DocumentTypeValueSetCode("26111-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_Radius_UlnaX_ray = DocumentTypeValueSetCode("46381-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityX_ray = DocumentTypeValueSetCode("37637-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FacialBonesX_ray = DocumentTypeValueSetCode("24695-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FacialBonesAndZygomaticArchX_ray = DocumentTypeValueSetCode("37303-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FemurX_ray = DocumentTypeValueSetCode("24704-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Femur_BilateralX_ray = DocumentTypeValueSetCode("26118-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Femur_LeftX_ray = DocumentTypeValueSetCode("26120-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Femur_RightX_ray = DocumentTypeValueSetCode("26122-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FingerX_ray = DocumentTypeValueSetCode("24706-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Finger_BilateralX_ray = DocumentTypeValueSetCode("26124-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FingerFifthX_ray = DocumentTypeValueSetCode("30783-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FingerFifth_BilateralX_ray = DocumentTypeValueSetCode("37517-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FingerFifth_LeftX_ray = DocumentTypeValueSetCode("37518-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FingerFifth_RightX_ray = DocumentTypeValueSetCode("38147-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FingerFourthX_ray = DocumentTypeValueSetCode("30782-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FingerFourth_BilateralX_ray = DocumentTypeValueSetCode("37519-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FingerFourth_LeftX_ray = DocumentTypeValueSetCode("37520-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FingerFourth_RightX_ray = DocumentTypeValueSetCode("38146-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Finger_LeftX_ray = DocumentTypeValueSetCode("26125-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Finger_RightX_ray = DocumentTypeValueSetCode("26126-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FingerSecondX_ray = DocumentTypeValueSetCode("30780-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FingerSecond_BilateralX_ray = DocumentTypeValueSetCode("37521-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FingerSecond_LeftX_ray = DocumentTypeValueSetCode("37522-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FingerSecond_RightX_ray = DocumentTypeValueSetCode("38144-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FingerThirdX_ray = DocumentTypeValueSetCode("30781-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FingerThird_BilateralX_ray = DocumentTypeValueSetCode("37523-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FingerThird_LeftX_ray = DocumentTypeValueSetCode("37524-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FingerThird_RightX_ray = DocumentTypeValueSetCode("38145-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FootX_ray = DocumentTypeValueSetCode("24709-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_BilateralX_ray = DocumentTypeValueSetCode("26127-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_LeftX_ray = DocumentTypeValueSetCode("26128-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_RightX_ray = DocumentTypeValueSetCode("26129-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FootSesamoidBonesX_ray = DocumentTypeValueSetCode("42399-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FootSesamoidBones_BilateralX_ray = DocumentTypeValueSetCode("42400-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FootSesamoidBones_LeftX_ray = DocumentTypeValueSetCode("43641-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FootSesamoidBones_RightX_ray = DocumentTypeValueSetCode("42434-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GreatToe_BilateralX_ray = DocumentTypeValueSetCode("37532-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GreatToe_LeftX_ray = DocumentTypeValueSetCode("37533-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GreatToe_RightX_ray = DocumentTypeValueSetCode("38152-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HandX_ray = DocumentTypeValueSetCode("28582-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_BilateralX_ray = DocumentTypeValueSetCode("36629-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_LeftX_ray = DocumentTypeValueSetCode("36630-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_RightX_ray = DocumentTypeValueSetCode("37716-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartFluoroscopyVideo = DocumentTypeValueSetCode("24752-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HipX_ray = DocumentTypeValueSetCode("24762-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_BilateralX_ray = DocumentTypeValueSetCode("26130-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_LeftX_ray = DocumentTypeValueSetCode("26131-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_RightX_ray = DocumentTypeValueSetCode("26132-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HumerusX_ray = DocumentTypeValueSetCode("28567-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HumerusBicipitalGrooveX_ray = DocumentTypeValueSetCode("37319-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HumerusBicipitalGroove_BilateralX_ray = DocumentTypeValueSetCode("37321-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HumerusBicipitalGroove_LeftX_ray = DocumentTypeValueSetCode("37320-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HumerusBicipitalGroove_RightX_ray = DocumentTypeValueSetCode("38797-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Humerus_BilateralX_ray = DocumentTypeValueSetCode("37062-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Humerus_LeftX_ray = DocumentTypeValueSetCode("36632-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Humerus_RightX_ray = DocumentTypeValueSetCode("37738-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InternalAuditoryCanalX_ray = DocumentTypeValueSetCode("36628-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeX_ray = DocumentTypeValueSetCode("28565-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralX_ray = DocumentTypeValueSetCode("36635-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_ray = DocumentTypeValueSetCode("36636-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_ray = DocumentTypeValueSetCode("37758-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LarynxFluoroscopy = DocumentTypeValueSetCode("48465-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityX_ray = DocumentTypeValueSetCode("24686-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremity_BilateralX_ray = DocumentTypeValueSetCode("26112-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremity_LeftX_ray = DocumentTypeValueSetCode("26113-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremity_RightX_ray = DocumentTypeValueSetCode("26114-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MandibleX_ray = DocumentTypeValueSetCode("24829-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Mandible_LeftX_ray = DocumentTypeValueSetCode("48745-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Mandible_RightX_ray = DocumentTypeValueSetCode("43533-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MastoidX_ray = DocumentTypeValueSetCode("24830-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Mastoid_BilateralX_ray = DocumentTypeValueSetCode("26139-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Mastoid_LeftX_ray = DocumentTypeValueSetCode("26140-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Mastoid_RightX_ray = DocumentTypeValueSetCode("26141-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MaxillaX_ray = DocumentTypeValueSetCode("36637-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NasalBonesX_ray = DocumentTypeValueSetCode("24834-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeckX_ray = DocumentTypeValueSetCode("37639-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Olecranon_LeftX_ray = DocumentTypeValueSetCode("37332-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Olecranon_RightX_ray = DocumentTypeValueSetCode("38798-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OpticForamenX_ray = DocumentTypeValueSetCode("24846-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OpticForamen_BilateralX_ray = DocumentTypeValueSetCode("26142-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OpticForamen_LeftX_ray = DocumentTypeValueSetCode("26143-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OpticForamen_RightX_ray = DocumentTypeValueSetCode("26144-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OrbitX_ray = DocumentTypeValueSetCode("36886-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Orbit_BilateralX_ray = DocumentTypeValueSetCode("24854-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Orbit_LeftX_ray = DocumentTypeValueSetCode("36887-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Orbit_RightX_ray = DocumentTypeValueSetCode("38774-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Orbit_FacialBonesX_ray = DocumentTypeValueSetCode("43529-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OropharynxFluoroscopyVideo = DocumentTypeValueSetCode("24855-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PatellaX_ray = DocumentTypeValueSetCode("30791-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Patella_BilateralX_ray = DocumentTypeValueSetCode("36638-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Patella_LeftX_ray = DocumentTypeValueSetCode("36639-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Patella_RightX_ray = DocumentTypeValueSetCode("37777-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisX_ray = DocumentTypeValueSetCode("28561-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisSymphysisPubisX_ray = DocumentTypeValueSetCode("30885-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisAndHipX_ray = DocumentTypeValueSetCode("30767-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisAndHip_BilateralX_ray = DocumentTypeValueSetCode("30768-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisAndHip_LeftX_ray = DocumentTypeValueSetCode("36631-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisAndHip_RightX_ray = DocumentTypeValueSetCode("38771-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisAndSpineLumbarX_ray = DocumentTypeValueSetCode("47984-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PetrousBoneX_ray = DocumentTypeValueSetCode("24745-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Radius_BilateralAndUlna_BilateralX_ray = DocumentTypeValueSetCode("26146-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Radius_LeftAndUlna_leftX_ray = DocumentTypeValueSetCode("26148-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Radius_RightAndUlna_RightX_ray = DocumentTypeValueSetCode("26150-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RadiusAndUlnaX_ray = DocumentTypeValueSetCode("24891-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RibsX_ray = DocumentTypeValueSetCode("24899-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RibsAnteriorX_ray = DocumentTypeValueSetCode("37937-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RibsAnterior_BilateralX_ray = DocumentTypeValueSetCode("38073-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RibsAnterior_LeftX_ray = DocumentTypeValueSetCode("38074-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RibsAnterior_RightX_ray = DocumentTypeValueSetCode("37963-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RibsAnteriorAndPosterior_LeftX_ray = DocumentTypeValueSetCode("38868-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RibsAnteriorAndPosterior_RightX_ray = DocumentTypeValueSetCode("37962-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ribs_BilateralX_ray = DocumentTypeValueSetCode("26151-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ribs_BilateralAndChestX_ray = DocumentTypeValueSetCode("69071-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ribs_LeftX_ray = DocumentTypeValueSetCode("26152-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ribs_LeftAndChestX_ray = DocumentTypeValueSetCode("39326-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RibsLower_LeftX_ray = DocumentTypeValueSetCode("38866-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RibsLowerPosteriorX_ray = DocumentTypeValueSetCode("39489-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RibsLowerPosterior_LeftX_ray = DocumentTypeValueSetCode("42381-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RibsLowerPosterior_RightX_ray = DocumentTypeValueSetCode("39493-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RibsLower_RightX_ray = DocumentTypeValueSetCode("37960-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RibsPosteriorX_ray = DocumentTypeValueSetCode("37938-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RibsPosterior_BilateralX_ray = DocumentTypeValueSetCode("39352-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RibsPosterior_LeftX_ray = DocumentTypeValueSetCode("38869-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RibsPosterior_RightX_ray = DocumentTypeValueSetCode("37964-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ribs_RightX_ray = DocumentTypeValueSetCode("26153-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RibsUpperAnteriorAndPosterior_LeftX_ray = DocumentTypeValueSetCode("39351-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RibsUpperAnteriorAndPosterior_RightX_ray = DocumentTypeValueSetCode("39491-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RibsUpper_LeftX_ray = DocumentTypeValueSetCode("38867-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RibsUpperPosterior_LeftX_ray = DocumentTypeValueSetCode("39353-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RibsUpperPosterior_RightX_ray = DocumentTypeValueSetCode("39492-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RibsUpper_RightX_ray = DocumentTypeValueSetCode("37961-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SacroiliacJointX_ray = DocumentTypeValueSetCode("24900-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SacroiliacJoint_BilateralX_ray = DocumentTypeValueSetCode("36633-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SacroiliacJoint_LeftX_ray = DocumentTypeValueSetCode("36634-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SacroiliacJoint_RightX_ray = DocumentTypeValueSetCode("37786-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SacrumX_ray = DocumentTypeValueSetCode("30884-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SacrumAndCoccyxX_ray = DocumentTypeValueSetCode("24665-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SalivaryGlandX_ray = DocumentTypeValueSetCode("39058-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScapulaX_ray = DocumentTypeValueSetCode("24903-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Scapula_BilateralX_ray = DocumentTypeValueSetCode("26154-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Scapula_LeftX_ray = DocumentTypeValueSetCode("26155-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Scapula_RightX_ray = DocumentTypeValueSetCode("26156-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SellaTurcicaX_ray = DocumentTypeValueSetCode("42159-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ShoulderX_ray = DocumentTypeValueSetCode("24909-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_BilateralX_ray = DocumentTypeValueSetCode("26157-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_ray = DocumentTypeValueSetCode("26158-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightX_ray = DocumentTypeValueSetCode("26159-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ShuntX_ray = DocumentTypeValueSetCode("42160-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ShuntFluoroscopy = DocumentTypeValueSetCode("24911-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SinusesX_ray = DocumentTypeValueSetCode("24916-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SkullX_ray = DocumentTypeValueSetCode("28564-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Skull_baseX_ray = DocumentTypeValueSetCode("48697-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SkullAndFacialBonesAndMandibleX_ray = DocumentTypeValueSetCode("37338-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineX_ray = DocumentTypeValueSetCode("28613-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalX_ray = DocumentTypeValueSetCode("24946-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalFluoroscopy = DocumentTypeValueSetCode("36640-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalFluoroscopyVideo = DocumentTypeValueSetCode("43538-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalAndSpineThoracicX_ray = DocumentTypeValueSetCode("37481-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalAndThoracicAndLumbarX_ray = DocumentTypeValueSetCode("38008-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicothoracicJunctionX_ray = DocumentTypeValueSetCode("43781-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_ray = DocumentTypeValueSetCode("24972-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarFluoroscopyVideo = DocumentTypeValueSetCode("43536-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Spine_lumbarAndSacroiliacJoint_BilateralX_ray = DocumentTypeValueSetCode("24975-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarAndSacrumX_ray = DocumentTypeValueSetCode("37340-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarAndSacrumAndCoccyxX_ray = DocumentTypeValueSetCode("37341-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarAndSacrumAndSacroiliacJointAndCoccyxX_ray = DocumentTypeValueSetCode(
        "37342-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbosacralJunctionX_ray = DocumentTypeValueSetCode("46340-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicX_ray = DocumentTypeValueSetCode("24983-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicAndLumbarX_ray = DocumentTypeValueSetCode("42692-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracolumbarJunctionX_ray = DocumentTypeValueSetCode("37975-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SternoclavicularJoint_BilateralX_ray = DocumentTypeValueSetCode("37323-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SternoclavicularJoint_LeftX_ray = DocumentTypeValueSetCode("37324-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SternoclavicularJoint_RightX_ray = DocumentTypeValueSetCode("37965-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SternoclavicularJointsX_ray = DocumentTypeValueSetCode("24993-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SternumX_ray = DocumentTypeValueSetCode("24994-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SurgicalSpecimenX_ray = DocumentTypeValueSetCode("72876-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporomandibularJointX_ray = DocumentTypeValueSetCode("25000-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporomandibularJoint_BilateralX_ray = DocumentTypeValueSetCode("37325-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporomandibularJoint_LeftX_ray = DocumentTypeValueSetCode("30889-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporomandibularJoint_RightX_ray = DocumentTypeValueSetCode("30890-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThumbX_ray = DocumentTypeValueSetCode("25006-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Thumb_BilateralX_ray = DocumentTypeValueSetCode("26160-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Thumb_LeftX_ray = DocumentTypeValueSetCode("26161-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Thumb_RightX_ray = DocumentTypeValueSetCode("26162-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Tibia_BilateralAndFibula_BilateralX_ray = DocumentTypeValueSetCode("26163-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Tibia_LeftAndFibula_LeftX_ray = DocumentTypeValueSetCode("26164-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Tibia_RightAndFibula_RightX_ray = DocumentTypeValueSetCode("26165-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TibiaAndFibulaX_ray = DocumentTypeValueSetCode("25011-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ToeFifth_LeftX_ray = DocumentTypeValueSetCode("37530-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ToeFifth_RightX_ray = DocumentTypeValueSetCode("38151-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ToeFourth_LeftX_ray = DocumentTypeValueSetCode("37531-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ToeFourth_RightX_ray = DocumentTypeValueSetCode("38150-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ToeSecond_LeftX_ray = DocumentTypeValueSetCode("37534-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ToeSecond_RightX_ray = DocumentTypeValueSetCode("38148-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ToeThird_LeftX_ray = DocumentTypeValueSetCode("37535-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ToeThird_RightX_ray = DocumentTypeValueSetCode("38149-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ToesX_ray = DocumentTypeValueSetCode("25013-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Toes_BilateralX_ray = DocumentTypeValueSetCode("26166-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Toes_LeftX_ray = DocumentTypeValueSetCode("26167-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Toes_RightX_ray = DocumentTypeValueSetCode("26168-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TracheaX_ray = DocumentTypeValueSetCode("44238-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TracheaFluoroscopy = DocumentTypeValueSetCode("48464-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityX_ray = DocumentTypeValueSetCode("24689-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremity_BilateralX_ray = DocumentTypeValueSetCode("26115-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremity_LeftX_ray = DocumentTypeValueSetCode("26116-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremity_RightX_ray = DocumentTypeValueSetCode("26117-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    WristX_ray = DocumentTypeValueSetCode("24619-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_BilateralX_ray = DocumentTypeValueSetCode("26169-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_LeftX_ray = DocumentTypeValueSetCode("26170-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_LeftAndHand_LeftX_ray = DocumentTypeValueSetCode("51392-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_RightX_ray = DocumentTypeValueSetCode("26171-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_RightAndHand_RightX_ray = DocumentTypeValueSetCode("51388-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionX_ray = DocumentTypeValueSetCode("43468-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionFluoroscopy = DocumentTypeValueSetCode("49512-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ZygomaticArchX_ray = DocumentTypeValueSetCode("25074-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ZygomaticArch_BilateralX_ray = DocumentTypeValueSetCode("26172-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ZygomaticArch_LeftX_ray = DocumentTypeValueSetCode("26173-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ZygomaticArch_RightX_ray = DocumentTypeValueSetCode("26174-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralX_rayAnd_APViewStanding_ = DocumentTypeValueSetCode("51387-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_RightX_rayAnd_viewWManualStress_ = DocumentTypeValueSetCode("39370-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GastrointestineUpperFluoroscopyAndAPWContrastPO = DocumentTypeValueSetCode(
        "30635-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GastrointestineUpperFluoroscopyAndAPWWaterSolubleContrastPO = (
        DocumentTypeValueSetCode("42162-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_RightX_rayAndCarpalTunnel = DocumentTypeValueSetCode("39400-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HipX_rayAndDaneliusMiller = DocumentTypeValueSetCode("69131-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_LeftX_rayAndDaneliusMiller = DocumentTypeValueSetCode("69140-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_RightX_rayAndDaneliusMiller = DocumentTypeValueSetCode("39513-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisX_rayAndInletAndOutlet = DocumentTypeValueSetCode("39360-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_BilateralX_rayAndLateralCrosstable = DocumentTypeValueSetCode("69059-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_LeftX_rayAndLateralCrosstable = DocumentTypeValueSetCode("69139-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_RightX_rayAndLateralCrosstable = DocumentTypeValueSetCode("39377-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisAndHip_BilateralX_rayAndLateralFrog = DocumentTypeValueSetCode("37583-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_RightX_rayAndMortise = DocumentTypeValueSetCode("39372-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_RightX_rayAndOblique = DocumentTypeValueSetCode("39373-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_rayAndOblique = DocumentTypeValueSetCode("39390-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisX_rayAndOblique = DocumentTypeValueSetCode("39511-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Radius_RightAndUlna_RightX_rayAndOblique = DocumentTypeValueSetCode("39376-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalX_rayAndOblique = DocumentTypeValueSetCode("42164-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_rayAndOblique = DocumentTypeValueSetCode("42163-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicX_rayAndOblique = DocumentTypeValueSetCode("39414-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Tibia_RightAndFibula_RightX_rayAndOblique = DocumentTypeValueSetCode("39398-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_BilateralX_rayAndObliques = DocumentTypeValueSetCode("69056-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ribs_BilateralAndChestX_rayAndPAChest = DocumentTypeValueSetCode("41811-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ribs_LeftAndChestX_rayAndPAChest = DocumentTypeValueSetCode("41832-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ribs_RightAndChestX_rayAndPAChest = DocumentTypeValueSetCode("42010-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RibsAndChestX_rayAndPAChest = DocumentTypeValueSetCode("42165-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_BilateralX_rayAndRadialHeadCapitellar = DocumentTypeValueSetCode("46389-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_rayAndSunrise = DocumentTypeValueSetCode("39391-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicX_rayAndSwimmers = DocumentTypeValueSetCode("39412-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_rayAndTunnel = DocumentTypeValueSetCode("69148-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_rayAndTunnel = DocumentTypeValueSetCode("39389-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThyroidScanAndUptake_single = DocumentTypeValueSetCode("30694-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThyroidScanAndUptakeWI_123IV = DocumentTypeValueSetCode("42271-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThyroidScanAndUptakeWI_123PO = DocumentTypeValueSetCode("60527-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThyroidScanAndUptakeWI_131IV = DocumentTypeValueSetCode("25008-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThyroidScanAndUptakeWI_131PO = DocumentTypeValueSetCode("69236-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThyroidScanAndUptake = DocumentTypeValueSetCode("43672-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThyroidScanAndUptakeWTc_99mPertechnetateIV = DocumentTypeValueSetCode("44147-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeX_ray_AP_standing_And_lateral_WHyperextension_ = DocumentTypeValueSetCode(
        "42405-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_ray_APWR_bendingAndWL_bendingAndWOBending_AndLateral = (
        DocumentTypeValueSetCode("42401-0")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_ray_AP_WR_bendingAndWL_bending_And_lateral_WFlexionAndWExtension_ = (
        DocumentTypeValueSetCode("42411-9")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightX_ray_WInternalRotationAndWExternalRotation_AndAxillary = (
        DocumentTypeValueSetCode("39392-6")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FacialBonesX_ray1Or2Views = DocumentTypeValueSetCode("44199-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeX_ray1Or2Views = DocumentTypeValueSetCode("44198-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_ray1Or2Views = DocumentTypeValueSetCode("47373-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_ray1Or2Views = DocumentTypeValueSetCode("47375-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MandibleX_ray1Or2Views = DocumentTypeValueSetCode("43521-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Mastoid_BilateralX_ray1Or2Views = DocumentTypeValueSetCode("47983-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Mastoid_LeftX_ray1Or2Views = DocumentTypeValueSetCode("48489-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Mastoid_RightX_ray1Or2Views = DocumentTypeValueSetCode("48488-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisX_ray1Or2Views = DocumentTypeValueSetCode("43522-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SacroiliacJointX_ray1Or2Views = DocumentTypeValueSetCode("48467-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SinusesX_ray1Or2Views = DocumentTypeValueSetCode("43523-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeX_ray1Or2ViewsPortable = DocumentTypeValueSetCode("44202-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisX_ray1Or2ViewsPortable = DocumentTypeValueSetCode("44201-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenX_ray2Views = DocumentTypeValueSetCode("36641-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Acetabulum_LeftX_ray2Views = DocumentTypeValueSetCode("37064-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Acetabulum_RightX_ray2Views = DocumentTypeValueSetCode("37664-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AcromioclavicularJoint_LeftX_ray2Views = DocumentTypeValueSetCode("36665-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AcromioclavicularJoint_RightX_ray2Views = DocumentTypeValueSetCode("37661-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AnkleX_ray2Views = DocumentTypeValueSetCode("24540-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_BilateralX_ray2Views = DocumentTypeValueSetCode("26385-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_LeftX_ray2Views = DocumentTypeValueSetCode("26386-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_RightX_ray2Views = DocumentTypeValueSetCode("26387-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_LeftMammogram2Views = DocumentTypeValueSetCode("36642-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_RightMammogram2Views = DocumentTypeValueSetCode("37768-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CalcaneusX_ray2Views = DocumentTypeValueSetCode("36661-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Calcaneus_BilateralX_ray2Views = DocumentTypeValueSetCode("48433-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Calcaneus_LeftX_ray2Views = DocumentTypeValueSetCode("36662-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Calcaneus_RightX_ray2Views = DocumentTypeValueSetCode("37718-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_ray2Views = DocumentTypeValueSetCode("36643-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestFluoroscopy2Views = DocumentTypeValueSetCode("36644-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClavicleX_ray2Views = DocumentTypeValueSetCode("36645-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Clavicle_LeftX_ray2Views = DocumentTypeValueSetCode("36646-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Clavicle_RightX_ray2Views = DocumentTypeValueSetCode("37679-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CoccyxX_ray2Views = DocumentTypeValueSetCode("36647-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ElbowX_ray2Views = DocumentTypeValueSetCode("36648-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_BilateralX_ray2Views = DocumentTypeValueSetCode("36649-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_LeftX_ray2Views = DocumentTypeValueSetCode("36650-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_RightX_ray2Views = DocumentTypeValueSetCode("37681-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FemurX_ray2Views = DocumentTypeValueSetCode("36652-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Femur_BilateralX_ray2Views = DocumentTypeValueSetCode("36653-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Femur_LeftX_ray2Views = DocumentTypeValueSetCode("36654-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Femur_RightX_ray2Views = DocumentTypeValueSetCode("37690-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FingerX_ray2Views = DocumentTypeValueSetCode("36655-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Finger_LeftX_ray2Views = DocumentTypeValueSetCode("36656-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Finger_RightX_ray2Views = DocumentTypeValueSetCode("37694-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FootX_ray2Views = DocumentTypeValueSetCode("30784-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_BilateralX_ray2Views = DocumentTypeValueSetCode("36657-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_LeftX_ray2Views = DocumentTypeValueSetCode("38846-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_RightX_ray2Views = DocumentTypeValueSetCode("37697-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HandX_ray2Views = DocumentTypeValueSetCode("24721-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_BilateralX_ray2Views = DocumentTypeValueSetCode("26388-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_LeftX_ray2Views = DocumentTypeValueSetCode("26389-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_RightX_ray2Views = DocumentTypeValueSetCode("26390-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HipX_ray2Views = DocumentTypeValueSetCode("36663-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_BilateralX_ray2Views = DocumentTypeValueSetCode("69058-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_LeftX_ray2Views = DocumentTypeValueSetCode("36664-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_RightX_ray2Views = DocumentTypeValueSetCode("37721-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HumerusX_ray2Views = DocumentTypeValueSetCode("24765-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Humerus_BilateralX_ray2Views = DocumentTypeValueSetCode("26391-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Humerus_LeftX_ray2Views = DocumentTypeValueSetCode("26392-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Humerus_RightX_ray2Views = DocumentTypeValueSetCode("26393-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeX_ray2Views = DocumentTypeValueSetCode("24806-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralX_ray2Views = DocumentTypeValueSetCode("26394-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_ray2Views = DocumentTypeValueSetCode("26395-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_ray2Views = DocumentTypeValueSetCode("26396-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityX_ray2Views = DocumentTypeValueSetCode("36651-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremity_RightX_ray2Views = DocumentTypeValueSetCode("69257-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PatellaX_ray2Views = DocumentTypeValueSetCode("24861-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Patella_BilateralX_ray2Views = DocumentTypeValueSetCode("26397-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Patella_LeftX_ray2Views = DocumentTypeValueSetCode("26398-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Patella_RightX_ray2Views = DocumentTypeValueSetCode("26399-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisX_ray2Views = DocumentTypeValueSetCode("37617-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisAndHip_LeftX_ray2Views = DocumentTypeValueSetCode("42685-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisAndHip_RightX_ray2Views = DocumentTypeValueSetCode("42686-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Radius_BilateralAndUlna_BilateralX_ray2Views = DocumentTypeValueSetCode("36659-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Radius_LeftAndUlna_leftX_ray2Views = DocumentTypeValueSetCode("36660-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Radius_RightAndUlna_RightX_ray2Views = DocumentTypeValueSetCode("37707-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RadiusAndUlnaX_ray2Views = DocumentTypeValueSetCode("36658-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RibsX_ray2Views = DocumentTypeValueSetCode("39060-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ribs_BilateralX_ray2Views = DocumentTypeValueSetCode("42687-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ribs_LeftX_ray2Views = DocumentTypeValueSetCode("37066-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ribs_RightX_ray2Views = DocumentTypeValueSetCode("37780-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SacrumX_ray2Views = DocumentTypeValueSetCode("37651-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SacrumAndCoccyxX_ray2Views = DocumentTypeValueSetCode("44179-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScapulaX_ray2Views = DocumentTypeValueSetCode("37655-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Scapula_LeftX_ray2Views = DocumentTypeValueSetCode("36666-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Scapula_RightX_ray2Views = DocumentTypeValueSetCode("37787-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SellaTurcicaX_ray2Views = DocumentTypeValueSetCode("42435-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ShoulderX_ray2Views = DocumentTypeValueSetCode("37840-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_BilateralX_ray2Views = DocumentTypeValueSetCode("36667-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_ray2Views = DocumentTypeValueSetCode("36668-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightX_ray2Views = DocumentTypeValueSetCode("37793-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SinusesX_ray2Views = DocumentTypeValueSetCode("37853-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SkullX_ray2Views = DocumentTypeValueSetCode("37867-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineX_ray2Views = DocumentTypeValueSetCode("37879-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalX_ray2Views = DocumentTypeValueSetCode("36669-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalAndThoracicAndLumbarX_ray2Views = DocumentTypeValueSetCode("43784-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_ray2Views = DocumentTypeValueSetCode("36670-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicX_ray2Views = DocumentTypeValueSetCode("37905-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicAndLumbarX_ray2Views = DocumentTypeValueSetCode("24984-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracolumbarJunctionX_ray2Views = DocumentTypeValueSetCode("69273-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SternumX_ray2Views = DocumentTypeValueSetCode("37883-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Tibia_BilateralAndFibula_BilateralX_ray2Views = DocumentTypeValueSetCode("36671-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Tibia_LeftAndFibula_LeftX_ray2Views = DocumentTypeValueSetCode("36672-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Tibia_RightAndFibula_RightX_ray2Views = DocumentTypeValueSetCode("37815-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TibiaAndFibulaX_ray2Views = DocumentTypeValueSetCode("37895-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ToesX_ray2Views = DocumentTypeValueSetCode("37902-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Toes_BilateralX_ray2Views = DocumentTypeValueSetCode("37348-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Toes_LeftX_ray2Views = DocumentTypeValueSetCode("36673-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Toes_RightX_ray2Views = DocumentTypeValueSetCode("37821-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityX_ray2Views = DocumentTypeValueSetCode("37922-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    WristX_ray2Views = DocumentTypeValueSetCode("37925-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_BilateralX_ray2Views = DocumentTypeValueSetCode("37482-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_LeftX_ray2Views = DocumentTypeValueSetCode("37483-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_RightX_ray2Views = DocumentTypeValueSetCode("37826-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ZygomaticArchX_ray2Views = DocumentTypeValueSetCode("69305-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_ray2ViewsAnd_viewsStanding_ = DocumentTypeValueSetCode("42430-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_ray2ViewsAndApical = DocumentTypeValueSetCode("42009-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_ray2ViewsAndOblique = DocumentTypeValueSetCode("39378-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ribs_BilateralAndChestX_ray2ViewsAndPAChest = DocumentTypeValueSetCode("48468-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_ray2ViewsAndRightObliqueAndLeftOblique = DocumentTypeValueSetCode("43467-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralX_ray2ViewsAndSunrise = DocumentTypeValueSetCode("69060-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_ray2ViewsAndSunrise = DocumentTypeValueSetCode("69142-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_ray2ViewsAndSunrise = DocumentTypeValueSetCode("39379-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_ray2ViewsAndSunriseAndTunnel = DocumentTypeValueSetCode("39380-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralX_ray2ViewsAndTunnel = DocumentTypeValueSetCode("69061-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_ray2ViewsAndTunnel = DocumentTypeValueSetCode("41819-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_ray2ViewsAndTunnel = DocumentTypeValueSetCode("39381-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_ray2ViewsAndTunnelStanding = DocumentTypeValueSetCode("69143-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_ray2ViewsAndTunnelStanding = DocumentTypeValueSetCode("39382-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeckX_ray2ViewsLateral = DocumentTypeValueSetCode("38118-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_LeftX_ray2ViewsOblique = DocumentTypeValueSetCode("38844-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_RightX_ray2ViewsOblique = DocumentTypeValueSetCode("37686-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_ray2ViewsOblique = DocumentTypeValueSetCode("38871-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_ray2ViewsOblique = DocumentTypeValueSetCode("38108-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Tibia_LeftAndFibula_LeftX_ray2ViewsOblique = DocumentTypeValueSetCode("38874-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Tibia_RightAndFibula_RightX_ray2ViewsOblique = DocumentTypeValueSetCode("38114-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SacroiliacJointX_ray2Or3Views = DocumentTypeValueSetCode("44181-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalX_ray2Or3Views = DocumentTypeValueSetCode("43539-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_ray2Or3Views = DocumentTypeValueSetCode("48469-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BoneScan2ViewsPhase = DocumentTypeValueSetCode("39880-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ElbowX_ray2ViewsPortable = DocumentTypeValueSetCode("44184-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HandX_ray2ViewsPortable = DocumentTypeValueSetCode("44182-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RadiusAndUlnaX_ray2ViewsPortable = DocumentTypeValueSetCode("44183-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_ray2ViewsPortable = DocumentTypeValueSetCode("36674-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicAndLumbarX_ray2ViewsScoliosis = DocumentTypeValueSetCode("37658-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_LeftX_ray2ViewsTunnel_carpal = DocumentTypeValueSetCode("38843-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_RightX_ray2ViewsTunnel_carpal = DocumentTypeValueSetCode("37678-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScan2ViewsAtRestAndWTl_201IV = DocumentTypeValueSetCode("42166-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_LeftX_ray2ViewsStanding = DocumentTypeValueSetCode("38841-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_RightX_ray2ViewsStanding = DocumentTypeValueSetCode("37675-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_BilateralX_ray2ViewsStanding = DocumentTypeValueSetCode("37068-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_LeftX_ray2ViewsStanding = DocumentTypeValueSetCode("37069-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_RightX_ray2ViewsStanding = DocumentTypeValueSetCode("37698-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralX_ray2ViewsStanding = DocumentTypeValueSetCode("36945-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_ray2ViewsStanding = DocumentTypeValueSetCode("38851-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_ray2ViewsStanding = DocumentTypeValueSetCode("37762-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_ray2ViewsStanding = DocumentTypeValueSetCode("36946-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicX_ray2ViewsStanding = DocumentTypeValueSetCode("69274-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_LeftX_ray2ViewsWManualStress = DocumentTypeValueSetCode("38840-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_RightX_ray2ViewsWManualStress = DocumentTypeValueSetCode("37672-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_ray2ViewsWNippleMarkers = DocumentTypeValueSetCode("37067-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenX_ray3Views = DocumentTypeValueSetCode("36293-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AcetabulumX_ray3Views = DocumentTypeValueSetCode("37635-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AnkleX_ray3Views = DocumentTypeValueSetCode("36294-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_BilateralX_ray3Views = DocumentTypeValueSetCode("36295-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_LeftX_ray3Views = DocumentTypeValueSetCode("36296-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_RightX_ray3Views = DocumentTypeValueSetCode("37665-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_ray3Views = DocumentTypeValueSetCode("36298-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ElbowX_ray3Views = DocumentTypeValueSetCode("36299-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_BilateralX_ray3Views = DocumentTypeValueSetCode("36300-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_LeftX_ray3Views = DocumentTypeValueSetCode("36301-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_RightX_ray3Views = DocumentTypeValueSetCode("37682-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FacialBonesX_ray3Views = DocumentTypeValueSetCode("36297-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FemurX_ray3Views = DocumentTypeValueSetCode("36302-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FingerX_ray3Views = DocumentTypeValueSetCode("36303-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Finger_LeftX_ray3Views = DocumentTypeValueSetCode("36304-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Finger_RightX_ray3Views = DocumentTypeValueSetCode("37695-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FootX_ray3Views = DocumentTypeValueSetCode("36305-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_BilateralX_ray3Views = DocumentTypeValueSetCode("36306-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_LeftX_ray3Views = DocumentTypeValueSetCode("36307-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_RightX_ray3Views = DocumentTypeValueSetCode("37699-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HandX_ray3Views = DocumentTypeValueSetCode("24722-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_BilateralX_ray3Views = DocumentTypeValueSetCode("26379-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_LeftX_ray3Views = DocumentTypeValueSetCode("26380-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_RightX_ray3Views = DocumentTypeValueSetCode("26381-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_BilateralX_ray3Views = DocumentTypeValueSetCode("36308-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_LeftX_ray3Views = DocumentTypeValueSetCode("36309-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_RightX_ray3Views = DocumentTypeValueSetCode("37722-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeX_ray3Views = DocumentTypeValueSetCode("30788-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralX_ray3Views = DocumentTypeValueSetCode("36310-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_ray3Views = DocumentTypeValueSetCode("36311-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_ray3Views = DocumentTypeValueSetCode("37742-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MandibleX_ray3Views = DocumentTypeValueSetCode("36312-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MastoidX_ray3Views = DocumentTypeValueSetCode("36838-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Mastoid_LeftX_ray3Views = DocumentTypeValueSetCode("48470-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Mastoid_RightX_ray3Views = DocumentTypeValueSetCode("48471-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NasalBonesX_ray3Views = DocumentTypeValueSetCode("37604-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Patella_RightX_ray3Views = DocumentTypeValueSetCode("69261-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisX_ray3Views = DocumentTypeValueSetCode("30766-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisAndSpineLumbarX_ray3Views = DocumentTypeValueSetCode("37256-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RibsX_ray3Views = DocumentTypeValueSetCode("39062-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ribs_BilateralX_ray3Views = DocumentTypeValueSetCode("36313-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ribs_LeftX_ray3Views = DocumentTypeValueSetCode("36314-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ribs_RightX_ray3Views = DocumentTypeValueSetCode("37781-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SacroiliacJointX_ray3Views = DocumentTypeValueSetCode("37648-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SacrumAndCoccyxX_ray3Views = DocumentTypeValueSetCode("39061-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ShoulderX_ray3Views = DocumentTypeValueSetCode("24908-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_BilateralX_ray3Views = DocumentTypeValueSetCode("26382-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_ray3Views = DocumentTypeValueSetCode("26383-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightX_ray3Views = DocumentTypeValueSetCode("26384-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SinusesX_ray3Views = DocumentTypeValueSetCode("37854-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SkullX_ray3Views = DocumentTypeValueSetCode("24918-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalX_ray3Views = DocumentTypeValueSetCode("24941-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_ray3Views = DocumentTypeValueSetCode("30775-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarAndSacroiliacJointX_ray3Views = DocumentTypeValueSetCode("37257-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarAndSacrumX_ray3Views = DocumentTypeValueSetCode("37259-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarAndSacrumAndCoccyxX_ray3Views = DocumentTypeValueSetCode("37260-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarAndSacrumAndSacroiliacJointAndCoccyxX_ray3Views = (
        DocumentTypeValueSetCode("37261-5")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicX_ray3Views = DocumentTypeValueSetCode("37906-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SternoclavicularJointX_ray3Views = DocumentTypeValueSetCode("37881-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThumbX_ray3Views = DocumentTypeValueSetCode("37888-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Thumb_LeftX_ray3Views = DocumentTypeValueSetCode("36315-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Thumb_RightX_ray3Views = DocumentTypeValueSetCode("37812-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Toes_LeftX_ray3Views = DocumentTypeValueSetCode("36316-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Toes_RightX_ray3Views = DocumentTypeValueSetCode("37820-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    WristX_ray3Views = DocumentTypeValueSetCode("37926-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_BilateralX_ray3Views = DocumentTypeValueSetCode("37454-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_BilateralAndHand_BilateralX_ray3Views = DocumentTypeValueSetCode("48738-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_LeftX_ray3Views = DocumentTypeValueSetCode("37455-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_RightX_ray3Views = DocumentTypeValueSetCode("37827-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    WristAndHandX_ray3Views = DocumentTypeValueSetCode("48737-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ZygomaticArchX_ray3Views = DocumentTypeValueSetCode("37933-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_ray3ViewsAndAxillary = DocumentTypeValueSetCode("69154-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightX_ray3ViewsAndAxillary = DocumentTypeValueSetCode("39393-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_RightX_ray3ViewsAndCarpalTunnel = DocumentTypeValueSetCode("39399-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_RightX_ray3ViewsAndRadialDeviation = DocumentTypeValueSetCode("39364-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SinusesX_ray3ViewsAndSubmentovertex = DocumentTypeValueSetCode("39404-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_ray3ViewsAndSunrise = DocumentTypeValueSetCode("39383-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicX_ray3ViewsAndSwimmers = DocumentTypeValueSetCode("48472-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_RightX_ray3ViewsAndUlnarDeviation = DocumentTypeValueSetCode("39365-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_ray3ViewsAndY = DocumentTypeValueSetCode("69155-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightX_ray3ViewsAndY = DocumentTypeValueSetCode("39394-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_LeftX_ray3Or4Views = DocumentTypeValueSetCode("43499-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_RightX_ray3Or4Views = DocumentTypeValueSetCode("43483-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BoneScan3ViewsPhaseMultipleAreas = DocumentTypeValueSetCode("39901-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BoneScan3ViewsPhaseSingleArea = DocumentTypeValueSetCode("39902-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BoneScan3ViewsPhaseWholeBody = DocumentTypeValueSetCode("39882-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BoneScan3ViewsPhase = DocumentTypeValueSetCode("39883-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_ray3ViewsPortable = DocumentTypeValueSetCode("30776-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_LeftX_ray3ViewsScaphoid = DocumentTypeValueSetCode("69151-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_BilateralX_ray3ViewsSerialWAndWOContrastIV = DocumentTypeValueSetCode(
        "24778-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_LeftX_ray3ViewsStanding = DocumentTypeValueSetCode("69138-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_RightX_ray3ViewsStanding = DocumentTypeValueSetCode("69254-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_BilateralX_ray3ViewsStanding = DocumentTypeValueSetCode("36947-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_LeftX_ray3ViewsStanding = DocumentTypeValueSetCode("36948-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_RightX_ray3ViewsStanding = DocumentTypeValueSetCode("37700-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_ray3ViewsStanding = DocumentTypeValueSetCode("36949-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicX_ray3ViewsStanding = DocumentTypeValueSetCode("42443-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AnkleX_ray4Views = DocumentTypeValueSetCode("36317-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastMammogram4Views = DocumentTypeValueSetCode("36319-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_ray4Views = DocumentTypeValueSetCode("36320-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestFluoroscopy4Views = DocumentTypeValueSetCode("36321-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_BilateralX_ray4Views = DocumentTypeValueSetCode("36322-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_LeftX_ray4Views = DocumentTypeValueSetCode("36323-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_RightX_ray4Views = DocumentTypeValueSetCode("37683-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FacialBonesX_ray4Views = DocumentTypeValueSetCode("36318-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Femur_LeftX_ray4Views = DocumentTypeValueSetCode("36324-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Femur_RightX_ray4Views = DocumentTypeValueSetCode("37691-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeX_ray4Views = DocumentTypeValueSetCode("30789-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralX_ray4Views = DocumentTypeValueSetCode("36325-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_ray4Views = DocumentTypeValueSetCode("36326-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_ray4Views = DocumentTypeValueSetCode("37743-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MandibleX_ray4Views = DocumentTypeValueSetCode("36327-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Mandible_LeftX_ray4Views = DocumentTypeValueSetCode("43534-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Mandible_RightX_ray4Views = DocumentTypeValueSetCode("43535-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MastoidX_ray4Views = DocumentTypeValueSetCode("36839-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OpticForamenX_ray4Views = DocumentTypeValueSetCode("37609-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Orbit_BilateralX_ray4Views = DocumentTypeValueSetCode("37612-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ribs_BilateralX_ray4Views = DocumentTypeValueSetCode("36328-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ShoulderX_ray4Views = DocumentTypeValueSetCode("69265-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_BilateralX_ray4Views = DocumentTypeValueSetCode("36329-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_ray4Views = DocumentTypeValueSetCode("36330-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightX_ray4Views = DocumentTypeValueSetCode("37794-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SinusesX_ray4Views = DocumentTypeValueSetCode("37855-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SkullX_ray4Views = DocumentTypeValueSetCode("37868-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineX_ray4Views = DocumentTypeValueSetCode("37876-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalX_ray4Views = DocumentTypeValueSetCode("36331-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_ray4Views = DocumentTypeValueSetCode("36332-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarAndSacrumX_ray4Views = DocumentTypeValueSetCode("48473-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicX_ray4Views = DocumentTypeValueSetCode("37907-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SternoclavicularJointX_ray4Views = DocumentTypeValueSetCode("37882-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    WristX_ray4Views = DocumentTypeValueSetCode("38155-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_BilateralX_ray4Views = DocumentTypeValueSetCode("37070-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_LeftX_ray4Views = DocumentTypeValueSetCode("37071-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_RightX_ray4Views = DocumentTypeValueSetCode("37828-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ZygomaticArchX_ray4Views = DocumentTypeValueSetCode("37934-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_ray4ViewsAndAPStanding = DocumentTypeValueSetCode("69144-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_ray4ViewsAndAPStanding = DocumentTypeValueSetCode("39384-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_ray4ViewsAndOblique = DocumentTypeValueSetCode("39385-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicX_ray4ViewsAndOblique = DocumentTypeValueSetCode("39413-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ribs_BilateralAndChestX_ray4ViewsAndPAChest = DocumentTypeValueSetCode("39099-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralX_ray4ViewsAndSunriseAndTunnel = DocumentTypeValueSetCode("69063-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_ray4ViewsAndSunriseAndTunnel = DocumentTypeValueSetCode("39387-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_ray4ViewsAndTunnel = DocumentTypeValueSetCode("69145-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_ray4ViewsAndTunnel = DocumentTypeValueSetCode("39386-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralX_ray4ViewsStanding = DocumentTypeValueSetCode("69062-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_ray4ViewsStanding = DocumentTypeValueSetCode("38852-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_ray4ViewsStanding = DocumentTypeValueSetCode("37763-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FacialBonesX_ray5Views = DocumentTypeValueSetCode("36675-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_ray5Views = DocumentTypeValueSetCode("36676-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_ray5Views = DocumentTypeValueSetCode("37744-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MastoidX_ray5Views = DocumentTypeValueSetCode("36890-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisAndSpineLumbarX_ray5Views = DocumentTypeValueSetCode("37351-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ShoulderX_ray5Views = DocumentTypeValueSetCode("30750-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_ray5Views = DocumentTypeValueSetCode("36677-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightX_ray5Views = DocumentTypeValueSetCode("37795-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SinusesX_ray5Views = DocumentTypeValueSetCode("37856-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SkullX_ray5Views = DocumentTypeValueSetCode("24922-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalX_ray5Views = DocumentTypeValueSetCode("24939-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_ray5Views = DocumentTypeValueSetCode("30797-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarAndSacroiliacJointX_ray5Views = DocumentTypeValueSetCode("37353-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarAndSacrumX_ray5Views = DocumentTypeValueSetCode("37355-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarAndSacrumAndCoccyxX_ray5Views = DocumentTypeValueSetCode("37356-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarAndSacrumAndSacroiliacJointAndCoccyxX_ray5Views = (
        DocumentTypeValueSetCode("37357-1")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporomandibularJoint_BilateralX_ray5Views = DocumentTypeValueSetCode("37350-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_LeftX_ray5Views = DocumentTypeValueSetCode("37072-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_RightX_ray5Views = DocumentTypeValueSetCode("37829-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicX_ray5ViewsAndOblique = DocumentTypeValueSetCode("39407-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalX_ray5ViewsAndSwimmers = DocumentTypeValueSetCode("69081-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_ray5ViewsStanding = DocumentTypeValueSetCode("37073-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalX_ray5ViewsWFlexionAndWExtension = DocumentTypeValueSetCode("69080-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_ray5ViewsWFlexionAndWExtension = DocumentTypeValueSetCode("39063-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_BilateralX_ray6Views = DocumentTypeValueSetCode("42273-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralX_ray6Views = DocumentTypeValueSetCode("36678-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_ray6Views = DocumentTypeValueSetCode("36679-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightX_ray6Views = DocumentTypeValueSetCode("37796-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalX_ray6Views = DocumentTypeValueSetCode("42691-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    WristX_ray6Views = DocumentTypeValueSetCode("38156-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_LeftX_ray6Views = DocumentTypeValueSetCode("37074-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_RightX_ray6Views = DocumentTypeValueSetCode("37830-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalX_ray7Views = DocumentTypeValueSetCode("36680-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_ray7Views = DocumentTypeValueSetCode("36681-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralX_ray8Views = DocumentTypeValueSetCode("36682-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_LeftX_ray8Views = DocumentTypeValueSetCode("36683-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_RightX_ray8Views = DocumentTypeValueSetCode("37831-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_ray90DegreeAbduction = DocumentTypeValueSetCode("42412-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RibsX_rayAnteriorAndLateral = DocumentTypeValueSetCode("39064-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ribs_BilateralX_rayAnteriorAndLateral = DocumentTypeValueSetCode("69070-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ribs_LeftX_rayAnteriorAndLateral = DocumentTypeValueSetCode("38856-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ribs_RightX_rayAnteriorAndLateral = DocumentTypeValueSetCode("37782-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenX_rayAPAndAPLeftLateral_decubitus = DocumentTypeValueSetCode("24796-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenX_rayAPAndAPLeftLateral_decubitusPortable = DocumentTypeValueSetCode(
        "24792-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayAPAndAPRightLateral_decubitus = DocumentTypeValueSetCode("24653-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayAPAndAPRightLateral_decubitusPortable = DocumentTypeValueSetCode(
        "24654-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_BilateralX_rayAPAndAxillary = DocumentTypeValueSetCode("37080-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_BilateralX_rayAPAndAxillaryAndOutlet = DocumentTypeValueSetCode("37081-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_rayAPAndAxillaryAndOutlet = DocumentTypeValueSetCode("37082-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightX_rayAPAndAxillaryAndOutlet = DocumentTypeValueSetCode("38781-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_BilateralX_rayAPAndAxillaryAndOutletAnd30DegreeCaudalAngle = (
        DocumentTypeValueSetCode("39339-7")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_rayAPAndAxillaryAndOutletAndZanca = DocumentTypeValueSetCode(
        "37083-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightX_rayAPAndAxillaryAndOutletAndZanca = DocumentTypeValueSetCode(
        "38782-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_BilateralX_rayAPAndAxillaryAndY = DocumentTypeValueSetCode("37126-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_rayAPAndAxillaryAndY = DocumentTypeValueSetCode("37084-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightX_rayAPAndAxillaryAndY = DocumentTypeValueSetCode("38783-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_RightX_rayAPAndDaneliusMiller = DocumentTypeValueSetCode("39512-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ShoulderX_rayAPAndGrasheyAndAxillary = DocumentTypeValueSetCode("39401-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_rayAPAndGrasheyAndAxillary = DocumentTypeValueSetCode("69153-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightX_rayAPAndGrasheyAndAxillary = DocumentTypeValueSetCode("69262-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisX_rayAPAndInlet = DocumentTypeValueSetCode("37618-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisX_rayAPAndInletAndOutlet = DocumentTypeValueSetCode("37623-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisX_rayAPAndInletAndOutletAndOblique = DocumentTypeValueSetCode("39065-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisX_rayAPAndJudet = DocumentTypeValueSetCode("37619-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenX_rayAPAndLateral = DocumentTypeValueSetCode("24794-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AnkleX_rayAPAndLateral = DocumentTypeValueSetCode("30779-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_BilateralX_rayAPAndLateral = DocumentTypeValueSetCode("36684-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_LeftX_rayAPAndLateral = DocumentTypeValueSetCode("36685-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_RightX_rayAPAndLateral = DocumentTypeValueSetCode("37667-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Calcaneus_BilateralX_rayAPAndLateral = DocumentTypeValueSetCode("36686-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Calcaneus_LeftX_rayAPAndLateral = DocumentTypeValueSetCode("36701-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Calcaneus_RightX_rayAPAndLateral = DocumentTypeValueSetCode("37719-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayAPAndLateral = DocumentTypeValueSetCode("36687-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestFluoroscopyAPAndLateral = DocumentTypeValueSetCode("39066-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CoccyxX_rayAPAndLateral = DocumentTypeValueSetCode("36688-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ElbowX_rayAPAndLateral = DocumentTypeValueSetCode("36689-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_BilateralX_rayAPAndLateral = DocumentTypeValueSetCode("36690-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_LeftX_rayAPAndLateral = DocumentTypeValueSetCode("36691-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_RightX_rayAPAndLateral = DocumentTypeValueSetCode("37684-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FemurX_rayAPAndLateral = DocumentTypeValueSetCode("36693-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Femur_BilateralX_rayAPAndLateral = DocumentTypeValueSetCode("36694-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Femur_LeftX_rayAPAndLateral = DocumentTypeValueSetCode("36695-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Femur_RightX_rayAPAndLateral = DocumentTypeValueSetCode("37692-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FootX_rayAPAndLateral = DocumentTypeValueSetCode("39069-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_BilateralX_rayAPAndLateral = DocumentTypeValueSetCode("36696-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_LeftX_rayAPAndLateral = DocumentTypeValueSetCode("36697-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_RightX_rayAPAndLateral = DocumentTypeValueSetCode("37701-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FootSesamoidBonesX_rayAPAndLateral = DocumentTypeValueSetCode("42409-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HandX_rayAPAndLateral = DocumentTypeValueSetCode("69130-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_BilateralX_rayAPAndLateral = DocumentTypeValueSetCode("48474-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_LeftX_rayAPAndLateral = DocumentTypeValueSetCode("38847-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_RightX_rayAPAndLateral = DocumentTypeValueSetCode("37710-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HipX_rayAPAndLateral = DocumentTypeValueSetCode("36702-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_BilateralX_rayAPAndLateral = DocumentTypeValueSetCode("36703-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_LeftX_rayAPAndLateral = DocumentTypeValueSetCode("36704-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_RightX_rayAPAndLateral = DocumentTypeValueSetCode("37725-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HumerusX_rayAPAndLateral = DocumentTypeValueSetCode("36706-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Humerus_BilateralX_rayAPAndLateral = DocumentTypeValueSetCode("36707-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Humerus_LeftX_rayAPAndLateral = DocumentTypeValueSetCode("36708-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Humerus_RightX_rayAPAndLateral = DocumentTypeValueSetCode("37736-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeX_rayAPAndLateral = DocumentTypeValueSetCode("36709-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralX_rayAPAndLateral = DocumentTypeValueSetCode("36590-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_rayAPAndLateral = DocumentTypeValueSetCode("36710-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_rayAPAndLateral = DocumentTypeValueSetCode("37745-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityX_rayAPAndLateral = DocumentTypeValueSetCode("36692-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremity_RightX_rayAPAndLateral = DocumentTypeValueSetCode("69258-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MandibleX_rayAPAndLateral = DocumentTypeValueSetCode("36711-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeckX_rayAPAndLateral = DocumentTypeValueSetCode("42438-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Patella_BilateralX_rayAPAndLateral = DocumentTypeValueSetCode("36712-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Patella_LeftX_rayAPAndLateral = DocumentTypeValueSetCode("36713-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Patella_RightX_rayAPAndLateral = DocumentTypeValueSetCode("37776-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisX_rayAPAndLateral = DocumentTypeValueSetCode("37620-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisAndHipX_rayAPAndLateral = DocumentTypeValueSetCode("36705-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Radius_BilateralAndUlna_BilateralX_rayAPAndLateral = DocumentTypeValueSetCode(
        "36699-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Radius_LeftAndUlna_leftX_rayAPAndLateral = DocumentTypeValueSetCode("36700-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Radius_RightAndUlna_RightX_rayAPAndLateral = DocumentTypeValueSetCode("37708-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RadiusAndUlnaX_rayAPAndLateral = DocumentTypeValueSetCode("36698-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SacrumX_rayAPAndLateral = DocumentTypeValueSetCode("37652-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Scapula_BilateralX_rayAPAndLateral = DocumentTypeValueSetCode("36714-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Scapula_LeftX_rayAPAndLateral = DocumentTypeValueSetCode("36715-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Scapula_RightX_rayAPAndLateral = DocumentTypeValueSetCode("37788-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ShoulderX_rayAPAndLateral = DocumentTypeValueSetCode("37841-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_BilateralX_rayAPAndLateral = DocumentTypeValueSetCode("36716-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SkullX_rayAPAndLateral = DocumentTypeValueSetCode("24919-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineX_rayAPAndLateral = DocumentTypeValueSetCode("24928-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalX_rayAPAndLateral = DocumentTypeValueSetCode("24942-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalAndSpineThoracicX_rayAPAndLateral = DocumentTypeValueSetCode("37361-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalAndThoracicAndLumbarX_rayAPAndLateral = DocumentTypeValueSetCode(
        "39067-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicothoracicJunctionX_rayAPAndLateral = DocumentTypeValueSetCode("43785-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_rayAPAndLateral = DocumentTypeValueSetCode("24970-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicX_rayAPAndLateral = DocumentTypeValueSetCode("30753-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicAndLumbarX_rayAPAndLateral = DocumentTypeValueSetCode("38123-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracolumbarJunctionX_rayAPAndLateral = DocumentTypeValueSetCode("37974-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThumbX_rayAPAndLateral = DocumentTypeValueSetCode("37889-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Tibia_BilateralAndFibula_BilateralX_rayAPAndLateral = DocumentTypeValueSetCode(
        "36717-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Tibia_LeftAndFibula_LeftX_rayAPAndLateral = DocumentTypeValueSetCode("36718-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Tibia_RightAndFibula_RightX_rayAPAndLateral = DocumentTypeValueSetCode("37816-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TibiaAndFibulaX_rayAPAndLateral = DocumentTypeValueSetCode("37896-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Toes_LeftX_rayAPAndLateral = DocumentTypeValueSetCode("36719-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Toes_RightX_rayAPAndLateral = DocumentTypeValueSetCode("37822-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    WristX_rayAPAndLateral = DocumentTypeValueSetCode("30793-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_LeftX_rayAPAndLateral = DocumentTypeValueSetCode("38860-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_RightX_rayAPAndLateral = DocumentTypeValueSetCode("37832-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ShoulderX_rayAPAndLateralAndAxillary = DocumentTypeValueSetCode("37839-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayAPAndLateralAndLordotic = DocumentTypeValueSetCode("39070-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_LeftX_rayAPAndLateralAndMeasurement = DocumentTypeValueSetCode("42404-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeX_rayAPAndLateralAndMerchants = DocumentTypeValueSetCode("39071-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AnkleX_rayAPAndLateralAndMortise = DocumentTypeValueSetCode("37095-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_BilateralX_rayAPAndLateralAndMortise = DocumentTypeValueSetCode("37096-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_LeftX_rayAPAndLateralAndMortise = DocumentTypeValueSetCode("37097-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_RightX_rayAPAndLateralAndMortise = DocumentTypeValueSetCode("37666-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AnkleX_rayAPAndLateralAndOblique = DocumentTypeValueSetCode("39072-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_BilateralX_rayAPAndLateralAndOblique = DocumentTypeValueSetCode("36720-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_LeftX_rayAPAndLateralAndOblique = DocumentTypeValueSetCode("36721-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_RightX_rayAPAndLateralAndOblique = DocumentTypeValueSetCode("37668-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CalcaneusX_rayAPAndLateralAndOblique = DocumentTypeValueSetCode("36731-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ElbowX_rayAPAndLateralAndOblique = DocumentTypeValueSetCode("36722-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_BilateralX_rayAPAndLateralAndOblique = DocumentTypeValueSetCode("36723-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_LeftX_rayAPAndLateralAndOblique = DocumentTypeValueSetCode("36724-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_RightX_rayAPAndLateralAndOblique = DocumentTypeValueSetCode("37685-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FingerX_rayAPAndLateralAndOblique = DocumentTypeValueSetCode("36725-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Finger_BilateralX_rayAPAndLateralAndOblique = DocumentTypeValueSetCode("36726-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Finger_LeftX_rayAPAndLateralAndOblique = DocumentTypeValueSetCode("36727-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Finger_RightX_rayAPAndLateralAndOblique = DocumentTypeValueSetCode("37696-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FootX_rayAPAndLateralAndOblique = DocumentTypeValueSetCode("36728-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_BilateralX_rayAPAndLateralAndOblique = DocumentTypeValueSetCode("36729-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_LeftX_rayAPAndLateralAndOblique = DocumentTypeValueSetCode("36730-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_RightX_rayAPAndLateralAndOblique = DocumentTypeValueSetCode("37702-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_BilateralX_rayAPAndLateralAndOblique = DocumentTypeValueSetCode("69057-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_LeftX_rayAPAndLateralAndOblique = DocumentTypeValueSetCode("38848-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_RightX_rayAPAndLateralAndOblique = DocumentTypeValueSetCode("37711-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralX_rayAPAndLateralAndOblique = DocumentTypeValueSetCode("36732-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_rayAPAndLateralAndOblique = DocumentTypeValueSetCode("36733-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_rayAPAndLateralAndOblique = DocumentTypeValueSetCode("37748-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisX_rayAPAndLateralAndOblique = DocumentTypeValueSetCode("37624-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalX_rayAPAndLateralAndOblique = DocumentTypeValueSetCode("36734-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_rayAPAndLateralAndOblique = DocumentTypeValueSetCode("36735-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicX_rayAPAndLateralAndOblique = DocumentTypeValueSetCode("37908-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Thumb_LeftX_rayAPAndLateralAndOblique = DocumentTypeValueSetCode("36736-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Thumb_RightX_rayAPAndLateralAndOblique = DocumentTypeValueSetCode("37813-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    WristX_rayAPAndLateralAndOblique = DocumentTypeValueSetCode("37927-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalX_rayAPAndLateralAndObliqueAndOdontoid = DocumentTypeValueSetCode(
        "37099-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalX_rayAPAndLateralAndObliqueAndOdontoidAndSwimmer = (
        DocumentTypeValueSetCode("38083-2")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_rayAPAndLateralAndObliqueAndSpot = DocumentTypeValueSetCode("37101-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_rayAPAndLateralAndObliqueAndSpotStanding = DocumentTypeValueSetCode(
        "42410-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralX_rayAPAndLateralAndObliqueAndSunrise = DocumentTypeValueSetCode(
        "37102-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralX_rayAPAndLateralAndObliqueAndSunriseAndTunnel = (
        DocumentTypeValueSetCode("37118-7")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeX_rayAPAndLateralAndObliqueAndTunnel = DocumentTypeValueSetCode("37115-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_LeftX_rayAPAndLateralAndObliqueStanding = DocumentTypeValueSetCode("69137-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_RightX_rayAPAndLateralAndObliqueStanding = DocumentTypeValueSetCode("39371-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_LeftX_rayAPAndLateralAndObliqueStanding = DocumentTypeValueSetCode("39334-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_RightX_rayAPAndLateralAndObliqueStanding = DocumentTypeValueSetCode("39375-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_BilateralX_rayAPAndLateralAndObliqueWManualStress = DocumentTypeValueSetCode(
        "42417-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_LeftX_rayAPAndLateralAndObliqueWManualStress = DocumentTypeValueSetCode(
        "42418-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_RightX_rayAPAndLateralAndObliqueWManualStress = DocumentTypeValueSetCode(
        "39369-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalX_rayAPAndLateralAndOdontoid = DocumentTypeValueSetCode("37103-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalX_rayAPAndLateralAndOdontoidPortable = DocumentTypeValueSetCode(
        "37079-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayAPAndLateralAndRightObliqueAndLeftOblique = DocumentTypeValueSetCode(
        "39074-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeX_rayAPAndLateralAndRightObliqueAndLeftOblique = DocumentTypeValueSetCode(
        "39073-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_rayAPAndLateralAndRightObliqueAndLeftOblique = DocumentTypeValueSetCode(
        "69147-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_rayAPAndLateralAndRightObliqueAndLeftOblique = DocumentTypeValueSetCode(
        "39388-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_rayAPAndLateralAndSpot = DocumentTypeValueSetCode("37105-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeX_rayAPAndLateralAndSunrise = DocumentTypeValueSetCode("37106-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralX_rayAPAndLateralAndSunrise = DocumentTypeValueSetCode("37107-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_rayAPAndLateralAndSunrise = DocumentTypeValueSetCode("37108-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_rayAPAndLateralAndSunrise = DocumentTypeValueSetCode("37749-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Patella_BilateralX_rayAPAndLateralAndSunrise = DocumentTypeValueSetCode("37109-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Patella_LeftX_rayAPAndLateralAndSunrise = DocumentTypeValueSetCode("37110-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Patella_RightX_rayAPAndLateralAndSunrise = DocumentTypeValueSetCode("38786-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeX_rayAPAndLateralAndSunriseAndTunnel = DocumentTypeValueSetCode("37111-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralX_rayAPAndLateralAndSunriseAndTunnel = DocumentTypeValueSetCode(
        "37116-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_rayAPAndLateralAndSunriseAndTunnel = DocumentTypeValueSetCode("37117-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_rayAPAndLateralAndSunriseAndTunnel = DocumentTypeValueSetCode("37740-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicX_rayAPAndLateralAndSwimmers = DocumentTypeValueSetCode("38009-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeX_rayAPAndLateralAndTunnel = DocumentTypeValueSetCode("37112-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralX_rayAPAndLateralAndTunnel = DocumentTypeValueSetCode("37113-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_rayAPAndLateralAndTunnel = DocumentTypeValueSetCode("37114-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_rayAPAndLateralAndTunnel = DocumentTypeValueSetCode("37747-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenX_rayAPAndLateralCrosstable = DocumentTypeValueSetCode("69065-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HipX_rayAPAndLateralCrosstable = DocumentTypeValueSetCode("37086-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_LeftX_rayAPAndLateralCrosstable = DocumentTypeValueSetCode("37087-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_RightX_rayAPAndLateralCrosstable = DocumentTypeValueSetCode("37723-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeX_rayAPAndLateralCrosstable = DocumentTypeValueSetCode("37090-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_rayAPAndLateralCrosstable = DocumentTypeValueSetCode("69146-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisAndHipX_rayAPAndLateralCrosstable = DocumentTypeValueSetCode("37089-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisAndHip_LeftX_rayAPAndLateralCrosstable = DocumentTypeValueSetCode("37088-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisAndHip_RightX_rayAPAndLateralCrosstable = DocumentTypeValueSetCode("38784-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenX_rayAPAndLateralCrosstablePortable = DocumentTypeValueSetCode("30763-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HipX_rayAPAndLateralCrosstablePortable = DocumentTypeValueSetCode("37077-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HipX_rayAPAndLateralFrog = DocumentTypeValueSetCode("37091-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_BilateralX_rayAPAndLateralFrog = DocumentTypeValueSetCode("37092-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_LeftX_rayAPAndLateralFrog = DocumentTypeValueSetCode("37093-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_RightX_rayAPAndLateralFrog = DocumentTypeValueSetCode("37724-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisAndHipX_rayAPAndLateralFrog = DocumentTypeValueSetCode("30770-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisAndHip_BilateralX_rayAPAndLateralFrog = DocumentTypeValueSetCode("42167-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisAndHip_LeftX_rayAPAndLateralFrog = DocumentTypeValueSetCode("37094-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisAndHip_RightX_rayAPAndLateralFrog = DocumentTypeValueSetCode("38785-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisAndHip_RightX_rayAPAndLateralFrogPortable = DocumentTypeValueSetCode(
        "41776-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenX_rayAPAndLateralPortable = DocumentTypeValueSetCode("24793-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FemurX_rayAPAndLateralPortable = DocumentTypeValueSetCode("44185-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FootX_rayAPAndLateralPortable = DocumentTypeValueSetCode("44186-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_LeftX_rayAPAndLateralPortable = DocumentTypeValueSetCode("41817-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_RightX_rayAPAndLateralPortable = DocumentTypeValueSetCode("41777-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalX_rayAPAndLateralPortable = DocumentTypeValueSetCode("30726-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_rayAPAndLateralPortable = DocumentTypeValueSetCode("37078-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicX_rayAPAndLateralPortable = DocumentTypeValueSetCode("30754-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_BilateralX_rayAPAndLateralStanding = DocumentTypeValueSetCode("39330-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_LeftX_rayAPAndLateralStanding = DocumentTypeValueSetCode("42380-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_RightX_rayAPAndLateralStanding = DocumentTypeValueSetCode("39368-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FootX_rayAPAndLateralStanding = DocumentTypeValueSetCode("39068-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_BilateralX_rayAPAndLateralStanding = DocumentTypeValueSetCode("39331-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_LeftX_rayAPAndLateralStanding = DocumentTypeValueSetCode("39332-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_RightX_rayAPAndLateralStanding = DocumentTypeValueSetCode("39374-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeX_rayAPAndLateralStanding = DocumentTypeValueSetCode("24805-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralX_rayAPAndLateralStanding = DocumentTypeValueSetCode("26364-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_rayAPAndLateralStanding = DocumentTypeValueSetCode("26365-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_rayAPAndLateralStanding = DocumentTypeValueSetCode("26366-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_rayAPAndLateralStanding = DocumentTypeValueSetCode("39333-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenX_rayAPAndLeftPosteriorOblique = DocumentTypeValueSetCode("38084-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenX_rayAPAndOblique = DocumentTypeValueSetCode("37119-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FootX_rayAPAndOblique = DocumentTypeValueSetCode("39076-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisX_rayAPAndOblique = DocumentTypeValueSetCode("37621-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SacroiliacJointX_rayAPAndOblique = DocumentTypeValueSetCode("37649-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ToesX_rayAPAndOblique = DocumentTypeValueSetCode("39075-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalX_rayAPAndObliqueAndLateralWFlexionAndWExtension = (
        DocumentTypeValueSetCode("37098-1")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalX_rayAPAndObliqueAndOdontoidAndLateralPortableWFlexionAndWExtension = (
        DocumentTypeValueSetCode("44187-3")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalX_rayAPAndObliqueAndOdontoidAndLateralWFlexionAndWExtension = (
        DocumentTypeValueSetCode("37100-5")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenX_rayAPAndObliqueProne = DocumentTypeValueSetCode("24797-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalX_rayAPAndOdontoidAndLateralCrosstable = DocumentTypeValueSetCode(
        "37120-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalX_rayAPAndOdontoidAndLateralWFlexionAndWExtension = (
        DocumentTypeValueSetCode("37104-7")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestAndAbdomenX_rayAPAndPAChest = DocumentTypeValueSetCode("42011-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayAPAndPAUpright = DocumentTypeValueSetCode("24642-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeX_rayAPAndPAStanding = DocumentTypeValueSetCode("24808-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralX_rayAPAndPAStanding = DocumentTypeValueSetCode("26361-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_rayAPAndPAStanding = DocumentTypeValueSetCode("26362-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_rayAPAndPAStanding = DocumentTypeValueSetCode("26363-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Clavicle_LeftX_rayAPAndSerendipity = DocumentTypeValueSetCode("37121-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Clavicle_RightX_rayAPAndSerendipity = DocumentTypeValueSetCode("37680-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_rayAPAndStrykerNotch = DocumentTypeValueSetCode("37122-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightX_rayAPAndStrykerNotch = DocumentTypeValueSetCode("37797-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HumerusX_rayAPAndTransthoracic = DocumentTypeValueSetCode("37485-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ShoulderX_rayAPAndTransthoracic = DocumentTypeValueSetCode("39077-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_BilateralX_rayAPAndTransthoracic = DocumentTypeValueSetCode("46349-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_rayAPAndTransthoracic = DocumentTypeValueSetCode("38082-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightX_rayAPAndTransthoracic = DocumentTypeValueSetCode("38822-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_rayAPAndWestPoint = DocumentTypeValueSetCode("37123-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightX_rayAPAndWestPoint = DocumentTypeValueSetCode("38787-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_rayAPAndWestPointAndOutlet = DocumentTypeValueSetCode("36961-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightX_rayAPAndWestPointAndOutlet = DocumentTypeValueSetCode("37799-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Scapula_LeftX_rayAPAndY = DocumentTypeValueSetCode("37124-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Scapula_RightX_rayAPAndY = DocumentTypeValueSetCode("37789-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ShoulderX_rayAPAndY = DocumentTypeValueSetCode("69266-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_rayAPAndY = DocumentTypeValueSetCode("37125-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightX_rayAPAndY = DocumentTypeValueSetCode("38788-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenX_rayAP_leftLateral_decubitusAndRightLateral_decubitus_ = (
        DocumentTypeValueSetCode("24562-1")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayAP_rightLateral_decubitusAndLeftLateral_decubitus_ = (
        DocumentTypeValueSetCode("24650-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayAP_rightLateral_decubitusAndLeftLateral_decubitus_Portable = (
        DocumentTypeValueSetCode("24649-6")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenX_rayAP_supineAndLateral_decubitus_ = DocumentTypeValueSetCode("37085-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenX_rayAP_supineAndLateral_decubitus_Portable = DocumentTypeValueSetCode(
        "37076-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenX_rayAP_supineAndUpright_ = DocumentTypeValueSetCode("24798-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestAndAbdomenX_rayAP_supineAndUpright_AndPAChest = DocumentTypeValueSetCode(
        "43463-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenX_rayAP_supineAndUpright_Portable = DocumentTypeValueSetCode("24795-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenX_rayAP_uprightAndLeftLateralDecubitus_ = DocumentTypeValueSetCode("42019-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_BilateralX_rayAP_WInternalRotationAndWExternalRotation_ = (
        DocumentTypeValueSetCode("39329-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_rayAP_WInternalRotationAndWExternalRotation_ = (
        DocumentTypeValueSetCode("39328-0")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightX_rayAP_WInternalRotationAndWExternalRotation_ = (
        DocumentTypeValueSetCode("39395-9")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ShoulderX_rayAP_WInternalRotationAndWExternalRotation_AndAxillary = (
        DocumentTypeValueSetCode("39321-5")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_BilateralX_rayAP_WInternalRotationAndWExternalRotation_AndAxillary = (
        DocumentTypeValueSetCode("39336-3")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_rayAP_WInternalRotationAndWExternalRotation_AndAxillary = (
        DocumentTypeValueSetCode("39335-5")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_BilateralX_rayAP_WInternalRotationAndWExternalRotation_AndAxillaryAndOutlet = DocumentTypeValueSetCode(
        "39337-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_BilateralX_rayAP_WInternalRotationAndWExternalRotation_AndAxillaryAndY = (
        DocumentTypeValueSetCode("39344-7")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_rayAP_WInternalRotationAndWExternalRotation_AndAxillaryAndY = (
        DocumentTypeValueSetCode("39338-9")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightX_rayAP_WInternalRotationAndWExternalRotation_AndWestPoint = (
        DocumentTypeValueSetCode("39397-5")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_BilateralX_rayAP_WInternalRotationAndWExternalRotation_AndY = (
        DocumentTypeValueSetCode("39343-9")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_rayAP_WInternalRotationAndWExternalRotation_AndY = (
        DocumentTypeValueSetCode("39348-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_rayAP_WInternalRotation_AndGrasheyAndAxillaryAndOutlet = (
        DocumentTypeValueSetCode("39325-6")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_BilateralX_rayAP_WInternalRotation_AndWestPoint = DocumentTypeValueSetCode(
        "39346-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_rayAP_WInternalRotation_AndWestPoint = DocumentTypeValueSetCode(
        "39347-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightX_rayAP_WInternalRotation_AndWestPoint = DocumentTypeValueSetCode(
        "39396-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayAPPortable = DocumentTypeValueSetCode("24632-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HipX_rayAPPortable = DocumentTypeValueSetCode("37075-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestAndAbdomenX_rayAPUprightAndAPChest = DocumentTypeValueSetCode("43561-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_LeftX_rayAPStanding = DocumentTypeValueSetCode("38003-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_RightX_rayAPStanding = DocumentTypeValueSetCode("38815-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_rayAPWAndWOLeftBending = DocumentTypeValueSetCode("42406-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_rayAPWAndWORightBending = DocumentTypeValueSetCode("42407-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicX_rayAPWLeftBendingAndWOBending = DocumentTypeValueSetCode("42445-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_rayAPWManualStress = DocumentTypeValueSetCode("37484-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_rayAPWManualStress = DocumentTypeValueSetCode("37746-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_rayAPWRightBendingAndWLeftBending = DocumentTypeValueSetCode("42403-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_rayAPWRightBendingAndWLeftBendingAndWOBending = (
        DocumentTypeValueSetCode("42408-5")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicX_rayAPWRightBendingAndWLeftBendingAndWOBending = (
        DocumentTypeValueSetCode("42444-0")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicX_rayAPWRightBendingAndWOBending = DocumentTypeValueSetCode("42446-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ShoulderX_rayAxillaryAndTranscapular = DocumentTypeValueSetCode("39403-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_BilateralX_rayAxillaryAndY = DocumentTypeValueSetCode("37127-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_rayAxillaryAndY = DocumentTypeValueSetCode("37128-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightX_rayAxillaryAndY = DocumentTypeValueSetCode("37807-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TeethX_rayBitewing = DocumentTypeValueSetCode("46386-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BoneScanBloodPool = DocumentTypeValueSetCode("39884-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanBloodPool = DocumentTypeValueSetCode("39861-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LiverScanBloodPool = DocumentTypeValueSetCode("42709-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanBloodPoolWStressAndWRadionuclideIV = DocumentTypeValueSetCode("39860-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_BilateralAndHand_BilateralX_rayBoneAge = DocumentTypeValueSetCode("26352-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_LeftAndHand_LeftX_rayBoneAge = DocumentTypeValueSetCode("26353-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_RightAndHand_RightX_rayBoneAge = DocumentTypeValueSetCode("26354-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    WristAndHandX_rayBoneAge = DocumentTypeValueSetCode("24724-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BonesX_rayBoneAge = DocumentTypeValueSetCode("37362-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainScanBrainDeathProtocolWTc_99mHMPAOIV = DocumentTypeValueSetCode("24591-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CalcaneusX_rayBroden = DocumentTypeValueSetCode("37996-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Calcaneus_BilateralX_rayBroden = DocumentTypeValueSetCode("37995-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Calcaneus_LeftX_rayBroden = DocumentTypeValueSetCode("37997-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Calcaneus_RightX_rayBroden = DocumentTypeValueSetCode("38814-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AnkleX_rayBrodenWManualStress = DocumentTypeValueSetCode("37486-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SinusesX_rayCaldwellAndWaters = DocumentTypeValueSetCode("37852-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainScanDelayedStatic = DocumentTypeValueSetCode("39859-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScanDelayedWGA_67IV = DocumentTypeValueSetCode("39875-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScanDelayedWI_131MIBGIV = DocumentTypeValueSetCode("39840-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScanDelayedWIn_111SatumomabIV = DocumentTypeValueSetCode("39842-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadCisternScanDelayedWRadionuclideIT = DocumentTypeValueSetCode("39874-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BoneScanDelayed = DocumentTypeValueSetCode("39819-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ParathyroidScanDelayed = DocumentTypeValueSetCode("39741-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastMammogramDiagnostic = DocumentTypeValueSetCode("24605-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastFFDMammogramDiagnostic = DocumentTypeValueSetCode("39152-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastImplantX_rayDiagnostic = DocumentTypeValueSetCode("69158-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastImplant_BilateralMammogramDiagnostic = DocumentTypeValueSetCode("48475-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastImplant_LeftMammogramDiagnostic = DocumentTypeValueSetCode("69150-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastImplant_RightMammogramDiagnostic = DocumentTypeValueSetCode("69259-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_BilateralMammogramDiagnostic = DocumentTypeValueSetCode("26346-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_BilateralFFDMammogramDiagnostic = DocumentTypeValueSetCode("39154-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_LeftMammogramDiagnostic = DocumentTypeValueSetCode("26347-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_LeftFFDMammogramDiagnostic = DocumentTypeValueSetCode("42169-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_RightMammogramDiagnostic = DocumentTypeValueSetCode("26348-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_RightFFDMammogramDiagnostic = DocumentTypeValueSetCode("42168-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_UnilateralMammogramDiagnostic = DocumentTypeValueSetCode("46350-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastMammogramDiagnosticLimited = DocumentTypeValueSetCode("24604-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_BilateralMammogramDiagnosticLimited = DocumentTypeValueSetCode("26349-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_LeftMammogramDiagnosticLimited = DocumentTypeValueSetCode("26350-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_RightMammogramDiagnosticLimited = DocumentTypeValueSetCode("26351-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastImplant_BilateralMammogramDisplacement = DocumentTypeValueSetCode("46351-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GallbladderScanEjectionFractionWTc_99mDISIDAIV = DocumentTypeValueSetCode("39895-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanFirstPassAndEjectionFractionAtRestAndWRadionuclideIV = (
        DocumentTypeValueSetCode("39887-5")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanFirstPassAndEjectionFraction = DocumentTypeValueSetCode("39889-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanFirstPassAndVentricularVolume = DocumentTypeValueSetCode("39885-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanFirstPassAndWallMotionAndEjectionFraction = DocumentTypeValueSetCode(
        "39910-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanFirstPassAndWallMotionAndVentricularVolumeAndEjectionFraction = (
        DocumentTypeValueSetCode("39912-1")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanFirstPassAndWallMotionAndVentricularVolumeAndEjectionFractionWStressAndWRadionuclideIV = DocumentTypeValueSetCode(
        "39909-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanFirstPassAndWallMotionAndVentricularVolumeWStressAndWRadionuclideIV = (
        DocumentTypeValueSetCode("39908-9")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanFirstPassAndWallMotionAtRestAndWRadionuclideIV = DocumentTypeValueSetCode(
        "39886-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanFirstPassAndWallMotion = DocumentTypeValueSetCode("39890-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanFirstPassAndWallMotionWStressAndWRadionuclideIV = DocumentTypeValueSetCode(
        "39888-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanFirstPassAtRestAndWRadionuclideIV = DocumentTypeValueSetCode("39867-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanFirstPassAtRestAndWStressAndWRadionuclideIV = DocumentTypeValueSetCode(
        "39863-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanFirstPassAtRestAndWTc_99mSestamibiIV = DocumentTypeValueSetCode("39866-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanFirstPass = DocumentTypeValueSetCode("39864-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LeftVentricleScanFirstPass = DocumentTypeValueSetCode("39865-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanFirstPassWStressAndWRadionuclideIV = DocumentTypeValueSetCode("39869-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanFirstPassWStressAndWTc_99mSestamibiIV = DocumentTypeValueSetCode("39868-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanFlowForShuntDetection = DocumentTypeValueSetCode("39893-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainScanFlowLimited = DocumentTypeValueSetCode("43644-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BoneScanFlow = DocumentTypeValueSetCode("39858-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainScanFlow = DocumentTypeValueSetCode("39636-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanFlow = DocumentTypeValueSetCode("39871-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_BilateralScanFlow = DocumentTypeValueSetCode("42261-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LiverScanFlow = DocumentTypeValueSetCode("42262-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LiverAndSpleenScanFlow = DocumentTypeValueSetCode("43653-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ParotidGlandScanFlow = DocumentTypeValueSetCode("39847-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SalivaryGlandScanFlow = DocumentTypeValueSetCode("39899-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScrotumAndTesticleScanFlow = DocumentTypeValueSetCode("42308-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpleenScanFlow = DocumentTypeValueSetCode("42263-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThyroidScanFlow = DocumentTypeValueSetCode("39856-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VesselScanFlow = DocumentTypeValueSetCode("43500-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainScanFlowWTc_99mBicisateIV = DocumentTypeValueSetCode("44148-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainScanFlowWTc_99mDTPAIV = DocumentTypeValueSetCode("43642-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RenalVesselsScanFlowWTc_99mDTPAIV = DocumentTypeValueSetCode("43664-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainScanFlowWTc_99mGlucoheptonateIV = DocumentTypeValueSetCode("43643-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_BilateralAndRenalVesselsScanFlowWTc_99mGlucoheptonateIV = (
        DocumentTypeValueSetCode("43666-7")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RenalVesselsScanFlowWTc_99mGlucoheptonateIV = DocumentTypeValueSetCode("43663-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RenalVesselsScanFlowWTc_99mMertiatideIV = DocumentTypeValueSetCode("43665-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanFlowWTc_99mPertechnetateIV = DocumentTypeValueSetCode("39870-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LiverScanFlowWTc_99mTaggedRBCIV = DocumentTypeValueSetCode("43654-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScanForAbscessWGA_67IV = DocumentTypeValueSetCode("39685-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LungScanClearanceWTc_99mDTPAAerosolInhaled = DocumentTypeValueSetCode("39940-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SkullAndFacialBonesAndMandibleX_rayForDentalMeasurement = DocumentTypeValueSetCode(
        "43787-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScanForEndocrineTumorMultipleAreasWI_131MIBGIV = DocumentTypeValueSetCode("43648-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScanForEndocrineTumorMultipleAreasWIn_111PentetreotideIV = DocumentTypeValueSetCode(
        "43649-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScanForEndocrineTumorWholeBodyWI_131MIBGIV = DocumentTypeValueSetCode("39827-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScanForEndocrineTumorWholeBodyWIn_111PentetreotideIV = DocumentTypeValueSetCode(
        "39828-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenAndFetusX_rayForFetalAge = DocumentTypeValueSetCode("39327-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OrbitX_rayForForeignBody = DocumentTypeValueSetCode("44208-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Orbit_BilateralX_rayForForeignBody = DocumentTypeValueSetCode("30720-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Orbit_LeftX_rayForForeignBody = DocumentTypeValueSetCode("42311-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Orbit_RightX_rayForForeignBody = DocumentTypeValueSetCode("42312-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    StomachScanForGastricEmptyingWTc_99mSCPO = DocumentTypeValueSetCode("39768-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    StomachScanForGastricEmptyingLiquidPhaseWRadionuclidePO = DocumentTypeValueSetCode(
        "39767-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    StomachScanForGastricEmptyingSolidPhaseWTc_99mSCPO = DocumentTypeValueSetCode(
        "24997-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    StomachScanForGastricEmptyingWRadionuclidePO = DocumentTypeValueSetCode("39769-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanForInfarctAndFirstPass = DocumentTypeValueSetCode("39892-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanForInfarctAndFirstPassWTc_99mPYPIV = DocumentTypeValueSetCode("39891-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanForInfarctQualitativeAndQuantitative = DocumentTypeValueSetCode("43646-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanForInfarctQualitative = DocumentTypeValueSetCode("43645-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanForInfarctQuantitative = DocumentTypeValueSetCode("43647-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanForInfarct = DocumentTypeValueSetCode("39653-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanForInfarctWTc_99mPYPIV = DocumentTypeValueSetCode("39657-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScanForInfectionMultipleAreasWGA_67IV = DocumentTypeValueSetCode("39933-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScanForInfectionWholeBodyWGA_67IV = DocumentTypeValueSetCode("39830-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScanForInfectionWGA_67IV = DocumentTypeValueSetCode("39677-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Femur_RightAndTibia_RightX_rayForLegLength = DocumentTypeValueSetCode("39490-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FemurAndTibiaX_rayForLegLength = DocumentTypeValueSetCode("24700-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScanForLymphomaWGA_67IV = DocumentTypeValueSetCode("39686-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScanForLymphoma = DocumentTypeValueSetCode("42170-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    EsophagusScanForMotilityWRadionuclidePO = DocumentTypeValueSetCode("39672-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenX_rayForMotilityWithRadioopaqueMarkers = DocumentTypeValueSetCode("72256-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BiliaryDuctsAndGallbladderScanForPatencyOfBiliaryStructuresAndEjectionFractionWSincalideAndWRadionuclideIV = DocumentTypeValueSetCode(
        "24571-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BiliaryDuctsAndGallbladderScanForPatencyOfBiliaryStructuresWTc_99mIV = (
        DocumentTypeValueSetCode("24572-0")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TubeFluoroscopyForPatencyWContrastViaTube = DocumentTypeValueSetCode("43788-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LiverAndBiliaryDuctsAndGallbladderScanForPatencyWTc_99mIV = (
        DocumentTypeValueSetCode("43789-7")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    EsophagusScanForRefluxWRadionuclidePO = DocumentTypeValueSetCode("39673-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionFluoroscopyForShunt = DocumentTypeValueSetCode("30650-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanForShuntDetection = DocumentTypeValueSetCode("39665-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanForShuntDetectionWTc_99mMAAIV = DocumentTypeValueSetCode("39664-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PeritoneovenousShuntScanForPatencyWIn_111IT = DocumentTypeValueSetCode("39848-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PeritoneovenousShuntScanForPatencyWRadionuclideIT = DocumentTypeValueSetCode(
        "39849-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PeritoneovenousShuntScanForPatencyWTc_99mDTPAIT = DocumentTypeValueSetCode(
        "24876-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PeritoneovenousShuntScanForPatencyWTc_99mMAAInj = DocumentTypeValueSetCode(
        "44149-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VeinScanForThrombosis = DocumentTypeValueSetCode("39954-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenAndPelvisScanForTumor = DocumentTypeValueSetCode("44140-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScanForTumorLimitedWGA_67IV = DocumentTypeValueSetCode("39831-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScanForTumorMultipleAreaWTc_99mSestamibiIV = DocumentTypeValueSetCode("39951-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScanForTumorMultipleAreasWGA_67IV = DocumentTypeValueSetCode("39934-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScanForTumorWholeBodyWGA_67IV = DocumentTypeValueSetCode("39829-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScanForTumorWholeBody = DocumentTypeValueSetCode("42171-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScanForTumorWholeBodyWTc_99mSestamibiIV = DocumentTypeValueSetCode("39749-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScanForTumorWGA_67IV = DocumentTypeValueSetCode("39679-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScanForTumorWTc_99mSestamibiIV = DocumentTypeValueSetCode("39750-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScanForTumorWTl_201IV = DocumentTypeValueSetCode("42305-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayFrontalStereo = DocumentTypeValueSetCode("42397-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanGatedAndEjectionFractionAtRestAndWRadionuclideIV = (
        DocumentTypeValueSetCode("39923-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanGatedAndEjectionFraction = DocumentTypeValueSetCode("39917-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanGatedAndFirstPass = DocumentTypeValueSetCode("39919-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanGatedAndWallMotionAndEjectionFractionAtRestAndWRadionuclideIV = (
        DocumentTypeValueSetCode("39925-3")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanGatedAndWallMotionAndEjectionFraction = DocumentTypeValueSetCode("39931-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanGatedAndWallMotion = DocumentTypeValueSetCode("42306-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanGatedAndWallMotionWStressAndWRadionuclideIV = DocumentTypeValueSetCode(
        "39929-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanGatedAtRestAndWRadionuclideIV = DocumentTypeValueSetCode("39921-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanGatedAtRestAndWStressAndWRadionuclideIV = DocumentTypeValueSetCode(
        "39924-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanGatedAtRestAndWTc_99mPertechnetateIV = DocumentTypeValueSetCode("39922-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanGatedAtRestAndWTc_99mSestamibiIV = DocumentTypeValueSetCode("39920-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanGated = DocumentTypeValueSetCode("39915-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanGatedWStressAndWRadionuclideIV = DocumentTypeValueSetCode("39928-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanGatedWStressAndWTc_99mPertechnetateIV = DocumentTypeValueSetCode("39927-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanGatedWTc_99mSestamibiIV = DocumentTypeValueSetCode("39914-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayGE2AndPAAndLateralViews = DocumentTypeValueSetCode("46348-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AnkleX_rayGE3Views = DocumentTypeValueSetCode("44210-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_BilateralX_rayGE3Views = DocumentTypeValueSetCode("48480-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_LeftX_rayGE3Views = DocumentTypeValueSetCode("46390-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_RightX_rayGE3Views = DocumentTypeValueSetCode("46347-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_BilateralX_rayGE3Views = DocumentTypeValueSetCode("48481-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_LeftX_rayGE3Views = DocumentTypeValueSetCode("46344-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_RightX_rayGE3Views = DocumentTypeValueSetCode("46345-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FacialBonesX_rayGE3Views = DocumentTypeValueSetCode("48479-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FingerFifth_LeftX_rayGE3Views = DocumentTypeValueSetCode("43492-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FingerFifth_RightX_rayGE3Views = DocumentTypeValueSetCode("43497-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FingerFourth_LeftX_rayGE3Views = DocumentTypeValueSetCode("43491-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FingerFourth_RightX_rayGE3Views = DocumentTypeValueSetCode("43496-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FingerSecond_LeftX_rayGE3Views = DocumentTypeValueSetCode("43489-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FingerSecond_RightX_rayGE3Views = DocumentTypeValueSetCode("43494-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FingerThird_LeftX_rayGE3Views = DocumentTypeValueSetCode("43490-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FingerThird_RightX_rayGE3Views = DocumentTypeValueSetCode("43495-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FootX_rayGE3Views = DocumentTypeValueSetCode("44188-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_BilateralX_rayGE3Views = DocumentTypeValueSetCode("48478-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_LeftX_rayGE3Views = DocumentTypeValueSetCode("48477-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_RightX_rayGE3Views = DocumentTypeValueSetCode("48476-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_LeftX_rayGE3Views = DocumentTypeValueSetCode("47370-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_RightX_rayGE3Views = DocumentTypeValueSetCode("47371-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_rayGE3Views = DocumentTypeValueSetCode("43498-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_rayGE3Views = DocumentTypeValueSetCode("43482-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MastoidX_rayGE3Views = DocumentTypeValueSetCode("47381-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisX_rayGE3Views = DocumentTypeValueSetCode("43543-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SacroiliacJointX_rayGE3Views = DocumentTypeValueSetCode("44189-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SacroiliacJoint_BilateralX_rayGE3Views = DocumentTypeValueSetCode("48746-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SinusesX_rayGE3Views = DocumentTypeValueSetCode("43486-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SkullX_rayGE3Views = DocumentTypeValueSetCode("46377-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SternoclavicularJointsX_rayGE3Views = DocumentTypeValueSetCode("48482-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Thumb_LeftX_rayGE3Views = DocumentTypeValueSetCode("43488-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Thumb_RightX_rayGE3Views = DocumentTypeValueSetCode("43493-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    WristX_rayGE3Views = DocumentTypeValueSetCode("44190-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_BilateralX_rayGE3Views = DocumentTypeValueSetCode("48483-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_LeftX_rayGE3Views = DocumentTypeValueSetCode("46346-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_RightX_rayGE3Views = DocumentTypeValueSetCode("46343-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ribs_BilateralAndChestX_rayGE3AndPAChestViews = DocumentTypeValueSetCode("48485-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ribs_LeftAndChestX_rayGE3AndPAChestViews = DocumentTypeValueSetCode("48486-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ribs_RightAndChestX_rayGE3AndPAChestViews = DocumentTypeValueSetCode("48484-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RibsAndChestX_rayGE3AndPAChestViews = DocumentTypeValueSetCode("44191-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ribs_UnilateralAndChestX_rayGe3AndPAChestPortableViews = DocumentTypeValueSetCode(
        "44239-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HandX_rayGE3PortableViews = DocumentTypeValueSetCode("44193-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisX_rayGE3PortableViews = DocumentTypeValueSetCode("44192-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayGE4Views = DocumentTypeValueSetCode("44211-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestFluoroscopyGE4Views = DocumentTypeValueSetCode("47367-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_rayGE4Views = DocumentTypeValueSetCode("47374-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_rayGE4Views = DocumentTypeValueSetCode("47376-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MandibleX_rayGE4Views = DocumentTypeValueSetCode("47379-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Orbit_BilateralX_rayGE4Views = DocumentTypeValueSetCode("48747-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SkullX_rayGE4Views = DocumentTypeValueSetCode("48487-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalX_rayGE4Views = DocumentTypeValueSetCode("44212-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_rayGE4Views = DocumentTypeValueSetCode("47382-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayGE4AndPaAndLateralViews = DocumentTypeValueSetCode("47368-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineX_rayGE4ViewsWRightBendingAndWLeftBending = DocumentTypeValueSetCode("44194-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeX_rayGE5Views = DocumentTypeValueSetCode("44195-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SkullX_rayGE5Views = DocumentTypeValueSetCode("43524-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralX_rayGE5ViewsStanding = DocumentTypeValueSetCode("44197-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_rayGE5ViewsWRightBendingAndWLeftBending = DocumentTypeValueSetCode(
        "44196-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_BilateralX_rayGE6Views = DocumentTypeValueSetCode("49570-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_rayGrasheyAndAxillary = DocumentTypeValueSetCode("37160-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightX_rayGrasheyAndAxillary = DocumentTypeValueSetCode("38793-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_rayGrasheyAndAxillaryAndOutlet = DocumentTypeValueSetCode("37158-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightX_rayGrasheyAndAxillaryAndOutlet = DocumentTypeValueSetCode("37806-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_BilateralX_rayGrasheyAndAxillaryAndOutletAndZanca = (
        DocumentTypeValueSetCode("37161-7")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ShoulderX_rayGrasheyAndAxillaryAndY = DocumentTypeValueSetCode("69267-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_rayGrasheyAndAxillaryAndY = DocumentTypeValueSetCode("37538-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightX_rayGrasheyAndAxillaryAndY = DocumentTypeValueSetCode("38789-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_rayGrasheyAndOutlet = DocumentTypeValueSetCode("37157-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightX_rayGrasheyAndOutlet = DocumentTypeValueSetCode("38791-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_BilateralX_rayGrasheyAndOutletAndSerendipity = DocumentTypeValueSetCode(
        "39350-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_rayGrasheyAndOutletAndSerendipity = DocumentTypeValueSetCode(
        "37162-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightX_rayGrasheyAndOutletAndSerendipity = DocumentTypeValueSetCode(
        "38794-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_rayGrasheyAndWestPoint = DocumentTypeValueSetCode("37167-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightX_rayGrasheyAndWestPoint = DocumentTypeValueSetCode("38795-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_rayGrasheyAndY = DocumentTypeValueSetCode("69156-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightX_rayGrasheyAndY = DocumentTypeValueSetCode("43790-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_rayGrasheyWAndWOWeight = DocumentTypeValueSetCode("38004-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightX_rayGrasheyWAndWOWeight = DocumentTypeValueSetCode("38816-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastMammogramGrid = DocumentTypeValueSetCode("37539-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralX_rayHolmbladStanding = DocumentTypeValueSetCode("37540-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisX_rayInletAndOutlet = DocumentTypeValueSetCode("30771-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisX_rayInletAndOutletAndOblique = DocumentTypeValueSetCode("37627-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FacialBonesX_rayLateralAndCaldwellAndWaters = DocumentTypeValueSetCode("37164-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SinusesX_rayLateralAndCaldwellAndWaters = DocumentTypeValueSetCode("37864-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FacialBonesX_rayLateralAndCaldwellAndWatersAndSubmentovertex = (
        DocumentTypeValueSetCode("37165-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FacialBonesX_rayLateralAndCaldwellAndWatersAndSubmentovertexAndTowne = (
        DocumentTypeValueSetCode("37166-6")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SkullX_rayLateralAndCaldwellAndWatersAndTowne = DocumentTypeValueSetCode("37871-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_BilateralX_rayLateralAndMortise = DocumentTypeValueSetCode("37134-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_LeftX_rayLateralAndMortise = DocumentTypeValueSetCode("37135-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_RightX_rayLateralAndMortise = DocumentTypeValueSetCode("37670-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_LeftX_rayLateralAndMortiseAndBrodenWManualStress = DocumentTypeValueSetCode(
        "42382-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScapulaX_rayLateralAndOutlet = DocumentTypeValueSetCode("39366-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ribs_BilateralAndChestX_rayLateralAndPAChest = DocumentTypeValueSetCode("43464-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ribs_LeftAndChestX_rayLateralAndPAChest = DocumentTypeValueSetCode("37603-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ribs_RightAndChestX_rayLateralAndPAChest = DocumentTypeValueSetCode("39100-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RibsAndChestX_rayLateralAndPAChest = DocumentTypeValueSetCode("39101-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayLateralAndPAWInspirationAndExpiration = DocumentTypeValueSetCode(
        "39341-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SternumX_rayLateralAndRightAnteriorOblique = DocumentTypeValueSetCode("39406-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SternumX_rayLateralAndRightObliqueAndLeftOblique = DocumentTypeValueSetCode(
        "39405-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SellaTurcicaX_rayLateralAndTowne = DocumentTypeValueSetCode("42436-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SkullX_rayLateralAndTowne = DocumentTypeValueSetCode("37869-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NasalBonesX_rayLateralAndWaters = DocumentTypeValueSetCode("37605-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SinusesX_rayLateralAndWaters = DocumentTypeValueSetCode("37862-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_rayLateralAndY = DocumentTypeValueSetCode("37136-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightX_rayLateralAndY = DocumentTypeValueSetCode("37803-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_rayLateralStandingAndWFlexionAndWExtension = DocumentTypeValueSetCode(
        "39340-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalX_rayLateralWFlexionAndWExtension = DocumentTypeValueSetCode("37133-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_rayLateralWFlexionAndWExtension = DocumentTypeValueSetCode("37132-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicX_rayLateralWFlexionAndWExtension = DocumentTypeValueSetCode("38010-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    WristX_rayLateralWFlexionAndWExtension = DocumentTypeValueSetCode("37929-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_LeftX_rayLateralWFlexionAndWExtension = DocumentTypeValueSetCode("69157-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_RightX_rayLateralWFlexionAndWExtension = DocumentTypeValueSetCode("39515-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_LeftX_rayLateralWManualStress = DocumentTypeValueSetCode("37474-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_RightX_rayLateralWManualStress = DocumentTypeValueSetCode("37669-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    JointX_rayLateralWManualStress = DocumentTypeValueSetCode("43480-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Mastoid_BilateralX_rayLawAndMayerAndStenverAndTowne = DocumentTypeValueSetCode(
        "37541-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MandibleX_rayLE3Views = DocumentTypeValueSetCode("47380-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SkullX_rayLE3Views = DocumentTypeValueSetCode("43470-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_rayLE4Views = DocumentTypeValueSetCode("47377-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastMammogramLimited = DocumentTypeValueSetCode("24610-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_BilateralMammogramLimited = DocumentTypeValueSetCode("26287-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_LeftMammogramLimited = DocumentTypeValueSetCode("26289-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_RightMammogramLimited = DocumentTypeValueSetCode("26291-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_LeftX_rayLimited = DocumentTypeValueSetCode("41826-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_RightX_rayLimited = DocumentTypeValueSetCode("41785-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FacialBonesX_rayLimited = DocumentTypeValueSetCode("36737-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_LeftX_rayLimited = DocumentTypeValueSetCode("41830-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_RightX_rayLimited = DocumentTypeValueSetCode("41789-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MandibleX_rayLimited = DocumentTypeValueSetCode("36738-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MastoidX_rayLimited = DocumentTypeValueSetCode("36893-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Mastoid_BilateralX_rayLimited = DocumentTypeValueSetCode("42007-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SacroiliacJointX_rayLimited = DocumentTypeValueSetCode("37646-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SinusesX_rayLimited = DocumentTypeValueSetCode("44209-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SkullX_rayLimited = DocumentTypeValueSetCode("48466-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalX_rayLimited = DocumentTypeValueSetCode("42710-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_BilateralX_rayLimited = DocumentTypeValueSetCode("36739-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_LeftX_rayLimited = DocumentTypeValueSetCode("38838-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_RightX_rayLimited = DocumentTypeValueSetCode("37642-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ColonFluoroscopyLimitedWAirAndBariumContrastPR = DocumentTypeValueSetCode("41797-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalFluoroscopyLimitedWContrastIT = DocumentTypeValueSetCode("42335-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalAndThoracicAndLumbarFluoroscopyLimitedWContrastIT = (
        DocumentTypeValueSetCode("38125-1")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicFluoroscopyLimitedWContrastIT = DocumentTypeValueSetCode("38120-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KidneyX_rayLimitedWContrastIV = DocumentTypeValueSetCode("37137-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScanLimitedWGA_67IV = DocumentTypeValueSetCode("39687-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThyroidScanLimitedWI_131IV = DocumentTypeValueSetCode("39754-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScanLimitedWI_131MIBGIV = DocumentTypeValueSetCode("49571-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScanLimitedWIn_111SatumomabIV = DocumentTypeValueSetCode("39843-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BoneScanLimitedWIn_111TaggedWBCIV = DocumentTypeValueSetCode("41836-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BoneScanLimited = DocumentTypeValueSetCode("39627-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BoneMarrowScanLimited = DocumentTypeValueSetCode("39822-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastScanLimited = DocumentTypeValueSetCode("39645-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LungScanLimited = DocumentTypeValueSetCode("39695-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    JointScanLimited = DocumentTypeValueSetCode("39936-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastMammogramMagnification = DocumentTypeValueSetCode("37542-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_BilateralMammogramMagnification = DocumentTypeValueSetCode("37543-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_BilateralMammogramMagnificationAndSpot = DocumentTypeValueSetCode("37554-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_LeftMammogramMagnificationAndSpot = DocumentTypeValueSetCode("38854-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_RightMammogramMagnificationAndSpot = DocumentTypeValueSetCode("37769-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisAndHip_BilateralX_rayMaxAbduction = DocumentTypeValueSetCode("30769-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeX_rayMerchants30And45And60Degrees = DocumentTypeValueSetCode("38086-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScanMultipleAreasWGA_67IV = DocumentTypeValueSetCode("39935-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScanMultipleAreasWIn_111SatumomabIV = DocumentTypeValueSetCode("39949-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BoneScanMultipleAreas = DocumentTypeValueSetCode("39904-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BoneMarrowScanMultipleAreas = DocumentTypeValueSetCode("39907-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    JointScanMultipleAreas = DocumentTypeValueSetCode("39937-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ProstateScanMultipleAreasWTc_99mCapromabPendatideIV = DocumentTypeValueSetCode(
        "39950-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ElbowX_rayOblique = DocumentTypeValueSetCode("36608-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_BilateralX_rayOblique = DocumentTypeValueSetCode("36740-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_LeftX_rayOblique = DocumentTypeValueSetCode("36741-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_RightX_rayOblique = DocumentTypeValueSetCode("37687-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Humerus_LeftX_rayOblique = DocumentTypeValueSetCode("36744-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Humerus_RightX_rayOblique = DocumentTypeValueSetCode("37737-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeX_rayOblique = DocumentTypeValueSetCode("36619-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralX_rayOblique = DocumentTypeValueSetCode("36745-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_rayOblique = DocumentTypeValueSetCode("36746-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_rayOblique = DocumentTypeValueSetCode("37757-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MandibleX_rayOblique = DocumentTypeValueSetCode("36747-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisX_rayOblique = DocumentTypeValueSetCode("37630-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Radius_BilateralAndUlna_BilateralX_rayOblique = DocumentTypeValueSetCode("36742-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Radius_LeftAndUlna_leftX_rayOblique = DocumentTypeValueSetCode("36743-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Radius_RightAndUlna_RightX_rayOblique = DocumentTypeValueSetCode("37709-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineX_rayOblique = DocumentTypeValueSetCode("48748-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalX_rayOblique = DocumentTypeValueSetCode("36748-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_rayOblique = DocumentTypeValueSetCode("43791-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicX_rayOblique = DocumentTypeValueSetCode("48749-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Tibia_LeftAndFibula_LeftX_rayOblique = DocumentTypeValueSetCode("36749-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Tibia_RightAndFibula_RightX_rayOblique = DocumentTypeValueSetCode("37817-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TibiaAndFibulaX_rayOblique = DocumentTypeValueSetCode("36894-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_BilateralX_rayOblique = DocumentTypeValueSetCode("37544-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_LeftX_rayOblique = DocumentTypeValueSetCode("38839-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_RightX_rayOblique = DocumentTypeValueSetCode("37643-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FootX_rayObliqueAnd_APAndLateral_Standing = DocumentTypeValueSetCode("42398-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalX_rayObliqueAndLateralWFlexionAndWExtension = DocumentTypeValueSetCode(
        "37139-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeX_rayObliqueAndSunrise = DocumentTypeValueSetCode("37154-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeX_rayObliqueAndSunriseAndTunnel = DocumentTypeValueSetCode("37155-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionX_rayOfForeignBody = DocumentTypeValueSetCode("43469-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionFluoroscopyOfForeignBody = DocumentTypeValueSetCode("37063-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporomandibularJoint_BilateralX_rayOpenAndClosedMouth = DocumentTypeValueSetCode(
        "37546-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporomandibularJoint_LeftX_rayOpenAndClosedMouth = DocumentTypeValueSetCode(
        "48491-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporomandibularJoint_RightX_rayOpenAndClosedMouth = DocumentTypeValueSetCode(
        "48490-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporomandibularJoint_UnilateralX_rayOpenAndClosedMouth = DocumentTypeValueSetCode(
        "48699-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_BilateralX_rayOutletAndY = DocumentTypeValueSetCode("37152-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_rayOutletAndY = DocumentTypeValueSetCode("37140-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightX_rayOutletAndY = DocumentTypeValueSetCode("37804-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayPAAndAPLateral_decubitus = DocumentTypeValueSetCode("36750-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayPAAndLateral = DocumentTypeValueSetCode("42272-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestFluoroscopyPAAndLateral = DocumentTypeValueSetCode("36751-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_BilateralX_rayPAAndLateral = DocumentTypeValueSetCode("36752-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_LeftX_rayPAAndLateral = DocumentTypeValueSetCode("36753-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_RightX_rayPAAndLateral = DocumentTypeValueSetCode("37713-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MandibleX_rayPAAndLateral = DocumentTypeValueSetCode("36754-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SinusesX_rayPAAndLateral = DocumentTypeValueSetCode("30721-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_BilateralX_rayPAAndLateral = DocumentTypeValueSetCode("37547-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_LeftX_rayPAAndLateral = DocumentTypeValueSetCode("37548-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_RightX_rayPAAndLateral = DocumentTypeValueSetCode("37835-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayPAAndLateralAndAPLateral_decubitus = DocumentTypeValueSetCode("37143-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayPAAndLateralAndAPLeftLateral_decubitus = DocumentTypeValueSetCode(
        "37144-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayPAAndLateralAndAPRightLateral_decubitus = DocumentTypeValueSetCode(
        "37145-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_BilateralX_rayPAAndLateralAndBallCatcher = DocumentTypeValueSetCode("37142-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SinusesX_rayPAAndLateralAndCaldwellAndWaters = DocumentTypeValueSetCode("37860-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayPAAndLateralAndLeftOblique = DocumentTypeValueSetCode("37146-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayPAAndLateralAndLordoticUpright = DocumentTypeValueSetCode("30741-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FingerX_rayPAAndLateralAndOblique = DocumentTypeValueSetCode("39078-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HandX_rayPAAndLateralAndOblique = DocumentTypeValueSetCode("36755-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_BilateralX_rayPAAndLateralAndOblique = DocumentTypeValueSetCode("36756-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_LeftX_rayPAAndLateralAndOblique = DocumentTypeValueSetCode("36757-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_RightX_rayPAAndLateralAndOblique = DocumentTypeValueSetCode("37715-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SternumX_rayPAAndLateralAndOblique = DocumentTypeValueSetCode("37884-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_BilateralX_rayPAAndLateralAndOblique = DocumentTypeValueSetCode("37549-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_LeftX_rayPAAndLateralAndOblique = DocumentTypeValueSetCode("37550-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_RightX_rayPAAndLateralAndOblique = DocumentTypeValueSetCode("37836-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayPAAndLateralAndObliqueAndLordotic = DocumentTypeValueSetCode("36758-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MandibleX_rayPAAndLateralAndObliqueAndTowne = DocumentTypeValueSetCode("37148-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayPAAndLateralAndRightOblique = DocumentTypeValueSetCode("37147-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayPAAndLateralAndRightObliqueAndLeftOblique = DocumentTypeValueSetCode(
        "30742-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayPAAndLateralAndRightObliqueAndLeftObliquePortable = (
        DocumentTypeValueSetCode("30743-9")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayPAAndLateralAndRightOr_leftOblique = DocumentTypeValueSetCode("30744-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayPAAndLateralAndRightOr_leftObliqueUpright = DocumentTypeValueSetCode(
        "24643-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Patella_LeftX_rayPAAndLateralAndSunrise = DocumentTypeValueSetCode("37149-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Patella_RightX_rayPAAndLateralAndSunrise = DocumentTypeValueSetCode("38790-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SinusesX_rayPAAndLateralAndWaters = DocumentTypeValueSetCode("37859-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SkullX_rayPAAndLateralAndWatersAndTowne = DocumentTypeValueSetCode("69271-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayPAAndLateralUpright = DocumentTypeValueSetCode("24647-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayPAAndLateralUprightPortable = DocumentTypeValueSetCode("24644-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayPAAndLordotic = DocumentTypeValueSetCode("36759-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HandX_rayPAAndOblique = DocumentTypeValueSetCode("39079-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayPAAndRightLateral = DocumentTypeValueSetCode("37141-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SkullX_rayPAAndRightLateralAndLeftLateral = DocumentTypeValueSetCode("39519-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SkullX_rayPAAndRightLateralAndLeftLateralAndCaldwellAndTowne = (
        DocumentTypeValueSetCode("39521-0")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SkullX_rayPAAndRightLateralAndLeftLateralAndTowne = DocumentTypeValueSetCode(
        "39520-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayPAAndRightLateralAndRightObliqueAndLeftObliqueUpright = (
        DocumentTypeValueSetCode("24646-2")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayPAAndRightLateralAndRightObliqueAndLeftObliqueUprightPortable = (
        DocumentTypeValueSetCode("24645-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayPAAndRightObliqueAndLeftOblique = DocumentTypeValueSetCode("37150-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayPAUprightWInspirationAndExpiration = DocumentTypeValueSetCode("24635-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralX_rayPAStandingAndWFlexion = DocumentTypeValueSetCode("46378-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanPerfusionQualitativeAtRestAndWRadionuclideIV = DocumentTypeValueSetCode(
        "43660-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanPerfusionQuantitativeAtRestAndWRadionuclideIV = DocumentTypeValueSetCode(
        "43661-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanPerfusionQuantitative = DocumentTypeValueSetCode("43658-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LungScanPerfusionQuantitative = DocumentTypeValueSetCode("43656-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanPerfusionAtRestAndWAdenosineAndWRadionuclideIV = DocumentTypeValueSetCode(
        "39719-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanPerfusionAtRestAndWAdenosineAndWTl_201IV = DocumentTypeValueSetCode(
        "43777-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanPerfusionAtRestAndWDipyridamoleAndWRadionuclideIV = (
        DocumentTypeValueSetCode("39722-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanPerfusionAtRestAndWDipyridamoleAndWTc_99mSestamibiIV = (
        DocumentTypeValueSetCode("39720-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanPerfusionAtRestAndWRadionuclideIV = DocumentTypeValueSetCode("39728-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanPerfusionAtRestAndWStressAndWRadionuclideIV = DocumentTypeValueSetCode(
        "39726-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanPerfusionAtRestAndWStressAndWTc_99mSestamibiIV = DocumentTypeValueSetCode(
        "39727-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanPerfusionAtRestAndWTc_99mSestamibiIV = DocumentTypeValueSetCode("39699-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanPerfusionWAdenosineAndWRadionuclideIV = DocumentTypeValueSetCode("39701-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanPerfusionWAdenosineAndWTc_99mSestamibiIV = DocumentTypeValueSetCode(
        "39731-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanPerfusionWAdenosineAndWTl_201IV = DocumentTypeValueSetCode("39735-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanPerfusionWDipyridamoleAndWRadionuclideIV = DocumentTypeValueSetCode(
        "39708-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanPerfusionWDipyridamoleAndWTc_99mIV = DocumentTypeValueSetCode("39709-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanPerfusionWDipyridamoleAndWTc_99mSestamibiIV = DocumentTypeValueSetCode(
        "39705-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanPerfusionWDipyridamoleAndWTl_201IV = DocumentTypeValueSetCode("39707-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanPerfusionWDobutamineAndWRadionuclideIV = DocumentTypeValueSetCode(
        "39703-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanPerfusionWDobutamineAndWTc_99mSestamibiIV = DocumentTypeValueSetCode(
        "39702-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanPerfusionWDobutamineAndWTl_201IV = DocumentTypeValueSetCode("39733-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LungScanPerfusionWParticulateRadionuclideIV = DocumentTypeValueSetCode("39941-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LungScanPerfusionWRadionuclideGaseousInhaled = DocumentTypeValueSetCode("39833-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanPerfusion = DocumentTypeValueSetCode("39716-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LungScanPerfusion = DocumentTypeValueSetCode("39697-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanPerfusionWStressAndWRadionuclideIV = DocumentTypeValueSetCode("39730-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanPerfusionWStressAndWTc_99mSestamibiIV = DocumentTypeValueSetCode("39732-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanPerfusionWStressAndWTl_201IV = DocumentTypeValueSetCode("39715-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanPerfusionWTc_99mSestamibiIV = DocumentTypeValueSetCode("39704-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanPerfusionWTl_201IV = DocumentTypeValueSetCode("39714-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanPerfusionWTl_201IVAndTc_99mTetrofosminIV = DocumentTypeValueSetCode(
        "39713-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AcetabulumX_rayPortable = DocumentTypeValueSetCode("30765-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Acetabulum_BilateralX_rayPortable = DocumentTypeValueSetCode("30764-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_LeftX_rayPortable = DocumentTypeValueSetCode("41823-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_RightX_rayPortable = DocumentTypeValueSetCode("41782-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayPortable = DocumentTypeValueSetCode("30746-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_LeftX_rayPortable = DocumentTypeValueSetCode("41827-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_RightX_rayPortable = DocumentTypeValueSetCode("41786-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FacialBonesX_rayPortable = DocumentTypeValueSetCode("41773-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Femur_LeftX_rayPortable = DocumentTypeValueSetCode("41818-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Femur_RightX_rayPortable = DocumentTypeValueSetCode("41778-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HandX_rayPortable = DocumentTypeValueSetCode("43570-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_LeftX_rayPortable = DocumentTypeValueSetCode("41829-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hand_RightX_rayPortable = DocumentTypeValueSetCode("41788-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HipX_rayPortable = DocumentTypeValueSetCode("37168-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_LeftX_rayPortable = DocumentTypeValueSetCode("37169-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_RightX_rayPortable = DocumentTypeValueSetCode("38796-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HumerusX_rayPortable = DocumentTypeValueSetCode("37170-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Humerus_LeftX_rayPortable = DocumentTypeValueSetCode("41825-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Humerus_RightX_rayPortable = DocumentTypeValueSetCode("41784-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_rayPortable = DocumentTypeValueSetCode("41820-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_rayPortable = DocumentTypeValueSetCode("41779-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PatellaX_rayPortable = DocumentTypeValueSetCode("30792-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisX_rayPortable = DocumentTypeValueSetCode("30772-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RibsX_rayPortable = DocumentTypeValueSetCode("30747-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ribs_LeftX_rayPortable = DocumentTypeValueSetCode("41831-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ribs_RightX_rayPortable = DocumentTypeValueSetCode("41791-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ShoulderX_rayPortable = DocumentTypeValueSetCode("46391-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftX_rayPortable = DocumentTypeValueSetCode("41824-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightX_rayPortable = DocumentTypeValueSetCode("41783-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SkullX_rayPortable = DocumentTypeValueSetCode("30723-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalX_rayPortable = DocumentTypeValueSetCode("37171-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalAndThoracicAndLumbarX_rayPortable = DocumentTypeValueSetCode("44203-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_rayPortable = DocumentTypeValueSetCode("37172-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_LeftX_rayPortable = DocumentTypeValueSetCode("41828-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_RightX_rayPortable = DocumentTypeValueSetCode("41787-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionFluoroscopyPortable = DocumentTypeValueSetCode("37151-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ZygomaticArchX_rayPortable = DocumentTypeValueSetCode("30731-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ZygomaticArch_BilateralX_rayPortable = DocumentTypeValueSetCode("30730-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayPortableWInspirationAndExpiration = DocumentTypeValueSetCode("24634-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LungScanPortable = DocumentTypeValueSetCode("24824-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionX_rayPostMortem = DocumentTypeValueSetCode("42402-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LungScanQuantitative = DocumentTypeValueSetCode("43657-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayRightAndLeftObliquePortable = DocumentTypeValueSetCode("30733-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenX_rayRightLateralAndLeftLateral = DocumentTypeValueSetCode("37131-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenX_rayRightObliqueAndLeftOblique = DocumentTypeValueSetCode("37138-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayRightObliqueAndLeftOblique = DocumentTypeValueSetCode("41792-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayRightObliqueAndLeftObliqueUpright = DocumentTypeValueSetCode("24651-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayRightObliqueAndLeftObliqueWNippleMarkers = DocumentTypeValueSetCode(
        "42414-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_BilateralMammogramRoll = DocumentTypeValueSetCode("37016-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_LeftMammogramRoll = DocumentTypeValueSetCode("37017-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_RightMammogramRoll = DocumentTypeValueSetCode("37775-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayRightOr_leftOblique = DocumentTypeValueSetCode("30740-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayRightOr_leftObliquePortable = DocumentTypeValueSetCode("30739-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AortaAbdominalFluoroscopicAngiogramRunoffWContrastIA = DocumentTypeValueSetCode(
        "43479-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AortaAndFemoralArtery_BilateralFluoroscopicAngiogramRunoffWContrastIA = (
        DocumentTypeValueSetCode("30838-7")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AortaAndFemoralArtery_LeftFluoroscopicAngiogramRunoffWContrastIA = (
        DocumentTypeValueSetCode("37364-7")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AortaAndFemoralArtery_RightFluoroscopicAngiogramRunoffWContrastIA = (
        DocumentTypeValueSetCode("38799-3")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    WristX_rayScaphoid = DocumentTypeValueSetCode("38107-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_BilateralX_rayScaphoid = DocumentTypeValueSetCode("37304-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_LeftX_rayScaphoid = DocumentTypeValueSetCode("37302-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_RightX_rayScaphoid = DocumentTypeValueSetCode("38115-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicAndLumbarX_rayScoliosis = DocumentTypeValueSetCode("24930-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicAndLumbarX_rayScoliosisAPAndLateral = DocumentTypeValueSetCode(
        "30715-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicAndLumbarX_rayScoliosisAPAndLateralSitting = DocumentTypeValueSetCode(
        "42424-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicAndLumbarX_rayScoliosisAPAndLateralStanding = DocumentTypeValueSetCode(
        "39367-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicAndLumbarX_rayScoliosisAPInTraction = DocumentTypeValueSetCode(
        "42472-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicAndLumbarX_rayScoliosisAPStandingAndWRightBendingAndWLeftBendingAndWOBending = DocumentTypeValueSetCode(
        "42425-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicAndLumbarX_rayScoliosisAPUprightAndSupine = DocumentTypeValueSetCode(
        "43569-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicAndLumbarX_rayScoliosisLateral = DocumentTypeValueSetCode("30716-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicAndLumbarX_rayScoliosisStanding = DocumentTypeValueSetCode("30717-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicAndLumbarX_rayScoliosisWFlexionAndWExtension = (
        DocumentTypeValueSetCode("24929-2")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastMammogramScreening = DocumentTypeValueSetCode("24606-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastFFDMammogramScreening = DocumentTypeValueSetCode("39153-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastImplantX_rayScreening = DocumentTypeValueSetCode("69159-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastImplant_BilateralMammogramScreening = DocumentTypeValueSetCode("48492-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_BilateralMammogramScreening = DocumentTypeValueSetCode("26175-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_BilateralFFDMammogramScreening = DocumentTypeValueSetCode("42174-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_LeftMammogramScreening = DocumentTypeValueSetCode("26176-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_LeftFFDMammogramScreening = DocumentTypeValueSetCode("46355-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_RightMammogramScreening = DocumentTypeValueSetCode("26177-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_RightFFDMammogramScreening = DocumentTypeValueSetCode("46354-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_UnilateralMammogramScreening = DocumentTypeValueSetCode("46356-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CalcaneusX_raySkiJump = DocumentTypeValueSetCode("37022-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Calcaneus_BilateralX_raySkiJump = DocumentTypeValueSetCode("37021-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Calcaneus_LeftX_raySkiJump = DocumentTypeValueSetCode("37023-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Calcaneus_RightX_raySkiJump = DocumentTypeValueSetCode("38778-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastMammogramSpot = DocumentTypeValueSetCode("37551-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_BilateralMammogramSpot = DocumentTypeValueSetCode("37552-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_RightMammogramSpot = DocumentTypeValueSetCode("38807-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_LeftMammogramSpotCompression = DocumentTypeValueSetCode("37553-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainScanStaticAndFlow = DocumentTypeValueSetCode("43550-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScrotumAndTesticleScanStaticAndFlow = DocumentTypeValueSetCode("39952-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScanStaticForInfectionWGA_67IV = DocumentTypeValueSetCode("39676-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanStaticForShuntDetection = DocumentTypeValueSetCode("39894-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScanStaticForTumorWGA_67IV = DocumentTypeValueSetCode("39896-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BoneScanStaticLimited = DocumentTypeValueSetCode("39814-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainScanStaticLimited = DocumentTypeValueSetCode("39634-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BoneScanStaticMultipleAreas = DocumentTypeValueSetCode("39903-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BoneScanStaticWholeBody = DocumentTypeValueSetCode("39817-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BoneScanStatic = DocumentTypeValueSetCode("39815-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BoneMarrowScanStatic = DocumentTypeValueSetCode("39824-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainScanStatic = DocumentTypeValueSetCode("39633-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_BilateralScanStatic = DocumentTypeValueSetCode("39853-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LiverScanStatic = DocumentTypeValueSetCode("39832-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LiverAndSpleenScanStatic = DocumentTypeValueSetCode("39878-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SalivaryGlandScanStatic = DocumentTypeValueSetCode("39900-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScrotumAndTesticleScanStatic = DocumentTypeValueSetCode("39855-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VesselScanStatic = DocumentTypeValueSetCode("43501-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainScanStaticWTc_99mBicisateIV = DocumentTypeValueSetCode("44150-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_BilateralScanStaticWTc_99mDMSAIV = DocumentTypeValueSetCode("39854-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MastoidX_rayStenverAndArcelin = DocumentTypeValueSetCode("37153-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeX_raySunriseAndTunnel = DocumentTypeValueSetCode("69136-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralX_raySunriseAndTunnel = DocumentTypeValueSetCode("37163-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_raySunriseAndTunnel = DocumentTypeValueSetCode("37156-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_raySunriseAndTunnel = DocumentTypeValueSetCode("37759-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_raySunriseAndTunnelStanding = DocumentTypeValueSetCode("39345-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_raySunriseAndTunnelStanding = DocumentTypeValueSetCode("69255-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralX_raySunrise20And40And60Degrees = DocumentTypeValueSetCode("38088-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_raySunrise20And40And60Degrees = DocumentTypeValueSetCode("38087-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_raySunrise20And40And60Degrees = DocumentTypeValueSetCode("38824-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BonesLongX_raySurvey = DocumentTypeValueSetCode("24579-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BonesX_raySurvey = DocumentTypeValueSetCode("43518-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BonesX_raySurveyForMetastasis = DocumentTypeValueSetCode("37365-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BonesLongX_raySurveyLimited = DocumentTypeValueSetCode("39518-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BonesX_raySurveyLimited = DocumentTypeValueSetCode("43519-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BonesX_raySurveyLimitedForMetastasis = DocumentTypeValueSetCode("38089-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_LeftX_rayTarsal = DocumentTypeValueSetCode("37159-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_RightX_rayTarsal = DocumentTypeValueSetCode("38792-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_BilateralX_rayTunnel_carpal = DocumentTypeValueSetCode("43796-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    WristX_rayUlnarDeviation = DocumentTypeValueSetCode("69304-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    WristX_rayUlnarDeviationAndRadialDeviation = DocumentTypeValueSetCode("69303-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_BilateralX_rayUlnarDeviationAndRadialDeviation = DocumentTypeValueSetCode(
        "69072-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_LeftX_rayUlnarDeviationAndRadialDeviation = DocumentTypeValueSetCode(
        "37555-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_RightX_rayUlnarDeviationAndRadialDeviation = DocumentTypeValueSetCode(
        "38808-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestAndAbdomenX_rayUprightAndPAChest = DocumentTypeValueSetCode("43532-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LungScanVentilationAndEquilibriumAndWashoutWRadionuclideInhaled = (
        DocumentTypeValueSetCode("39944-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LungScanVentilationAndEquilibriumAndWashoutWRadionuclideInhaledSingleBreath = (
        DocumentTypeValueSetCode("39948-5")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LungScanVentilationAndEquilibriumWRadionuclideInhaledSingleBreath = (
        DocumentTypeValueSetCode("39947-7")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LungScanVentilationAndPerfusionAndDifferentialWRadionuclideInhaledAndWRadionuclideIV = DocumentTypeValueSetCode(
        "39946-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LungScanVentilationAndPerfusionWRadionuclideInhaledAndWParticulateRadionuclideIV = (
        DocumentTypeValueSetCode("39943-6")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PulmonarySystemScanVentilationAndPerfusionWRadionuclideInhaledAndWRadionuclideIV = (
        DocumentTypeValueSetCode("30697-7")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LungScanVentilationAndPerfusionWRadionuclideInhaledSingleBreathAndWParticulateRadionuclideIV = DocumentTypeValueSetCode(
        "39942-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PulmonarySystemScanVentilationAndPerfusionWXe_133InhaledAndWTc_99mMAAIV = (
        DocumentTypeValueSetCode("24888-0")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LungScanVentilationWRadionuclideAerosolInhaled = DocumentTypeValueSetCode("39835-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LungScanVentilationWRadionuclideGaseousInhaled = DocumentTypeValueSetCode("39836-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LungScanVentilationWRadionuclideGaseousInhaledSingleBreath = (
        DocumentTypeValueSetCode("39945-1")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LungScanVentilationWRadionuclideInhaled = DocumentTypeValueSetCode("39837-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LungScanVentilationWTc_99mDTPAAerosolInhaled = DocumentTypeValueSetCode("39834-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LungScanVentilationWXe_133Inhaled = DocumentTypeValueSetCode("46361-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanWallMotionAndEjectionFraction = DocumentTypeValueSetCode("39932-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanWallMotion = DocumentTypeValueSetCode("39873-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScanWholeBodyWGA_67IV = DocumentTypeValueSetCode("39683-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScanWholeBodyWI_131MIBGIV = DocumentTypeValueSetCode("39698-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScanWholeBodyWIn_111SatumomabIV = DocumentTypeValueSetCode("39845-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScanWholeBodyWIn_111TaggedWBCIV = DocumentTypeValueSetCode("42711-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScanWholeBody = DocumentTypeValueSetCode("42175-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BoneScanWholeBody = DocumentTypeValueSetCode("39818-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BoneMarrowScanWholeBody = DocumentTypeValueSetCode("39826-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScanWholeBodyWTc_99mArcitumomabIV = DocumentTypeValueSetCode("39669-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GallbladderX_ray48HoursPostContrastPO = DocumentTypeValueSetCode("24713-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanAtRestAndWDipyridamoleAndWRadionuclideIV = DocumentTypeValueSetCode(
        "39660-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanAtRestAndWDobutamineAndWRadionuclideIV = DocumentTypeValueSetCode(
        "39661-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanAtRestAndWStressAndWRadionuclideIV = DocumentTypeValueSetCode("39663-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanAtRestAndWStressAndWTl_201IV = DocumentTypeValueSetCode("42309-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanAtRestAndWTl_201IV = DocumentTypeValueSetCode("24750-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainScanDuringElectroconvulsiveShockTreatment = DocumentTypeValueSetCode("43459-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BoneX_rayDuringSurgery = DocumentTypeValueSetCode("24577-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HipX_rayDuringSurgery = DocumentTypeValueSetCode("47372-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionFluoroscopyDuringSurgery = DocumentTypeValueSetCode("25070-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BiliaryDuctsAndGallbladderFluoroscopyDuringSurgeryWContrastBiliaryDuct = (
        DocumentTypeValueSetCode("24574-6")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastDuctMammogramDuringSurgeryWContrastIntraDuct = DocumentTypeValueSetCode(
        "46352-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KidneyX_rayDuringSurgeryWContrastRetrograde = DocumentTypeValueSetCode("43485-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastFFDMammogramPostLocalization = DocumentTypeValueSetCode("39150-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastMammogramPostWirePlacement = DocumentTypeValueSetCode("69251-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_BilateralMammogramPostWirePlacement = DocumentTypeValueSetCode("42415-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_LeftMammogramPostWirePlacement = DocumentTypeValueSetCode("42416-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AnkleX_rayStanding = DocumentTypeValueSetCode("37201-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_BilateralX_rayStanding = DocumentTypeValueSetCode("37202-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_LeftX_rayStanding = DocumentTypeValueSetCode("37203-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_RightX_rayStanding = DocumentTypeValueSetCode("37676-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CalcaneusX_rayStanding = DocumentTypeValueSetCode("37205-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Calcaneus_LeftX_rayStanding = DocumentTypeValueSetCode("37206-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Calcaneus_RightX_rayStanding = DocumentTypeValueSetCode("37720-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Femur_LeftX_rayStanding = DocumentTypeValueSetCode("38845-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Femur_RightX_rayStanding = DocumentTypeValueSetCode("37693-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FootX_rayStanding = DocumentTypeValueSetCode("24708-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_BilateralX_rayStanding = DocumentTypeValueSetCode("26094-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_LeftX_rayStanding = DocumentTypeValueSetCode("26095-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_RightX_rayStanding = DocumentTypeValueSetCode("26096-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GreatToe_LeftX_rayStanding = DocumentTypeValueSetCode("37584-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GreatToe_RightX_rayStanding = DocumentTypeValueSetCode("38810-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeX_rayStanding = DocumentTypeValueSetCode("24809-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralX_rayStanding = DocumentTypeValueSetCode("26085-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_rayStanding = DocumentTypeValueSetCode("26086-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_rayStanding = DocumentTypeValueSetCode("26087-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityX_rayStanding = DocumentTypeValueSetCode("37204-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SacrumX_rayStanding = DocumentTypeValueSetCode("69264-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_rayStanding = DocumentTypeValueSetCode("37208-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicX_rayStanding = DocumentTypeValueSetCode("69275-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicAndLumbarX_rayStanding = DocumentTypeValueSetCode("38124-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TibiaAndFibulaX_rayStanding = DocumentTypeValueSetCode("37899-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Toes_LeftX_rayStanding = DocumentTypeValueSetCode("37209-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Toes_RightX_rayStanding = DocumentTypeValueSetCode("37823-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_BilateralScanWAndWOTc_99mDTPAIV = DocumentTypeValueSetCode("44233-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_BilateralScanWAndWOTc_99mMertiatideIV = DocumentTypeValueSetCode("44232-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AcromioclavicularJointX_rayWAndWOWeight = DocumentTypeValueSetCode("37579-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AcromioclavicularJoint_BilateralX_rayWAndWOWeight = DocumentTypeValueSetCode(
        "37580-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AcromioclavicularJoint_LeftX_rayWAndWOWeight = DocumentTypeValueSetCode("37581-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AcromioclavicularJoint_RightX_rayWAndWOWeight = DocumentTypeValueSetCode("37663-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanWAdenosineAndWTl_201IV = DocumentTypeValueSetCode("39651-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_BilateralMammogramWAir = DocumentTypeValueSetCode("38090-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Breast_LeftMammogramWAir = DocumentTypeValueSetCode("38091-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GastrointestineUpperFluoroscopyWAirAndBariumContrastPO = DocumentTypeValueSetCode(
        "39059-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ColonFluoroscopyWAirAndBariumContrastPR = DocumentTypeValueSetCode("24666-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ColonFluoroscopyWAirContrastPR = DocumentTypeValueSetCode("46357-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    EsophagusFluoroscopyWBariumContrastPO = DocumentTypeValueSetCode("30633-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GastrointestineUpperFluoroscopyWBariumContrastPO = DocumentTypeValueSetCode(
        "42683-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperGastrointestineAndSmallBowelFluoroscopyWBariumContrastPO = (
        DocumentTypeValueSetCode("43574-3")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ColonFluoroscopyWBariumContrastPR = DocumentTypeValueSetCode("44227-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionFluoroscopyWBariumContrastViaFistula = (
        DocumentTypeValueSetCode("37565-9")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UrinaryBladderFluoroscopyWChainAndContrastIntraBladder = DocumentTypeValueSetCode(
        "38092-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GallbladderScanWCholecystokininAndWRadionuclideIV = DocumentTypeValueSetCode(
        "41770-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LiverAndBiliaryDuctsAndGallbladderScanWCholecystokininAndWRadionuclideIV = (
        DocumentTypeValueSetCode("43650-1")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadCisternFluoroscopyVideoWContrast = DocumentTypeValueSetCode("30630-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    IntercranialVesselAndNeckVesselFluoroscopicAngiogramWContrast = (
        DocumentTypeValueSetCode("30824-7")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    JejunumFluoroscopyWContrast = DocumentTypeValueSetCode("37585-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVessels_LeftFluoroscopicAngiogramWContrast = DocumentTypeValueSetCode(
        "38853-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVessels_RightFluoroscopicAngiogramWContrast = (
        DocumentTypeValueSetCode("37765-5")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisVesselsFluoroscopicAngiogramWContrast = DocumentTypeValueSetCode("37615-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PeripheralVesselsFluoroscopicAngiogramWContrast = DocumentTypeValueSetCode(
        "37936-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RenalVesselsFluoroscopicAngiogramWContrast = DocumentTypeValueSetCode("37640-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RenalVessels_LeftFluoroscopicAngiogramWContrast = DocumentTypeValueSetCode(
        "64140-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RenalVessels_RightFluoroscopicAngiogramWContrast = DocumentTypeValueSetCode(
        "64141-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Spine_cavityFluoroscopyWContrast = DocumentTypeValueSetCode("38094-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TesticleVesselsFluoroscopyWContrast = DocumentTypeValueSetCode("37973-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThreeVesselsFluoroscopicAngiogramWContrast = DocumentTypeValueSetCode("25005-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TwoVesselsFluoroscopicAngiogramWContrast = DocumentTypeValueSetCode("25014-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityVesselsFluoroscopicAngiogramWContrast = DocumentTypeValueSetCode(
        "37976-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UrinaryBladderAndUrethraFluoroscopyWContrast = DocumentTypeValueSetCode("42014-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VertebralVesselsFluoroscopicAngiogramWContrast = DocumentTypeValueSetCode("37980-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VisceralVesselsFluoroscopicAngiogramWContrast = DocumentTypeValueSetCode("37981-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GallbladderX_rayWContrastAndFattyMealPO = DocumentTypeValueSetCode("37575-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KidneyX_rayWContrastAntegrade = DocumentTypeValueSetCode("38101-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_BilateralFluoroscopyWContrastAntegrade = DocumentTypeValueSetCode("46376-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UrinaryBladderAndUrethraFluoroscopyWContrastAntegrade = DocumentTypeValueSetCode(
        "38100-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KidneyX_rayWContrastAntegradeViaPyelostomy = DocumentTypeValueSetCode("38102-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdominalArteriesFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "25030-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AdrenalArteryFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode("30832-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AdrenalArtery_BilateralFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "30831-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AdrenalArtery_LeftFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "37387-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AdrenalArtery_RightFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "37939-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AnkleArteries_LeftFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "38861-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AnkleArteries_RightFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "37941-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AortaFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode("24658-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AortaAbdominalFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode("30837-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AortaArchAndNeckFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "24546-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdominalAortaAndArteriesFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("37366-2")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AorticArchFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode("69054-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AorticArchAndBrachialArteryFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("37380-3")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AorticArchAndCarotidArteryFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("37381-1")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AorticArchAndCarotidArtery_BilateralAndVertebralArtery_BilateralFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "37587-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AorticArchAndCarotidArtery_common_BilateralFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("37588-1")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AorticArchAndCarotidArtery_common_LeftFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("37589-9")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AorticArchAndCarotidArtery_common_RightFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("37590-7")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AorticArchAndCarotidArtery_external_BilateralFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("37591-5")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AorticArchAndCarotidArtery_external_LeftFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("37592-3")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AorticArchAndCarotidArtery_external_RightFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("37593-1")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AorticArchAndCarotidArteryAndVertebralArteryFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("37594-9")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AorticArchAndSubclavianArteryFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("37382-9")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AorticArchAndSubclavianArtery_LeftFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("37383-7")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AorticArchAndSubclavianArtery_RightFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("38800-9")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AorticArchAndUpperExtremityArteryFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("37379-5")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AorticArchAndVertebralArteryFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("37384-5")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AorticArchAndVertebralArtery_LeftFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("37385-2")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AorticArchAndVertebralArtery_RightFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("37386-0")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AVFistulaFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode("24551-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrachialArteryFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode("30828-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrachialArtery_BilateralFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "37388-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrachialArteryAndSubclavianArteryFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("24581-1")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrachiocephalicArteryFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "69077-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BronchialArteryFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "37389-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CarotidArteryFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode("24617-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CarotidArtery_BilateralFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "26079-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CarotidArtery_BilateralAndCerebralArtery_BilateralFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "39097-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CarotidArtery_cervicalFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "39094-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CarotidArtery_cervical_BilateralFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("39098-9")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CarotidArtery_cervical_LeftFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("38863-7")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CarotidArtery_cervical_RightFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("37945-3")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CarotidArtery_externalFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "30821-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CarotidArtery_external_BilateralFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("30820-5")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CarotidArtery_external_LeftFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("37390-2")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CarotidArtery_external_RightFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("37948-7")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CarotidArtery_internal_LeftFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("38864-5")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CarotidArtery_internal_RightFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("37952-9")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CarotidArtery_LeftFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "26080-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CarotidArtery_RightFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "26081-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CarotidArteryAndCerebralArteryFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("39095-5")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CarotidArteryAndCerebralArteryInternal_LeftFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("38865-2")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CarotidArteryAndCerebralArteryInternal_RightFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("37953-7")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CarotidArteryAndCerebralArtery_LeftFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("38862-9")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CarotidArteryAndCerebralArtery_RightFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("37944-6")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CarotidArteryAndVertebralArteryFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("37391-0")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CarotidArteryAndVertebralArtery_BilateralFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("37392-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CarotidArtery_VertebralArtery_LeftFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("37393-6")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CarotidArtery_VertebralArtery_RightFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("37943-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CeliacArteryFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode("24622-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CeliacArteryAndGastricArtery_LeftAndSuperiorMesentericArteryFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "37403-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CeliacArteryAndSuperiorMesentericArteryAndInferiorMesentericArteryFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "37394-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CerebralArteryFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode("37173-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CervicocerebralArteryFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "30891-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CoronaryArteriesFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "37174-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CoronaryGraftFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode("37595-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityArteriesFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "30848-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityArteries_BilateralFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("30849-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityArteries_LeftFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "37395-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityArteries_RightFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "37949-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FemoralArteryFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode("37175-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FemoralArteryAndPoplitealArteryFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("37176-5")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GastricArteryFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode("37397-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GastricArtery_LeftFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "37398-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GastricArtery_RightFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "38801-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GastroduodenalArteryFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "37399-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadArtery_BilateralAndNeckArtery_BilateralFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("30822-1")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadArtery_left_NeckArtery_leftFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("62448-6")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadArtery_right_NeckArtery_rightFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("62449-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadArteryAndNeckArteryFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "30823-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HepaticArteryFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode("25076-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    IliacArteryFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode("43782-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    IliacArtery_BilateralFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "37177-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    IliacArteryInternalFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "24862-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    IliacArtery_LeftFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "37178-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    IliacArtery_RightFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "37739-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InferiorMesentericArteryFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "37179-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KidneyArteriesFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode("25079-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityArteriesFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "37487-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityArteries_LeftFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("47986-5")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityArteries_RightFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("47987-3")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InternalMammaryArteryFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "30829-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MammaryArtery_internal_LeftFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("64995-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MammaryArtery_internal_RightFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("65000-2")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MaxillaryArtery_internalFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "37401-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MesentericArteryFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "24833-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PancreaticArteryFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "24860-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisArteriesFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode("30833-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PelvisArteriesAndLowerExtremityArteries_BilateralFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "37935-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PeripheralArteriesFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "24874-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PeripheralArteries_BilateralFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("44240-0")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PoplitealArteryFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "69249-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PoplitealArtery_LeftFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "37181-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PoplitealArtery_RightFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "37778-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PudendalArtery_internalFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "37404-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PulmonaryArteryFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "39057-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PulmonaryArtery_BilateralFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("30830-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PulmonaryArtery_LeftFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "37182-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PulmonaryArtery_RightFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "37779-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RenalArtery_BilateralFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "30834-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RenalArtery_LeftFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "62446-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RenalArtery_RightFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "62447-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpinalArteryFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode("24925-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpinalArtery_BilateralFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "26082-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpinalArtery_LeftFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "26083-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpinalArtery_RightFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "26084-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SplenicArteryFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode("24992-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SplenicVeinAndPortalVeinFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "24991-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SubclavianArteryFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "37886-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SubclavianArtery_BilateralFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("37405-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SubclavianArtery_LeftFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "37406-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SubclavianArtery_RightFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "37966-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SuperiorMesentericArteryFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "37180-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SuperiorMesentericArteryAndInferiorMesentericArteryFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "37402-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThoracicArteryFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode("38119-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TibialArteryFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode("37900-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TibioperonealArteriesFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "37489-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityArteriesFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "37977-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityArteries_BilateralFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("37396-9")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityArteries_LeftFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("37488-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityArteries_RightFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("37967-7")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UrinaryBladderArteriesFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "24576-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UterineArteryFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode("37979-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VertebralArtery_BilateralFluoroscopicAngiogramWContrastIA = (
        DocumentTypeValueSetCode("37407-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VertebralArtery_LeftFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "37490-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VertebralArtery_RightFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode(
        "37968-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VesselsFluoroscopicAngiogramWContrastIA = DocumentTypeValueSetCode("42156-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UrinaryBladderAndUrethraFluoroscopyWContrastIntraBladder = DocumentTypeValueSetCode(
        "25017-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UrinaryBladderAndUrethraFluoroscopyWContrastIntraBladderDuringVoiding = (
        DocumentTypeValueSetCode("43559-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PenisFluoroscopyWContrastIntraCorpusCavernosum = DocumentTypeValueSetCode("37586-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastDuctMammogramWContrastIntraDuct = DocumentTypeValueSetCode("39054-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastDuct_BilateralMammogramWContrastIntraDuct = DocumentTypeValueSetCode(
        "38095-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastDuct_LeftMammogramWContrastIntraDuct = DocumentTypeValueSetCode("38096-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastDuct_RightMammogramWContrastIntraDuct = DocumentTypeValueSetCode("38825-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LacrimalDuctFluoroscopyWContrastIntraLacrimalDuct = DocumentTypeValueSetCode(
        "30810-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LacrimalDuct_BilateralFluoroscopyWContrastIntraLacrimalDuct = (
        DocumentTypeValueSetCode("38098-0")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LacrimalDuct_LeftFluoroscopyWContrastIntraLacrimalDuct = DocumentTypeValueSetCode(
        "38099-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LacrimalDuct_RightFluoroscopyWContrastIntraLacrimalDuct = DocumentTypeValueSetCode(
        "38827-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeckFluoroscopyWContrastIntraLarynx = DocumentTypeValueSetCode("24845-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityLymphaticsFluoroscopyWContrastIntraLymphatic = DocumentTypeValueSetCode(
        "30850-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityLymphatics_BilateralFluoroscopyWContrastIntraLymphatic = (
        DocumentTypeValueSetCode("30851-0")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityLymphatics_LeftFluoroscopyWContrastIntraLymphatic = (
        DocumentTypeValueSetCode("37599-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityLymphatics_RightFluoroscopyWContrastIntraLymphatic = (
        DocumentTypeValueSetCode("38812-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LymphaticsFluoroscopyWContrastIntraLymphatic = DocumentTypeValueSetCode("24827-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LymphaticsAbdominalFluoroscopyWContrastIntraLymphatic = DocumentTypeValueSetCode(
        "30839-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LymphaticsAbdominal_BilateralFluoroscopyWContrastIntraLymphatic = (
        DocumentTypeValueSetCode("30840-3")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LymphaticsAbdominalAndLymphaticsPelvicFluoroscopyWContrastIntraLymphatic = (
        DocumentTypeValueSetCode("37597-2")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LymphaticsAbdominalAndLymphaticsPelvic_BilateralFluoroscopyWContrastIntraLymphatic = DocumentTypeValueSetCode(
        "37598-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LymphaticsAbdominalAndLymphaticsPelvic_LeftFluoroscopyWContrastIntraLymphatic = (
        DocumentTypeValueSetCode("37596-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LymphaticsAbdominalAndLymphaticsPelvic_RightFluoroscopyWContrastIntraLymphatic = (
        DocumentTypeValueSetCode("38811-6")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Lymphatics_LeftFluoroscopyWContrastIntraLymphatic = DocumentTypeValueSetCode(
        "37600-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LymphaticsPelvicFluoroscopyWContrastIntraLymphatic = DocumentTypeValueSetCode(
        "39510-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LymphaticsPelvic_BilateralFluoroscopyWContrastIntraLymphatic = (
        DocumentTypeValueSetCode("37601-2")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Lymphatics_RightFluoroscopyWContrastIntraLymphatic = DocumentTypeValueSetCode(
        "38813-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastDuctMammogramWContrastIntraMultipleDucts = DocumentTypeValueSetCode("39148-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastDuct_BilateralMammogramWContrastIntraMultipleDucts = DocumentTypeValueSetCode(
        "39146-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastDuct_LeftMammogramWContrastIntraMultipleDucts = DocumentTypeValueSetCode(
        "39145-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastDuct_RightMammogramWContrastIntraMultipleDucts = DocumentTypeValueSetCode(
        "39147-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PleuralSpaceFluoroscopyWContrastIntraPleuralSpace = DocumentTypeValueSetCode(
        "24661-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ParotidGlandFluoroscopyWContrastIntraSalivaryDuct = DocumentTypeValueSetCode(
        "38116-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ParotidGland_LeftFluoroscopyWContrastIntraSalivaryDuct = DocumentTypeValueSetCode(
        "38097-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ParotidGland_RightFluoroscopyWContrastIntraSalivaryDuct = DocumentTypeValueSetCode(
        "38826-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SalivaryGlandFluoroscopyWContrastIntraSalivaryDuct = DocumentTypeValueSetCode(
        "24902-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SalivaryGland_BilateralFluoroscopyWContrastIntraSalivaryDuct = (
        DocumentTypeValueSetCode("26067-9")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SalivaryGland_LeftFluoroscopyWContrastIntraSalivaryDuct = DocumentTypeValueSetCode(
        "26068-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SalivaryGland_RightFluoroscopyWContrastIntraSalivaryDuct = DocumentTypeValueSetCode(
        "26069-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SubmandibularGlandFluoroscopyWContrastIntraSalivaryDuct = DocumentTypeValueSetCode(
        "38153-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SubmandibularGland_BilateralFluoroscopyWContrastIntraSalivaryDuct = (
        DocumentTypeValueSetCode("48698-5")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SubmandibularGland_LeftFluoroscopyWContrastIntraSalivaryDuct = (
        DocumentTypeValueSetCode("42460-6")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SubmandibularGland_RightFluoroscopyWContrastIntraSalivaryDuct = (
        DocumentTypeValueSetCode("48696-9")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SinusTractFluoroscopyWContrastIntraSinusTract = DocumentTypeValueSetCode("24912-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    StentFluoroscopyWContrastIntraStent = DocumentTypeValueSetCode("24552-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UrethraFluoroscopyWContrastIntraUrethra = DocumentTypeValueSetCode("25016-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VasDeferensFluoroscopyWContrastIntraVasDeferens = DocumentTypeValueSetCode(
        "39151-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AnkleFluoroscopyWContrastIntraarticular = DocumentTypeValueSetCode("37183-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_BilateralFluoroscopyWContrastIntraarticular = DocumentTypeValueSetCode(
        "37184-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_LeftFluoroscopyWContrastIntraarticular = DocumentTypeValueSetCode("37185-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_RightFluoroscopyWContrastIntraarticular = DocumentTypeValueSetCode("37942-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ElbowFluoroscopyWContrastIntraarticular = DocumentTypeValueSetCode("37186-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_BilateralFluoroscopyWContrastIntraarticular = DocumentTypeValueSetCode(
        "37187-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_LeftFluoroscopyWContrastIntraarticular = DocumentTypeValueSetCode("37188-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Elbow_RightFluoroscopyWContrastIntraarticular = DocumentTypeValueSetCode("37947-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HipFluoroscopyWContrastIntraarticular = DocumentTypeValueSetCode("24764-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_BilateralFluoroscopyWContrastIntraarticular = DocumentTypeValueSetCode(
        "26070-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_LeftFluoroscopyWContrastIntraarticular = DocumentTypeValueSetCode("26071-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Hip_RightFluoroscopyWContrastIntraarticular = DocumentTypeValueSetCode("26072-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeFluoroscopyWContrastIntraarticular = DocumentTypeValueSetCode("24800-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralFluoroscopyWContrastIntraarticular = DocumentTypeValueSetCode(
        "26073-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftFluoroscopyWContrastIntraarticular = DocumentTypeValueSetCode("26074-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightFluoroscopyWContrastIntraarticular = DocumentTypeValueSetCode("26075-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SacroiliacJointFluoroscopyWContrastIntraarticular = DocumentTypeValueSetCode(
        "37647-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SacroiliacJoint_BilateralFluoroscopyWContrastIntraarticular = (
        DocumentTypeValueSetCode("37189-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SacroiliacJoint_LeftFluoroscopyWContrastIntraarticular = DocumentTypeValueSetCode(
        "37190-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SacroiliacJoint_RightFluoroscopyWContrastIntraarticular = DocumentTypeValueSetCode(
        "37785-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ShoulderFluoroscopyWContrastIntraarticular = DocumentTypeValueSetCode("24910-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_BilateralFluoroscopyWContrastIntraarticular = DocumentTypeValueSetCode(
        "26076-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_LeftFluoroscopyWContrastIntraarticular = DocumentTypeValueSetCode(
        "26077-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Shoulder_RightFluoroscopyWContrastIntraarticular = DocumentTypeValueSetCode(
        "26078-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporomandibularJointFluoroscopyWContrastIntraarticular = DocumentTypeValueSetCode(
        "37901-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporomandibularJoint_BilateralFluoroscopyWContrastIntraarticular = (
        DocumentTypeValueSetCode("37409-0")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporomandibularJoint_LeftFluoroscopyWContrastIntraarticular = (
        DocumentTypeValueSetCode("37410-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    TemporomandibularJoint_RightFluoroscopyWContrastIntraarticular = (
        DocumentTypeValueSetCode("37818-2")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    WristFluoroscopyWContrastIntraarticular = DocumentTypeValueSetCode("25034-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_BilateralFluoroscopyWContrastIntraarticular = DocumentTypeValueSetCode(
        "37570-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_LeftFluoroscopyWContrastIntraarticular = DocumentTypeValueSetCode("37571-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Wrist_RightFluoroscopyWContrastIntraarticular = DocumentTypeValueSetCode("37641-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    JointFluoroscopyWContrastIntraarticular = DocumentTypeValueSetCode("37191-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LungX_rayWContrastIntrabronchial = DocumentTypeValueSetCode("24825-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Lung_BilateralX_rayWContrastIntrabronchial = DocumentTypeValueSetCode("30813-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Lung_LeftX_rayWContrastIntrabronchial = DocumentTypeValueSetCode("64996-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Lung_RightX_rayWContrastIntrabronchial = DocumentTypeValueSetCode("64997-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineFluoroscopyWContrastIntradisc = DocumentTypeValueSetCode("24927-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalFluoroscopyWContrastIntradisc = DocumentTypeValueSetCode("37192-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarFluoroscopyWContrastIntradisc = DocumentTypeValueSetCode("37193-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicFluoroscopyWContrastIntradisc = DocumentTypeValueSetCode("70933-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UterusAndFallopianTubesFluoroscopyWContrastIntrauterine = DocumentTypeValueSetCode(
        "25022-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PosteriorFossaFluoroscopyWContrastIT = DocumentTypeValueSetCode("30811-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineFluoroscopyWContrastIT = DocumentTypeValueSetCode("37572-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalFluoroscopyWContrastIT = DocumentTypeValueSetCode("24947-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalAndSpineLumbarFluoroscopyWContrastIT = DocumentTypeValueSetCode(
        "38103-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalAndThoracicAndLumbarFluoroscopyWContrastIT = DocumentTypeValueSetCode(
        "30808-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Spine_epiduralSpaceFluoroscopyWContrastIT = DocumentTypeValueSetCode("38104-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarFluoroscopyWContrastIT = DocumentTypeValueSetCode("24974-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineThoracicFluoroscopyWContrastIT = DocumentTypeValueSetCode("24985-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdominalVesselsFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode(
        "69066-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AdrenalVeinFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode("30843-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AdrenalVeinLeftFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode(
        "37602-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AdrenalVein_BilateralFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode(
        "30844-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AdrenalVein_RightFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode(
        "37940-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AVFistulaFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode("58746-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AVShuntFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode("24569-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AzygosVeinFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode("37411-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BiliaryDuctsAndGallbladderX_rayWContrastIV = DocumentTypeValueSetCode("24573-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CerebralVeinFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode("37195-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    EpiduralVeinsFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode("30819-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityVeinsFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode("39055-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityVeins_BilateralFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode(
        "37412-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityVeins_LeftFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode(
        "37413-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityVeins_RightFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode(
        "37950-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExtremityVesselsFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode(
        "42157-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FemoralVeinFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode("37416-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HepaticVeinsFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode("39093-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InferiorMesentericVeinFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode(
        "37421-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    IntraosseousVeinsFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode(
        "37419-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    JugularVeinFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode("37197-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    JugularVein_LeftFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode(
        "37420-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    JugularVein_RightFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode(
        "37954-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KidneyX_rayWContrastIV = DocumentTypeValueSetCode("37607-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_BilateralX_rayWContrastIV = DocumentTypeValueSetCode("24788-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVeins_BilateralFluoroscopicAngiogramWContrastIV = (
        DocumentTypeValueSetCode("37414-0")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVeins_LeftFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode(
        "37196-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVeins_RightFluoroscopicAngiogramWContrastIV = (
        DocumentTypeValueSetCode("37767-1")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LowerExtremityVesselsFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode(
        "37574-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OrbitVeinsFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode("30825-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OrbitVeins_LeftFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode(
        "37422-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OrbitVeins_RightFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode(
        "37958-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PeripheralVeins_BilateralFluoroscopicAngiogramWContrastIV = (
        DocumentTypeValueSetCode("30852-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PeripheralVeinsFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode(
        "24685-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PortalVeinFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode("69250-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RenalVeinFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode("30847-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RenalVein_BilateralFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode(
        "30846-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RenalVein_LeftFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode("37423-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RenalVein_RightFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode(
        "37959-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SagittalSinusVeinFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode(
        "30827-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SagittalSinusVein_LeftFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode(
        "65803-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SagittalSinusAndJugularVeins_LeftFluoroscopicAngiogramWContrastIV = (
        DocumentTypeValueSetCode("65802-1")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SagittalSinusVein_RightFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode(
        "65804-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SagittalSinusAndJugularVeins_RightFluoroscopicAngiogramWContrastIV = (
        DocumentTypeValueSetCode("65805-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SagittalSinusAndJugularVeinsFluoroscopicAngiogramWContrastIV = (
        DocumentTypeValueSetCode("30826-2")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SinusVeinFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode("37969-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SplenicVeinFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode("37970-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SubclavianVeinFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode("37971-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SuperiorMesentericVeinFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode(
        "37972-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityVeinsFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode(
        "24550-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityVeins_BilateralFluoroscopicAngiogramWContrastIV = (
        DocumentTypeValueSetCode("37415-7")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityVeins_LeftFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode(
        "38859-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UpperExtremityVeins_RightFluoroscopicAngiogramWContrastIV = (
        DocumentTypeValueSetCode("37824-0")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VeinFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode("25023-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Vein_BilateralFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode("26064-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Vein_LeftFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode("26065-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Vein_RightFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode("26066-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VenaCavaFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode("25025-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InferiorVenaCavaFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode(
        "30845-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SuperiorVenaCavaFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode(
        "30645-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Vessels_LeftFluoroscopicAngiogramWContrastIV = DocumentTypeValueSetCode("43554-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HepaticVeinsFluoroscopicAngiogramWContrastIVAndWHemodynamics = (
        DocumentTypeValueSetCode("39096-3")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RenalVeinFluoroscopicAngiogramWContrastIVAndWReninSampling = (
        DocumentTypeValueSetCode("43783-0")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RenalVein_BilateralFluoroscopicAngiogramWContrastIVAndWReninSampling = (
        DocumentTypeValueSetCode("25080-3")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PeritoneumFluoroscopicAngiogramWContrastPercutaneous = DocumentTypeValueSetCode(
        "30816-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BiliaryDuctsAndGallbladderFluoroscopyWContrastPercutaneousTranshepatic = (
        DocumentTypeValueSetCode("24575-3")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayWContrastPO = DocumentTypeValueSetCode("37200-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestFluoroscopyWContrastPO = DocumentTypeValueSetCode("37199-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    EsophagusX_rayWContrastPO = DocumentTypeValueSetCode("37198-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    EsophagusFluoroscopyWContrastPO = DocumentTypeValueSetCode("24678-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GallbladderX_rayWContrastPO = DocumentTypeValueSetCode("24712-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GastrointestineUpperFluoroscopyWContrastPO = DocumentTypeValueSetCode("42459-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SmallBowelFluoroscopyWContrastPO = DocumentTypeValueSetCode("24924-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    DuodenumFluoroscopyWContrastPOAndHypotonicAgentPerNg = DocumentTypeValueSetCode(
        "24673-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    EsophagusAndHypopharynxFluoroscopyVideoWContrastPODuringSwallowing = (
        DocumentTypeValueSetCode("24681-9")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ColonFluoroscopyWContrastPR = DocumentTypeValueSetCode("24667-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RectumAndUrinaryBladderFluoroscopyWContrastPRAndIntraBladderDuringDefecationAndVoiding = DocumentTypeValueSetCode(
        "24894-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FistulaFluoroscopyWContrastRetrograde = DocumentTypeValueSetCode("39363-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KidneyX_rayWContrastRetrograde = DocumentTypeValueSetCode("38105-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_BilateralFluoroscopyWContrastRetrograde = DocumentTypeValueSetCode("39349-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_BilateralFluoroscopyWContrastRetrogradeViaUrethra = DocumentTypeValueSetCode(
        "30761-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_LeftAndCollectingSystemFluoroscopyWContrastRetrogradeViaUrethra = (
        DocumentTypeValueSetCode("38873-6")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_RightAndCollectingSystemFluoroscopyWContrastRetrogradeViaUrethra = (
        DocumentTypeValueSetCode("38113-7")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UrinaryBladderAndUrethraFluoroscopyWContrastRetrogradeViaUrethra = (
        DocumentTypeValueSetCode("25020-9")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PortalVeinFluoroscopicAngiogramWContrastTranshepatic = DocumentTypeValueSetCode(
        "30841-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PortalVeinFluoroscopicAngiogramWContrastTranshepaticAndWHemodynamics = (
        DocumentTypeValueSetCode("30842-9")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionFluoroscopyWContrastViaCatheter = DocumentTypeValueSetCode(
        "37566-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ColonFluoroscopyWContrastViaColostomy = DocumentTypeValueSetCode("37567-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionFluoroscopyWContrastViaFistula = DocumentTypeValueSetCode(
        "37568-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SmallBowelFluoroscopyWContrastViaIleostomy = DocumentTypeValueSetCode("69272-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_BilateralFluoroscopyWContrastViaNephrostomyTube = DocumentTypeValueSetCode(
        "24780-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_LeftAndCollectingSystemFluoroscopyWContrastViaNephrostomyTube = (
        DocumentTypeValueSetCode("38872-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_RightAndCollectingSystemFluoroscopyWContrastViaNephrostomyTube = (
        DocumentTypeValueSetCode("38112-9")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UrinaryBladderFluoroscopyWContrastViaSuprapubicTube = DocumentTypeValueSetCode(
        "37569-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BiliaryDuctsAndGallbladderFluoroscopyWContrastViaT_tube = DocumentTypeValueSetCode(
        "30647-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LungScanWDepreotideAndWRadionuclideIV = DocumentTypeValueSetCode("39696-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanWDobutamineAndWRadionuclideIV = DocumentTypeValueSetCode("42161-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanWDobutamineAndWTl_201IV = DocumentTypeValueSetCode("39652-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GallbladderX_rayWDoubleDoseContrastPO = DocumentTypeValueSetCode("42383-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineX_rayWFlexionAndWExtension = DocumentTypeValueSetCode("42690-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineCervicalX_rayWFlexionAndWExtension = DocumentTypeValueSetCode("24945-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_rayWFlexionAndWExtension = DocumentTypeValueSetCode("24971-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    JointX_rayWFlexionAndWExtension = DocumentTypeValueSetCode("43481-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FootX_rayWForcedDorsiflexion = DocumentTypeValueSetCode("30785-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_BilateralScanWFurosemideAndWRadionuclideIV = DocumentTypeValueSetCode(
        "43461-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScanWGA_67IV = DocumentTypeValueSetCode("39688-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    EsophagusFluoroscopyWGastrografinPO = DocumentTypeValueSetCode("24679-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GastrointestineUpperFluoroscopyWGastrografinPO = DocumentTypeValueSetCode("42684-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ColonFluoroscopyWGastrografinPR = DocumentTypeValueSetCode("42681-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionFluoroscopyWGastrografinViaFistula = DocumentTypeValueSetCode(
        "37576-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_BilateralScanWI_131IV = DocumentTypeValueSetCode("39850-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThyroidScanWI_131IV = DocumentTypeValueSetCode("25007-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScanWI_131MIBGIV = DocumentTypeValueSetCode("39841-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AdrenalGlandScanWI_131MIBGIV = DocumentTypeValueSetCode("39857-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AdrenalGlandScanWI_131NP59IV = DocumentTypeValueSetCode("39624-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    JointScanWIn_111Intrajoint = DocumentTypeValueSetCode("24770-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScanWIn_111SatumomabIV = DocumentTypeValueSetCode("39846-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AbdomenScanWIn_111SatumomabIV = DocumentTypeValueSetCode("39738-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BoneScanWIn_111TaggedWBCIV = DocumentTypeValueSetCode("25032-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScanWIn_111TiuxetanIV = DocumentTypeValueSetCode("42708-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayWInspirationAndExpiration = DocumentTypeValueSetCode("30736-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    EsophagusAndHypopharynxFluoroscopyVideoWLiquidAndPasteContrastPODuringSwallowing = (
        DocumentTypeValueSetCode("24682-7")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AnkleX_rayWManualStress = DocumentTypeValueSetCode("37556-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_BilateralX_rayWManualStress = DocumentTypeValueSetCode("37557-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_LeftX_rayWManualStress = DocumentTypeValueSetCode("37558-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Ankle_RightX_rayWManualStress = DocumentTypeValueSetCode("37673-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_LeftX_rayWManualStress = DocumentTypeValueSetCode("37559-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Foot_RightX_rayWManualStress = DocumentTypeValueSetCode("37705-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeX_rayWManualStress = DocumentTypeValueSetCode("37560-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralX_rayWManualStress = DocumentTypeValueSetCode("37561-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftX_rayWManualStress = DocumentTypeValueSetCode("37562-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightX_rayWManualStress = DocumentTypeValueSetCode("37753-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Thumb_BilateralX_rayWManualStress = DocumentTypeValueSetCode("37563-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Thumb_LeftX_rayWManualStress = DocumentTypeValueSetCode("37564-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Thumb_RightX_rayWManualStress = DocumentTypeValueSetCode("37814-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionX_rayWManualStress = DocumentTypeValueSetCode("39056-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ChestX_rayWNippleMarkers = DocumentTypeValueSetCode("38093-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LacrimalDuctScanWRadionuclideIntraLacrimalDuct = DocumentTypeValueSetCode("39670-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastLymphatics_LeftScanWRadionuclideIntraLymphatic = DocumentTypeValueSetCode(
        "64051-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastLymphatics_RightScanWRadionuclideIntraLymphatic = DocumentTypeValueSetCode(
        "64052-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LymphaticsScanWRadionuclideIntraLymphatic = DocumentTypeValueSetCode("24826-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeadCisternScanWRadionuclideIT = DocumentTypeValueSetCode("24663-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AdrenalGlandScan = DocumentTypeValueSetCode("42158-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AVShuntScan = DocumentTypeValueSetCode("42776-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BoneScan = DocumentTypeValueSetCode("25031-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainScan = DocumentTypeValueSetCode("24730-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainVeinsScan = DocumentTypeValueSetCode("39643-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastScan = DocumentTypeValueSetCode("39646-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScan = DocumentTypeValueSetCode("39650-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_BilateralScan = DocumentTypeValueSetCode("24776-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_BilateralAndRenalVesselsScan = DocumentTypeValueSetCode("30877-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    KneeScan = DocumentTypeValueSetCode("24804-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_BilateralScan = DocumentTypeValueSetCode("26088-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_LeftScan = DocumentTypeValueSetCode("26089-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Knee_RightScan = DocumentTypeValueSetCode("26090-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LiverScan = DocumentTypeValueSetCode("39693-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LiverTransplantScan = DocumentTypeValueSetCode("39694-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LiverAndBiliaryDuctsAndGallbladderScan = DocumentTypeValueSetCode("43557-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LiverAndLungScan = DocumentTypeValueSetCode("39897-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LiverAndSpleenScan = DocumentTypeValueSetCode("39877-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MeckelsDiverticulumScan = DocumentTypeValueSetCode("39629-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    NeckScan = DocumentTypeValueSetCode("39737-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PancreasScan = DocumentTypeValueSetCode("39739-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ParathyroidScan = DocumentTypeValueSetCode("39742-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PulmonarySystemScan = DocumentTypeValueSetCode("39619-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RenalVesselsScan = DocumentTypeValueSetCode("43669-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SalivaryGlandScan = DocumentTypeValueSetCode("39747-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScrotumAndTesticleScan = DocumentTypeValueSetCode("30696-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpleenScan = DocumentTypeValueSetCode("39751-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThyroidScan = DocumentTypeValueSetCode("30695-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UrinaryBladderScan = DocumentTypeValueSetCode("25018-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Vein_BilateralScan = DocumentTypeValueSetCode("39626-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    UnspecifiedBodyRegionScan = DocumentTypeValueSetCode("49118-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    JointScan = DocumentTypeValueSetCode("39939-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RectumScanWRadionuclidePO = DocumentTypeValueSetCode("39671-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpleenScanWRadionuclideTaggedHeatDamagedRBCIV = DocumentTypeValueSetCode("39752-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_BilateralScanWRadionuclideTransplantScan = DocumentTypeValueSetCode(
        "24773-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineX_rayWRightBendingAndWLeftBending = DocumentTypeValueSetCode("30713-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SpineLumbarX_rayWRightBendingAndWLeftBending = DocumentTypeValueSetCode("42413-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LiverAndBiliaryDuctsAndGallbladderScanWSincalideAndWRadionuclideIV = (
        DocumentTypeValueSetCode("43651-9")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BoneScanWSM153IV = DocumentTypeValueSetCode("39820-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanWStressAndW201ThIV = DocumentTypeValueSetCode("39666-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanWStressAndWRadionuclideIV = DocumentTypeValueSetCode("39667-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanWStressAndWTc_99mIV = DocumentTypeValueSetCode("69231-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanWStressAndWTc_99mSestamibiIV = DocumentTypeValueSetCode("69232-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LiverAndSpleenScanWTc_99mCalciumColloidIV = DocumentTypeValueSetCode("24819-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ProstateScanWTc_99mCapromabPendatideIV = DocumentTypeValueSetCode("39744-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GallbladderScanWTc_99mDISIDAIV = DocumentTypeValueSetCode("39674-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_BilateralScanWTc_99mDMSAIV = DocumentTypeValueSetCode("41771-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ArteryScanWTc_99mDTPAIA = DocumentTypeValueSetCode("39625-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_BilateralScanWTc_99mDTPAIV = DocumentTypeValueSetCode("39745-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_BilateralAndRenalVesselsScanWTc_99mDTPAIV = DocumentTypeValueSetCode(
        "43667-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScrotumAndTesticleScanWTc_99mDTPAIV = DocumentTypeValueSetCode("39753-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VeinScanWTc_99mDTPAIV = DocumentTypeValueSetCode("39765-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainScanWTc_99mGlucoheptonateIV = DocumentTypeValueSetCode("39642-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_BilateralScanWTc_99mGlucoheptonateIV = DocumentTypeValueSetCode("44234-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VeinScanWTc_99mHDPIV = DocumentTypeValueSetCode("39766-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BoneScanWTc_99mHMPAOIV = DocumentTypeValueSetCode("39812-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainScanWTc_99mHMPAOIV = DocumentTypeValueSetCode("39630-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThyroidScanWTc_99mIV = DocumentTypeValueSetCode("39757-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MeckelsDiverticulumScanWTc_99mM04IV = DocumentTypeValueSetCode("24831-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LiverAndSpleenScanWTc_99mMAAIV = DocumentTypeValueSetCode("44141-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BoneScanWTc_99mMedronateIV = DocumentTypeValueSetCode("44142-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Kidney_BilateralScanWTc_99mMertiatideIV = DocumentTypeValueSetCode("39746-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ParotidGlandScanWTc_99mPertechnetateIV = DocumentTypeValueSetCode("69233-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScrotumAndTesticleScanWTc_99mPertechnetateIV = DocumentTypeValueSetCode("25001-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScrotumAndTesticle_BilateralScanWTc_99mPertechnetateIV = DocumentTypeValueSetCode(
        "26091-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScrotumAndTesticle_LeftScanWTc_99mPertechnetateIV = DocumentTypeValueSetCode(
        "26092-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ScrotumAndTesticle_RightScanWTc_99mPertechnetateIV = DocumentTypeValueSetCode(
        "26093-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BoneMarrowScanWTc_99mSCIV = DocumentTypeValueSetCode("44146-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GastrointestineScanWTc_99mSCIV = DocumentTypeValueSetCode("39689-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LiverScanWTc_99mSCIV = DocumentTypeValueSetCode("69230-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VeinScanWTc_99mSCIV = DocumentTypeValueSetCode("39764-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    EsophagusAndStomachScanWTc_99mSCPO = DocumentTypeValueSetCode("24683-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ParathyroidScanWTc_99mSestamibiIV = DocumentTypeValueSetCode("44145-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ThyroidScanWTc_99mSestamibiIV = DocumentTypeValueSetCode("39756-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GastrointestineScanWTc_99mTaggedRBCIV = DocumentTypeValueSetCode("24714-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HeartScanWTc_99mTaggedRBCIV = DocumentTypeValueSetCode("44143-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LiverScanWTc_99mTaggedRBCIV = DocumentTypeValueSetCode("39690-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BoneScanWTc_99mTaggedWBCIV = DocumentTypeValueSetCode("42700-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ParathyroidScanWTI_201SubtractionTc_99mIV = DocumentTypeValueSetCode("24751-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BrainScanWTl_201IV = DocumentTypeValueSetCode("39635-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    BreastScanWTl_201IV = DocumentTypeValueSetCode("51389-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GastrointestineUpperFluoroscopyWWaterSolubleContrastPO = DocumentTypeValueSetCode(
        "42012-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ColonFluoroscopyWWaterSolubleContrastPR = DocumentTypeValueSetCode("24669-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AcromioclavicularJointX_rayWWeight = DocumentTypeValueSetCode("37577-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AcromioclavicularJoint_BilateralX_rayWWeight = DocumentTypeValueSetCode("37578-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LiverScanWXe_133Inhaled = DocumentTypeValueSetCode("44144-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AcromioclavicularJointX_rayWOWeight = DocumentTypeValueSetCode("37582-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AcromioclavicularJoint_BilateralX_rayWOWeight = DocumentTypeValueSetCode("69055-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VisionAttachment = DocumentTypeValueSetCode("52073-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VisualAcuityStudy = DocumentTypeValueSetCode("28631-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FetalDocumentVitalSignsMeasurements = DocumentTypeValueSetCode("46242-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    WorkersCompensation = DocumentTypeValueSetCode("52070-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    IndividualCounselingNote = DocumentTypeValueSetCode("74282-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertPMI_StopTakingAndCallYourDoctorSection = DocumentTypeValueSetCode(
        "71683-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertPMI_TellYourDoctorBeforeTakingSection = DocumentTypeValueSetCode(
        "71685-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertAbuseSection = DocumentTypeValueSetCode("34086-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertAccessories = DocumentTypeValueSetCode("60555-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertAdverseReactionsSection = DocumentTypeValueSetCode("34084-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertAlarms = DocumentTypeValueSetCode("69761-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AncillaryEyeTestsNarrative = DocumentTypeValueSetCode("70946-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertAnimalPharmacology_toxicologySection = DocumentTypeValueSetCode(
        "34091-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    AnnotationCommentNarrative = DocumentTypeValueSetCode("48767-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertAssemblyOrInstallationInstructions = DocumentTypeValueSetCode(
        "60556-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClinicalTrialProtocolAssessmentOfSafetySection = DocumentTypeValueSetCode("35519-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClinicalTrialProtocolAssessmentSection = DocumentTypeValueSetCode("35517-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClinicalTrialProtocolBackgroundInformationSection = DocumentTypeValueSetCode(
        "35511-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertBoxedWarningSection = DocumentTypeValueSetCode("34066-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertCalibrationInstructions = DocumentTypeValueSetCode("60557-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    CancerDiagnosisNarrative = DocumentTypeValueSetCode("72135-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertCarcinogenesisAndMutagenesisAndImpairmentOfFertilitySection = (
        DocumentTypeValueSetCode("34083-6")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAProductLabelCellularTherapy = DocumentTypeValueSetCode("60684-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertCleaning_Disinfecting_AndSterilizationInstructions = (
        DocumentTypeValueSetCode("60558-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertClinicalPharmacologySection = DocumentTypeValueSetCode("34090-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertClinicalStudiesSection = DocumentTypeValueSetCode("34092-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClinicalTrialProtocolClinicalTrialProtocol = DocumentTypeValueSetCode("35528-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertCompatibleAccessories = DocumentTypeValueSetCode("69760-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertComponents = DocumentTypeValueSetCode("60559-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ConfrontationVisualFieldNarrative = DocumentTypeValueSetCode("70940-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertContraindicationsSection = DocumentTypeValueSetCode("34070-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertControlledSubstanceSection = DocumentTypeValueSetCode("34085-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Co_paymentAmountNarrative = DocumentTypeValueSetCode("57826-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    DataCriteriaNarrative = DocumentTypeValueSetCode("57025-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClinicalTrialProtocolDataHandlingAndRecordKeepingSection = DocumentTypeValueSetCode(
        "35524-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertDependenceSection = DocumentTypeValueSetCode("34087-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertDescriptionSection = DocumentTypeValueSetCode("34089-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertDiagramOfDevice = DocumentTypeValueSetCode("69758-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClinicalTrialProtocolDirectAccessToSourceData_documentsSection = (
        DocumentTypeValueSetCode("35521-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertDisposalAndWasteHandling = DocumentTypeValueSetCode("69763-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertDosageAndAdministrationSection = DocumentTypeValueSetCode("34068-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertDosageFormsAndStrengthsSection = DocumentTypeValueSetCode("43678-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertDrug_laboratoryTestInteractionsSection = DocumentTypeValueSetCode(
        "34074-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertDrugAbuseAndDependenceSection = DocumentTypeValueSetCode("42227-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertDrugInteractionsSection = DocumentTypeValueSetCode("34073-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClinicalTrialProtocolEfficacyAssessmentSection = DocumentTypeValueSetCode("35518-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClinicalTrialProtocolEthicsSection = DocumentTypeValueSetCode("35523-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ExpectedOutcomesNarrative = DocumentTypeValueSetCode("61147-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    EyeAnteriorSegmentNarrative = DocumentTypeValueSetCode("70943-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    EyeExternalNarrative = DocumentTypeValueSetCode("70941-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    EyePosteriorSegmentNarrative = DocumentTypeValueSetCode("70944-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClinicalTrialProtocolFinancingAndInsuranceSection = DocumentTypeValueSetCode(
        "35525-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClinicalTrialProtocolGeneralInformationSection = DocumentTypeValueSetCode("35510-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertGeneralPrecautionsSection = DocumentTypeValueSetCode("34072-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAProductLabelGenericDrugFacilityIdentificationSubmission = (
        DocumentTypeValueSetCode("71743-9")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertGeriatricUseSection = DocumentTypeValueSetCode("34082-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    GoalsNarrative = DocumentTypeValueSetCode("61146-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertHealthCareProviderLetter = DocumentTypeValueSetCode("71744-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAProductLabelHealthClaimSection = DocumentTypeValueSetCode("69719-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    HealthQualityMeasureSupplementalDataNarrative = DocumentTypeValueSetCode("69670-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertHowSuppliedSection = DocumentTypeValueSetCode("34069-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAProductLabelIdentificationOfCBER_regulatedGenericDrugFacility = (
        DocumentTypeValueSetCode("72090-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertIndexing_AdverseReaction = DocumentTypeValueSetCode("64123-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertIndexing_BillingUnit = DocumentTypeValueSetCode("71446-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertIndexing_PharmacologicClass = DocumentTypeValueSetCode("60685-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertIndexing_ProductConcept = DocumentTypeValueSetCode("73815-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertIndexing_Substance = DocumentTypeValueSetCode("64124-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertIndicationsAndUsageSection = DocumentTypeValueSetCode("34067-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertInformationForPatientsSection = DocumentTypeValueSetCode("34076-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Instructions_Text_Narrative = DocumentTypeValueSetCode("69730-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertInstructionsForUseSection = DocumentTypeValueSetCode("59845-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertIntendedUseOfTheDevice = DocumentTypeValueSetCode("60560-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InterventionsNarrative = DocumentTypeValueSetCode("62387-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertLaborAndDeliverySection = DocumentTypeValueSetCode("34079-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertLaboratoryTestsSection = DocumentTypeValueSetCode("34075-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LacrimalNarrative = DocumentTypeValueSetCode("70945-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    LensometryMeasurementsNarrative = DocumentTypeValueSetCode("70939-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertLotDistributionData = DocumentTypeValueSetCode("66105-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MeasureDescriptionNarrative = DocumentTypeValueSetCode("74045-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    MeasureObservationsNarrative = DocumentTypeValueSetCode("57027-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertMechanismOfActionSection = DocumentTypeValueSetCode("43679-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertMicrobiologySection = DocumentTypeValueSetCode("49489-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertNonclinicalToxicologySection = DocumentTypeValueSetCode("43680-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertNonteratogenicEffectsSection = DocumentTypeValueSetCode("34078-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertNursingMothersSection = DocumentTypeValueSetCode("34080-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ObjectiveNarrative = DocumentTypeValueSetCode("61149-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OcularAlignmentAndMotilityNarrative = DocumentTypeValueSetCode("70942-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OcularHistoryNarrative = DocumentTypeValueSetCode("70934-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OcularPhysicalExamNarrative = DocumentTypeValueSetCode("70948-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    OphthalmicMedicationsNarrative = DocumentTypeValueSetCode("70935-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertOtherSafetyInformation = DocumentTypeValueSetCode("60561-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertOverdosageSection = DocumentTypeValueSetCode("34088-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAProductLabelBackPanelOfPackage = DocumentTypeValueSetCode("51941-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAProductLabelBottomPanelOfPackage = DocumentTypeValueSetCode("51947-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAProductLabelFlapPanelOfPackage = DocumentTypeValueSetCode("51948-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAProductLabelPrincipalDisplayPanelOfPackage = DocumentTypeValueSetCode("51945-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAProductLabelSidePanelOfPackage = DocumentTypeValueSetCode("51944-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAProductLabelSidePanelOfPackageLeft = DocumentTypeValueSetCode("51943-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAProductLabelSidePanelOfPackageRight = DocumentTypeValueSetCode("51942-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAProductLabelTopPanelOfPackage = DocumentTypeValueSetCode("51946-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertPediatricUseSection = DocumentTypeValueSetCode("34081-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertPharmacodynamicsSection = DocumentTypeValueSetCode("43681-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertPharmacogenomicsSection = DocumentTypeValueSetCode("66106-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertPharmacokineticsSection = DocumentTypeValueSetCode("43682-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PlannedProcedureNarrative = DocumentTypeValueSetCode("59772-4")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAProductLabelPlasmaDerivative = DocumentTypeValueSetCode("60683-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertPMI_CommonSideEffectsSection = DocumentTypeValueSetCode("71681-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertPMI_DirectionsForUseSection = DocumentTypeValueSetCode("71684-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertPMI_DoNotTakeSection = DocumentTypeValueSetCode("71686-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertPMI_GetEmergencyMedicalHelpSection = DocumentTypeValueSetCode(
        "71682-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertPMI_ImportantInformationSection = DocumentTypeValueSetCode(
        "71687-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertPMI_UsesSection = DocumentTypeValueSetCode("71688-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PopulationCriteriaNarrative = DocumentTypeValueSetCode("57026-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PopulationStratificationDescriptionNarrative = DocumentTypeValueSetCode("69669-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PostprocedureDiagnosisNarrative = DocumentTypeValueSetCode("59769-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertPrecautionsSection = DocumentTypeValueSetCode("42232-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertPregnancySection = DocumentTypeValueSetCode("42228-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PregnancyVisitSummaryNoteNarrative = DocumentTypeValueSetCode("57059-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ProcedureAnesthesiaNarrative = DocumentTypeValueSetCode("59774-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ProcedureDispositionNarrative = DocumentTypeValueSetCode("59775-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ProcedureEstimatedBloodLossNarrative = DocumentTypeValueSetCode("59770-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ProcedureFindingsNarrative = DocumentTypeValueSetCode("59776-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ProcedureImplantsNarrative = DocumentTypeValueSetCode("59771-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ProcedureIndicationsNarrative = DocumentTypeValueSetCode("59768-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ProcedureSpecimensTakenNarrative = DocumentTypeValueSetCode("59773-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClinicalTrialProtocolPublicationPolicySection = DocumentTypeValueSetCode("35526-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClinicalTrialProtocolQualityControlAndQualityAssuranceSection = (
        DocumentTypeValueSetCode("35522-2")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ReasonForCo_paymentExemptionNarrative = DocumentTypeValueSetCode("57827-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertRecentMajorChangesSection = DocumentTypeValueSetCode("43683-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertReferencesSection = DocumentTypeValueSetCode("34093-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    RefractiveMeasurementsNarrative = DocumentTypeValueSetCode("70938-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertRisks = DocumentTypeValueSetCode("69759-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertStructuredProductLabellingIndexingDataElementsSection = (
        DocumentTypeValueSetCode("48779-3")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertStructuredProductLabellingListingDataElementsSection = (
        DocumentTypeValueSetCode("48780-1")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertStructuredProductLabellingMedguideSection = (
        DocumentTypeValueSetCode("42231-1")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertStructuredProductLaballingPatientPackageInsertSection = (
        DocumentTypeValueSetCode("42230-3")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertStructuredProductLaballingSupplementalPatientMaterial = (
        DocumentTypeValueSetCode("38056-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertStructuredPatientLabellingUnclassifiedSection = (
        DocumentTypeValueSetCode("42229-5")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAProductLabelStatementOfIdentitySection = DocumentTypeValueSetCode("69718-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClinicalTrialProtocolStatisticsSection = DocumentTypeValueSetCode("35520-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertStorageAndHandlingSection = DocumentTypeValueSetCode("44425-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClinicalTrialProtocolSubjectParticipation_EpochsSection = DocumentTypeValueSetCode(
        "35515-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClinicalTrialProtocolSubjectSelectionAndWithdrawalSection = (
        DocumentTypeValueSetCode("35514-9")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SubjectiveNarrative = DocumentTypeValueSetCode("61150-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClinicalTrialProtocolSupplementsSection = DocumentTypeValueSetCode("35527-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SurgicalOperationNoteImplantsNarrative = DocumentTypeValueSetCode("55122-6")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertTeratogenicEffectsSection = DocumentTypeValueSetCode("34077-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClinicalTrialProtocolTreatmentOfSubjects_EpochsSection = DocumentTypeValueSetCode(
        "35516-4"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClinicalTrialProtocolTrialDesignSection = DocumentTypeValueSetCode("35513-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClinicalTrialProtocolTrialName = DocumentTypeValueSetCode("42796-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClinicalTrialProtocolTrialObjectivesAndPurposeSection = DocumentTypeValueSetCode(
        "35512-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertTroubleshooting = DocumentTypeValueSetCode("69762-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertUseInSpecificPopulationsSection = DocumentTypeValueSetCode(
        "43684-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertUserSafetyWarningsSection = DocumentTypeValueSetCode("54433-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    VisionTestingNarrative = DocumentTypeValueSetCode("70936-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertWarningsAndPrecautionsSection = DocumentTypeValueSetCode("43685-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    FDAPackageInsertWarningsSection = DocumentTypeValueSetCode("34071-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClinicalDocumentKindOfDocumentFromLOINCDocumentOntology = DocumentTypeValueSetCode(
        "74477-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClinicalDocumentRoleFromLOINCDocumentOntology = DocumentTypeValueSetCode("74479-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClinicalDocumentSettingFromLOINCDocumentOntology = DocumentTypeValueSetCode(
        "74476-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClinicalDocumentSubjectMatterDomainFromLOINCDocumentOntology = (
        DocumentTypeValueSetCode("74480-5")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ClinicalDocumentTypeOfServiceFromLOINCDocumentOntology = DocumentTypeValueSetCode(
        "74478-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ContributingFactorCommunication_DocumentationMERSTH = DocumentTypeValueSetCode(
        "42566-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SourceOfDocumentUsedToAbstractCancer = DocumentTypeValueSetCode("21862-8")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    DocumentType = DocumentTypeValueSetCode("69764-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    InformationSource = DocumentTypeValueSetCode("48766-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PathologyReport_sectionHeading = DocumentTypeValueSetCode("70949-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ReportTemplateID = DocumentTypeValueSetCode("60572-5")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ReportTemplateSource = DocumentTypeValueSetCode("60573-3")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ReportTemplateVersionID = DocumentTypeValueSetCode("60574-1")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Report_sectionHeadingUnspecifiedBodyRegion = DocumentTypeValueSetCode("73983-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    _11_Deoxycorticosterone_Presence_InSerumOrPlasma = DocumentTypeValueSetCode(
        "40811-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PhotoDocumentationEye_Left = DocumentTypeValueSetCode("29112-0")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PhotoDocumentationEye_Right = DocumentTypeValueSetCode("29111-2")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PermissionToReleaseImmunizationDataFromSchoolRecord = DocumentTypeValueSetCode(
        "72169-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    SelfManagement = DocumentTypeValueSetCode("44943-9")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    _18_Hydroxydeoxycorticosterone_Mass_volume_InSerumOrPlasma = (
        DocumentTypeValueSetCode("11206-0")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    _18_Hydroxydeoxycorticosterone_Mass_time_In24HourUrine = DocumentTypeValueSetCode(
        "26988-6"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    _18_Hydroxydeoxycorticosterone_Moles_volume_InSerumOrPlasma = (
        DocumentTypeValueSetCode("50081-9")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    _18_Hydroxydeoxycorticosterone_Moles_volume_InSerumOrPlasma_1HourPostDoseCorticotropin = DocumentTypeValueSetCode(
        "57553-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    _18_Hydroxydeoxycorticosterone_Moles_volume_InSerumOrPlasma_30MinutesPostDoseCorticotropin = DocumentTypeValueSetCode(
        "57552-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    _18_Hydroxydeoxycorticosterone_Moles_volume_InSerumOrPlasma_preDoseCorticotropin = (
        DocumentTypeValueSetCode("57551-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    _11_Deoxycorticosterone_Mass_volume_InDriedBloodSpot = DocumentTypeValueSetCode(
        "53347-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    _11_Deoxycorticosterone_Mass_volume_InSerumOrPlasma = DocumentTypeValueSetCode(
        "1656-8"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    _11_Deoxycorticosterone_Mass_volume_InUrine = DocumentTypeValueSetCode("42855-7")
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    _11_Deoxycorticosterone_Mass_time_In24HourUrine = DocumentTypeValueSetCode(
        "16110-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    _11_Deoxycorticosterone_Moles_volume_In24HourUrine = DocumentTypeValueSetCode(
        "40818-7"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    _11_Deoxycorticosterone_Moles_volume_InDriedBloodSpot = DocumentTypeValueSetCode(
        "53348-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    _11_Deoxycorticosterone_Moles_volume_InSerumOrPlasma = DocumentTypeValueSetCode(
        "25561-2"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    _11_Deoxycorticosterone_Moles_time_In24HourUrine = DocumentTypeValueSetCode(
        "55808-0"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    _11_Deoxycorticosterone_Mass_volume_InSerumOrPlasma_1_5HoursPostXXXChallenge = (
        DocumentTypeValueSetCode("56611-7")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    _11_Deoxycorticosterone_Mass_volume_InSerumOrPlasma_15MinutesPostXXXChallenge = (
        DocumentTypeValueSetCode("56608-3")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    _11_Deoxycorticosterone_Moles_volume_InSerumOrPlasma_1HourPost250UgCorticotropin = (
        DocumentTypeValueSetCode("57493-9")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    _11_Deoxycorticosterone_Mass_volume_InSerumOrPlasma_1HourPostXXXChallenge = (
        DocumentTypeValueSetCode("40816-1")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    _11_Deoxycorticosterone_Mass_volume_InSerumOrPlasma_1stSpecimenPostXXXChallenge = (
        DocumentTypeValueSetCode("56602-6")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    _11_Deoxycorticosterone_Mass_volume_InSerumOrPlasma_2_5HoursPostXXXChallenge = (
        DocumentTypeValueSetCode("56613-3")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    _11_Deoxycorticosterone_Mass_volume_InSerumOrPlasma_20MinutesPostXXXChallenge = (
        DocumentTypeValueSetCode("56609-1")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    _11_Deoxycorticosterone_Mass_volume_InSerumOrPlasma_2HoursPostXXXChallenge = (
        DocumentTypeValueSetCode("56612-5")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    _11_Deoxycorticosterone_Mass_volume_InSerumOrPlasma_2ndSpecimenPostXXXChallenge = (
        DocumentTypeValueSetCode("56603-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    _11_Deoxycorticosterone_Moles_volume_InSerumOrPlasma_30MinutesPost250UgCorticotropin = DocumentTypeValueSetCode(
        "57492-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    _11_Deoxycorticosterone_Mass_volume_InSerumOrPlasma_30MinutesPostXXXChallenge = (
        DocumentTypeValueSetCode("56556-4")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    _11_Deoxycorticosterone_Mass_volume_InSerumOrPlasma_3rdSpecimenPostXXXChallenge = (
        DocumentTypeValueSetCode("56604-2")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    _11_Deoxycorticosterone_Mass_volume_InSerumOrPlasma_40MinutesPostXXXChallenge = (
        DocumentTypeValueSetCode("56610-9")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    _11_Deoxycorticosterone_Mass_volume_InSerumOrPlasma_4thSpecimenPostXXXChallenge = (
        DocumentTypeValueSetCode("56605-9")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    _11_Deoxycorticosterone_Mass_volume_InSerumOrPlasma_5thSpecimenPostXXXChallenge = (
        DocumentTypeValueSetCode("59987-8")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    _11_Deoxycorticosterone_Mass_volume_InSerumOrPlasma_6thSpecimenPostXXXChallenge = (
        DocumentTypeValueSetCode("59986-0")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    _11_Deoxycorticosterone_Mass_volume_InSerumOrPlasma_7thSpecimenPostXXXChallenge = (
        DocumentTypeValueSetCode("59985-2")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    _11_Deoxycorticosterone_Mass_volume_InSerumOrPlasma_8thSpecimenPostXXXChallenge = (
        DocumentTypeValueSetCode("59984-5")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    _11_Deoxycorticosterone_Mass_volume_InSerumOrPlasma_baseline = (
        DocumentTypeValueSetCode("56555-6")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    _11_Deoxycorticosterone_Mass_volume_InSerumOrPlasma_postXXXChallenge = (
        DocumentTypeValueSetCode("16294-1")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    _11_Deoxycorticosterone_Moles_volume_InSerumOrPlasma_pre250UgCorticotropin = (
        DocumentTypeValueSetCode("57491-3")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    _11_Deoxycorticosterone_Mass_volume_InSerumOrPlasma_preXXXChallenge = (
        DocumentTypeValueSetCode("56606-7")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    _18_Hydroxydeoxycortisol_Creatinine_MassRatio_InUrine = DocumentTypeValueSetCode(
        "13480-9"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    Progesterone_11_Deoxycorticosterone_MassRatio_InSerumOrPlasma = (
        DocumentTypeValueSetCode("44729-2")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    _21_Deoxycorticosterone_Moles_volume_InSerumOrPlasma = DocumentTypeValueSetCode(
        "69799-5"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    _21_Deoxycorticosterone_Moles_volume_InSerumOrPlasma_1HourPostDoseCorticotropin = (
        DocumentTypeValueSetCode("57562-1")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    _21_Deoxycorticosterone_Moles_volume_InSerumOrPlasma_30MinutesPostDoseCorticotropin = DocumentTypeValueSetCode(
        "57561-3"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    _21_Deoxycorticosterone_Moles_volume_InSerumOrPlasma_preDoseCorticotropin = (
        DocumentTypeValueSetCode("57560-5")
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    PerformanceRateReportingPeriodPopulationCalculated = DocumentTypeValueSetCode(
        "72510-1"
    )
    """
    From: http://hl7.org/fhir/ValueSet/c80-doc-typecodes in valuesets.xml
    """
    ReportingRateReportingPeriodPopulationCalculated = DocumentTypeValueSetCode(
        "72509-3"
    )
